(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
Signal Processing Packages:
:[font = title; inactive; ]
Implementing Linear Systems Theory in
:[font = special1; inactive; ]
MATHEMATICA
:[font = special4; inactive; center; ]

by
:[font = subtitle; inactive; ]

Brian L. Evans and James H. McClellan
:[font = text; inactive; ]

	We have developed a set of extensions to Mathematica to help you in learning signals and systems.  These extensions come in the form of new routines to compute linear transforms and convolutions and to plot signals and sequences.  Accompanying these extensions are a set of hands-on tutorials on various aspects on signals and systems.  These extensions are available on the network of Macintosh computers in the basement of the Georgia Tech Library.  The Mac lab is only open when the library is open:  
:[font = print; inactive; center; ]
Mon-Thu   8:00 AM - 12:00 AM
Fri       8:00 AM -  6:00 PM
Sat       9:00 AM -  6:00 PM
Sun      12:00 PM - 12:00 AM
:[font = text; inactive; ]
You can copy and freely distribute these extensions (but not Mathematica) .
:[font = smalltext; inactive; ]

:[font = special1; inactive; startGroup; ]
The Macintosh Cluster
:[font = text; inactive; ]
	Every machine in the Mac lab is assigned a number from 1 to 40.   In order to use these Macs, you will have to log in using your Georgia Tech account and password.  This information is available from the Office of Information Technology in the back of the Rich Building (room 104).
:[font = text; inactive; ]
	Once you have logged in to a Mac, you should see three icons in the upper right-hand corner of the screen:  ``Libmac NN'', "Library Cluster 1'', and ``gtXXXXv'', where NN is the number of the Mac that you are using and gtXXXXv is your Georgia Tech account.  ``Libmac NN'' is the local disk, ``Library Cluster 1'' is the file server, and ``gtXXXXv'' is actually not your hydra account but instead a local one.  To use the Macintoshes efficiently, you will want to download the software that you will be using from the file server to the local disk (much as you do when you use the Vectra lab).
:[font = text; inactive; ]
	Therefore, you will need to follow these steps to invoke Mathematica running the Signal Processing Packages:
:[font = special3; inactive; ]
(1) Check to see if Mathematica has already been downloaded
:[font = text; inactive; ]
        Open the ``Libmac NN'' folder by moving the mouse to the icon and
        hitting the mouse button twice.  You should see the Mathematica folder.
        If you do not, then you will need to download the Mathematica folder
        from the ``Library Cluster 1'' folder---  open the ``Library Cluster 1''
        folder, then click once on the Mathematica folder, and finally hold the
        mouse button down while dragging the selected folder to the
        ``Libmac NN'' folder.  The downloading process may take a minute.
:[font = special3; inactive; ]
(2) Make sure that Mathematica will allocate enough memory
:[font = text; inactive; ]
        Open the ``Mathematica'' folder which is inside the ``Libmac NN''
        folder.  The Mathematica program will appear as an icon that is a
        geometric figure labeled as Mathematica.  Next, click once on the
        icon, go to the File menu, and choose the ``Get Info'' option.  Move the
        mouse to the lower right-hand portion of the info window.  That number
        is the number of bytes of memory that Mathematica will allocate.  It
        needs to be at least 6000.  Close the info window.
:[font = special3; inactive; ]
(3) Tell Mathematica where to find the signal processing packages
:[font = text; inactive; ]
       Run Mathematica by double clicking on the Mathematica icon.  Once
       a new window appears, type in the following command (exactly)
:[font = network; inactive; ]
    $Path = Append[ $Path,
    "Library Cluster 1:EE:DSP Class:Version 2.74:Packages" ]
:[font = text; inactive; endGroup; ]
       and evaluate it by hitting the ENTER key (or SHIFT-RETURN).  Note
       that the RETURN key is only useful for formatting text.
:[font = special1; inactive; startGroup; ]
Mathematica
:[font = text; inactive; ]
	Mathematica is a program to perform (tedious) algebraic calculations.  The purpose of this section is to introduce you to Mathematica's syntax and familiarize you with its basic functions and operators. 
:[font = section; inactive; startGroup; ]
Mathematica's syntax
:[font = text; inactive; ]
	Mathematica's syntax is regular and consistent.  Built-in functions, symbols, and operators begin with a capital letter:
:[font = print; inactive; ]
    Cos[x]        cos(x)
    I             square root of -1
    D[2 x^2, x]   derivative of 2 x^2 w/r to x
:[font = text; inactive; ]
Parentheses are useful for grouping expressions together, but  square brackets are used for functions calls.   Other useful functions are:
:[font = print; inactive; ]
    Sin, Cos, Tan, Cot, Sec, Csc
    ArcSin, ArcCos, ArcTan, ArcCot, ...
    Exp, Log, Cosh, Sinh, Tanh, ...
    BesselI, BesselJ, BesselK, BesselY
:[font = text; inactive; ]
Useful symbols are:	
:[font = print; inactive; ]
    E             Euler's number, e = 2.718 ...
    Pi            Your favorite, 3.141592 ...
    Infinity      Positive infinity
:[font = text; inactive; ]
Any variables or symbols that you are using should begin with a lower case letter.  This means that a polynomial in x would be written as:
:[font = input; center; ]
a4 x^4 + a3 x^3 + a2 x^2 + a1 x + a0 
:[font = text; inactive; ]
The space between a4 and x^4 denotes multiplication.  The bold font is used by Mathematica to denote Mathematica input that can be evaluated.
:[font = text; inactive; ]
	Mathematica provides a rich set of operators.  The following operators are ``borrowed'' from the C programming language:
:[font = print; inactive; center; ]
+   -   *   /    addition, subtraction, ... 
+=  -=  *=  /=   accumulate, ...            
++  --  ^        increment, decrement, power
==  !=           logical equality tests     
&&  ||           logical and, logical or    
:[font = text; inactive; ]
For example, a loop that iterates on i from 1 to 100 and accumulates the value of i in the variable sum would be written in Mathematica as
:[font = input; ]
sum = 0;
For [ i = 1, i <= 100, i++, sum += i ];
sum
:[font = text; inactive; endGroup; ]
Here, the For[ ] loop contains four arguments separated by commas.  Semicolons are used to separate expressions. 
:[font = section; inactive; startGroup; ]
Simple Calculus with Mathematica
:[font = text; inactive; ]
	Mathematica can of course do simple calculus.  Integrating 3 x^2 with respect to x is carried out by (hit ENTER on the Mac to evaluate this)
:[font = input; startGroup; ]
Integrate[ 3 x^2, x ]
:[font = output; inactive; output; endGroup; ]
x^3
;[o]
 3
x
:[font = text; inactive; ]
To integrate x Log[x] over an interval, say 1 to 2, use
:[font = input; startGroup; ]
Integrate[ x Log[x], {x, 1, 2} ]
:[font = output; inactive; output; endGroup; ]
-3/4 + 2*Log[2]
;[o]
  3
-(-) + 2 Log[2]
  4
:[font = text; inactive; ]
First, notice how the definite limits were specified---  as a list.  The curly braces are short-hand notation for a list.  Second, notice that Log[2] was never given a value.  This is because Mathematica keeps expressions in EXACT form.  That is, there is no integer or rational number that exactly equals Log[2].  You, the user, can ask Mathematica to approximate an expression to a given number of digits (20 in the example below):
:[font = input; startGroup; ]
N[ %, 20 ]
:[font = output; inactive; output; endGroup; ]
0.6362943611198906188
;[o]
0.6362943611198906188
:[font = text; inactive; ]
Here, % means the output of the previous expression. 
:[font = text; inactive; ]
	Mathematica also takes partial derivatives.  Taking the derivative of
C x^2 Tan[x] with respect to x is carried out by
:[font = input; startGroup; pageBreak; ]
D[ C x^2 Tan[x], x ]
:[font = output; inactive; output; endGroup; ]
(C*x^2)/Cos[x]^2 + 2*C*x*Tan[x]
;[o]
    2
 C x
------- + 2 C x Tan[x]
      2
Cos[x]
:[font = text; inactive; ]
	Solve handles simultaneous equations, even non-linear ones, e.g.
:[font = input; ]
Solve[ {-a B + b + a - a^3 / 8 - a b^2 / 8 == G,
        -b B - a + b - b^3 / 8 - a^2 b / 8 == 0},
       {a, b} ]
:[font = text; inactive; endGroup; ]
We have two equations (specified by == not =) in two unknowns (a and b). We do not show the answer here because it would occupy 2 printed pages. 
:[font = section; inactive; startGroup; ]
Giving Values to Symbols
:[font = text; inactive; ]
	To replace symbols in an expression with values, use the /. operator:
:[font = input; ]
b Cos[a Pi] /. { a -> 1, b -> 2 }
:[font = text; inactive; ]
This gives -2.  Another way is to define your own function:
:[font = input; ]
myfun[a_, b_] := b Cos[a Pi]
:[font = text; inactive; endGroup; ]
Similarly,  myfun[1, 2] would give -2.  You could plot myfun in 3-D, etc.
:[font = section; inactive; startGroup; ]
Getting Help from the Kernel
:[font = text; inactive; ]
	The kernel offers a help function (abbreviated ?) which can give usage information on a particular Mathematica definition
:[font = input; startGroup; ]
?I
:[font = info; inactive; endGroup; ]
I represents the imaginary unit Sqrt[-1].
:[font = text; inactive; ]
or can match a collection of object names
:[font = input; startGroup; ]
?*Solve
:[font = info; inactive; endGroup; ]
DSolve      LinearSolve MainSolve   Solve
:[font = text; inactive; endGroup; ]
The "SignalProcessingIntroduction" Notebook (located in the folder "Library Cluster 1:EE:DSP Class:Version 2.74:Notebooks") gives an overview of Mathematica and the signal processing extensions.
:[font = section; inactive; startGroup; pageBreak; ]
Graphics and Plotting
:[font = text; inactive; ]
	Mathematica handles all of the details of plotting badly behaved functions
:[font = input; startGroup; ]
Plot[ Tan[x], {x, 0, 6 Pi} ]
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.05053 0.304 0.01364 [
[(2.5)] 0.15012 0.2915 0 1 Msboxa
[(5)] 0.27644 0.2915 0 1 Msboxa
[(7.5)] 0.40275 0.2915 0 1 Msboxa
[(10)] 0.52906 0.2915 0 1 Msboxa
[(12.5)] 0.65538 0.2915 0 1 Msboxa
[(15)] 0.78169 0.2915 0 1 Msboxa
[(17.5)] 0.908 0.2915 0 1 Msboxa
[(-20)] 0.01131 0.03126 1 0 Msboxa
[(-10)] 0.01131 0.16763 1 0 Msboxa
[(10)] 0.01131 0.44037 1 0 Msboxa
[(20)] 0.01131 0.57674 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.304 moveto
1 0.304 lineto
stroke
0.15012 0.29775 moveto
0.15012 0.31025 lineto
stroke
0 setgray
[(2.5)] 0.15012 0.2915 0 1 Mshowa
0.27644 0.29775 moveto
0.27644 0.31025 lineto
stroke
0 setgray
[(5)] 0.27644 0.2915 0 1 Mshowa
0.40275 0.29775 moveto
0.40275 0.31025 lineto
stroke
0 setgray
[(7.5)] 0.40275 0.2915 0 1 Mshowa
0.52906 0.29775 moveto
0.52906 0.31025 lineto
stroke
0 setgray
[(10)] 0.52906 0.2915 0 1 Mshowa
0.65538 0.29775 moveto
0.65538 0.31025 lineto
stroke
0 setgray
[(12.5)] 0.65538 0.2915 0 1 Mshowa
0.78169 0.29775 moveto
0.78169 0.31025 lineto
stroke
0 setgray
[(15)] 0.78169 0.2915 0 1 Mshowa
0.908 0.29775 moveto
0.908 0.31025 lineto
stroke
0 setgray
[(17.5)] 0.908 0.2915 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.03126 moveto
0.03006 0.03126 lineto
stroke
0 setgray
[(-20)] 0.01131 0.03126 1 0 Mshowa
0.01756 0.16763 moveto
0.03006 0.16763 lineto
stroke
0 setgray
[(-10)] 0.01131 0.16763 1 0 Mshowa
0.01756 0.44037 moveto
0.03006 0.44037 lineto
stroke
0 setgray
[(10)] 0.01131 0.44037 1 0 Mshowa
0.01756 0.57674 moveto
0.03006 0.57674 lineto
stroke
0 setgray
[(20)] 0.01131 0.57674 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.304 moveto
0.04365 0.30965 lineto
0.05357 0.31311 lineto
0.05853 0.31519 lineto
0.06349 0.31764 lineto
0.06845 0.32062 lineto
0.07341 0.32441 lineto
0.07837 0.32951 lineto
0.08085 0.33283 lineto
0.08333 0.33692 lineto
0.08581 0.34211 lineto
0.08829 0.34896 lineto
0.09077 0.35844 lineto
0.09201 0.36473 lineto
0.09325 0.37256 lineto
0.09449 0.38259 lineto
0.09573 0.39593 lineto
0.09697 0.41457 lineto
0.09821 0.44246 lineto
0.09945 0.48887 lineto
0.10069 0.58159 lineto
0.10193 0.85951 lineto
0.10317 2.227182e+14 lineto
0.10441 -0.25151 lineto
0.10565 0.02641 lineto
0.10689 0.11913 lineto
0.10813 0.16554 lineto
0.10938 0.19343 lineto
0.11062 0.21207 lineto
0.11186 0.22541 lineto
0.1131 0.23544 lineto
0.11434 0.24327 lineto
0.11558 0.24956 lineto
0.11806 0.25904 lineto
0.12054 0.26589 lineto
0.12302 0.27108 lineto
0.1255 0.27517 lineto
0.12798 0.27849 lineto
0.13294 0.28359 lineto
0.1379 0.28738 lineto
0.14286 0.29036 lineto
0.15278 0.29489 lineto
0.1627 0.29835 lineto
0.18254 0.304 lineto
0.20238 0.30965 lineto
0.2123 0.31311 lineto
0.21726 0.31519 lineto
0.22222 0.31764 lineto
0.22718 0.32062 lineto
0.23214 0.32441 lineto
Mistroke
0.23462 0.32675 lineto
0.2371 0.32951 lineto
0.23958 0.33283 lineto
0.24206 0.33692 lineto
0.24454 0.34211 lineto
0.24702 0.34896 lineto
0.2495 0.35844 lineto
0.25074 0.36473 lineto
0.25198 0.37256 lineto
0.25322 0.38259 lineto
0.25446 0.39593 lineto
0.2557 0.41457 lineto
0.25694 0.44246 lineto
0.25818 0.48887 lineto
0.25942 0.58159 lineto
0.26066 0.85951 lineto
0.2619 7.42394e+13 lineto
0.26314 -0.25151 lineto
0.26438 0.02641 lineto
0.26563 0.11913 lineto
0.26687 0.16554 lineto
0.26811 0.19343 lineto
0.26935 0.21207 lineto
0.27059 0.22541 lineto
0.27183 0.23544 lineto
0.27307 0.24327 lineto
0.27431 0.24956 lineto
0.27679 0.25904 lineto
0.27927 0.26589 lineto
0.28175 0.27108 lineto
0.28423 0.27517 lineto
0.28671 0.27849 lineto
0.29167 0.28359 lineto
0.29663 0.28738 lineto
0.30159 0.29036 lineto
0.31151 0.29489 lineto
0.32143 0.29835 lineto
0.34127 0.304 lineto
0.36111 0.30965 lineto
0.37103 0.31311 lineto
0.37599 0.31519 lineto
0.38095 0.31764 lineto
0.38591 0.32062 lineto
0.39087 0.32441 lineto
0.39335 0.32675 lineto
0.39583 0.32951 lineto
0.39831 0.33283 lineto
0.40079 0.33692 lineto
0.40327 0.34211 lineto
0.40575 0.34896 lineto
Mistroke
0.40823 0.35844 lineto
0.40947 0.36473 lineto
0.41071 0.37256 lineto
0.41195 0.38259 lineto
0.41319 0.39593 lineto
0.41443 0.41457 lineto
0.41567 0.44246 lineto
0.41691 0.48887 lineto
0.41815 0.58159 lineto
0.41939 0.85951 lineto
0.42063 4.454364e+13 lineto
0.42188 -0.25151 lineto
0.42312 0.02641 lineto
0.42436 0.11913 lineto
0.4256 0.16554 lineto
0.42684 0.19343 lineto
0.42808 0.21207 lineto
0.42932 0.22541 lineto
0.43056 0.23544 lineto
0.4318 0.24327 lineto
0.43304 0.24956 lineto
0.43552 0.25904 lineto
0.438 0.26589 lineto
0.44048 0.27108 lineto
0.44296 0.27517 lineto
0.44544 0.27849 lineto
0.4504 0.28359 lineto
0.45536 0.28738 lineto
0.46032 0.29036 lineto
0.47024 0.29489 lineto
0.48016 0.29835 lineto
0.5 0.304 lineto
0.51984 0.30965 lineto
0.52976 0.31311 lineto
0.53472 0.31519 lineto
0.53968 0.31764 lineto
0.54464 0.32062 lineto
0.5496 0.32441 lineto
0.55208 0.32675 lineto
0.55456 0.32951 lineto
0.55704 0.33283 lineto
0.55952 0.33692 lineto
0.562 0.34211 lineto
0.56448 0.34896 lineto
0.56572 0.35328 lineto
0.56696 0.35844 lineto
0.5682 0.36473 lineto
0.56944 0.37256 lineto
0.57068 0.38259 lineto
0.57192 0.39593 lineto
Mistroke
0.57316 0.41457 lineto
0.5744 0.44246 lineto
0.57564 0.48887 lineto
0.57688 0.58159 lineto
0.57813 0.85951 lineto
0.57937 3.181689e+13 lineto
0.58061 -0.25151 lineto
0.58185 0.02641 lineto
0.58309 0.11913 lineto
0.58433 0.16554 lineto
0.58557 0.19343 lineto
0.58681 0.21207 lineto
0.58805 0.22541 lineto
0.58929 0.23544 lineto
0.59053 0.24327 lineto
0.59177 0.24956 lineto
0.59425 0.25904 lineto
0.59673 0.26589 lineto
0.59921 0.27108 lineto
0.60169 0.27517 lineto
0.60417 0.27849 lineto
0.60913 0.28359 lineto
0.61409 0.28738 lineto
0.61905 0.29036 lineto
0.62897 0.29489 lineto
0.63889 0.29835 lineto
0.65873 0.304 lineto
0.67857 0.30965 lineto
0.68849 0.31311 lineto
0.69345 0.31519 lineto
0.69841 0.31764 lineto
0.70337 0.32062 lineto
0.70833 0.32441 lineto
0.71081 0.32675 lineto
0.71329 0.32951 lineto
0.71577 0.33283 lineto
0.71825 0.33692 lineto
0.72073 0.34211 lineto
0.72321 0.34896 lineto
0.72445 0.35328 lineto
0.72569 0.35844 lineto
0.72693 0.36473 lineto
0.72817 0.37256 lineto
0.72941 0.38259 lineto
0.73065 0.39593 lineto
0.73189 0.41457 lineto
0.73313 0.44246 lineto
0.73438 0.48887 lineto
0.73562 0.58159 lineto
0.73686 0.85951 lineto
Mistroke
0.7381 2.474647e+13 lineto
0.73934 -0.25151 lineto
0.74058 0.02641 lineto
0.74182 0.11913 lineto
0.74306 0.16554 lineto
0.7443 0.19343 lineto
0.74554 0.21207 lineto
0.74678 0.22541 lineto
0.74802 0.23544 lineto
0.74926 0.24327 lineto
0.7505 0.24956 lineto
0.75298 0.25904 lineto
0.75546 0.26589 lineto
0.75794 0.27108 lineto
0.76042 0.27517 lineto
0.7629 0.27849 lineto
0.76786 0.28359 lineto
0.77282 0.28738 lineto
0.77778 0.29036 lineto
0.7877 0.29489 lineto
0.79762 0.29835 lineto
0.81746 0.304 lineto
0.8373 0.30965 lineto
0.84722 0.31311 lineto
0.85218 0.31519 lineto
0.85714 0.31764 lineto
0.8621 0.32062 lineto
0.86706 0.32441 lineto
0.86954 0.32675 lineto
0.87202 0.32951 lineto
0.8745 0.33283 lineto
0.87698 0.33692 lineto
0.87946 0.34211 lineto
0.88194 0.34896 lineto
0.88318 0.35328 lineto
0.88442 0.35844 lineto
0.88566 0.36473 lineto
0.8869 0.37256 lineto
0.88814 0.38259 lineto
0.88938 0.39593 lineto
0.89063 0.41457 lineto
0.89187 0.44246 lineto
0.89311 0.48887 lineto
0.89435 0.58159 lineto
0.89559 0.85951 lineto
0.89683 5.566415e+12 lineto
0.89807 -0.25151 lineto
0.89931 0.02641 lineto
0.90055 0.11913 lineto
0.90179 0.16554 lineto
Mistroke
0.90303 0.19343 lineto
0.90427 0.21207 lineto
0.90551 0.22541 lineto
0.90675 0.23544 lineto
0.90923 0.24956 lineto
0.91047 0.25472 lineto
0.91171 0.25904 lineto
0.91419 0.26589 lineto
0.91667 0.27108 lineto
0.91915 0.27517 lineto
0.92163 0.27849 lineto
0.92659 0.28359 lineto
0.93155 0.28738 lineto
0.93651 0.29036 lineto
0.94643 0.29489 lineto
0.95635 0.29835 lineto
0.97619 0.304 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]
and can render two-dimensional functions as 3-D graphics (the space between x and y represents multiplication)
:[font = input; startGroup; ]
Plot3D[ Sin[x y], {x, 0, 3}, {y, 0, 3} ]
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; pictureLeft = 40; pictureWidth = 268; pictureHeight = 268; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(1)] 0.23549 0.24184 0.931731 1 Msboxa
[(2)] 0.42902 0.16572 0.792736 1 Msboxa
[(3)] 0.63943 0.08304 0.653742 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(1)] 0.75282 0.23534 -1 0.355817 Msboxa
[(2)] 0.83538 0.36178 -1 0.326047 Msboxa
[(3)] 0.90729 0.47191 -1 0.300874 Msboxa
[(-1)] 0.05378 0.32904 1 -0.390635 Msboxa
[(-0.5)] 0.04626 0.37616 1 -0.380695 Msboxa
[(0)] 0.03848 0.42493 1 -0.370371 Msboxa
[(0.5)] 0.03042 0.47544 1 -0.359642 Msboxa
[(1)] 0.02207 0.52777 1 -0.348483 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.23954 0.2462 moveto
0.24766 0.25491 lineto
stroke
0 setgray
[(1)] 0.23549 0.24184 0.931731 1 Mshowa
0.43272 0.17039 moveto
0.44012 0.17972 lineto
stroke
0 setgray
[(2)] 0.42902 0.16572 0.792736 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(3)] 0.63943 0.08304 0.653742 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.74721 0.23734 moveto
0.73599 0.24133 lineto
stroke
0 setgray
[(1)] 0.75282 0.23534 -1 0.355817 Mshowa
0.82972 0.36363 moveto
0.8184 0.36732 lineto
stroke
0 setgray
[(2)] 0.83538 0.36178 -1 0.326047 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(3)] 0.90729 0.47191 -1 0.300874 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05933 0.32687 moveto
0.07042 0.32254 lineto
stroke
0 setgray
[(-1)] 0.05378 0.32904 1 -0.390635 Mshowa
0.05183 0.37404 moveto
0.06295 0.36981 lineto
stroke
0 setgray
[(-0.5)] 0.04626 0.37616 1 -0.380695 Mshowa
0.04406 0.42286 moveto
0.05523 0.41873 lineto
stroke
0 setgray
[(0)] 0.03848 0.42493 1 -0.370371 Mshowa
0.03602 0.47342 moveto
0.04722 0.46939 lineto
stroke
0 setgray
[(0.5)] 0.03042 0.47544 1 -0.359642 Mshowa
0.02769 0.52581 moveto
0.03893 0.5219 lineto
stroke
0 setgray
[(1)] 0.02207 0.52777 1 -0.348483 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.49975 setgray
0.0015 setlinewidth
0.37007 0.70047 0.39027 0.7181 0.4226 0.76375 0.40243 0.74276 Metetra
0.71417 setgray
0.40243 0.74276 0.4226 0.76375 0.45688 0.78857 0.43676 0.76824 Metetra
0.85443 setgray
0.43676 0.76824 0.45688 0.78857 0.49252 0.77696 0.47266 0.76305 Metetra
0.87201 setgray
0.47266 0.76305 0.49252 0.77696 0.5283 0.72948 0.5091 0.72503 Metetra
0.76083 setgray
0.5091 0.72503 0.5283 0.72948 0.56336 0.6626 0.54511 0.66484 Metetra
0.55935 setgray
0.54511 0.66484 0.56336 0.6626 0.59773 0.59974 0.58037 0.60079 Metetra
0.33725 setgray
0.58037 0.60079 0.59773 0.59974 0.63244 0.56082 0.61543 0.551 Metetra
0.17136 setgray
0.61543 0.551 0.63244 0.56082 0.66891 0.55603 0.65143 0.52779 Metetra
0.11905 setgray
0.65143 0.52779 0.66891 0.55603 0.70832 0.58368 0.68962 0.53501 Metetra
0.19841 setgray
0.68962 0.53501 0.70832 0.58368 0.75084 0.63038 0.7308 0.56751 Metetra
0.382 setgray
0.7308 0.56751 0.75084 0.63038 0.79516 0.67396 0.77481 0.61176 Metetra
0.60632 setgray
0.77481 0.61176 0.79516 0.67396 0.83868 0.6911 0.82019 0.64873 Metetra
0.79377 setgray
0.82019 0.64873 0.83868 0.6911 0.87879 0.66869 0.86456 0.66011 Metetra
0.87953 setgray
0.86456 0.66011 0.87879 0.66869 0.9145 0.61155 0.90563 0.63651 Metetra
0.49975 setgray
0.34934 0.68237 0.37007 0.70047 0.40243 0.74276 0.38177 0.72115 Metetra
0.69946 setgray
0.38177 0.72115 0.40243 0.74276 0.43676 0.76824 0.41614 0.74662 Metetra
0.84006 setgray
0.41614 0.74662 0.43676 0.76824 0.47266 0.76305 0.45223 0.74691 Metetra
0.87991 setgray
0.45223 0.74691 0.47266 0.76305 0.5091 0.72503 0.48919 0.71816 Metetra
0.80723 setgray
0.48919 0.71816 0.5091 0.72503 0.54511 0.66484 0.52609 0.66639 Metetra
0.64353 setgray
0.52609 0.66639 0.54511 0.66484 0.58037 0.60079 0.56235 0.60485 Metetra
0.43727 setgray
0.56235 0.60485 0.58037 0.60079 0.61543 0.551 0.59811 0.54878 Metetra
0.2495 setgray
0.59811 0.54878 0.61543 0.551 0.65143 0.52779 0.63411 0.51072 Metetra
0.1358 setgray
0.63411 0.51072 0.65143 0.52779 0.68962 0.53501 0.67146 0.49774 Metetra
0.12985 setgray
0.67146 0.49774 0.68962 0.53501 0.7308 0.56751 0.71119 0.51046 Metetra
0.23338 setgray
0.71119 0.51046 0.7308 0.56751 0.77481 0.61176 0.75387 0.54291 Metetra
0.41577 setgray
0.75387 0.54291 0.77481 0.61176 0.82019 0.64873 0.79919 0.58323 Metetra
0.62302 setgray
0.79919 0.58323 0.82019 0.64873 0.86456 0.66011 0.84578 0.61598 Metetra
0.79377 setgray
0.84578 0.61598 0.86456 0.66011 0.90563 0.63651 0.89152 0.62656 Metetra
0.49975 setgray
0.32804 0.66379 0.34934 0.68237 0.38177 0.72115 0.3606 0.69888 Metetra
0.68433 setgray
0.3606 0.69888 0.38177 0.72115 0.41614 0.74662 0.39502 0.72372 Metetra
0.82282 setgray
0.39502 0.72372 0.41614 0.74662 0.45223 0.74691 0.43123 0.72841 Metetra
0.88062 setgray
0.43123 0.72841 0.45223 0.74691 0.48919 0.71816 0.4686 0.70836 Metetra
0.84329 setgray
0.4686 0.70836 0.48919 0.71816 0.52609 0.66639 0.50627 0.66609 Metetra
0.72017 setgray
0.50627 0.66609 0.52609 0.66639 0.56235 0.60485 0.54355 0.61027 Metetra
0.54199 setgray
0.54355 0.61027 0.56235 0.60485 0.59811 0.54878 0.58024 0.55266 Metetra
0.35327 setgray
0.58024 0.55266 0.59811 0.54878 0.63411 0.51072 0.61672 0.5046 Metetra
0.20112 setgray
0.61672 0.5046 0.63411 0.51072 0.67146 0.49774 0.65376 0.47441 Metetra
0.12356 setgray
0.65376 0.47441 0.67146 0.49774 0.71119 0.51046 0.69237 0.46618 Metetra
0.13995 setgray
0.69237 0.46618 0.71119 0.51046 0.75387 0.54291 0.73341 0.47933 Metetra
0.2462 setgray
0.73341 0.47933 0.75387 0.54291 0.79919 0.58323 0.77732 0.50861 Metetra
0.41577 setgray
0.77732 0.50861 0.79919 0.58323 0.84578 0.61598 0.82382 0.54465 Metetra
0.60632 setgray
0.82382 0.54465 0.84578 0.61598 0.89152 0.62656 0.87179 0.57538 Metetra
0.49975 setgray
0.30617 0.6447 0.32804 0.66379 0.3606 0.69888 0.33889 0.67596 Metetra
0.66881 setgray
0.33889 0.67596 0.3606 0.69888 0.39502 0.72372 0.37339 0.69953 Metetra
0.80286 setgray
0.37339 0.69953 0.39502 0.72372 0.43123 0.72841 0.40968 0.70749 Metetra
0.8741 setgray
0.40968 0.70749 0.43123 0.72841 0.4686 0.70836 0.44733 0.69519 Metetra
0.86779 setgray
0.44733 0.69519 0.4686 0.70836 0.50627 0.66609 0.48562 0.66276 Metetra
0.78524 setgray
0.48562 0.66276 0.50627 0.66609 0.54355 0.61027 0.52386 0.61512 Metetra
0.64353 setgray
0.52386 0.61512 0.54355 0.61027 0.58024 0.55266 0.56164 0.56045 Metetra
0.47204 setgray
0.56164 0.56045 0.58024 0.55266 0.61672 0.5046 0.59897 0.50788 Metetra
0.30629 setgray
0.59897 0.50788 0.61672 0.5046 0.65376 0.47441 0.6363 0.46548 Metetra
0.18062 setgray
0.6363 0.46548 0.65376 0.47441 0.69237 0.46618 0.67438 0.43889 Metetra
0.12106 setgray
0.67438 0.43889 0.69237 0.46618 0.73341 0.47933 0.71407 0.43075 Metetra
0.13995 setgray
0.71407 0.43075 0.73341 0.47933 0.77732 0.50861 0.75612 0.44048 Metetra
0.23338 setgray
0.75612 0.44048 0.77732 0.50861 0.82382 0.54465 0.80095 0.46426 Metetra
0.382 setgray
0.80095 0.46426 0.82382 0.54465 0.87179 0.57538 0.84846 0.49537 Metetra
0.49975 setgray
0.2837 0.62508 0.30617 0.6447 0.33889 0.67596 0.31663 0.65236 Metetra
0.65294 setgray
0.31663 0.65236 0.33889 0.67596 0.37339 0.69953 0.35124 0.67407 Metetra
0.78034 setgray
0.35124 0.67407 0.37339 0.69953 0.40968 0.70749 0.3876 0.68412 Metetra
0.8605 setgray
0.3876 0.68412 0.40968 0.70749 0.44733 0.69519 0.42543 0.67828 Metetra
0.87991 setgray
0.42543 0.67828 0.44733 0.69519 0.48562 0.66276 0.46419 0.65533 Metetra
0.83532 setgray
0.46419 0.65533 0.48562 0.66276 0.52386 0.61512 0.50325 0.61737 Metetra
0.73423 setgray
0.50325 0.61737 0.52386 0.61512 0.56164 0.56045 0.54212 0.56935 Metetra
0.59365 setgray
0.54212 0.56935 0.56164 0.56045 0.59897 0.50788 0.58057 0.51775 Metetra
0.43727 setgray
0.58057 0.51775 0.59897 0.50788 0.6363 0.46548 0.6187 0.46929 Metetra
0.2914 setgray
0.6187 0.46929 0.6363 0.46548 0.67438 0.43889 0.65696 0.42968 Metetra
0.18062 setgray
0.65696 0.42968 0.67438 0.43889 0.71407 0.43075 0.696 0.403 Metetra
0.12356 setgray
0.696 0.403 0.71407 0.43075 0.75612 0.44048 0.73654 0.3913 Metetra
0.12985 setgray
0.73654 0.3913 0.75612 0.44048 0.80095 0.46426 0.77928 0.39451 Metetra
0.19841 setgray
0.77928 0.39451 0.80095 0.46426 0.84846 0.49537 0.82468 0.41045 Metetra
0.49975 setgray
0.2606 0.60492 0.2837 0.62508 0.31663 0.65236 0.29381 0.62806 Metetra
0.63674 setgray
0.29381 0.62806 0.31663 0.65236 0.35124 0.67407 0.32857 0.64736 Metetra
0.75546 setgray
0.32857 0.64736 0.35124 0.67407 0.3876 0.68412 0.365 0.65831 Metetra
0.84006 setgray
0.365 0.65831 0.3876 0.68412 0.42543 0.67828 0.40293 0.65742 Metetra
0.87924 setgray
0.40293 0.65742 0.42543 0.67828 0.46419 0.65533 0.44201 0.64288 Metetra
0.86779 setgray
0.44201 0.64288 0.46419 0.65533 0.50325 0.61737 0.48172 0.61501 Metetra
0.80723 setgray
0.48172 0.61501 0.50325 0.61737 0.54212 0.56935 0.52158 0.57617 Metetra
0.70565 setgray
0.52158 0.57617 0.54212 0.56935 0.58057 0.51775 0.56124 0.53029 Metetra
0.57658 setgray
0.56124 0.53029 0.58057 0.51775 0.6187 0.46929 0.60055 0.48211 Metetra
0.43727 setgray
0.60055 0.48211 0.6187 0.46929 0.65696 0.42968 0.63965 0.43639 Metetra
0.30629 setgray
0.63965 0.43639 0.65696 0.42968 0.696 0.403 0.67889 0.39724 Metetra
0.20112 setgray
0.67889 0.39724 0.696 0.403 0.73654 0.3913 0.7188 0.3678 Metetra
0.1358 setgray
0.7188 0.3678 0.73654 0.3913 0.77928 0.39451 0.76 0.34992 Metetra
0.11905 setgray
0.76 0.34992 0.77928 0.39451 0.82468 0.41045 0.8031 0.34415 Metetra
0.49975 setgray
0.23685 0.58419 0.2606 0.60492 0.29381 0.62806 0.27039 0.60306 Metetra
0.62026 setgray
0.27039 0.60306 0.29381 0.62806 0.32857 0.64736 0.30537 0.61941 Metetra
0.72842 setgray
0.30537 0.61941 0.32857 0.64736 0.365 0.65831 0.34189 0.63011 Metetra
0.81317 setgray
0.34189 0.63011 0.365 0.65831 0.40293 0.65742 0.3799 0.63249 Metetra
0.86581 setgray
0.3799 0.63249 0.40293 0.65742 0.44201 0.64288 0.41917 0.62475 Metetra
0.88095 setgray
0.41917 0.62475 0.44201 0.64288 0.48172 0.61501 0.45933 0.60626 Metetra
0.85705 setgray
0.45933 0.60626 0.48172 0.61501 0.52158 0.57617 0.5 0.57767 Metetra
0.79655 setgray
0.5 0.57767 0.52158 0.57617 0.56124 0.53029 0.54079 0.54081 Metetra
0.70565 setgray
0.54079 0.54081 0.56124 0.53029 0.60055 0.48211 0.58144 0.49842 Metetra
0.59365 setgray
0.58144 0.49842 0.60055 0.48211 0.63965 0.43639 0.62185 0.4537 Metetra
0.47204 setgray
0.62185 0.4537 0.63965 0.43639 0.67889 0.39724 0.66209 0.40992 Metetra
0.35327 setgray
0.66209 0.40992 0.67889 0.39724 0.7188 0.3678 0.70242 0.37007 Metetra
0.2495 setgray
0.70242 0.37007 0.7188 0.3678 0.76 0.34992 0.74322 0.33658 Metetra
0.17136 setgray
0.74322 0.33658 0.76 0.34992 0.8031 0.34415 0.78499 0.31121 Metetra
0.49975 setgray
0.21241 0.56286 0.23685 0.58419 0.27039 0.60306 0.24636 0.57734 Metetra
0.60352 setgray
0.24636 0.57734 0.27039 0.60306 0.30537 0.61941 0.28162 0.59026 Metetra
0.69946 setgray
0.28162 0.59026 0.30537 0.61941 0.34189 0.63011 0.31829 0.59961 Metetra
0.78034 setgray
0.31829 0.59961 0.34189 0.63011 0.3799 0.63249 0.35637 0.60354 Metetra
0.84006 setgray
0.35637 0.60354 0.3799 0.63249 0.41917 0.62475 0.39575 0.60056 Metetra
0.8741 setgray
0.39575 0.60056 0.41917 0.62475 0.45933 0.60626 0.4362 0.58975 Metetra
0.87991 setgray
0.4362 0.58975 0.45933 0.60626 0.5 0.57767 0.47744 0.57088 Metetra
0.85705 setgray
0.47744 0.57088 0.5 0.57767 0.54079 0.54081 0.51917 0.5444 Metetra
0.80723 setgray
0.51917 0.5444 0.54079 0.54081 0.58144 0.49842 0.56109 0.51143 Metetra
0.73423 setgray
0.56109 0.51143 0.58144 0.49842 0.62185 0.4537 0.603 0.47361 Metetra
0.64353 setgray
0.603 0.47361 0.62185 0.4537 0.66209 0.40992 0.64479 0.43293 Metetra
0.54199 setgray
0.64479 0.43293 0.66209 0.40992 0.70242 0.37007 0.68645 0.39149 Metetra
0.43727 setgray
0.68645 0.39149 0.70242 0.37007 0.74322 0.33658 0.72812 0.35134 Metetra
0.33725 setgray
0.72812 0.35134 0.74322 0.33658 0.78499 0.31121 0.77004 0.31432 Metetra
0.49975 setgray
0.18726 0.54091 0.21241 0.56286 0.24636 0.57734 0.2217 0.55087 Metetra
0.58656 setgray
0.2217 0.55087 0.24636 0.57734 0.28162 0.59026 0.25732 0.55995 Metetra
0.66881 setgray
0.25732 0.55995 0.28162 0.59026 0.31829 0.59961 0.29421 0.56695 Metetra
0.7422 setgray
0.29421 0.56695 0.31829 0.59961 0.35637 0.60354 0.3324 0.57073 Metetra
0.80286 setgray
0.3324 0.57073 0.35637 0.60354 0.39575 0.60056 0.37186 0.57025 Metetra
0.84761 setgray
0.37186 0.57025 0.39575 0.60056 0.4362 0.58975 0.41246 0.56472 Metetra
0.8741 setgray
0.41246 0.56472 0.4362 0.58975 0.47744 0.57088 0.45406 0.55361 Metetra
0.88095 setgray
0.45406 0.55361 0.47744 0.57088 0.51917 0.5444 0.49644 0.53673 Metetra
0.86779 setgray
0.49644 0.53673 0.51917 0.5444 0.56109 0.51143 0.53939 0.51422 Metetra
0.83532 setgray
0.53939 0.51422 0.56109 0.51143 0.603 0.47361 0.58269 0.48659 Metetra
0.78524 setgray
0.58269 0.48659 0.603 0.47361 0.64479 0.43293 0.62617 0.45463 Metetra
0.72017 setgray
0.62617 0.45463 0.64479 0.43293 0.68645 0.39149 0.66969 0.41936 Metetra
0.64353 setgray
0.66969 0.41936 0.68645 0.39149 0.72812 0.35134 0.71319 0.38197 Metetra
0.55935 setgray
0.71319 0.38197 0.72812 0.35134 0.77004 0.31432 0.75669 0.3437 Metetra
0.49975 setgray
0.16137 0.51831 0.18726 0.54091 0.2217 0.55087 0.19637 0.52363 Metetra
0.56942 setgray
0.19637 0.52363 0.2217 0.55087 0.25732 0.55995 0.23244 0.5285 Metetra
0.63674 setgray
0.23244 0.5285 0.25732 0.55995 0.29421 0.56695 0.26964 0.53228 Metetra
0.69946 setgray
0.26964 0.53228 0.29421 0.56695 0.3324 0.57073 0.30802 0.53436 Metetra
0.75546 setgray
0.30802 0.53436 0.3324 0.57073 0.37186 0.57025 0.34758 0.53414 Metetra
0.80286 setgray
0.34758 0.53414 0.37186 0.57025 0.41246 0.56472 0.38828 0.5311 Metetra
0.84006 setgray
0.38828 0.5311 0.41246 0.56472 0.45406 0.55361 0.43007 0.52478 Metetra
0.86581 setgray
0.43007 0.52478 0.45406 0.55361 0.49644 0.53673 0.47283 0.51487 Metetra
0.87924 setgray
0.47283 0.51487 0.49644 0.53673 0.53939 0.51422 0.51645 0.50115 Metetra
0.87991 setgray
0.51645 0.50115 0.53939 0.51422 0.58269 0.48659 0.56079 0.48356 Metetra
0.86779 setgray
0.56079 0.48356 0.58269 0.48659 0.62617 0.45463 0.6057 0.4622 Metetra
0.84329 setgray
0.6057 0.4622 0.62617 0.45463 0.66969 0.41936 0.65104 0.4373 Metetra
0.80723 setgray
0.65104 0.4373 0.66969 0.41936 0.71319 0.38197 0.6967 0.40922 Metetra
0.76083 setgray
0.6967 0.40922 0.71319 0.38197 0.75669 0.3437 0.74256 0.37844 Metetra
0.49975 setgray
0.13469 0.49503 0.16137 0.51831 0.19637 0.52363 0.17035 0.49562 Metetra
0.55213 setgray
0.17035 0.49562 0.19637 0.52363 0.23244 0.5285 0.20697 0.49596 Metetra
0.60352 setgray
0.20697 0.49596 0.23244 0.5285 0.26964 0.53228 0.24459 0.4958 Metetra
0.65294 setgray
0.24459 0.4958 0.26964 0.53228 0.30802 0.53436 0.28325 0.49484 Metetra
0.69946 setgray
0.28325 0.49484 0.30802 0.53436 0.34758 0.53414 0.32299 0.49284 Metetra
0.7422 setgray
0.32299 0.49284 0.34758 0.53414 0.38828 0.5311 0.36381 0.48951 Metetra
0.78034 setgray
0.36381 0.48951 0.38828 0.5311 0.43007 0.52478 0.4057 0.48463 Metetra
0.81317 setgray
0.4057 0.48463 0.43007 0.52478 0.47283 0.51487 0.44863 0.47796 Metetra
0.84006 setgray
0.44863 0.47796 0.47283 0.51487 0.51645 0.50115 0.49258 0.4693 Metetra
0.8605 setgray
0.49258 0.4693 0.51645 0.50115 0.56079 0.48356 0.53749 0.45851 Metetra
0.8741 setgray
0.53749 0.45851 0.56079 0.48356 0.6057 0.4622 0.58329 0.44545 Metetra
0.88062 setgray
0.58329 0.44545 0.6057 0.4622 0.65104 0.4373 0.62992 0.43005 Metetra
0.87991 setgray
0.62992 0.43005 0.65104 0.4373 0.6967 0.40922 0.6773 0.4123 Metetra
0.87201 setgray
0.6773 0.4123 0.6967 0.40922 0.74256 0.37844 0.72533 0.39219 Metetra
0.49975 setgray
0.10721 0.47104 0.13469 0.49503 0.17035 0.49562 0.14362 0.4668 Metetra
0.53473 setgray
0.14362 0.4668 0.17035 0.49562 0.20697 0.49596 0.18088 0.46238 Metetra
0.56942 setgray
0.18088 0.46238 0.20697 0.49596 0.24459 0.4958 0.21903 0.4577 Metetra
0.60352 setgray
0.21903 0.4577 0.24459 0.4958 0.28325 0.49484 0.25811 0.45268 Metetra
0.63674 setgray
0.25811 0.45268 0.28325 0.49484 0.32299 0.49284 0.29813 0.44723 Metetra
0.66881 setgray
0.29813 0.44723 0.32299 0.49284 0.36381 0.48951 0.33913 0.44125 Metetra
0.69946 setgray
0.33913 0.44125 0.36381 0.48951 0.4057 0.48463 0.38113 0.43467 Metetra
0.72842 setgray
0.38113 0.43467 0.4057 0.48463 0.44863 0.47796 0.42415 0.4274 Metetra
0.75546 setgray
0.42415 0.4274 0.44863 0.47796 0.49258 0.4693 0.46818 0.41935 Metetra
0.78034 setgray
0.46818 0.41935 0.49258 0.4693 0.53749 0.45851 0.51325 0.41045 Metetra
0.80286 setgray
0.51325 0.41045 0.53749 0.45851 0.58329 0.44545 0.55936 0.40061 Metetra
0.82282 setgray
0.55936 0.40061 0.58329 0.44545 0.62992 0.43005 0.6065 0.38975 Metetra
0.84006 setgray
0.6065 0.38975 0.62992 0.43005 0.6773 0.4123 0.65466 0.37783 Metetra
0.85443 setgray
0.65466 0.37783 0.6773 0.4123 0.72533 0.39219 0.70384 0.36476 Metetra
0.49975 setgray
0.07887 0.44631 0.10721 0.47104 0.14362 0.4668 0.11613 0.43715 Metetra
0.51726 setgray
0.11613 0.43715 0.14362 0.4668 0.18088 0.46238 0.15415 0.42779 Metetra
0.53473 setgray
0.15415 0.42779 0.18088 0.46238 0.21903 0.4577 0.19295 0.41822 Metetra
0.55213 setgray
0.19295 0.41822 0.21903 0.4577 0.25811 0.45268 0.23256 0.40842 Metetra
0.56942 setgray
0.23256 0.40842 0.25811 0.45268 0.29813 0.44723 0.273 0.39838 Metetra
0.58656 setgray
0.273 0.39838 0.29813 0.44723 0.33913 0.44125 0.3143 0.38808 Metetra
0.60352 setgray
0.3143 0.38808 0.33913 0.44125 0.38113 0.43467 0.35648 0.3775 Metetra
0.62026 setgray
0.35648 0.3775 0.38113 0.43467 0.42415 0.4274 0.39958 0.36662 Metetra
0.63674 setgray
0.39958 0.36662 0.42415 0.4274 0.46818 0.41935 0.44361 0.35543 Metetra
0.65294 setgray
0.44361 0.35543 0.46818 0.41935 0.51325 0.41045 0.4886 0.3439 Metetra
0.66881 setgray
0.4886 0.3439 0.51325 0.41045 0.55936 0.40061 0.53458 0.33202 Metetra
0.68433 setgray
0.53458 0.33202 0.55936 0.40061 0.6065 0.38975 0.58158 0.31976 Metetra
0.69946 setgray
0.58158 0.31976 0.6065 0.38975 0.65466 0.37783 0.62963 0.30711 Metetra
0.71417 setgray
0.62963 0.30711 0.65466 0.37783 0.70384 0.36476 0.67875 0.29405 Metetra
0.49975 setgray
0.04964 0.4208 0.07887 0.44631 0.11613 0.43715 0.08786 0.40664 Metetra
0.49975 setgray
0.08786 0.40664 0.11613 0.43715 0.15415 0.42779 0.12675 0.39224 Metetra
0.49975 setgray
0.12675 0.39224 0.15415 0.42779 0.19295 0.41822 0.16631 0.37759 Metetra
0.49975 setgray
0.16631 0.37759 0.19295 0.41822 0.23256 0.40842 0.20657 0.36267 Metetra
0.49975 setgray
0.20657 0.36267 0.23256 0.40842 0.273 0.39838 0.24755 0.3475 Metetra
0.49975 setgray
0.24755 0.3475 0.273 0.39838 0.3143 0.38808 0.28926 0.33205 Metetra
0.49975 setgray
0.28926 0.33205 0.3143 0.38808 0.35648 0.3775 0.33173 0.31632 Metetra
0.49975 setgray
0.33173 0.31632 0.35648 0.3775 0.39958 0.36662 0.37498 0.3003 Metetra
0.49975 setgray
0.37498 0.3003 0.39958 0.36662 0.44361 0.35543 0.41902 0.28399 Metetra
0.49975 setgray
0.41902 0.28399 0.44361 0.35543 0.4886 0.3439 0.46389 0.26737 Metetra
0.49975 setgray
0.46389 0.26737 0.4886 0.3439 0.53458 0.33202 0.50959 0.25044 Metetra
0.49975 setgray
0.50959 0.25044 0.53458 0.33202 0.58158 0.31976 0.55617 0.23319 Metetra
0.49975 setgray
0.55617 0.23319 0.58158 0.31976 0.62963 0.30711 0.60363 0.21561 Metetra
0.49975 setgray
0.60363 0.21561 0.62963 0.30711 0.67875 0.29405 0.65202 0.19769 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.23954 0.2462 moveto
0.24766 0.25491 lineto
stroke
0 setgray
[(1)] 0.23549 0.24184 0.931731 1 Mshowa
0.43272 0.17039 moveto
0.44012 0.17972 lineto
stroke
0 setgray
[(2)] 0.42902 0.16572 0.792736 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(3)] 0.63943 0.08304 0.653742 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.74721 0.23734 moveto
0.73599 0.24133 lineto
stroke
0 setgray
[(1)] 0.75282 0.23534 -1 0.355817 Mshowa
0.82972 0.36363 moveto
0.8184 0.36732 lineto
stroke
0 setgray
[(2)] 0.83538 0.36178 -1 0.326047 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(3)] 0.90729 0.47191 -1 0.300874 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05933 0.32687 moveto
0.07042 0.32254 lineto
stroke
0 setgray
[(-1)] 0.05378 0.32904 1 -0.390635 Mshowa
0.05183 0.37404 moveto
0.06295 0.36981 lineto
stroke
0 setgray
[(-0.5)] 0.04626 0.37616 1 -0.380695 Mshowa
0.04406 0.42286 moveto
0.05523 0.41873 lineto
stroke
0 setgray
[(0)] 0.03848 0.42493 1 -0.370371 Mshowa
0.03602 0.47342 moveto
0.04722 0.46939 lineto
stroke
0 setgray
[(0.5)] 0.03042 0.47544 1 -0.359642 Mshowa
0.02769 0.52581 moveto
0.03893 0.5219 lineto
stroke
0 setgray
[(1)] 0.02207 0.52777 1 -0.348483 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = special1; inactive; startGroup; pageBreak; ]
Signal Processing Extensions
:[font = text; inactive; ]
	The signal processing packages for Mathematica implement a comprehensive set of signal processing operations and functions, including transforms and convolution as well as solvers for linear differential/difference equations.  The new packages can plot sequences, pole-zero diagrams, root loci, and frequency responses.
:[font = section; inactive; startGroup; ]
Loading the Signal Processing Packages
:[font = text; inactive; ]
	You can some or all of them as desired.   If all you want to do is to compute convolutions and plot signals and systems, then evaluate
:[font = input; center; ]
Needs[ "SignalProcessing`Support`Convolution`" ]
:[font = text; inactive; ]
Note here that the single quotes are back quotes (the key above the TAB key on the Mac keyboard).  If you wish to compute z-transforms, DTFT's, DFT's, solve difference equations, or perform analysis of discrete-time signals, then evaluate
:[font = input; center; ]
Needs[ "SignalProcessing`Digital`" ]
:[font = text; inactive; ]
If you wish to compute Laplace and Fourier transforms, solve differential equations, or perform analysis of analog signals, then evaluate
:[font = input; center; ]
Needs[ "SignalProcessing`Analog`" ]
:[font = text; inactive; endGroup; ]
It is best to load in only what you need.
:[font = section; inactive; startGroup; ]
Supporting Packages
:[font = text; inactive; ]
	These packages introduce the following new signals (functions):
:[font = print; inactive; ]
CPulse     continuous pulse function
CStep      continuous step functions
Delta      continuous impulse (Dirac delta)
Dirichlet  aliased sinc
Impulse    discrete (Kronecker) impulse
Pulse      discrete pulse function
Sinc       sinc
Step       discrete step functions
Unit[n]    generalized unit function of order n
:[font = text; inactive; ]
The functions need a time variable, e.g. Step[n] and Sinc[2  -  Pi  t], and CPulse and Pulse also require a length argument, e.g. Pulse[L, n].
:[font = subsection; inactive; ]
New Plotting Routines
:[font = text; inactive; ]
	The signal processing packages provide the following routines for plotting signals and sequences and their transforms:
:[font = print; inactive; center; ]
MagPhasePlot   PiecewisePlot  PoleZeroPlot
RootLocus      SequencePlot   SignalPlot  
:[font = text; inactive; ]
Their syntax (except for PoleZeroPlot) is the same as Plot.  SignalPlot displays the real and imaginary components of the signal on the same plot.
:[font = subsection; inactive; ]
Convolution
:[font = text; inactive; endGroup; endGroup; ]
	The supporting packages provide routines to perform discrete and continuous convolution.  For discrete convolution, the main routine is DTPiecewiseConvolution which takes three arguments--  f[n], g[n], and n.   (CTPiecewiseConvolution is the continuous counterpart).  An example of discrete convolution is given at the end of this handout.
:[font = section; inactive; ]
Analog and Digital Signal Processing Packages
:[font = text; inactive; startGroup; ]
	The signal processing packages implement many of the linear transforms used in signals and systems---  Laplace, Fourier, z, discrete-time Fourier, etc.  These transforms can justify their answers (as shown at the end of the handout).  You can also specify your own transform pairs.  The following example examines the effect of multiplication of a function by an exponential (the last argument specifies the transform pair x(t) <--> X(s)):
:[font = input; startGroup; ]
LaPlace[ Exp[a t] x[t], t, s,
         TransformLookup -> { x[t] :> X[s] } ]
:[font = output; inactive; output; endGroup; ]
LTransData[X[-a + s], 
  Rminus[DirectedInfinity[-1]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
LTransData[X[-a + s], Rminus[-Infinity], 
 
  Rplus[Infinity], LVariables[s]]
:[font = text; inactive; ]
Here is a complete list of implemented linear transforms:
:[font = input; ]
CTFTransform     InvDFTransform    InvZTransform
DFTransform      InvDTFTransform   LaPlace
DTFTransform     InvLaPlace        ZTransform
InvCTFTransform
:[font = text; inactive; ]
We can invert the previous Laplace transform using InvLaPlace:
:[font = input; startGroup; ]
InvLaPlace[ X[s - a], s, t,
            TransformLookup -> { X[s] :> x[t] } ]
:[font = output; inactive; output; endGroup; endGroup; ]
E^(a*t)*x[t]
;[o]
 a t
E    x[t]
:[font = text; inactive; ]
	We can have Mathematica perform a complicated z-transform and tell us how to do it by hand via the Dialogue -> All option:
:[font = input; startGroup; ]
ZTransform[ a^n Cos[b n] Step[n], n, z,
            Dialogue -> All ]
:[font = print; inactive; startGroup; ]
     n
Z  {a  Cos[b n] Step[n]}
  n
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
{Z  {Cos[b n] Step[n]}}
   n                   z -> z/a and scale ROC
:[font = print; inactive; ]
which becomes
:[font = output; inactive; output; endGroup; endGroup; ]
ZTransData[(1 - (a*Cos[b])/z)/
   (1 + a^2/z^2 - (2*a*Cos[b])/z), 
  Rminus[Abs[a]], Rplus[DirectedInfinity[1]], 
  ZVariables[z]]
;[o]
                  a Cos[b]
              1 - --------
                     z
ZTransData[-------------------, Rminus[Abs[a]], 
                2
               a    2 a Cos[b]
           1 + -- - ----------
                2       z
               z
 
  Rplus[Infinity], ZVariables[z]]
:[font = text; inactive; ]
The z-transform returns the transform as well as R- and R+ in the region of convergence.  You can extract the transform function by using TheFunction. You can plot the pole-zero plot by passing the entire transform structure into PoleZeroPlot (but you will need to give a value to the parameter a ).
:[font = special1; inactive; startGroup; pageBreak; ]
The Notebook Interface
:[font = text; inactive; ]
	What you are reading was prepared using the Notebook interface.  A Notebook is a collection of cells containing text, graphics, animation, equations, tables, and "live" Mathematica code arranged in a tree structure.  A closed section is displayed with a downward pointing half arrow.
:[font = text; inactive; ]
	Fonts are indicative of what the cell is.  For example, the cell you are reading is normal-sized text.  The next cell is "live" Mathematica code, and the cell after that contains the output of the "live" code:
:[font = input; startGroup; ]
2 + 2
:[font = output; inactive; output; endGroup; endGroup; ]
4
;[o]
4
:[font = special1; inactive; startGroup; ]
Signal Processing Notebooks
:[font = text; inactive; ]
	We have written 10 Notebooks.  Six serve as on-line help.  Four are tutorials explaining various aspects of signal processing:
:[font = network; inactive; ]
AnalogFilters         design of classical analog filters      
DTFT                  discrete-time Fourier analysis         
PiecewiseConvolution  continuous and discrete convolution
zTransform            three-parter on the z-transform and DTFT
:[font = text; inactive; endGroup; ]
They are in "Library Cluster 1:EE:DSP Class:Version 2.74:Notebooks" under the Tutorial folder.  The Handouts folder contains this handout (Intro).
:[font = special1; inactive; startGroup; ]
Advanced Users
:[font = text; inactive; ]
	If you plan to do computations other than convolutions and plotting, then it is beneficial to download the signal processing packages from the file server to the local disk.  This is accomplished by first opening the ``Packages'' folder of the ``Mathematica'' folder of the ``Libmac NN'' folder.  Then, open up a serious of folders beginning with the ``Library Cluster 1'' until you find the folder entitled
:[font = network; inactive; ]
   "Library Cluster 1:EE:DSP Class:Version 2.74:Packages"
:[font = text; inactive; endGroup; ]
Now, move the ``SignalProcessing'' folder from the above folder to the folder ``Libmac NN:Mathematica:Packages''.  This download will take 1-2 minutes.   Afterwards, the signal processing packages will be loaded from local disk which will be much faster than loading them from the file server.    
:[font = special1; inactive; pageBreak; ]
Discrete Convolution Example
:[font = text; inactive; ]
	This example computes and plots the convolution of two discrete pulses.  First, we need to load the appropriate signal processing packages:
:[font = input; ]
Needs[ "SignalProcessing`Support`Convolution`" ]
:[font = print; inactive; ]
Support module has been loaded.
The knowledge base of signal processing operators
  has been loaded.
Piecewise convolution rules have been loaded.
:[font = text; inactive; ]
Second,  we convolve two discrete pulses.  The first pulse has an amplitude of 2 for 0 <= n <= 6 and the second has amplitude 3 for 0 <= n <= 3:
:[font = input; startGroup; ]
testcase =
  DTPiecewiseConvolution[{2,0,6}, {3,0,3}, n]
:[font = output; inactive; output; endGroup; ]
{{6*(1 + n), 0, 3}, {24, 4, 6}, {60 - 6*n, 7, 9}}
;[o]
{{6 (1 + n), 0, 3}, {24, 4, 6}, {60 - 6 n, 7, 9}}
:[font = text; inactive; ]
The resulting convolution behaves differently over three distinct intervals:  (a) 0 <= n <= 3,  (b)  4 <= n <= 6,  and  (c)  7 <= n <= 9.  Below, we show this by plotting the convolution for n in [-5, 15]:
:[font = input; startGroup; ]
PiecewisePlot[ testcase,
               {n, -5, 15},
               Domain->Discrete ]
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.2619 0.04762 0.01472 0.02453 [
[(Sequence Plot)] 0.5 0.62428 0 -1 Msboxa
[(-5)] 0.02381 0.00222 0 1 Msboxa
[(5)] 0.5 0.00222 0 1 Msboxa
[(10)] 0.7381 0.00222 0 1 Msboxa
[(15)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(5)] 0.2494 0.13734 1 0 Msboxa
[(10)] 0.2494 0.25997 1 0 Msboxa
[(15)] 0.2494 0.38259 1 0 Msboxa
[(20)] 0.2494 0.50522 1 0 Msboxa
[( )] 0.2619 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-5)] 0.02381 0.00222 0 1 Mshowa
0.5 0.00847 moveto
0.5 0.02097 lineto
stroke
0 setgray
[(5)] 0.5 0.00222 0 1 Mshowa
0.7381 0.00847 moveto
0.7381 0.02097 lineto
stroke
0 setgray
[(10)] 0.7381 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(15)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.2619 0 moveto
0.2619 0.61803 lineto
stroke
0.25565 0.13734 moveto
0.26815 0.13734 lineto
stroke
0 setgray
[(5)] 0.2494 0.13734 1 0 Mshowa
0.25565 0.25997 moveto
0.26815 0.25997 lineto
stroke
0 setgray
[(10)] 0.2494 0.25997 1 0 Mshowa
0.25565 0.38259 moveto
0.26815 0.38259 lineto
stroke
0 setgray
[(15)] 0.2494 0.38259 1 0 Mshowa
0.25565 0.50522 moveto
0.26815 0.50522 lineto
stroke
0 setgray
[(20)] 0.2494 0.50522 1 0 Mshowa
0 setgray
[( )] 0.2619 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.00587 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.01762 setlinewidth
0.02381 0.01472 Mdot
0.00587 setlinewidth
0.07143 0.01472 moveto
0.07143 0.01472 lineto
stroke
0.01762 setlinewidth
0.07143 0.01472 Mdot
0.00587 setlinewidth
0.11905 0.01472 moveto
0.11905 0.01472 lineto
stroke
0.01762 setlinewidth
0.11905 0.01472 Mdot
0.00587 setlinewidth
0.16667 0.01472 moveto
0.16667 0.01472 lineto
stroke
0.01762 setlinewidth
0.16667 0.01472 Mdot
0.00587 setlinewidth
0.21429 0.01472 moveto
0.21429 0.01472 lineto
stroke
0.01762 setlinewidth
0.21429 0.01472 Mdot
0.00587 setlinewidth
0.2619 0.01472 moveto
0.2619 0.16187 lineto
stroke
0.01762 setlinewidth
0.2619 0.16187 Mdot
0.00587 setlinewidth
0.30952 0.01472 moveto
0.30952 0.30902 lineto
stroke
0.01762 setlinewidth
0.30952 0.30902 Mdot
0.00587 setlinewidth
0.35714 0.01472 moveto
0.35714 0.45617 lineto
stroke
0.01762 setlinewidth
0.35714 0.45617 Mdot
0.00587 setlinewidth
0.40476 0.01472 moveto
0.40476 0.60332 lineto
stroke
0.01762 setlinewidth
0.40476 0.60332 Mdot
0.00587 setlinewidth
0.45238 0.01472 moveto
0.45238 0.60332 lineto
stroke
0.01762 setlinewidth
0.45238 0.60332 Mdot
0.00587 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
stroke
0.01762 setlinewidth
0.5 0.60332 Mdot
0.00587 setlinewidth
0.54762 0.01472 moveto
0.54762 0.60332 lineto
stroke
0.01762 setlinewidth
0.54762 0.60332 Mdot
0.00587 setlinewidth
0.59524 0.01472 moveto
0.59524 0.45617 lineto
stroke
0.01762 setlinewidth
0.59524 0.45617 Mdot
0.00587 setlinewidth
0.64286 0.01472 moveto
0.64286 0.30902 lineto
stroke
0.01762 setlinewidth
0.64286 0.30902 Mdot
0.00587 setlinewidth
0.69048 0.01472 moveto
0.69048 0.16187 lineto
stroke
0.01762 setlinewidth
0.69048 0.16187 Mdot
0.00587 setlinewidth
0.7381 0.01472 moveto
0.7381 0.01472 lineto
stroke
0.01762 setlinewidth
0.7381 0.01472 Mdot
0.00587 setlinewidth
0.78571 0.01472 moveto
0.78571 0.01472 lineto
stroke
0.01762 setlinewidth
0.78571 0.01472 Mdot
0.00587 setlinewidth
0.83333 0.01472 moveto
0.83333 0.01472 lineto
stroke
0.01762 setlinewidth
0.83333 0.01472 Mdot
0.00587 setlinewidth
0.88095 0.01472 moveto
0.88095 0.01472 lineto
stroke
0.01762 setlinewidth
0.88095 0.01472 Mdot
0.00587 setlinewidth
0.92857 0.01472 moveto
0.92857 0.01472 lineto
stroke
0.01762 setlinewidth
0.92857 0.01472 Mdot
0.00587 setlinewidth
0.97619 0.01472 moveto
0.97619 0.01472 lineto
stroke
0.01762 setlinewidth
0.97619 0.01472 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]
Note that intervals can be infinite in length.  For example, a step function in interval form is {1, 0, Infinity}.  A reversed step function is {1, -Infinity, 0}.
:[font = special1; inactive; pageBreak; ]
Continuous Convolution Example
:[font = text; inactive; ]
	The same convolution package also performs piecewise continuous convolution.  In this example, we will convolve a triangle and a pulse.  The triangle will last 6 times units, whereas the pulse will last four.
:[font = input; startGroup; ]
triangle = t CPulse[3,t] + (6 - t) CPulse[3,t-3];
pulse = CPulse[4,t];
conv = CTPiecewiseConvolution[triangle, pulse, t]
:[font = output; inactive; output; endGroup; ]
{{t^2/2, 0, 3}, {-9 + 6*t - t^2/2, 3, 4}, 
  {-17 + 10*t - t^2, 4, 6}, 
  {1 + 4*t - t^2/2, 6, 7}, {(-10 + t)^2/2, 7, 10}}
;[o]
   2                      2
  t                      t
{{--, 0, 3}, {-9 + 6 t - --, 3, 4}, 
  2                      2
 
                                       2
                 2                    t
  {-17 + 10 t - t , 4, 6}, {1 + 4 t - --, 6, 7}, 
                                      2
 
            2
   (-10 + t)
  {----------, 7, 10}}
       2
:[font = input; startGroup; ]
PiecewisePlot[ conv,
               {t, -2, 12},
               Domain -> Continuous]
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.15986 0.06803 0.01472 0.07358 [
[(Signal Plot)] 0.5 0.62428 0 -1 Msboxa
[(-2)] 0.02381 0.00222 0 1 Msboxa
[(2)] 0.29592 0.00222 0 1 Msboxa
[(4)] 0.43197 0.00222 0 1 Msboxa
[(6)] 0.56803 0.00222 0 1 Msboxa
[(8)] 0.70408 0.00222 0 1 Msboxa
[(10)] 0.84014 0.00222 0 1 Msboxa
[(12)] 0.97619 0.00222 0 1 Msboxa
[(t)] 1.00625 0.01472 -1 0 Msboxa
[(2)] 0.14736 0.16187 1 0 Msboxa
[(4)] 0.14736 0.30902 1 0 Msboxa
[(6)] 0.14736 0.45617 1 0 Msboxa
[(8)] 0.14736 0.60332 1 0 Msboxa
[( )] 0.15986 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Signal Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-2)] 0.02381 0.00222 0 1 Mshowa
0.29592 0.00847 moveto
0.29592 0.02097 lineto
stroke
0 setgray
[(2)] 0.29592 0.00222 0 1 Mshowa
0.43197 0.00847 moveto
0.43197 0.02097 lineto
stroke
0 setgray
[(4)] 0.43197 0.00222 0 1 Mshowa
0.56803 0.00847 moveto
0.56803 0.02097 lineto
stroke
0 setgray
[(6)] 0.56803 0.00222 0 1 Mshowa
0.70408 0.00847 moveto
0.70408 0.02097 lineto
stroke
0 setgray
[(8)] 0.70408 0.00222 0 1 Mshowa
0.84014 0.00847 moveto
0.84014 0.02097 lineto
stroke
0 setgray
[(10)] 0.84014 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(12)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.01472 -1 0 Mshowa
0.15986 0 moveto
0.15986 0.61803 lineto
stroke
0.15361 0.16187 moveto
0.16611 0.16187 lineto
stroke
0 setgray
[(2)] 0.14736 0.16187 1 0 Mshowa
0.15361 0.30902 moveto
0.16611 0.30902 lineto
stroke
0 setgray
[(4)] 0.14736 0.30902 1 0 Mshowa
0.15361 0.45617 moveto
0.16611 0.45617 lineto
stroke
0 setgray
[(6)] 0.14736 0.45617 1 0 Mshowa
0.15361 0.60332 moveto
0.16611 0.60332 lineto
stroke
0 setgray
[(8)] 0.14736 0.60332 1 0 Mshowa
0 setgray
[( )] 0.15986 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.006 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.12302 0.01472 lineto
0.14286 0.01472 lineto
0.14782 0.01472 lineto
0.15278 0.01472 lineto
0.15526 0.01472 lineto
0.15774 0.01472 lineto
0.15898 0.01472 lineto
0.16022 0.01472 lineto
0.16146 0.01474 lineto
0.1627 0.01478 lineto
0.16394 0.01485 lineto
0.16518 0.01494 lineto
0.16766 0.0152 lineto
0.17014 0.01555 lineto
0.17262 0.01601 lineto
0.17758 0.01721 lineto
0.18254 0.0188 lineto
0.19246 0.02316 lineto
0.20238 0.02909 lineto
0.22222 0.04563 lineto
0.24206 0.06843 lineto
0.2619 0.09749 lineto
0.30159 0.17438 lineto
0.34127 0.27632 lineto
0.38095 0.39869 lineto
0.40079 0.45457 lineto
0.42063 0.5042 lineto
0.44048 0.54699 lineto
0.4504 0.5642 lineto
0.46032 0.57828 lineto
0.47024 0.58924 lineto
0.4752 0.59354 lineto
0.48016 0.59706 lineto
0.48512 0.5998 lineto
0.4876 0.60087 lineto
0.49008 0.60175 lineto
0.49256 0.60244 lineto
0.4938 0.60271 lineto
0.49504 0.60293 lineto
0.49628 0.6031 lineto
0.49752 0.60322 lineto
0.49876 0.60329 lineto
0.5 0.60332 lineto
0.50124 0.60329 lineto
0.50248 0.60322 lineto
0.50372 0.6031 lineto
0.50496 0.60293 lineto
Mistroke
0.50744 0.60244 lineto
0.50992 0.60175 lineto
0.5124 0.60087 lineto
0.51488 0.5998 lineto
0.51984 0.59706 lineto
0.5248 0.59354 lineto
0.52976 0.58924 lineto
0.53968 0.57828 lineto
0.5496 0.5642 lineto
0.55952 0.54699 lineto
0.57937 0.5042 lineto
0.61905 0.39869 lineto
0.65873 0.27632 lineto
0.69841 0.17438 lineto
0.7381 0.09749 lineto
0.75794 0.06843 lineto
0.77778 0.04563 lineto
0.79762 0.02909 lineto
0.80754 0.02316 lineto
0.8125 0.02079 lineto
0.81746 0.0188 lineto
0.82242 0.01721 lineto
0.82738 0.01601 lineto
0.82986 0.01555 lineto
0.83234 0.0152 lineto
0.83482 0.01494 lineto
0.83606 0.01485 lineto
0.8373 0.01478 lineto
0.83854 0.01474 lineto
0.83978 0.01472 lineto
0.84102 0.01472 lineto
0.84226 0.01472 lineto
0.8435 0.01472 lineto
0.84474 0.01472 lineto
0.84722 0.01472 lineto
0.85714 0.01472 lineto
0.86706 0.01472 lineto
0.87698 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
Mfstroke
grestore
grestore
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = special1; inactive; pageBreak; ]
Laplace Transform Example
:[font = text; inactive; ]
	Consider the Laplace transform of t Exp[-a t]  CStep[t] with respect to t.  First, we need to load in the analog signal processing packages:
:[font = input; ]
Needs[ "SignalProcessing`Analog`" ]
:[font = text; inactive; ]
(output not shown).  Now, we can take the Laplace transform:
:[font = input; startGroup; ]
LaPlace[ t Exp[-a t] CStep[t],
         t, s, Dialogue -> All ]
:[font = print; inactive; startGroup; ]
    t CStep[t]
L  {----------}
  t     a t
       E
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
{L  {t CStep[t]}}
   t             s -> a + s and shift ROC
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                 -2
Transform[(a + s)  , -Re[a], Infinity]
:[font = print; inactive; ]
which becomes
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(a + s)^(-2), Rminus[-Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                  -2
LTransData[(a + s)  , Rminus[-Re[a]], 
 
  Rplus[Infinity], LVariables[s]]
:[font = text; inactive; ]
The Laplace transform returns a data structure that contains the Laplace transform, its region of convergence R- and R+ such that R- < Re(s) < R+, and the transform variables.  Since the region of convergence is known, we can ask for the conditions on the free parameters for the signal to be stable:
:[font = input; startGroup; ]
Stable[ % ]
:[font = output; inactive; output; endGroup; ]
Re[a] > 0
;[o]
Re[a] > 0
:[font = special1; inactive; startGroup; pageBreak; ]
Downloading the Extensions at Home
:[font = text; inactive; ]
	You can download the signal processing packages and Notebooks from our file server in EE.  It appears in three archive formats, so you should be able to download the one that fits your computer:
:[font = input; center; ]
(1) compressed tar file for Unix Systems
(2) zip file for IBM PC's               
(3) self-extracting archive for Mac's   
:[font = text; inactive; ]
In any case, you will need to use the File Transfer Program, ftp, which runs on hydra and is available for personal computers and Macintosh from the Office of Information Technology.  If you have trouble finding the symbolic address gauss.eedsp.gatech.edu, then try to use its numeric address of 130.207.226.24.
:[font = section; inactive; ]
Downloading to a Unix workstation
:[font = text; inactive; ]
	The following instructions use HOME to denote the Unix workstation that you are using.   What you type appears in bold italics. 
:[font = input; ]
HOME> ftp gauss.eedsp.gatech.edu
....
Username: anonymous
Password: <use your e-mail address>
...
ftp> cd Mathematica
ftp> binary
ftp> get SigProc2.0.tar.Z
ftp> quit
...
HOME> uncompress SigProc2.0.tar.Z
HOME> tar xf SigProc2.0.tar
:[font = section; inactive; pageBreak; ]
Downloading to an IBM PC running MS-DOS
:[font = text; inactive; ]
	The following instructions use HOME to denote the IBM PC that you are using.   What you type appears in bold italics. 
:[font = input; ]
HOME> ftp gauss.eedsp.gatech.edu
....
Username: anonymous
Password: <use your e-mail address>
...
ftp> cd Mathematica
ftp> binary
ftp> get SigProc2_IBM_PC.zip
ftp> quit
...
HOME> unzip SigProc2.zip
:[font = section; inactive; ]
Downloading to a Macintosh computer
:[font = text; inactive; ]
	On the Macintosh, run the ftp program and connect to
:[font = input; center; ]
gauss.eedsp.gatech.edu
:[font = text; inactive; ]
You will then be asked for a username and a password.  What you type in is given in bold italics. 
:[font = input; ]
Username: anonymous
Password: <use your e-mail address>
...
ftp> cd Mathematica
ftp> binary
ftp> get SigProc2.0.mac.sea.hqx
ftp> quit
:[font = text; inactive; endGroup; ]
Now, you will need to run the BinHex program with the Text Filter de-selected using the Download -> Application command.  This will produce SigProc2.0.mac.sea  which is a self-extracting archive file.  To extract its contents, simply click twice on its icon.
:[font = section; inactive; startGroup; pageBreak; ]
Contents of the Signal Processing Extensions
:[font = text; inactive; endGroup; ]
	The signal processing extensions are a bunch of ASCII files available in the public domain, so you may freely copy them as long as you do not charge a fee (the copyright is held by the Georgia Tech Research Corporation).  When unbundled, they form several new directories:  Packages, Notebooks, doc, and Macintosh.  Packages contains the Mathematica  code to implement functions, routines, and operators common in signal processing but missing in the core of Mathematica.   Notebooks contain tutorials on signal processing topics and on-line help about the signal processing extensions.  The tutorials cover the topics of analog filter design, discrete-time Fourier analysis, convolution, and the z-transform. One new file called README should also have been created.
:[font = section; inactive; startGroup; ]
Buying Student Versions of Mathematica
:[font = text; inactive; ]
	The prices for student versions for Mathematica 2.0 (the lab runs Mathematica 1.2) are:
:[font = input; center; ]
Macintosh    $175.00
MS-DOS       $175.00
MS Windows*  $175.00
:[font = message; inactive; wordwrap; ]
* Mathematica works much better under MS Windows 3.1 than under MS Windows 3.0.
:[font = text; inactive; endGroup; ]
For this price, the student version means that you cannot update the software and the floating point coprocessor is disabled.  However, I believe that you do get a copy of the Mathematica  reference book which has a retail value of $30.
^*)