(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
Mathematica as an Educational Tool for Signal Processing
:[font = subtitle; inactive; ]

by Brian Evans, James McClellan, and Kevin West
:[font = subsubtitle; inactive; ]

Digital Signal Processing Laboratory
School of Electrical Engineering
Georgia Institute of Technology
Atlanta, GA  30332-0250

EMAIL:  evans@eedsp.gatech.edu
:[font = text; inactive; ]
		This is the notebook version of the 1991 IEEE Southeastern Conference (Southeastcon '91) paper entitled ``Mathematica as an Educational Tool for Signal Processing''.
:[font = special3; inactive; wordwrap; ]
WARNING:  The Notebook was originally generated using Mathematica 1.2.  Under Mathematica 2.0 and higher,  the graphics in this Notebook will be rendered in the new PostScript format.  The conversion will take a couple of minutes, but you will be able to move around in the Notebook during it.  For this Notebook, the conversion process on the 35 or so graphics cells will require an extra 700 kb of memory (35 cells x 20 kb/cell).
:[font = section; inactive; startGroup; Cclosed; ]
Abstract
:[font = text; inactive; endGroup; ]
 		This paper describes extensions for a symbolic mathematics program that make it an effective educational tool for courses in linear systems theory.  These extensions are in the form of packages and notebooks for the Mathematica environment. The new signal processing packages contain rule bases that symbolically compute convolutions and all the transforms common to signal processing:  Fourier, Laplace, z, etc.  In order to introduce a student to these concepts and how they are implemented in Mathematica, we have written four tutorials in Mathematica's notebook format.  Notebooks, a form of hypertext, allow students to access material randomly, to discover insights at their own pace, and to evaluate code provided in the examples.  Students can also use notebooks to solve homework problems in a self-documenting fashion.
:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = input; initialization; startGroup; ]
*)
Needs[ "SignalProcessing`SignalProcessing`" ]
(*
:[font = print; inactive; ]
Loading the signal processing support packages ...
Support module has been loaded.
Supporting routines for filter design are loaded.
The knowledge base of signal processing operators has been\
 
  loaded.
Region of convergence routines for the transform rule bases\
 
  are loaded.
Supporting routines for transform rule bases are loaded.
Loading in the digital signal processing packages ...
Supporting routines for the z-transform rule bases are\
 
  loaded.
The supporting functions are loaded for symbolic Fourier\
 
  transforms.
The forward z-transform rules have been loaded.
The inverse z-transform rules have been loaded.
The discrete-time Fourier transform (DTFT) rule bases are\
 
  loaded.
Correlation functions are now loaded.
ZSolve, a difference equation solver, is loaded.
The digital signal analyzer is now loaded.
The discrete Fourier transform (DFT) rule bases are loaded.
 
The digital signal processing extensions has been loaded.
Good starting points are the objects DSPAnalyze and\
 
  ZTransform.
Active packages are maintained in the variable\
 
  $ContextPath.
  New signal primitives are in SPsignals.
  New system primitives are in SPoperators.
  New Mathematica functions are in SPfunctions.
Note that all signal processing expressions will
be automatically simplified.
 
Loading the signal processing support packages ...
Loading in the analog signal processing packages ...
Piecewise convolution rules have been loaded.
The one-dimensional analog filter design objects are\
 
  loaded.
Supporting routines and objects for the Laplace transform\
 
  are loaded.
The forward Laplace transform rule base LaPlace has been\
 
  loaded.
The inverse Laplace transform rule base InvLaPlace has been\
 
  loaded.
The continuous Fourier transform (CTFT) functions are\
 
  loaded.
LSolve, a differential equation solver, is loaded.
The analog signal analyzer is now loaded.
 
The analog signal processing extensions has been loaded.
Good starting points are the objects ASPAnalyze and\
 
  LaPlace.
Active packages are maintained in the variable\
 
  $ContextPath.
  New signal primitives are in SPsignals.
  New system primitives are in SPoperators.
  New Mathematica functions are in SPfunctions.
Note that all signal processing expressions will
be automatically simplified.
 
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically loaded
    (the signal processing packages no longer rely on the
    definitions in these files).
:[font = message; inactive; ]
Digital::loaded: 
   Routines, objects, and rules for the digital signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically loaded
    (the signal processing packages no longer rely on the
    definitions in these files).
:[font = message; inactive; endGroup; endGroup; ]
Analog::loaded: 
   Routines, objects, and rules for the analog signal
    processing package have been loaded successfully.
:[font = section; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; ]
 		Several symbolic mathematical programs have recently become available on a wide variety of machines.  This paper discusses the use of one such environment, Mathematica, to supplement signal processing lectures and laboratories.  One attraction to using Mathematica in an educational setting is its notebook facility [1].  Not only can instructors write highly interactive tutorials in the notebook format, but students can use notebooks to solve homework problems in a self-documenting fashion.  Notebooks (a form of hypertext) arrange formatted text, graphs, and Mathematica code in a hierarchy of cells.  Students can discover insights at their own pace because they can access material randomly and ask for more information on a subject [2].  Most important, though, is the ability to evaluate and tweak existing code, as well as to write, edit, and run new code, all while perusing a notebook.
:[font = text; inactive; ]
		Since Mathematica is primarily a ``system for doing mathematics by computer'' [1], its knowledge of operations and structures common to signal processing is limited.  Therefore, we have developed new packages that enable Mathematica to understand signals, operators, and transforms [3,4].  These signal processing packages contain rule bases that symbolically compute convolutions and all the transforms common to signal processing:  Fourier, Laplace, z, DFT, etc.  The transforms can fully justify their answers so that students can view each step of the transformation process.
:[font = text; inactive; endGroup; ]
 		Accompanying these signal processing packages are several notebooks.  One summarizes all of the new definitions, and another provides a brief overview of the new capabilities.  A third notebook is this paper itself.  The remaining notebooks are tutorials discussing piecewise convolution, analog filter design, the z-transform, and the Laplace transform.  We discuss all four tutorial notebooks in the sections following the introduction to Mathematica and the overview of the signal processing packages.
:[font = section; inactive; startGroup; Cclosed; ]
Mathematica
:[font = text; inactive; ]
		The Mathematica environment consists of two distinct pieces: a front-end user interface and a back-end kernel [1].  On a Macintosh and a NeXT machine, the front-end interface is none other than the notebook format mentioned in the introduction.  Notebooks use the machine's windowing system and rely on a mouse to select menu options (keyboard short-cuts are also supported).  Notebooks also provide on-line help in the form of text mixed with useful examples, although the kernel does provide its own simple help facility.  For example,
:[font = input; startGroup; ]
?*Transform
:[font = info; inactive; endGroup; ]
CTFTransform       InvDFTransform     MultiDInvTransform
DFTransform        InvDTFTransform    MultiDTransform
DTFTransform       InvLaPlace         Transform
FilterTransform    InvZTransform      ZTransform
InvCTFTransform    LaPlace
:[font = text; inactive; ]
will return the names of all symbolic transforms in the signal processing packages,
:[font = input; startGroup; ]
?ZTransform
:[font = info; inactive; endGroup; ]
ZTransform[e,n] or ZTransform[e,n,z] gives the z-transform
   of the expression e, which is a function of n, by
   returning an object of three slots which is tagged by
   ZTransData:  <z-transform>, <rminus>, <rplus>, and
   <z-variables>.  The Region of Convergence (ROC) is
   <rminus> < |z| < <rplus>.  Note that the returned ROC is
   either the actual ROC or a subset of the actual ROC. In
   two dimensions, ZTransform[e, {n1, n2}, {z1, z2}], is the
   same as ZTransform [ ZTransform [e, n1, z1], n2, z2 ]. 
   This notation extends naturally to higher dimensions.
:[font = text; inactive; ]
explains how to call the forward z-transform rule base properly, and
:[font = input; startGroup; ]
Options[ZTransform]
:[font = output; inactive; output; endGroup; ]
{Dialogue -> True}
;[o]
{Dialogue -> True}
:[font = text; inactive; ]
lists the default options for an object (routine).  On other machines, the front-end is nothing more than a line-by-line interface to the kernel, although notebook readers are available for these machines [2].  It is the kernel that crunches numbers, manipulates symbols, and generates graphics, but it is the front-end that displays answers and renders graphics.
:[font = text; inactive; ]
		The Mathematica kernel supports many programming paradigms, including procedural programming (like Fortran) and functional programming (like APL).  Mathematica even has its own version of object-oriented (like C++) and data-directed (like Lisp) programming.  These styles are certainly useful for implementing functions and operators common to signal processing, but we still need a convenient way to take transforms.  To this end, Mathematica provides a style of logic programming similar to Prolog and a powerful pattern matcher [5].
:[font = text; inactive; ]
		The key to the generality of the pattern matcher is that all data, functions, and expressions are represented in the same format--- as objects.  Each object contains a head, which serves as the object's tag and data type, and a collection of other objects.  For example, a list of the elements 1, a, 2.0, and c + d x would be represented as
:[font = input; ]
List[1, a, 2.0, c + d x]
:[font = text; inactive; endGroup; ]
		The Mathematica kernel, of course, possesses much inherent knowledge about mathematical structures and operations.  It supports integer, rational, real, imaginary, and complex numeric data types, maintaining rational numbers and integers to an exact number of digits and representing floating point numbers to an arbitrary number of digits.  Besides addition, subtraction, multiplication, division, and exponentiation, Mathematica provides over 150 mathematical operators and functions.  For example, it can recognize, rearrange, factor, decompose, add, subtract, multiply, and divide polynomials.  In the signal processing packages, the transform rule bases rely on many of Mathematica's inherent abilities, especially the symbolic operations of partial fractions decomposition, series expansion, integration, and differentiation.
:[font = section; inactive; startGroup; Cclosed; ]
Signal Processing Extensions
:[font = text; inactive; ]
		Mathematica provides many of computational functions common to linear systems and signal processing--  exponentials, sinusoids, Bessel functions, etc.  This environment, however, is missing functions that are basic components of signals, like step and impulse functions.  The signal processing packages introduce the continuous and discrete functions shown below in Table 1.  These new signal primitives are maintained the list SPsignals:
:[font = input; startGroup; ]
SPsignals
:[font = output; inactive; output; endGroup; ]
{"ASinc", "AliasSinc", CPulse, CStep, Delta, 
  Dirichlet, FIR, IIR, Impulse, LineImpulse, 
  Pulse, Sinc, Step, Unit}
;[o]
{ASinc, AliasSinc, CPulse, CStep, Delta, 
 
  Dirichlet, FIR, IIR, Impulse, LineImpulse, 
 
  Pulse, Sinc, Step, Unit}
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Table 1:   New Computational Functions
:[font = output; inactive; ]
ASinc        Dirichlet discrete kernel
AliasSinc    Dirichlet discrete kernel
CPulse       continuous pulse         
CStep        continuous step
Delta        Dirac delta
Dirichlet    Dirichlet discrete kernel
FIR          finite impulse response
IIR          infinite impulse response
Impulse      Kronecker delta
Pulse        discrete pulse
Sinc         Sine x over x
Step         discrete step
Unit[k]      order-continuous unit function
:[font = text; inactive; locked; startGroup; Cclosed; ]
( MORE INFORMATION )
:[font = info; inactive; locked; ]
CFIR[t, {h0, h1, h2, ...}] represents the finite impulse
   response of an all-zero analog filter.  Input to the
   filter is specified as FIR[t, h] [ x[t] ], where x[t] is
   some symbolic signal processing expression.  For the
   generalized N-dimensional FIR structure, the argument t
   becomes a list of indices (like {t1, t2} for N=2) and
   the feedback coefficients are in an N x N matrix.
:[font = info; inactive; locked; ]
CIIR[t, {a0, a1, a2, ...}] represents the infinite impulse
   response of an all-pole analog filter with gain 1, where
   a1, a2, ..., are the feedback coefficients and a0 is the
   scaling factor of the output. By default, the input to
   the filter structure is a Dirac delta function. An
   alternate input h can be specified by the code CIIR[t,
   {a0, a1, a2, ...}][h]. For the generalized N-dimensional
   IIR structure, the argument t becomes a list of indices
   (like {t1, t2} for N=2) and the feedback coefficients
   are specified by an N x N matrix.
:[font = info; inactive; locked; ]
CPulse[l,t] defines a pulse which begins at t=0 and ends at
    t = l.  The CPulse has value 1 within the range (0,l),
   0 outside this range, and 1/2 at the points t=0 and t=l.
   A continuous-pulse center at the origin is written as
   CPulse[l, t + l/2] or Shift[-l/2, t][CPulse[l, t]].
:[font = info; inactive; locked; ]
CStep[t], a.k.a. Unit[-1][t], is the unit step function
   which is 1 for t > 0, 0 for t < 0, and 1/2 at t = 0. It
   is commonly used for continuous expressions t. See also
   Step and Unit.
:[font = info; inactive; locked; ]
Delta[expr] is the Dirac delta function.  The area under
   this functions is 1 but it only has value at the origin.
   That is, Integrate[ Delta[t] g[t], {t, t1, t2} ] is g[0]
   if t1 <= 0 <= t2, 0 otherwise.  It differs from the
   Kronecker  delta function Impulse[t].
:[font = info; inactive; locked; ]
Dirichlet[N, w] is the aliased sinc function.  Its
   magnitude is of the form Sin[N w / 2] / ( N Sin [w / 2]
   ).
:[font = info; inactive; locked; ]
FIR[n, {h0, h1, h2, ...}] represents the finite impulse
   response of an all-zero digital filter.  As a function
   of n, the response is actually equal to h0, h1, h2, ...,
   for n = 0, 1, 2, ....  Note that FIR[n, 2] will be
   simplified to 2 Impulse[n].  FIR can also represent an
   all-zero filter.  In this case, the input x[n] to the
   filter is specified as FIR[n, h] [ x[n] ], where x[n] is
   some symbolic signal processing expression.  For the
   generalized N-dimensional FIR structure, the argument n
   becomes a list of indices (like {n1, n2} for N=2) and
   the feedback coefficients are in an N x N matrix.
:[font = info; inactive; locked; ]
IIR[n, {a0, a1, a2, ...}] represents the infinite impulse
   response of an all-pole filter with gain 1, where a1,
   a2, ..., are the feedback coefficients and a0 is the
   scaling factor of the output. In discrete time, the
   output of IIR is the solution to y[n] in the difference
   equation  a0 y[n] + a1 y[n-1] + ... + aN y[n - N] =
   impulse[n],  with y[n] = 0 for n < 0. By default, the
   input into the filter (a.k.a. the forcing function) is
   an impulse.  An alternate input h can be specified by
   the code IIR[n, {a0, a1, a2, ...}][h]. For the
   generalized N-dimensional IIR structure, the argument n
   becomes a list of indices (like {n1, n2} for N=2) and
   the feedback coefficients are specified by an N x N
   matrix.
:[font = info; inactive; locked; ]
Impulse[t] is the unit Kronecker Delta function.  At t = 0,
   the function evaluates to 1.  Elsewhere, it evaluates to
   0.
:[font = info; inactive; locked; ]
Sinc[t] is the unit sinc function which is the ratio of
   Sin[t] over t.  Note that Sinc[0] = 1.
:[font = info; inactive; locked; ]
Step[n] is the unit step function which is 1 for n >= 0 and
   0 otherwise.  It is commonly used for discrete n. This
   function differs from CStep only at the origin.
:[font = info; inactive; locked; endGroup; endGroup; ]
Unit[n][t] is the nth order continuous unit function in t.
   Unit[0][t] is the Dirac delta function (see Delta).
   Unit[-1][t] is the continuous step function (see CStep).
:[font = subsection; inactive; startGroup; Cclosed; ]
New Operators
:[font = text; inactive; ]
		The signal processing packages also introduce common signal processing operators, such as reverse and summation [4].  When one of these operators is applied to a function, no evaluation takes place immediately.  Instead, the operation is represented symbolically, until it becomes convenient to compute it explicitly.  By deferring evaluation of operators, certain obvious simplifications can be carried out
:[font = input; startGroup; ]
InvZ[z,n][ Z[n,z][ f[n] ] ]
:[font = output; endGroup; ]
f[n]
:[font = text; inactive; ]
and code can be generated for the original operation (e.g., the equivalent TeX code).  The user can force an evaluation by applying to the expression, much as a numerical evaluation in Mathematica is triggered by the action of.  Thus, represents the z-transform of, but the transformation is not carried out.
:[font = text; inactive; ]
		The new signal processing operators are maintained in SPoperators:
:[font = input; startGroup; ]
SPoperators
:[font = output; inactive; output; endGroup; ]
{Aliasby, CConvolve, Convolve, DFT, DTFT, 
  Difference, Downsample, FIR, FT, IIR, 
  Interleave, InvDFT, InvDTFT, InvFT, InvL, 
  InvZ, L, Periodic, PolyphaseDownsample, 
  PolyphaseUpsample, Rev, ScaleAxis, Shift, 
  Summation, Upsample, Z}
;[o]
{Aliasby, CConvolve, Convolve, DFT, DTFT, 
 
  Difference, Downsample, FIR, FT, IIR, 
 
  Interleave, InvDFT, InvDTFT, InvFT, InvL, 
 
  InvZ, L, Periodic, PolyphaseDownsample, 
 
  PolyphaseUpsample, Rev, ScaleAxis, Shift, 
 
  Summation, Upsample, Z}
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Table 2: New Operators
:[font = special2; inactive; startGroup; Cclosed; ]
( More Information on Operators )
:[font = info; inactive; locked; ]
Aliasby[m,w][x] represents the aliasing of x,
   a continuous-frequency signal, by
   replicating it every (2 Pi / m) in w and
   dividing the result by m.
:[font = info; inactive; locked; ]
CConvolve[t][x1, x2, ...] represents the
   continuous convolution in t of functions
   x1, x2, .... CConvolve[{t1, t2, ...}][x1,
   x2, ...] represents the multidimensional 
   continuous convolution in t1, t2, ... of
   functions x1, x2, ...
:[font = info; inactive; locked; ]
Convolve[n][x1, x2, ...] represents the
   discrete convolution in n of functions x1,
   x2, .... Convolve[{n1, n2, ...}][x1, x2,
   ...] represents the multidimensional 
   discrete convolution in n1, n2, ... of
   functions x1, x2, ...
:[font = info; inactive; locked; ]
DFT[L, n, k] is the forward discrete Fourier
   transform operator. Here, L is the DFT
   length(s), n is the time-domain
   variable(s), and k is the frequency-domain
   variable(s). Multidimensional DFT's are
   supported. Applying TheFunction to the DFT
   operator will invoke the DFT rule base
   (object DFTransform) if loaded.
:[font = info; inactive; locked; ]
DTFT[n, w] is the forward discrete-time
   Fourier transform operator. Here, n is the
   time-domain variable(s), and w is the
   frequency-domain variable(s).
   Multidimensional DTFT's are supported.
   Applying TheFunction to the DTFT operator
   will invoke the DTFT rule base DTFTransform
   if loaded.
:[font = info; inactive; locked; ]
Difference[k,n] represents the k-th backward
   difference with respect to the variable n.
   The first-order difference of f equals f[n]
   - f[n-1], the second-order difference is
   f[n] - 2 f[n-1] + f[n-2], and so on.
   Applying this operator to the sequence x[n]
   would be written as Difference[k,n][x[n]].
:[font = info; inactive; locked; ]
Downsample[m,n] represents the downsampling
   operator. Downsampling resamples a function
   at the points n = 0, m, 2m, 3m, ... In N
   dimensions, n is a list of N indices and m
   is an N x N matrix. Applying TheFunction to
   f[n] which is downsampled in one dimension,
   (written as Downsample[m, n][ f[n] ]) will
   produce f[m n].
:[font = info; inactive; locked; ]
FIR[n, {h0, h1, h2, ...}] represents the
   finite impulse response of an all-zero
   digital filter. As a function of n, the
   response is actually equal to h0, h1, h2,
   ..., for n = 0, 1, 2, ....  Note that
   FIR[n, 2] will be simplified to 2
   Impulse[n]. FIR can also represent an
   all-zero filter. In this case, the input
   x[n] to the filter is specified as  FIR[n,
   h] [ x[n] ], where x[n] is some symbolic
   signal processing expression. For the
   generalized N-dimensional FIR structure,
   the argument n becomes a list of indices
   (like {n1, n2} for N=2) and the feedback
   coefficients are in an N x N matrix.
:[font = info; inactive; locked; ]
FT[t, w] is the forward continuous Fourier
   transform operator. Here, t is the
   time-domain variable(s) and w is the
   frequency-domain variable(s). Applying
   TheFunction to this operator will cause the
   invocation of the continuous-time Fourier
   transform rule base (object CTFTransform)
   if loaded.
:[font = info; inactive; locked; ]
IIR[n, {a0, a1, a2, ...}] represents the
   infinite impulse response of an all-pole
   filter with gain 1, where a1, a2, ..., are
   the feedback coefficients and a0 is the
   scaling factor of the output. In discrete
   time, the output of IIR is the solution to
   y[n] in the difference equation  a0 y[n] +
   a1 y[n-1] + ... + aN y[n - N] = impulse[n],
    with y[n] = 0 for n < 0. By default, the
   input into the filter (a.k.a. the forcing
   function) is an impulse. An alternate input
   h can be specified by the code IIR[n, {a0,
   a1, a2, ...}][h]. For the generalized
   N-dimensional IIR structure, the argument n
   becomes a list of indices (like {n1, n2}
   for N=2) and the feedback coefficients are
   specified by an N x N matrix.
:[font = info; inactive; locked; ]
Interleave[n][x0, x1, ...] interleaves samples
   of signals x0, x1, ..., which are functions
   of n. This is only applicable to discrete
   signals.
:[font = info; inactive; locked; ]
InvDFT[L, k, n] is the inverse discrete
   Fourier transform operator. Here, L is the
   DFT length(s), n is the time-domain
   variable(s), and k is the frequency-domain
   variable(s). Multidimensional inverse DFT's
   are supported. Applying TheFunction to the
   InvDFT operator will invoke the inverse DFT
   rule base (object InvDFTransform) if
   loaded.
:[font = info; inactive; locked; ]
InvDTFT[w, n] is the inverse discrete-time
   Fourier transform operator. Here, n is the
   time-domain variable(s), and w is the
   frequency-domain variable(s).
   Multidimensional inverse DTFT's are
   supported. Applying TheFunction to the
   InvDTFT operator will invoke the inverse
   DTFT rule base InvDTFTransform if loaded.
:[font = info; inactive; locked; ]
InvL[s, t] is the inverse Laplace transform
   operator. Applying TheFunction to the InvL
   operator will invoke the bilateral inverse
   Laplace transform rule base InvLaPlace if
   loaded.
:[font = info; inactive; locked; ]
InvZ[z, n] is the inverse z-transform
   operator. Applying TheFunction to the InvZ
   operator will invoke the inverse
   z-transform rule base ZTransform if loaded.
:[font = info; inactive; locked; ]
L[t, s] is the forward Laplace transform
   operator. Applying TheFunction to the L
   operator will invoke the forward bilateral
   Laplace rule base LaPlace if loaded.
:[font = info; inactive; locked; ]
Periodic[k,n][f] indicates that f is a
   function of n which is periodic with period
   of k.
:[font = info; inactive; locked; ]
PolyphaseDownsample[m, n][x, h] is
   equivalent to downsampling x by m and then
   convolving the result with h.
:[font = info; inactive; locked; ]
PolyphaseUpsample[l, n][x, h] is
   equivalent to upsampling x by l and then
   convolving the result with h.
:[font = info; inactive; locked; ]
Rev[n][x] represents the operation of
   reversing the direction of x, with respect
   to the variables(s) n.
:[font = info; inactive; locked; ]
ScaleAxis[l,w][x] represents the compression
   by a factor of l (an integer) of the
   continuous w axis of x, which is usually a
   continuous-frequency signal.
:[font = info; inactive; locked; ]
Shift[m,v][x] represents the shifting of the
   expression x by m samples to the right in
   the v direction, i.e. x[v] --> x[v - m].
:[font = info; inactive; locked; ]
Summation[i][f], Summation[i, iend][f], and
   Summation[i, istart, iend, inc][f]
   represents the summation of f with respect
   to variable i:  i = (istart) to (iend) step
   (inc). The Summation operator is an
   abstraction of Mathematica's Sum object.
   Applying the object TheFunction to a
   Summation operator will invoke the Sum
   object if istart, iend, and inc are
   numbers.
:[font = info; inactive; locked; ]
Upsample[k,n][f] represents the upsampling
   operation on f, which is either an
   expression of n or a sequence (list) of
   values. Upsampling inserts k-1 zeroes
   between every two samples. In N dimensions,
   n is a list of N indices and k is an N x N
   matrix.
:[font = info; inactive; locked; endGroup; endGroup; endGroup; ]
Z[n, z] is the forward z-transform operator.
   Applying TheFunction to the Z operator will
   invoke the z-transform rule base (object
   ZTransform) if loaded.
:[font = subsection; inactive; startGroup; Cclosed; ]
Mixing Systems (Operators) and Signals (Functions)
:[font = text; inactive; startGroup; ]
		An example of combining signals and systems is
:[font = input; ]
Downsample[2, n] [ IIR [n, {5/2, 3/4, 1/8}] ]
:[font = text; inactive; ]
This expression represents the downsampling by 2 of h[n], the impulse response of an all-pole digital IIR filter with gain 5/2 and feedback coefficients -3/4 and -1/8.   In this case,  h[n] = 5/2 delta[n] + 3/4 h[n-1] + 1/8 h[n-2],  with h[-1] = h[-2] = 0.  As Mathematica code, h[n] could be defined using three rules:
:[font = input; ]
h[-1] := 0;
h[-2] := 1;
h[n_] :=
	5/2 Impulse[n] + 3/4 h[n-1] + 1/8 h[n-2]
:[font = text; inactive; ]
The values of h[n] can be cached as they are computed by altering the last line to
:[font = input; endGroup; endGroup; endGroup; ]
h[n_] := h[n] =
	5/2 Impulse[n] + 3/4 h[n-1] + 1/8 h[n-2]
:[font = section; inactive; startGroup; Cclosed; ]
Piecewise Convolution
:[font = text; inactive; ]
		The linear convolution of two functions f(t) and g(t) is defined as:
:[font = postscript; inactive; PostScript; locked; output; height = 94; pictureLeft = 46; pictureWidth = 287; pictureHeight = 287; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.583333 0.0833333 0.833333 0.0833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
gsave
0.0075 setlinewidth
0.29167 0.925 moveto
0.27917 0.91667 lineto
0.27083 0.9 lineto
0.27083 0.76667 lineto
0.2625 0.75 lineto
0.25 0.74167 lineto
stroke
gsave
/Plain findfont 14 scalefont setfont
[(y\(t\))] 0.04167 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(=)] 0.16667 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.33333 0.925 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.35 0.925 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.325 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.34167 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(-)] 0.29167 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(x\(u\) h\(t - u\) du)] 0.35417 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(\(1\))] 0.91667 0.83333 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]
 Here, f(t) and g(t) are piecewise-continuous functions.  Piecewise convolution is a time-domain approach that finds the convolution by computing the integral over each interval where the two functions overlap as g(t-u) ``slides'' through f(u).  This is usually the first approach for solving convolution problems that electrical engineers learn.
:[font = text; inactive; ]
		The piecewise convolution notebook shows the student how to use the piecewise convolution package to solve one-dimensional continuous-time convolution problems.  In the introduction, the notebook informs the user that a piecewise function can be represented as a list of intervals.  Each interval is itself a list containing the start of the interval, the end of the interval, and the function defined on that interval.  For example, the function  , a unit triangle defined on  , can be represented as an expression  
:[font = input; ]
(1 + t) CPulse[1, 1 + t] + (1 - t) CPulse[1, t] 
:[font = text; inactive; ]
or in list form as
:[font = input; ]
{{1+t, -1, 0}, {1-t, 0, 1}}
:[font = text; inactive; ]
		The notebook gives several examples of piecewise convolution using the newly defined object PiecewiseConvolution, which requires three arguments--- f(t), g(t), and t.  For example, the Mathematica dialogue
:[font = input; startGroup; ]
PiecewiseConvolution[ Delta[t - t0], f[t], t ]
:[font = output; inactive; output; endGroup; ]
{{f[t - t0], DirectedInfinity[-1], DirectedInfinity[1]}}
;[o]
{{f[t - t0], -Infinity, Infinity}}
:[font = text; inactive; ]
illustrates the shifting property of the Dirac delta function.  In this example, we could have used the piecewise form of Delta[t - a] , which is {Area[1], a, a}. The notebook also gives an example of a convolution that produces an unstable function:  
:[font = input; startGroup; ]
PiecewiseConvolution[ CStep[t], CStep[t], t ]
:[font = message; inactive; startGroup; ]
Integrate::divg: Integral does not converge.
:[font = output; inactive; output; endGroup; endGroup; ]
{{t, 0, DirectedInfinity[1]}}
;[o]
{{t, 0, Infinity}}
:[font = text; inactive; endGroup; ]
Part of computing a piecewise convolution requires identifying the overlapping intervals by drawing pictures of g(t-u) and f(u).  So, for two simple functions, the notebook shows an animation of g(t-u) sliding through f(u).  Each frame shows an important interval over which to integrate, and the reader can control the frame rate.
:[font = section; inactive; startGroup; Cclosed; ]
The Laplace Transform
:[font = text; inactive; ]
		The more common approach to solving convolution problems utilizes transform theory, so the signal processing packages implement bilateral Laplace and Fourier transforms.  The rule bases LaPlace and InvLaPlace implement the bilateral Laplace transform F(s) of a continuous-time function f(t):  [6]
:[font = postscript; inactive; PostScript; locked; output; height = 94; pictureLeft = 62; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.541667 0.0833333 0.833333 0.0833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
gsave
0.0075 setlinewidth
0.375 0.925 moveto
0.3625 0.91667 lineto
0.35417 0.9 lineto
0.35417 0.76667 lineto
0.34583 0.75 lineto
0.33333 0.74167 lineto
stroke
gsave
/Plain findfont 14 scalefont setfont
[(L{f\(t\)} =)] 0.29167 0.83333 1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.41667 0.925 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.43333 0.925 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.40833 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.425 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(-)] 0.375 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(f\(t\))] 0.45833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(e)] 0.58333 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(dt)] 0.70833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(-st)] 0.625 0.875 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(\(1\))] 0.875 0.83333 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; locked; output; height = 94; pictureLeft = 71; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.583333 0.0833333 0.833333 0.0833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
gsave
0.0075 setlinewidth
0.41667 0.925 moveto
0.40417 0.91667 lineto
0.39583 0.9 lineto
0.39583 0.76667 lineto
0.3875 0.75 lineto
0.375 0.74167 lineto
stroke
newpath
0.39583 0.83333 0.01667 0 365.73 arc
stroke
gsave
/Plain findfont 14 scalefont setfont
[(L)] 0 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[({F\(s\)})] 0.08333 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(=)] 0.275 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(-1)] 0.03333 0.88333 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.49167 0.95833 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(a+jo)] 0.5 0.95833 1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.425 0.70833 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(a-jo)] 0.43333 0.70833 1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(F\(s\))] 0.47917 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(e)] 0.60833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(ds)] 0.70833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(st)] 0.65 0.875 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(\(2\))] 0.91667 0.83333 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]
(Note that (2) is actually a contour integral.)  The forward transform tracks the region of convergence (ROC), which is a strip along the real s-axis.  The inverse transform uses ROC information to determine the corresponding time function.  In the inverse transform, the contour of integration includes the section of the s-plane whose real components are bounded by the constant a, i.e., either Re(s) < a or Re(s) > a.
:[font = text; inactive; ]
		The Laplace transform notebook states the definition and properties of the bilateral Laplace transform.  It discusses strategies for finding forward and inverse transforms and tests over 100 transforms.  The notebook also shows how to use the Laplace transform to solve linear constant coefficient differential equations with initial conditions.  The last section of the notebook demonstrates how to use the Laplace transform in analysis of signals using Stable and ASPAnalyze.  For example, exp(a t) u(t) is stable if the real part of is negative, as shown by the following Mathematica dialogue (note that means the output of the previous command):  
:[font = input; startGroup; ]
LaPlace[ Exp[a t] CStep[t], t]
:[font = output; inactive; output; endGroup; ]
LTransData[(-a + s)^(-1), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[Re[a]], Rplus[Infinity], 
           -a + s
 
  LVariables[s]]
:[font = input; startGroup; ]
Stable[%]
:[font = output; inactive; output; endGroup; ]
Re[a] < 0
;[o]
Re[a] < 0
:[font = text; inactive; ]
The general analysis of a 1-D or 2-D time domain expression consists of graphing the time-domain function, finding the function's Laplace transform and displaying its poles and zeroes, checking for stability, and computing the Fourier transform and plotting the frequency response.   Figure 1 shows the general analysis of the function t exp(- a t) cos(3 pi t / 16) u(t), one of the two ASPAnalyze examples in the notebook (the second involves a sum of Dirac delta functions).  This functions depends on the time variable t and the free parameter a.  Whenever a time-domain expression is a function of free parameters, ASPAnalyze will manipulate the entire expression including the free parameters and temporarily assign a numeric value of to the free parameters only when generating a graph.  The user can specify the numeric value (default is 1 for each free parameter) by specifying options to ASPAnalyze--  in this case, one of the form a -> value:
:[font = input; ]
ASPAnalyze[t Exp[- a t] Cos[3 Pi t / 16] CStep[t],
			t, 0, 10, a -> 2 ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Figure 1:  Analog Signal Analysis
:[font = input; startGroup; ]
ASPAnalyze[t Exp[-a t] Cos[3 Pi t/16] CStep[t],
           t, 0, 10 ]
:[font = print; inactive; startGroup; ]
For plotting only, these symbols will
be assigned a value of 1: {a}
:[font = print; inactive; ]
Real part of the function is shown as solid
  lines.
Imaginary part of the function is shown as
  dashed lines.
:[font = postscript; inactive; PostScript; output; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.09524 0.09775 1.57759 [
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(2)] 0.21429 0.08525 0 1 Msboxa
[(4)] 0.40476 0.08525 0 1 Msboxa
[(6)] 0.59524 0.08525 0 1 Msboxa
[(8)] 0.78571 0.08525 0 1 Msboxa
[(10)] 0.97619 0.08525 0 1 Msboxa
[(t)] 1.00625 0.09775 -1 0 Msboxa
[(-0.05)] 0.01131 0.01887 1 0 Msboxa
[(0.05)] 0.01131 0.17663 1 0 Msboxa
[(0.1)] 0.01131 0.2555 1 0 Msboxa
[(0.15)] 0.01131 0.33438 1 0 Msboxa
[(0.2)] 0.01131 0.41326 1 0 Msboxa
[(0.25)] 0.01131 0.49214 1 0 Msboxa
[(0.3)] 0.01131 0.57102 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.09775 moveto
1 0.09775 lineto
stroke
0.21429 0.0915 moveto
0.21429 0.104 lineto
stroke
0 setgray
[(2)] 0.21429 0.08525 0 1 Mshowa
0.40476 0.0915 moveto
0.40476 0.104 lineto
stroke
0 setgray
[(4)] 0.40476 0.08525 0 1 Mshowa
0.59524 0.0915 moveto
0.59524 0.104 lineto
stroke
0 setgray
[(6)] 0.59524 0.08525 0 1 Mshowa
0.78571 0.0915 moveto
0.78571 0.104 lineto
stroke
0 setgray
[(8)] 0.78571 0.08525 0 1 Mshowa
0.97619 0.0915 moveto
0.97619 0.104 lineto
stroke
0 setgray
[(10)] 0.97619 0.08525 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.09775 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.01887 moveto
0.03006 0.01887 lineto
stroke
0 setgray
[(-0.05)] 0.01131 0.01887 1 0 Mshowa
0.01756 0.17663 moveto
0.03006 0.17663 lineto
stroke
0 setgray
[(0.05)] 0.01131 0.17663 1 0 Mshowa
0.01756 0.2555 moveto
0.03006 0.2555 lineto
stroke
0 setgray
[(0.1)] 0.01131 0.2555 1 0 Mshowa
0.01756 0.33438 moveto
0.03006 0.33438 lineto
stroke
0 setgray
[(0.15)] 0.01131 0.33438 1 0 Mshowa
0.01756 0.41326 moveto
0.03006 0.41326 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.41326 1 0 Mshowa
0.01756 0.49214 moveto
0.03006 0.49214 lineto
stroke
0 setgray
[(0.25)] 0.01131 0.49214 1 0 Mshowa
0.01756 0.57102 moveto
0.03006 0.57102 lineto
stroke
0 setgray
[(0.3)] 0.01131 0.57102 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.09775 moveto
0.03373 0.24554 lineto
0.04365 0.36259 lineto
0.05357 0.45234 lineto
0.05853 0.48801 lineto
0.06349 0.5181 lineto
0.06845 0.54298 lineto
0.07341 0.56304 lineto
0.07837 0.57865 lineto
0.08333 0.59015 lineto
0.08581 0.59446 lineto
0.08829 0.59788 lineto
0.09077 0.60043 lineto
0.09201 0.6014 lineto
0.09325 0.60217 lineto
0.09449 0.60274 lineto
0.09573 0.60312 lineto
0.09697 0.60331 lineto
0.09821 0.60332 lineto
0.09945 0.60315 lineto
0.10069 0.60281 lineto
0.10193 0.6023 lineto
0.10317 0.60163 lineto
0.10565 0.59981 lineto
0.10813 0.59738 lineto
0.1131 0.59084 lineto
0.11806 0.58224 lineto
0.12302 0.57184 lineto
0.14286 0.51637 lineto
0.18254 0.37365 lineto
0.22222 0.23561 lineto
0.2619 0.12948 lineto
0.28175 0.09076 lineto
0.30159 0.06121 lineto
0.32143 0.03997 lineto
0.33135 0.03213 lineto
0.34127 0.02596 lineto
0.35119 0.02129 lineto
0.35615 0.01947 lineto
0.36111 0.01798 lineto
0.36607 0.01679 lineto
0.36855 0.0163 lineto
0.37103 0.01588 lineto
0.37351 0.01553 lineto
0.37599 0.01525 lineto
0.37847 0.01503 lineto
0.38095 0.01487 lineto
0.38219 0.01481 lineto
0.38343 0.01476 lineto
0.38467 0.01473 lineto
Mistroke
0.38591 0.01472 lineto
0.38715 0.01472 lineto
0.38839 0.01473 lineto
0.38963 0.01475 lineto
0.39087 0.01479 lineto
0.39211 0.01484 lineto
0.39335 0.0149 lineto
0.39583 0.01506 lineto
0.39831 0.01527 lineto
0.40079 0.01552 lineto
0.41071 0.01695 lineto
0.42063 0.01897 lineto
0.44048 0.02434 lineto
0.46032 0.03094 lineto
0.5 0.04562 lineto
0.53968 0.05983 lineto
0.57937 0.07196 lineto
0.61905 0.08142 lineto
0.63889 0.08516 lineto
0.65873 0.08828 lineto
0.67857 0.09085 lineto
0.69841 0.09293 lineto
0.71825 0.09457 lineto
0.7381 0.09585 lineto
0.75794 0.09681 lineto
0.77778 0.09752 lineto
0.79762 0.09802 lineto
0.80754 0.09821 lineto
0.81746 0.09836 lineto
0.82738 0.09848 lineto
0.8373 0.09857 lineto
0.84226 0.09861 lineto
0.84722 0.09864 lineto
0.85218 0.09866 lineto
0.85714 0.09868 lineto
0.8621 0.0987 lineto
0.86458 0.0987 lineto
0.86706 0.09871 lineto
0.86954 0.09871 lineto
0.87202 0.09871 lineto
0.87326 0.09872 lineto
0.8745 0.09872 lineto
0.87574 0.09872 lineto
0.87698 0.09872 lineto
0.87822 0.09872 lineto
0.87946 0.09872 lineto
0.8807 0.09872 lineto
0.88194 0.09872 lineto
0.88318 0.09872 lineto
0.88442 0.09872 lineto
Mistroke
0.8869 0.09872 lineto
0.88814 0.09872 lineto
0.88938 0.09871 lineto
0.89187 0.09871 lineto
0.89683 0.0987 lineto
0.90179 0.09869 lineto
0.90675 0.09868 lineto
0.91667 0.09865 lineto
0.93651 0.09858 lineto
0.97619 0.09841 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.02381 0.09775 moveto
0.06349 0.09775 lineto
0.10317 0.09775 lineto
0.14286 0.09775 lineto
0.18254 0.09775 lineto
0.22222 0.09775 lineto
0.2619 0.09775 lineto
0.30159 0.09775 lineto
0.34127 0.09775 lineto
0.38095 0.09775 lineto
0.42063 0.09775 lineto
0.46032 0.09775 lineto
0.5 0.09775 lineto
0.53968 0.09775 lineto
0.57937 0.09775 lineto
0.61905 0.09775 lineto
0.65873 0.09775 lineto
0.69841 0.09775 lineto
0.7381 0.09775 lineto
0.77778 0.09775 lineto
0.81746 0.09775 lineto
0.85714 0.09775 lineto
0.89683 0.09775 lineto
0.93651 0.09775 lineto
0.97619 0.09775 lineto
stroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
               3 Pi t
t CStep[t] Cos[------]
                 16
----------------------
          a t
         E
:[font = print; inactive; ]
has the following Laplace transform:
:[font = print; inactive; ]
                2
      -2 (a + s)               1
-(------------------- + ----------------)
       2                    2
   9 Pi           2 2   9 Pi           2
  (----- + (a + s) )    ----- + (a + s)
    256                  256
:[font = print; inactive; ]
The strip of convergence is:
:[font = print; inactive; ]
-Re[a] < Re(s) < Infinity
:[font = print; inactive; ]
The system is stable if Re[a] > 0
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {-1.58905, -0.410951}
:[font = print; inactive; ]
The poles are:   {-1. + 0.589049 I, 
 
   -1. - 0.589049 I, -1. + 0.589049 I, 
 
   -1. - 0.589049 I}
:[font = postscript; inactive; PostScript; output; pictureLeft = 58; pictureWidth = 322; pictureHeight = 198; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
1 0.50345 0.30902 0.41968 [
[(-1.75)] 0.11897 0.29652 0 1 Msboxa
[(-1.5)] 0.24483 0.29652 0 1 Msboxa
[(-1.25)] 0.37069 0.29652 0 1 Msboxa
[(-1)] 0.49655 0.29652 0 1 Msboxa
[(-0.75)] 0.62242 0.29652 0 1 Msboxa
[(-0.5)] 0.74828 0.29652 0 1 Msboxa
[(-0.25)] 0.87414 0.29652 0 1 Msboxa
[(Re s)] 1.00625 0.30902 -1 0 Msboxa
[(-0.6)] 0.9875 0.05721 1 0 Msboxa
[(-0.4)] 0.9875 0.14114 1 0 Msboxa
[(-0.2)] 0.9875 0.22508 1 0 Msboxa
[(0.2)] 0.9875 0.39295 1 0 Msboxa
[(0.4)] 0.9875 0.47689 1 0 Msboxa
[(0.6)] 0.9875 0.56083 1 0 Msboxa
[(Im s)] 1 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.00725 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.11897 0.30277 moveto
0.11897 0.31527 lineto
stroke
0 setgray
[(-1.75)] 0.11897 0.29652 0 1 Mshowa
0.24483 0.30277 moveto
0.24483 0.31527 lineto
stroke
0 setgray
[(-1.5)] 0.24483 0.29652 0 1 Mshowa
0.37069 0.30277 moveto
0.37069 0.31527 lineto
stroke
0 setgray
[(-1.25)] 0.37069 0.29652 0 1 Mshowa
0.49655 0.30277 moveto
0.49655 0.31527 lineto
stroke
0 setgray
[(-1)] 0.49655 0.29652 0 1 Mshowa
0.62242 0.30277 moveto
0.62242 0.31527 lineto
stroke
0 setgray
[(-0.75)] 0.62242 0.29652 0 1 Mshowa
0.74828 0.30277 moveto
0.74828 0.31527 lineto
stroke
0 setgray
[(-0.5)] 0.74828 0.29652 0 1 Mshowa
0.87414 0.30277 moveto
0.87414 0.31527 lineto
stroke
0 setgray
[(-0.25)] 0.87414 0.29652 0 1 Mshowa
0 setgray
[(Re s)] 1.00625 0.30902 -1 0 Mshowa
1 0 moveto
1 0.61803 lineto
stroke
0.99375 0.05721 moveto
1.00625 0.05721 lineto
stroke
0 setgray
[(-0.6)] 0.9875 0.05721 1 0 Mshowa
0.99375 0.14114 moveto
1.00625 0.14114 lineto
stroke
0 setgray
[(-0.4)] 0.9875 0.14114 1 0 Mshowa
0.99375 0.22508 moveto
1.00625 0.22508 lineto
stroke
0 setgray
[(-0.2)] 0.9875 0.22508 1 0 Mshowa
0.99375 0.39295 moveto
1.00625 0.39295 lineto
stroke
0 setgray
[(0.2)] 0.9875 0.39295 1 0 Mshowa
0.99375 0.47689 moveto
1.00625 0.47689 lineto
stroke
0 setgray
[(0.4)] 0.9875 0.47689 1 0 Mshowa
0.99375 0.56083 moveto
1.00625 0.56083 lineto
stroke
0 setgray
[(0.6)] 0.9875 0.56083 1 0 Mshowa
0 setgray
[(Im s)] 1 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
[ 0.05 0.05 ] 0 setdash
0.004 setlinewidth
0.49655 0 moveto
0.49655 0.61803 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
1 0.30902 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.2 0.30902 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.79311 0.30902 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(*X*)] 0.49655 0.0618 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(*X*)] 0.49655 0.55623 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
               3 Pi t
t CStep[t] Cos[------]
                 16
----------------------
          a t
         E
:[font = print; inactive; ]
has the following frequency response:
:[font = print; inactive; ]
                                      2
          1                2 (a + I w)
-(------------------ - ---------------------)
      2                     2
  9 Pi             2    9 Pi             2 2
  ----- + (a + I w)    (----- + (a + I w) )
   256                   256
:[font = postscript; inactive; PostScript; output; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.41202 0.0103 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.39952 0 1 Msboxa
[(-0.7)] 0.16667 0.39952 0 1 Msboxa
[(-0.3)] 0.35714 0.39952 0 1 Msboxa
[(0.3)] 0.64286 0.39952 0 1 Msboxa
[(0.7)] 0.83333 0.39952 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.41202 -1 0 Msboxa
[(-40)] 0.4875 0 1 0 Msboxa
[(-30)] 0.4875 0.10301 1 0 Msboxa
[(-20)] 0.4875 0.20601 1 0 Msboxa
[(-10)] 0.4875 0.30902 1 0 Msboxa
[(10)] 0.4875 0.51503 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.41202 moveto
1 0.41202 lineto
stroke
0.02381 0.40577 moveto
0.02381 0.41827 lineto
stroke
0 setgray
[(-1)] 0.02381 0.39952 0 1 Mshowa
0.16667 0.40577 moveto
0.16667 0.41827 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.39952 0 1 Mshowa
0.35714 0.40577 moveto
0.35714 0.41827 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.39952 0 1 Mshowa
0.64286 0.40577 moveto
0.64286 0.41827 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.39952 0 1 Mshowa
0.83333 0.40577 moveto
0.83333 0.41827 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.39952 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.41202 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-40)] 0.4875 0 1 0 Mshowa
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(-30)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(-20)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(-10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(10)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.3227 moveto
0.36176 0.34868 lineto
0.38158 0.35086 lineto
0.39967 0.35252 lineto
0.40816 0.35314 lineto
0.41631 0.35363 lineto
0.42027 0.35382 lineto
0.42415 0.35398 lineto
0.42796 0.3541 lineto
0.4317 0.35419 lineto
0.43538 0.35425 lineto
0.43899 0.35428 lineto
0.44254 0.35427 lineto
0.44603 0.35423 lineto
0.44946 0.35416 lineto
0.45284 0.35406 lineto
0.45616 0.35392 lineto
0.45943 0.35376 lineto
0.46582 0.35334 lineto
0.47202 0.35281 lineto
0.48388 0.35142 lineto
0.4951 0.34962 lineto
0.50574 0.34746 lineto
0.5255 0.3422 lineto
0.54355 0.33595 lineto
0.56014 0.329 lineto
0.61573 0.29803 lineto
0.6595 0.26726 lineto
0.69561 0.23921 lineto
0.72634 0.21419 lineto
0.75309 0.19187 lineto
0.77677 0.17183 lineto
0.79801 0.15372 lineto
0.81728 0.13721 lineto
0.8349 0.12206 lineto
0.85114 0.10808 lineto
0.86619 0.0951 lineto
0.88023 0.08298 lineto
0.89337 0.07163 lineto
0.90572 0.06096 lineto
0.91738 0.05088 lineto
0.92842 0.04133 lineto
0.9389 0.03227 lineto
0.94887 0.02365 lineto
0.95838 0.01542 lineto
0.96748 0.00755 lineto
0.97619 1e-05 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.60241 0.00349 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.58991 0 1 Msboxa
[(-0.7)] 0.16667 0.58991 0 1 Msboxa
[(-0.3)] 0.35714 0.58991 0 1 Msboxa
[(0.3)] 0.64286 0.58991 0 1 Msboxa
[(0.7)] 0.83333 0.58991 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.60241 -1 0 Msboxa
[(-150)] 0.4875 0.07912 1 0 Msboxa
[(-125)] 0.4875 0.16633 1 0 Msboxa
[(-100)] 0.4875 0.25355 1 0 Msboxa
[(-75)] 0.4875 0.34076 1 0 Msboxa
[(-50)] 0.4875 0.42798 1 0 Msboxa
[(-25)] 0.4875 0.51519 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.60241 moveto
1 0.60241 lineto
stroke
0.02381 0.59616 moveto
0.02381 0.60866 lineto
stroke
0 setgray
[(-1)] 0.02381 0.58991 0 1 Mshowa
0.16667 0.59616 moveto
0.16667 0.60866 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.58991 0 1 Mshowa
0.35714 0.59616 moveto
0.35714 0.60866 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.58991 0 1 Mshowa
0.64286 0.59616 moveto
0.64286 0.60866 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.58991 0 1 Mshowa
0.83333 0.59616 moveto
0.83333 0.60866 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.58991 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.60241 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07912 moveto
0.50625 0.07912 lineto
stroke
0 setgray
[(-150)] 0.4875 0.07912 1 0 Mshowa
0.49375 0.16633 moveto
0.50625 0.16633 lineto
stroke
0 setgray
[(-125)] 0.4875 0.16633 1 0 Mshowa
0.49375 0.25355 moveto
0.50625 0.25355 lineto
stroke
0 setgray
[(-100)] 0.4875 0.25355 1 0 Mshowa
0.49375 0.34076 moveto
0.50625 0.34076 lineto
stroke
0 setgray
[(-75)] 0.4875 0.34076 1 0 Mshowa
0.49375 0.42798 moveto
0.50625 0.42798 lineto
stroke
0 setgray
[(-50)] 0.4875 0.42798 1 0 Mshowa
0.49375 0.51519 moveto
0.50625 0.51519 lineto
stroke
0 setgray
[(-25)] 0.4875 0.51519 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.04888 0.60316 lineto
0.07125 0.6029 lineto
0.09142 0.60254 lineto
0.10981 0.60206 lineto
0.12669 0.60148 lineto
0.14229 0.60077 lineto
0.1568 0.59995 lineto
0.17036 0.59899 lineto
0.19508 0.5967 lineto
0.21715 0.59389 lineto
0.23709 0.59057 lineto
0.25527 0.58674 lineto
0.28746 0.57765 lineto
0.3153 0.56682 lineto
0.33983 0.55449 lineto
0.36176 0.54091 lineto
0.39967 0.51101 lineto
0.4317 0.47893 lineto
0.48388 0.41402 lineto
0.56014 0.30325 lineto
0.61573 0.22676 lineto
0.6595 0.17594 lineto
0.69561 0.14117 lineto
0.72634 0.11633 lineto
0.75309 0.09786 lineto
0.77677 0.08363 lineto
0.79801 0.07235 lineto
0.81728 0.06319 lineto
0.8349 0.05562 lineto
0.85114 0.04924 lineto
0.86619 0.04381 lineto
0.88023 0.03911 lineto
0.89337 0.03502 lineto
0.90572 0.03142 lineto
0.91738 0.02822 lineto
0.92842 0.02537 lineto
0.9389 0.02281 lineto
0.94887 0.02049 lineto
0.95838 0.01839 lineto
0.96748 0.01647 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
LTransData[-((-2*(a + s)^2)/
      ((9*Pi^2)/256 + (a + s)^2)^2 + 
     ((9*Pi^2)/256 + (a + s)^2)^(-1)), 
  Rminus[-Re[a]], Rplus[DirectedInfinity[1]], 
  LVariables[s]]
;[o]
                           2
                 -2 (a + s)
LTransData[-(------------------- + 
                  2
              9 Pi           2 2
             (----- + (a + s) )
               256
 
            1
     ----------------), Rminus[-Re[a]], 
         2
     9 Pi           2
     ----- + (a + s)
      256
 
  Rplus[Infinity], LVariables[s]]
:[font = section; inactive; startGroup; Cclosed; ]
Analog Filter Design
:[font = text; inactive; ]
		Linear filters are certainly the workhorse of signal processing.  The signal processing packages allow a user to design Butterworth, Chebyshev (type I and type II), elliptic, and Bessel filters using the object DesignFilter.  DesignFilter takes seven arguments:  Analog, filter class (Butterworth, ...), filter type (Lowpass, ...), time variable, delta1, delta2, w1, and w2.  For bandpass and bandstop filters, two additional frequencies w3 and w4 are needed.  Frequencies are in rad/sec and given in ascending order  w1 < w2 < w3 < w4 (for a lowpass filter, then, w1 = wp and w2 = ws).  The magnitude response of the passband resides on the interval [1 - delta1, 1] and all stopbands reside on the interval [0, delta2].  DesignFilter returns a time domain expression.  The Laplace and Fourier rule bases can transform such expressions, which means that the pole-zero diagram and frequency response of a filter can be plotted using PoleZeroPlot and MagnitudePhasePlot.
:[font = input; startGroup; Cclosed; ]
?DesignFilter
:[font = info; inactive; endGroup; ]
DesignFilter[domain, class, type, time-variable, deltap,
   deltas, w1, w2, w3, w4] returns a filter expression
   (involving IIR/FIR or CIIR/CFIR filter sections). 
   Domain is either Analog or Digital. Possibilities for
   class include Butterworth, ChebyshevI, ChebyshevII, and
   Elliptic.  Possible filter types are Lowpass, Highpass,
   Bandpass, and Bandstop.  For lowpass filters, the
   magnitude response of the passband resides on [1, 1 -
   deltap] and the magnitude response of the stopband
   occupies [0, deltas]. The last two arguments, w3 and w4,
   are only necessary for bandpass and bandstop filters. 
   Frequencies w1, w2, w3, and w4 are measured in rad/sec
   and should be given in ascending order.
:[font = text; inactive; ]
		 The notebook introduces the topic of filter design and guides the reader through several design examples.  These examples include a lowpass design example for each filter type, as well as a bandpass, bandstop, and highpass design example.  Using animation, the student gets a chance to visualize the changes in the filter's magnitude response as one design parameter varies (three animations are provided---  two for ripple control parameter and one for the filter order which is shown below).  The last section of the notebook examines the effects of precision in implementation--- the student can truncate the coefficients of the filter and observe the frequency response.
:[font = text; inactive; ]
		This animation demonstrates the improvement in transition region and stopband attenuation as the filter length increases.  The sequence of frames consists of magnitude responses of Butterworth filters of order 2 , 3, ... 10:
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04529 0.49443 lineto
0.04772 0.49443 lineto
0.05015 0.49443 lineto
0.05258 0.49443 lineto
0.05501 0.49443 lineto
0.05744 0.49443 lineto
0.0623 0.49443 lineto
0.06473 0.49442 lineto
0.06716 0.49442 lineto
0.07202 0.49442 lineto
0.07688 0.49442 lineto
0.08175 0.49442 lineto
0.08661 0.49441 lineto
0.09147 0.49441 lineto
0.09633 0.4944 lineto
0.10119 0.4944 lineto
0.11091 0.49438 lineto
0.12063 0.49435 lineto
0.13036 0.49432 lineto
0.14008 0.49427 lineto
0.1498 0.49421 lineto
0.15952 0.49413 lineto
0.17897 0.49393 lineto
0.18869 0.49379 lineto
0.19841 0.49363 lineto
0.21786 0.49322 lineto
0.2373 0.49268 lineto
0.25675 0.49198 lineto
0.27619 0.49111 lineto
0.31508 0.4888 lineto
0.35397 0.48568 lineto
0.39286 0.48179 lineto
0.43175 0.47723 lineto
0.47063 0.47216 lineto
0.50952 0.46674 lineto
0.54841 0.46114 lineto
0.5873 0.45547 lineto
0.62619 0.44982 lineto
0.66508 0.44425 lineto
0.70397 0.43881 lineto
0.74286 0.43353 lineto
0.78175 0.4284 lineto
0.82063 0.42345 lineto
0.85952 0.41867 lineto
0.89841 0.41405 lineto
0.9373 0.4096 lineto
0.97619 0.4053 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05987 0.49443 lineto
0.0623 0.49443 lineto
0.06473 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07202 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.07932 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08661 0.49443 lineto
0.09147 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.10119 0.49443 lineto
0.10605 0.49443 lineto
0.11091 0.49443 lineto
0.11577 0.49442 lineto
0.12063 0.49442 lineto
0.1255 0.49442 lineto
0.13036 0.49442 lineto
0.14008 0.49441 lineto
0.14494 0.49441 lineto
0.1498 0.49441 lineto
0.15466 0.4944 lineto
0.15952 0.4944 lineto
0.16925 0.49438 lineto
0.17897 0.49436 lineto
0.18869 0.49433 lineto
0.19841 0.49429 lineto
0.20813 0.49423 lineto
0.21786 0.49416 lineto
0.22758 0.49407 lineto
0.2373 0.49396 lineto
0.24702 0.49382 lineto
0.25675 0.49365 lineto
0.26647 0.49343 lineto
Mistroke
0.27619 0.49318 lineto
0.29563 0.4925 lineto
0.31508 0.49156 lineto
0.33452 0.4903 lineto
0.35397 0.48867 lineto
0.39286 0.48415 lineto
0.43175 0.4779 lineto
0.47063 0.47016 lineto
0.50952 0.46138 lineto
0.54841 0.45205 lineto
0.5873 0.44254 lineto
0.62619 0.4331 lineto
0.66508 0.4239 lineto
0.70397 0.415 lineto
0.74286 0.40644 lineto
0.78175 0.39823 lineto
0.82063 0.39037 lineto
0.85952 0.38283 lineto
0.89841 0.37561 lineto
0.9373 0.36868 lineto
0.97619 0.36202 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.07932 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08661 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10605 0.49443 lineto
0.11091 0.49443 lineto
0.11334 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.1255 0.49443 lineto
0.13036 0.49443 lineto
0.13522 0.49443 lineto
0.14008 0.49443 lineto
0.14494 0.49443 lineto
0.1498 0.49443 lineto
0.15466 0.49442 lineto
0.15952 0.49442 lineto
Mistroke
0.16438 0.49442 lineto
0.16925 0.49442 lineto
0.17411 0.49442 lineto
0.17897 0.49442 lineto
0.18383 0.49442 lineto
0.18869 0.49441 lineto
0.19355 0.49441 lineto
0.19841 0.4944 lineto
0.20813 0.49439 lineto
0.213 0.49438 lineto
0.21786 0.49437 lineto
0.22758 0.49434 lineto
0.2373 0.49431 lineto
0.24702 0.49425 lineto
0.25675 0.49418 lineto
0.26647 0.49409 lineto
0.27619 0.49397 lineto
0.28591 0.49381 lineto
0.29563 0.4936 lineto
0.30536 0.49334 lineto
0.31508 0.493 lineto
0.3248 0.49259 lineto
0.33452 0.49208 lineto
0.35397 0.49071 lineto
0.37341 0.48877 lineto
0.39286 0.48614 lineto
0.4123 0.48274 lineto
0.43175 0.47855 lineto
0.47063 0.46806 lineto
0.50952 0.45554 lineto
0.54841 0.44207 lineto
0.5873 0.42843 lineto
0.62619 0.41507 lineto
0.66508 0.40219 lineto
0.70397 0.38987 lineto
0.74286 0.37813 lineto
0.78175 0.36694 lineto
0.82063 0.35628 lineto
0.85952 0.34609 lineto
0.89841 0.33636 lineto
0.9373 0.32704 lineto
0.97619 0.3181 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.06109 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10605 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11334 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.1255 0.49443 lineto
Mistroke
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.1498 0.49443 lineto
0.15466 0.49443 lineto
0.15952 0.49443 lineto
0.16438 0.49443 lineto
0.16925 0.49443 lineto
0.17411 0.49443 lineto
0.17897 0.49443 lineto
0.18383 0.49443 lineto
0.18869 0.49442 lineto
0.19355 0.49442 lineto
0.19841 0.49442 lineto
0.20327 0.49442 lineto
0.20813 0.49442 lineto
0.213 0.49442 lineto
0.21786 0.49442 lineto
0.22272 0.49441 lineto
0.22758 0.49441 lineto
0.2373 0.4944 lineto
0.24216 0.49439 lineto
0.24702 0.49438 lineto
0.25188 0.49437 lineto
0.25675 0.49435 lineto
0.26647 0.49431 lineto
0.27133 0.49429 lineto
0.27619 0.49426 lineto
0.28591 0.49418 lineto
0.29563 0.49408 lineto
0.30536 0.49393 lineto
0.31508 0.49373 lineto
0.3248 0.49346 lineto
0.33452 0.49311 lineto
0.34425 0.49265 lineto
0.35397 0.49206 lineto
0.36369 0.49131 lineto
0.37341 0.49037 lineto
0.38313 0.4892 lineto
0.39286 0.48779 lineto
0.4123 0.4841 lineto
0.43175 0.47919 lineto
0.47063 0.46585 lineto
0.50952 0.44928 lineto
0.54841 0.43143 lineto
0.5873 0.41358 lineto
Mistroke
0.62619 0.39632 lineto
0.66508 0.37985 lineto
0.70397 0.36421 lineto
0.74286 0.34938 lineto
0.78175 0.33529 lineto
0.82063 0.32189 lineto
0.85952 0.30912 lineto
0.89841 0.29692 lineto
0.9373 0.28525 lineto
0.97619 0.27406 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.06109 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10605 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
Mistroke
0.11334 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17897 0.49443 lineto
0.18383 0.49443 lineto
0.18869 0.49443 lineto
0.19355 0.49443 lineto
0.19841 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.213 0.49443 lineto
0.21786 0.49442 lineto
0.22272 0.49442 lineto
0.22758 0.49442 lineto
0.23244 0.49442 lineto
0.2373 0.49442 lineto
0.24216 0.49442 lineto
0.24702 0.49441 lineto
0.25188 0.49441 lineto
0.25675 0.4944 lineto
0.26647 0.49439 lineto
0.27133 0.49438 lineto
0.27619 0.49437 lineto
0.28105 0.49435 lineto
0.28591 0.49433 lineto
0.29563 0.49428 lineto
0.3005 0.49424 lineto
0.30536 0.4942 lineto
Mistroke
0.31022 0.49415 lineto
0.31508 0.49409 lineto
0.3248 0.49393 lineto
0.33452 0.4937 lineto
0.34425 0.49338 lineto
0.35397 0.49293 lineto
0.36369 0.49234 lineto
0.37341 0.49154 lineto
0.38313 0.49049 lineto
0.39286 0.48914 lineto
0.40258 0.48744 lineto
0.4123 0.48534 lineto
0.43175 0.4798 lineto
0.45119 0.47246 lineto
0.47063 0.46354 lineto
0.50952 0.44266 lineto
0.54841 0.42031 lineto
0.5873 0.39828 lineto
0.62619 0.3772 lineto
0.66508 0.35723 lineto
0.70397 0.33835 lineto
0.74286 0.32048 lineto
0.78175 0.30353 lineto
0.82063 0.28742 lineto
0.85952 0.27208 lineto
0.89841 0.25743 lineto
0.9373 0.24342 lineto
0.97619 0.23 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04772 0.49443 lineto
0.05015 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.06109 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08296 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
Mistroke
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.213 0.49443 lineto
0.21786 0.49443 lineto
0.22272 0.49443 lineto
0.22758 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
0.24216 0.49442 lineto
0.24702 0.49442 lineto
0.25188 0.49442 lineto
0.25675 0.49442 lineto
0.26161 0.49442 lineto
0.26647 0.49441 lineto
0.27133 0.49441 lineto
0.27619 0.49441 lineto
Mistroke
0.28105 0.4944 lineto
0.28591 0.49439 lineto
0.29077 0.49438 lineto
0.29563 0.49436 lineto
0.3005 0.49435 lineto
0.30536 0.49432 lineto
0.31022 0.4943 lineto
0.31508 0.49426 lineto
0.3248 0.49417 lineto
0.32966 0.4941 lineto
0.33452 0.49402 lineto
0.34425 0.49381 lineto
0.34911 0.49366 lineto
0.35397 0.49349 lineto
0.35883 0.49328 lineto
0.36369 0.49303 lineto
0.37341 0.49238 lineto
0.38313 0.49148 lineto
0.39286 0.49024 lineto
0.40258 0.48859 lineto
0.4123 0.48644 lineto
0.43175 0.4804 lineto
0.45119 0.47187 lineto
0.47063 0.46114 lineto
0.50952 0.43575 lineto
0.54841 0.40888 lineto
0.5873 0.38271 lineto
0.62619 0.35789 lineto
0.66508 0.33448 lineto
0.70397 0.31239 lineto
0.74286 0.29152 lineto
0.78175 0.27173 lineto
0.82063 0.25293 lineto
0.85952 0.23503 lineto
0.89841 0.21794 lineto
0.9373 0.20159 lineto
0.97619 0.18593 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.05258 0.49443 lineto
0.05744 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08296 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09025 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09754 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
0.11456 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.11942 0.49443 lineto
0.12063 0.49443 lineto
0.12185 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12671 0.49443 lineto
Mistroke
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17654 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.21057 0.49443 lineto
0.213 0.49443 lineto
0.21543 0.49443 lineto
0.21786 0.49443 lineto
0.22272 0.49443 lineto
0.22515 0.49443 lineto
0.22758 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
0.24216 0.49443 lineto
0.24702 0.49443 lineto
0.25188 0.49443 lineto
0.25675 0.49442 lineto
0.26161 0.49442 lineto
0.26647 0.49442 lineto
0.27133 0.49442 lineto
0.27619 0.49442 lineto
0.28105 0.49442 lineto
Mistroke
0.28591 0.49441 lineto
0.29077 0.49441 lineto
0.29563 0.4944 lineto
0.3005 0.49439 lineto
0.30536 0.49438 lineto
0.31022 0.49437 lineto
0.31508 0.49435 lineto
0.31994 0.49432 lineto
0.3248 0.49429 lineto
0.32966 0.49425 lineto
0.33452 0.4942 lineto
0.33938 0.49414 lineto
0.34425 0.49406 lineto
0.34911 0.49396 lineto
0.35397 0.49384 lineto
0.35883 0.49369 lineto
0.36369 0.4935 lineto
0.37341 0.49299 lineto
0.37827 0.49264 lineto
0.38313 0.49223 lineto
0.39286 0.49112 lineto
0.40258 0.48957 lineto
0.4123 0.48743 lineto
0.42202 0.4846 lineto
0.43175 0.48098 lineto
0.45119 0.47126 lineto
0.47063 0.45865 lineto
0.50952 0.42861 lineto
0.54841 0.39722 lineto
0.5873 0.367 lineto
0.62619 0.3385 lineto
0.66508 0.31168 lineto
0.70397 0.28641 lineto
0.74286 0.26254 lineto
0.78175 0.23992 lineto
0.82063 0.21844 lineto
0.85952 0.19797 lineto
0.89841 0.17844 lineto
0.9373 0.15976 lineto
0.97619 0.14185 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.05258 0.49443 lineto
0.0623 0.49443 lineto
0.06473 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08904 0.49443 lineto
0.09025 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09754 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10241 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.1097 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
0.11456 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.11942 0.49443 lineto
0.12063 0.49443 lineto
0.12185 0.49443 lineto
Mistroke
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12671 0.49443 lineto
0.12793 0.49443 lineto
0.12914 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.134 0.49443 lineto
0.13522 0.49443 lineto
0.13643 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14129 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17654 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19112 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.21057 0.49443 lineto
0.213 0.49443 lineto
0.21543 0.49443 lineto
0.21786 0.49443 lineto
0.22272 0.49443 lineto
0.22515 0.49443 lineto
0.22758 0.49443 lineto
0.23001 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
Mistroke
0.23973 0.49443 lineto
0.24216 0.49443 lineto
0.24459 0.49443 lineto
0.24702 0.49443 lineto
0.25188 0.49443 lineto
0.25432 0.49443 lineto
0.25675 0.49443 lineto
0.26161 0.49443 lineto
0.26647 0.49443 lineto
0.27133 0.49443 lineto
0.27619 0.49442 lineto
0.28105 0.49442 lineto
0.28591 0.49442 lineto
0.29077 0.49442 lineto
0.29563 0.49442 lineto
0.3005 0.49441 lineto
0.30536 0.49441 lineto
0.31022 0.4944 lineto
0.31508 0.49439 lineto
0.31994 0.49438 lineto
0.3248 0.49436 lineto
0.32966 0.49433 lineto
0.33452 0.4943 lineto
0.33938 0.49426 lineto
0.34425 0.49421 lineto
0.34911 0.49415 lineto
0.35397 0.49406 lineto
0.35883 0.49395 lineto
0.36369 0.49381 lineto
0.36855 0.49364 lineto
0.37341 0.49342 lineto
0.37827 0.49314 lineto
0.38313 0.49279 lineto
0.388 0.49236 lineto
0.39286 0.49183 lineto
0.40258 0.49039 lineto
0.40744 0.48944 lineto
0.4123 0.48831 lineto
0.42202 0.48541 lineto
0.43175 0.48154 lineto
0.45119 0.47065 lineto
0.47063 0.45607 lineto
0.50952 0.42128 lineto
0.54841 0.38542 lineto
0.5873 0.35121 lineto
0.62619 0.31906 lineto
0.66508 0.28886 lineto
0.70397 0.26042 lineto
0.74286 0.23356 lineto
0.78175 0.20811 lineto
Mistroke
0.82063 0.18394 lineto
0.85952 0.16092 lineto
0.89841 0.13894 lineto
0.9373 0.11792 lineto
0.97619 0.09778 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.0623 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08296 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09025 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
0.11456 0.49443 lineto
0.11577 0.49443 lineto
0.11699 0.49443 lineto
0.1182 0.49443 lineto
0.11942 0.49443 lineto
Mistroke
0.12063 0.49443 lineto
0.12185 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12671 0.49443 lineto
0.12793 0.49443 lineto
0.12914 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.134 0.49443 lineto
0.13522 0.49443 lineto
0.13643 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14129 0.49443 lineto
0.14251 0.49443 lineto
0.14373 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.14859 0.49443 lineto
0.1498 0.49443 lineto
0.15102 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15588 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17654 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19112 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.2057 0.49443 lineto
0.20813 0.49443 lineto
0.21057 0.49443 lineto
0.213 0.49443 lineto
0.21543 0.49443 lineto
Mistroke
0.21786 0.49443 lineto
0.22029 0.49443 lineto
0.22272 0.49443 lineto
0.22515 0.49443 lineto
0.22758 0.49443 lineto
0.23001 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
0.23973 0.49443 lineto
0.24216 0.49443 lineto
0.24459 0.49443 lineto
0.24702 0.49443 lineto
0.25188 0.49443 lineto
0.25432 0.49443 lineto
0.25675 0.49443 lineto
0.25918 0.49443 lineto
0.26161 0.49443 lineto
0.26647 0.49443 lineto
0.2689 0.49443 lineto
0.27133 0.49443 lineto
0.27376 0.49443 lineto
0.27619 0.49443 lineto
0.28105 0.49443 lineto
0.28348 0.49443 lineto
0.28591 0.49442 lineto
0.29077 0.49442 lineto
0.29563 0.49442 lineto
0.3005 0.49442 lineto
0.30536 0.49442 lineto
0.31022 0.49441 lineto
0.31508 0.49441 lineto
0.31994 0.4944 lineto
0.3248 0.49439 lineto
0.32966 0.49438 lineto
0.33452 0.49436 lineto
0.33938 0.49433 lineto
0.34425 0.4943 lineto
0.34911 0.49426 lineto
0.35397 0.4942 lineto
0.35883 0.49412 lineto
0.36369 0.49402 lineto
0.36855 0.49389 lineto
0.37341 0.49372 lineto
0.37827 0.4935 lineto
0.38313 0.49322 lineto
0.388 0.49285 lineto
0.39286 0.49239 lineto
0.40258 0.49109 lineto
0.40744 0.49019 lineto
0.4123 0.48909 lineto
Mistroke
0.42202 0.48616 lineto
0.43175 0.48208 lineto
0.44147 0.4767 lineto
0.45119 0.47002 lineto
0.47063 0.45341 lineto
0.50952 0.41381 lineto
0.54841 0.37353 lineto
0.5873 0.33537 lineto
0.62619 0.29959 lineto
0.66508 0.26602 lineto
0.70397 0.23442 lineto
0.74286 0.20458 lineto
0.78175 0.1763 lineto
0.82063 0.14944 lineto
0.85952 0.12386 lineto
0.89841 0.09944 lineto
0.9373 0.07609 lineto
0.97619 0.05371 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = section; inactive; startGroup; Cclosed; ]
The z-Transform
:[font = text; inactive; ]
		The objects ZTransform and InvZTransform compute the forward and inverse z-transform, respectively, according to the standard definitions: [7]
:[font = postscript; inactive; PostScript; locked; output; height = 94; pictureLeft = 38; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.625 0.0833333 0.833333 0.0833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
gsave
0.01 setlinewidth
0.625 0.91667 moveto
0.54167 0.91667 lineto
0.625 0.83333 lineto
0.54167 0.75 lineto
0.625 0.75 lineto
stroke
gsave
/Plain findfont 14 scalefont setfont
[(X\(z\) = Z{x[n]} =)] 0.5 0.83333 1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.57917 0.95833 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.59583 0.95833 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(n=-)] 0.53333 0.70833 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.625 0.70833 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.64167 0.70833 0 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(x[n])] 0.65833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(z)] 0.78333 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(-n)] 0.81667 0.875 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(\(1\))] 0.925 0.83333 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; locked; output; height = 94; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.583333 0.0833333 0.833333 0.0833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
gsave
0.0075 setlinewidth
0.43333 0.925 moveto
0.42083 0.91667 lineto
0.4125 0.9 lineto
0.4125 0.76667 lineto
0.40417 0.75 lineto
0.39167 0.74167 lineto
stroke
newpath
0.4125 0.83333 0.01667 0 365.73 arc
stroke
gsave
/Plain findfont 14 scalefont setfont
[(Z)] 0.025 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(-1)] 0.06667 0.875 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[({X\(z\)})] 0.13333 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(=)] 0.31667 0.83333 -1 0 Mshowa
grestore
gsave
/Bold findfont 16 scalefont setfont
[(C)] 0.39583 0.70833 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(X\(z\))] 0.47917 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(z)] 0.625 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(dz)] 0.75 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(n-1)] 0.65 0.875 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(\(2\))] 0.91667 0.83333 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]
The forward rule base works for 1-D and m-D signals, whereas the inverse rule base only inverts 1-D and separable m-D transforms (Mathematica simply cannot perform the multiple contour integrations required in the general m-D case).  Since the rule bases implement the bilateral form of the z-transform, ZTransform tracks the region of convergence (ROC) so that InvZTransform can uniquely determine the inverse [3].
:[font = text; inactive; ]
		The z-transform notebook first defines the bilateral z-transform and discusses the importance of the ROC in uniquely defining the transform. Discussion of the ROC leads naturally into introducing stability and causality of a signal based on the location of its poles relative to the ROC.  The next section links the z-transform with the discrete-time Fourier transform (DTFT) and includes several animations relating pole-zero diagrams to magnitude frequency responses, a basic idea behind digital filter design [7, ch. 5].  Figure 2 shows one frame for three-pole, two-zero filter whose magnitude response is being evaluated at a frequency of pi rad.  The z-transform notebook concludes with examples of high-level digital signal analysis using DSPAnalyze [4], the discrete-time version of ASPAnalyze .
:[font = subsection; inactive; startGroup; Cclosed; ]
Figure 2:  Animation of System with Multiple Poles and Zeroes
:[font = text; inactive; ]
		Animate the following cells by selecting the graphics cells to be animated and then choosing the Animation option from the Graph submenu. You can also set the desired animation speed by using the Preferences option in the main menu, or the options in the bottom right side of  the notebook border. 
		The black dot on the circle represents the point z = e^jw moving around the unit circle, while the symbol "X" represents a pole and the symbol "O" represents a zero.
		 Note that the frequency response becomes zero whenever the black dot crosses a zero located on the unit circle. Also, the resulting frequency response corresponds to a low-pass filter. The more poles we will have in the right part of the unit circle the flatter the response can become around the low frequencies if these poles are placed appropriately.
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 68; pictureTop = 3; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.5 0.9 lineto
stroke
0.1 0.5 moveto
0.5 0.1 lineto
stroke
0.1 0.5 moveto
0.82 0.5 lineto
stroke
0.1 0.5 moveto
0.75456 0.75456 lineto
stroke
0.1 0.5 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.21716 moveto
0.5 0.9 lineto
stroke
0.21716 0.21716 moveto
0.5 0.1 lineto
stroke
0.21716 0.21716 moveto
0.82 0.5 lineto
stroke
0.21716 0.21716 moveto
0.75456 0.75456 lineto
stroke
0.21716 0.21716 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.1 moveto
0.5 0.9 lineto
stroke
0.5 0.1 moveto
0.5 0.1 lineto
stroke
0.5 0.1 moveto
0.82 0.5 lineto
stroke
0.5 0.1 moveto
0.75456 0.75456 lineto
stroke
0.5 0.1 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.1 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.21716 moveto
0.5 0.9 lineto
stroke
0.78284 0.21716 moveto
0.5 0.1 lineto
stroke
0.78284 0.21716 moveto
0.82 0.5 lineto
stroke
0.78284 0.21716 moveto
0.75456 0.75456 lineto
stroke
0.78284 0.21716 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.21716 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.5 0.9 lineto
stroke
0.9 0.5 moveto
0.5 0.1 lineto
stroke
0.9 0.5 moveto
0.82 0.5 lineto
stroke
0.9 0.5 moveto
0.75456 0.75456 lineto
stroke
0.9 0.5 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.9 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.78284 0.78284 moveto
0.5 0.9 lineto
stroke
0.78284 0.78284 moveto
0.5 0.1 lineto
stroke
0.78284 0.78284 moveto
0.82 0.5 lineto
stroke
0.78284 0.78284 moveto
0.75456 0.75456 lineto
stroke
0.78284 0.78284 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.78284 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.5 0.9 moveto
0.5 0.9 lineto
stroke
0.5 0.9 moveto
0.5 0.1 lineto
stroke
0.5 0.9 moveto
0.82 0.5 lineto
stroke
0.5 0.9 moveto
0.75456 0.75456 lineto
stroke
0.5 0.9 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.5 0.9 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.21716 0.78284 moveto
0.5 0.9 lineto
stroke
0.21716 0.78284 moveto
0.5 0.1 lineto
stroke
0.21716 0.78284 moveto
0.82 0.5 lineto
stroke
0.21716 0.78284 moveto
0.75456 0.75456 lineto
stroke
0.21716 0.78284 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.21716 0.78284 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 68; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.24544 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.75456 0.75456 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.82 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.1 0.5 moveto
0.5 0.9 lineto
stroke
0.1 0.5 moveto
0.5 0.1 lineto
stroke
0.1 0.5 moveto
0.82 0.5 lineto
stroke
0.1 0.5 moveto
0.75456 0.75456 lineto
stroke
0.1 0.5 moveto
0.75456 0.24544 lineto
stroke
grestore
grestore
gsave
gsave
0.05 setlinewidth
0.1 0.5 Mdot
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01525 0.01113 lineto
-0.01459 0.01113 lineto
-0.01393 0.01113 lineto
-0.01326 0.01113 lineto
-0.0126 0.01113 lineto
-0.01194 0.01113 lineto
-0.01127 0.01113 lineto
-0.01061 0.01113 lineto
-0.00995 0.01113 lineto
-0.00928 0.01113 lineto
-0.00862 0.01113 lineto
-0.00796 0.01114 lineto
-0.00729 0.01114 lineto
-0.00663 0.01114 lineto
-0.00597 0.01114 lineto
-0.00531 0.01114 lineto
-0.00464 0.01114 lineto
-0.00398 0.01114 lineto
-0.00332 0.01114 lineto
-0.00265 0.01114 lineto
-0.00199 0.01114 lineto
-0.00166 0.01114 lineto
-0.00133 0.01114 lineto
-0.00099 0.01114 lineto
-0.00083 0.01114 lineto
-0.00066 0.01114 lineto
-0.0005 0.01114 lineto
-0.00041 0.01114 lineto
-0.00033 0.01114 lineto
-0.00025 0.01114 lineto
-0.00021 0.01114 lineto
-0.00017 0.01114 lineto
-0.00012 0.01114 lineto
-0.0001 0.01114 lineto
-8e-05 0.01114 lineto
-6e-05 0.01114 lineto
-4e-05 0.01114 lineto
0 0.01114 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01298 0.01113 lineto
-0.01004 0.01113 lineto
-0.00858 0.01113 lineto
-0.00711 0.01114 lineto
-0.00564 0.01114 lineto
-0.00491 0.01114 lineto
-0.00417 0.01114 lineto
-0.00344 0.01114 lineto
-0.0027 0.01114 lineto
-0.00234 0.01114 lineto
-0.00197 0.01114 lineto
-0.0016 0.01114 lineto
-0.00124 0.01114 lineto
-0.00105 0.01114 lineto
-0.00087 0.01114 lineto
-0.00069 0.01114 lineto
-0.0005 0.01114 lineto
-0.00032 0.01114 lineto
-0.00014 0.01114 lineto
5e-05 0.01114 lineto
0.00023 0.01114 lineto
0.00041 0.01114 lineto
0.0006 0.01114 lineto
0.00097 0.01114 lineto
0.00115 0.01114 lineto
0.00133 0.01114 lineto
0.0017 0.01114 lineto
0.00243 0.01114 lineto
0.00317 0.01114 lineto
0.00463 0.01114 lineto
0.0061 0.01114 lineto
0.00757 0.01114 lineto
0.01051 0.01113 lineto
0.01344 0.01113 lineto
0.01931 0.01112 lineto
0.02518 0.01111 lineto
0.03106 0.0111 lineto
0.03693 0.01108 lineto
0.0428 0.01107 lineto
0.04867 0.01104 lineto
0.05454 0.01102 lineto
0.06041 0.01099 lineto
0.06629 0.01095 lineto
0.07216 0.01092 lineto
0.07803 0.01087 lineto
0.0839 0.01082 lineto
0.08977 0.01077 lineto
0.09564 0.01071 lineto
0.10151 0.01064 lineto
Mistroke
0.10739 0.01056 lineto
0.11326 0.01047 lineto
0.11913 0.01038 lineto
0.125 0.01027 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01315 0.01113 lineto
-0.01038 0.01113 lineto
-0.00899 0.01113 lineto
-0.00761 0.01114 lineto
-0.00622 0.01114 lineto
-0.00484 0.01114 lineto
-0.00414 0.01114 lineto
-0.00345 0.01114 lineto
-0.00276 0.01114 lineto
-0.00207 0.01114 lineto
-0.00172 0.01114 lineto
-0.00137 0.01114 lineto
-0.00103 0.01114 lineto
-0.00068 0.01114 lineto
-0.00033 0.01114 lineto
1e-05 0.01114 lineto
0.00036 0.01114 lineto
0.0007 0.01114 lineto
0.00105 0.01114 lineto
0.0014 0.01114 lineto
0.00209 0.01114 lineto
0.00278 0.01114 lineto
0.00347 0.01114 lineto
0.00486 0.01114 lineto
0.00624 0.01114 lineto
0.00901 0.01113 lineto
0.01178 0.01113 lineto
0.01732 0.01113 lineto
0.02286 0.01112 lineto
0.0284 0.01111 lineto
0.03948 0.01108 lineto
0.05056 0.01104 lineto
0.06164 0.01098 lineto
0.07272 0.01091 lineto
0.0838 0.01082 lineto
0.09488 0.01071 lineto
0.10596 0.01058 lineto
0.11704 0.01041 lineto
0.12812 0.01021 lineto
0.1392 0.00996 lineto
0.15028 0.00965 lineto
0.16136 0.00927 lineto
0.17244 0.0088 lineto
0.18352 0.00823 lineto
0.1946 0.00751 lineto
0.20568 0.00662 lineto
0.21676 0.0055 lineto
0.22784 0.00409 lineto
0.23892 0.0023 lineto
Mistroke
0.25 0 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01388 0.01113 lineto
-0.01184 0.01113 lineto
-0.00981 0.01113 lineto
-0.00777 0.01114 lineto
-0.00675 0.01114 lineto
-0.00574 0.01114 lineto
-0.00472 0.01114 lineto
-0.0037 0.01114 lineto
-0.00319 0.01114 lineto
-0.00268 0.01114 lineto
-0.00217 0.01114 lineto
-0.00166 0.01114 lineto
-0.00115 0.01114 lineto
-0.00065 0.01114 lineto
-0.00014 0.01114 lineto
0.00037 0.01114 lineto
0.00088 0.01114 lineto
0.00139 0.01114 lineto
0.0019 0.01114 lineto
0.00241 0.01114 lineto
0.00343 0.01114 lineto
0.00444 0.01114 lineto
0.00648 0.01114 lineto
0.00852 0.01113 lineto
0.01259 0.01113 lineto
0.01666 0.01113 lineto
0.02073 0.01112 lineto
0.0248 0.01111 lineto
0.03295 0.0111 lineto
0.04109 0.01107 lineto
0.04924 0.01104 lineto
0.06553 0.01096 lineto
0.07367 0.0109 lineto
0.08181 0.01084 lineto
0.0981 0.01068 lineto
0.11439 0.01046 lineto
0.13068 0.01015 lineto
0.14697 0.00975 lineto
0.16325 0.0092 lineto
0.17954 0.00845 lineto
0.19583 0.00742 lineto
0.21212 0.006 lineto
0.22841 0.00401 lineto
0.23655 0.00272 lineto
0.24062 0.00198 lineto
0.24469 0.00118 lineto
0.24673 0.00074 lineto
0.24775 0.00052 lineto
0.24877 0.00029 lineto
Mistroke
0.24928 0.00017 lineto
0.24978 5e-05 lineto
0.25029 7e-05 lineto
0.2508 0.00019 lineto
0.25182 0.00044 lineto
0.25284 0.00069 lineto
0.26098 0.00296 lineto
0.27727 0.00918 lineto
0.28542 0.01347 lineto
0.29356 0.01889 lineto
0.3017 0.02585 lineto
0.30985 0.03494 lineto
0.31799 0.04704 lineto
0.32614 0.06357 lineto
0.33428 0.08683 lineto
0.33835 0.10211 lineto
0.34242 0.12071 lineto
0.3465 0.14355 lineto
0.35057 0.17177 lineto
0.35871 0.24974 lineto
0.375 0.45547 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01323 0.01113 lineto
-0.01054 0.01113 lineto
-0.00785 0.01114 lineto
-0.00651 0.01114 lineto
-0.00517 0.01114 lineto
-0.0045 0.01114 lineto
-0.00382 0.01114 lineto
-0.00315 0.01114 lineto
-0.00248 0.01114 lineto
-0.00181 0.01114 lineto
-0.00114 0.01114 lineto
-0.00046 0.01114 lineto
0.00021 0.01114 lineto
0.00088 0.01114 lineto
0.00155 0.01114 lineto
0.00222 0.01114 lineto
0.00289 0.01114 lineto
0.00424 0.01114 lineto
0.00558 0.01114 lineto
0.00827 0.01114 lineto
0.01096 0.01113 lineto
0.01364 0.01113 lineto
0.01633 0.01113 lineto
0.0217 0.01112 lineto
0.02708 0.01111 lineto
0.03783 0.01108 lineto
0.04857 0.01104 lineto
0.05932 0.01099 lineto
0.07007 0.01093 lineto
0.08082 0.01085 lineto
0.09157 0.01075 lineto
0.10232 0.01063 lineto
0.11306 0.01048 lineto
0.12381 0.01029 lineto
0.13456 0.01007 lineto
0.14531 0.00979 lineto
0.15606 0.00946 lineto
0.1668 0.00905 lineto
0.17755 0.00855 lineto
0.1883 0.00794 lineto
0.19905 0.00718 lineto
0.22055 0.00506 lineto
0.23129 0.00358 lineto
0.23667 0.0027 lineto
0.24204 0.00171 lineto
0.24742 0.00059 lineto
0.24876 0.00029 lineto
0.24943 0.00013 lineto
0.2501 2e-05 lineto
Mistroke
0.25145 0.00035 lineto
0.25279 0.00068 lineto
0.26354 0.00377 lineto
0.27429 0.00783 lineto
0.28504 0.01324 lineto
0.29578 0.02062 lineto
0.30116 0.02533 lineto
0.30653 0.03093 lineto
0.31191 0.03767 lineto
0.31728 0.04583 lineto
0.32265 0.05584 lineto
0.32803 0.06827 lineto
0.3334 0.08391 lineto
0.33878 0.10388 lineto
0.34415 0.12982 lineto
0.34952 0.16395 lineto
0.3549 0.20923 lineto
0.36027 0.26848 lineto
0.36565 0.34111 lineto
0.36833 0.37938 lineto
0.37102 0.41516 lineto
0.37371 0.4446 lineto
0.37505 0.45585 lineto
0.37572 0.46047 lineto
0.3764 0.4644 lineto
0.37707 0.46763 lineto
0.37774 0.47015 lineto
0.37841 0.472 lineto
0.37908 0.47318 lineto
0.37975 0.47372 lineto
0.38043 0.47367 lineto
0.3811 0.47306 lineto
0.38177 0.47194 lineto
0.39252 0.42022 lineto
0.39789 0.3928 lineto
0.40327 0.37134 lineto
0.40595 0.36293 lineto
0.40864 0.35596 lineto
0.41133 0.35033 lineto
0.41401 0.34594 lineto
0.41536 0.34418 lineto
0.4167 0.3427 lineto
0.41804 0.34148 lineto
0.41939 0.34052 lineto
0.42006 0.34013 lineto
0.42073 0.33981 lineto
0.4214 0.33954 lineto
0.42208 0.33934 lineto
0.42275 0.33919 lineto
0.42342 0.3391 lineto
Mistroke
0.42409 0.33907 lineto
0.42476 0.3391 lineto
0.42543 0.33918 lineto
0.42611 0.33931 lineto
0.42678 0.33951 lineto
0.42745 0.33975 lineto
0.42879 0.3404 lineto
0.43014 0.34127 lineto
0.43282 0.34362 lineto
0.43551 0.34678 lineto
0.44088 0.35553 lineto
0.44626 0.36747 lineto
0.45701 0.40111 lineto
0.46776 0.4475 lineto
0.4785 0.50283 lineto
0.48388 0.53013 lineto
0.48656 0.54252 lineto
0.48925 0.55351 lineto
0.49194 0.56264 lineto
0.49328 0.56638 lineto
0.49463 0.56951 lineto
0.49597 0.57199 lineto
0.49664 0.57297 lineto
0.49731 0.57378 lineto
0.49798 0.57441 lineto
0.49866 0.57486 lineto
0.5 0.57523 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01258 0.01113 lineto
-0.01091 0.01113 lineto
-0.00924 0.01113 lineto
-0.00757 0.01114 lineto
-0.0059 0.01114 lineto
-0.00423 0.01114 lineto
-0.0034 0.01114 lineto
-0.00256 0.01114 lineto
-0.00173 0.01114 lineto
-0.00089 0.01114 lineto
-6e-05 0.01114 lineto
0.00078 0.01114 lineto
0.00161 0.01114 lineto
0.00244 0.01114 lineto
0.00328 0.01114 lineto
0.00411 0.01114 lineto
0.00578 0.01114 lineto
0.00745 0.01114 lineto
0.01079 0.01113 lineto
0.01413 0.01113 lineto
0.01747 0.01113 lineto
0.02414 0.01112 lineto
0.03082 0.0111 lineto
0.03749 0.01108 lineto
0.05085 0.01103 lineto
0.0642 0.01097 lineto
0.07755 0.01088 lineto
0.0909 0.01076 lineto
0.10426 0.0106 lineto
0.11761 0.0104 lineto
0.13096 0.01015 lineto
0.14431 0.00982 lineto
0.15767 0.0094 lineto
0.17102 0.00887 lineto
0.18437 0.00818 lineto
0.19772 0.00728 lineto
0.21108 0.00611 lineto
0.22443 0.00456 lineto
0.23778 0.00251 lineto
0.24446 0.00122 lineto
0.24613 0.00087 lineto
0.24779 0.00051 lineto
0.24863 0.00032 lineto
0.24946 0.00013 lineto
0.2503 7e-05 lineto
0.25113 0.00027 lineto
0.2528 0.00068 lineto
0.25447 0.00111 lineto
0.25781 0.00202 lineto
Mistroke
0.26449 0.00409 lineto
0.27116 0.00653 lineto
0.27784 0.00944 lineto
0.28451 0.01294 lineto
0.29119 0.01718 lineto
0.29787 0.02235 lineto
0.30454 0.02874 lineto
0.31122 0.03673 lineto
0.31789 0.04687 lineto
0.32457 0.05996 lineto
0.33125 0.07718 lineto
0.33792 0.10036 lineto
0.3446 0.13232 lineto
0.35128 0.17733 lineto
0.35795 0.24107 lineto
0.36463 0.32663 lineto
0.36797 0.3742 lineto
0.3713 0.41863 lineto
0.37297 0.4374 lineto
0.37464 0.4527 lineto
0.37548 0.45886 lineto
0.37631 0.46395 lineto
0.37715 0.46796 lineto
0.37798 0.4709 lineto
0.37882 0.47278 lineto
0.37965 0.47368 lineto
0.38048 0.47364 lineto
0.38132 0.47275 lineto
0.38215 0.47109 lineto
0.38299 0.46877 lineto
0.38466 0.46247 lineto
0.39133 0.42685 lineto
0.39801 0.39227 lineto
0.40135 0.37828 lineto
0.40469 0.36671 lineto
0.40802 0.35744 lineto
0.41136 0.35027 lineto
0.41303 0.34741 lineto
0.4147 0.34501 lineto
0.41637 0.34304 lineto
0.41804 0.34148 lineto
0.41971 0.34033 lineto
0.42054 0.33989 lineto
0.42138 0.33955 lineto
0.42221 0.3393 lineto
0.42304 0.33914 lineto
0.42388 0.33907 lineto
0.42471 0.33909 lineto
0.42555 0.3392 lineto
0.42638 0.33939 lineto
Mistroke
0.42722 0.33966 lineto
0.42805 0.34002 lineto
0.42972 0.34098 lineto
0.43139 0.34226 lineto
0.43473 0.34578 lineto
0.43807 0.35054 lineto
0.44474 0.36378 lineto
0.45142 0.38199 lineto
0.46477 0.43344 lineto
0.47812 0.50084 lineto
0.4848 0.53452 lineto
0.48814 0.54915 lineto
0.49148 0.56122 lineto
0.49314 0.56603 lineto
0.49481 0.5699 lineto
0.49565 0.57146 lineto
0.49648 0.57275 lineto
0.49732 0.57378 lineto
0.49815 0.57454 lineto
0.49899 0.57502 lineto
0.49982 0.57522 lineto
0.50066 0.57514 lineto
0.50149 0.57478 lineto
0.50232 0.57414 lineto
0.50316 0.57323 lineto
0.50399 0.57204 lineto
0.50483 0.5706 lineto
0.51818 0.51996 lineto
0.53153 0.45097 lineto
0.53821 0.42027 lineto
0.54489 0.39424 lineto
0.55156 0.37324 lineto
0.5549 0.36462 lineto
0.55824 0.35726 lineto
0.56158 0.35113 lineto
0.56491 0.34623 lineto
0.56825 0.34258 lineto
0.56992 0.34123 lineto
0.57076 0.34067 lineto
0.57159 0.3402 lineto
0.57242 0.3398 lineto
0.57326 0.33949 lineto
0.57409 0.33927 lineto
0.57493 0.33913 lineto
0.57576 0.33907 lineto
0.5766 0.3391 lineto
0.57743 0.33922 lineto
0.57827 0.33943 lineto
0.5791 0.33973 lineto
0.57994 0.34013 lineto
Mistroke
0.5816 0.3412 lineto
0.58327 0.34267 lineto
0.58494 0.34455 lineto
0.58828 0.34962 lineto
0.59162 0.35657 lineto
0.59496 0.36561 lineto
0.5983 0.37693 lineto
0.625 0.45547 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01193 0.01113 lineto
-0.00993 0.01113 lineto
-0.00794 0.01114 lineto
-0.00594 0.01114 lineto
-0.00495 0.01114 lineto
-0.00395 0.01114 lineto
-0.00295 0.01114 lineto
-0.00195 0.01114 lineto
-0.00096 0.01114 lineto
4e-05 0.01114 lineto
0.00104 0.01114 lineto
0.00204 0.01114 lineto
0.00303 0.01114 lineto
0.00403 0.01114 lineto
0.00602 0.01114 lineto
0.00802 0.01114 lineto
0.01001 0.01113 lineto
0.01201 0.01113 lineto
0.016 0.01113 lineto
0.01999 0.01112 lineto
0.02398 0.01112 lineto
0.03195 0.0111 lineto
0.03993 0.01108 lineto
0.04791 0.01105 lineto
0.06387 0.01097 lineto
0.07982 0.01086 lineto
0.09578 0.0107 lineto
0.11174 0.0105 lineto
0.12769 0.01022 lineto
0.14365 0.00984 lineto
0.15961 0.00933 lineto
0.17556 0.00865 lineto
0.19152 0.00773 lineto
0.20748 0.00645 lineto
0.22343 0.00469 lineto
0.23141 0.00356 lineto
0.23939 0.00222 lineto
0.24338 0.00145 lineto
0.24537 0.00103 lineto
0.24737 0.0006 lineto
0.24837 0.00038 lineto
0.24936 0.00015 lineto
0.25036 9e-05 lineto
0.25136 0.00032 lineto
0.25235 0.00057 lineto
0.25335 0.00082 lineto
0.25535 0.00134 lineto
0.26332 0.0037 lineto
0.2713 0.00659 lineto
Mistroke
0.27928 0.01015 lineto
0.28726 0.01458 lineto
0.29524 0.02019 lineto
0.30322 0.02736 lineto
0.31119 0.0367 lineto
0.31917 0.04912 lineto
0.32715 0.06604 lineto
0.33114 0.07687 lineto
0.33513 0.08979 lineto
0.33912 0.10534 lineto
0.34311 0.12422 lineto
0.3471 0.14734 lineto
0.35109 0.17582 lineto
0.35906 0.25386 lineto
0.36704 0.36107 lineto
0.37103 0.41529 lineto
0.37303 0.43794 lineto
0.37402 0.44747 lineto
0.37502 0.45562 lineto
0.37602 0.46228 lineto
0.37702 0.4674 lineto
0.37801 0.47099 lineto
0.37901 0.47308 lineto
0.38001 0.47377 lineto
0.381 0.47318 lineto
0.382 0.47145 lineto
0.383 0.46873 lineto
0.39098 0.42886 lineto
0.39497 0.40708 lineto
0.39896 0.38805 lineto
0.40294 0.37245 lineto
0.40693 0.36023 lineto
0.40893 0.3553 lineto
0.41092 0.3511 lineto
0.41292 0.34759 lineto
0.41491 0.34473 lineto
0.41691 0.34249 lineto
0.4189 0.34084 lineto
0.4199 0.34022 lineto
0.4209 0.33974 lineto
0.42189 0.33939 lineto
0.42289 0.33917 lineto
0.42389 0.33907 lineto
0.42488 0.33911 lineto
0.42588 0.33926 lineto
0.42688 0.33954 lineto
0.42788 0.33994 lineto
0.42887 0.34045 lineto
0.43087 0.34183 lineto
0.43286 0.34366 lineto
Mistroke
0.43486 0.34594 lineto
0.43885 0.35183 lineto
0.44284 0.35949 lineto
0.44683 0.36892 lineto
0.4548 0.39315 lineto
0.46278 0.42455 lineto
0.47874 0.50406 lineto
0.48273 0.5245 lineto
0.48672 0.54319 lineto
0.49071 0.55871 lineto
0.4927 0.56483 lineto
0.4937 0.56741 lineto
0.49469 0.56965 lineto
0.49569 0.57153 lineto
0.49669 0.57303 lineto
0.49769 0.57415 lineto
0.49868 0.57488 lineto
0.49968 0.57521 lineto
0.50068 0.57514 lineto
0.50168 0.57466 lineto
0.50267 0.57379 lineto
0.50367 0.57253 lineto
0.50467 0.57089 lineto
0.50666 0.56652 lineto
0.50866 0.5608 lineto
0.51065 0.55387 lineto
0.52661 0.47596 lineto
0.53459 0.4364 lineto
0.54256 0.40272 lineto
0.55054 0.37611 lineto
0.55852 0.35669 lineto
0.56251 0.34963 lineto
0.5645 0.34676 lineto
0.5665 0.34434 lineto
0.56849 0.34236 lineto
0.56949 0.34154 lineto
0.57049 0.34084 lineto
0.57149 0.34025 lineto
0.57248 0.33978 lineto
0.57348 0.33943 lineto
0.57448 0.33919 lineto
0.57547 0.33908 lineto
0.57647 0.33909 lineto
0.57747 0.33923 lineto
0.57847 0.3395 lineto
0.57946 0.33989 lineto
0.58046 0.34043 lineto
0.58146 0.34109 lineto
0.58246 0.3419 lineto
0.58445 0.34395 lineto
Mistroke
0.58645 0.34661 lineto
0.59043 0.35388 lineto
0.59442 0.36402 lineto
0.59841 0.37737 lineto
0.60639 0.41425 lineto
0.61038 0.43657 lineto
0.61237 0.44771 lineto
0.61437 0.45802 lineto
0.61537 0.46257 lineto
0.61636 0.46656 lineto
0.61736 0.46981 lineto
0.61836 0.47219 lineto
0.61936 0.47353 lineto
0.62035 0.47367 lineto
0.62135 0.47249 lineto
0.62235 0.46987 lineto
0.6383 0.28662 lineto
0.64229 0.23833 lineto
0.64628 0.19816 lineto
0.65426 0.13893 lineto
0.65825 0.11737 lineto
0.66224 0.09971 lineto
0.67022 0.07297 lineto
0.6782 0.05412 lineto
0.68617 0.0404 lineto
0.69415 0.03016 lineto
0.70213 0.02235 lineto
0.71011 0.01629 lineto
0.71809 0.0115 lineto
0.72607 0.00768 lineto
0.73404 0.00459 lineto
0.75 0 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.0136 0.01113 lineto
-0.01128 0.01113 lineto
-0.00896 0.01113 lineto
-0.0078 0.01114 lineto
-0.00664 0.01114 lineto
-0.00548 0.01114 lineto
-0.00432 0.01114 lineto
-0.00315 0.01114 lineto
-0.00199 0.01114 lineto
-0.00083 0.01114 lineto
0.00033 0.01114 lineto
0.00149 0.01114 lineto
0.00265 0.01114 lineto
0.00381 0.01114 lineto
0.00497 0.01114 lineto
0.00729 0.01114 lineto
0.00961 0.01113 lineto
0.01193 0.01113 lineto
0.01657 0.01113 lineto
0.02121 0.01112 lineto
0.03049 0.0111 lineto
0.03977 0.01108 lineto
0.04905 0.01104 lineto
0.05833 0.011 lineto
0.06761 0.01095 lineto
0.07689 0.01088 lineto
0.08617 0.0108 lineto
0.09545 0.01071 lineto
0.11401 0.01046 lineto
0.13257 0.01011 lineto
0.15113 0.00962 lineto
0.16969 0.00893 lineto
0.17897 0.00848 lineto
0.18825 0.00794 lineto
0.19753 0.00729 lineto
0.20681 0.00652 lineto
0.21609 0.00558 lineto
0.22537 0.00444 lineto
0.23465 0.00304 lineto
0.23929 0.00223 lineto
0.24393 0.00133 lineto
0.24625 0.00084 lineto
0.24858 0.00033 lineto
0.24974 6e-05 lineto
0.2509 0.00021 lineto
0.25322 0.00079 lineto
0.2625 0.00344 lineto
0.27178 0.00678 lineto
0.28106 0.01105 lineto
Mistroke
0.29034 0.01659 lineto
0.29962 0.02389 lineto
0.3089 0.03374 lineto
0.31818 0.04736 lineto
0.32282 0.05618 lineto
0.32746 0.06681 lineto
0.3321 0.07976 lineto
0.33674 0.09571 lineto
0.34138 0.11558 lineto
0.34602 0.14062 lineto
0.35066 0.17248 lineto
0.3553 0.21314 lineto
0.36458 0.32595 lineto
0.36922 0.39163 lineto
0.37154 0.42146 lineto
0.3727 0.43454 lineto
0.37386 0.446 lineto
0.37502 0.45562 lineto
0.37618 0.46322 lineto
0.37734 0.46874 lineto
0.3785 0.47219 lineto
0.37966 0.47368 lineto
0.38082 0.47338 lineto
0.38198 0.47149 lineto
0.38314 0.46828 lineto
0.38546 0.45883 lineto
0.38778 0.44687 lineto
0.39242 0.42075 lineto
0.39706 0.39668 lineto
0.4017 0.37694 lineto
0.40634 0.36184 lineto
0.40866 0.35591 lineto
0.41098 0.35098 lineto
0.4133 0.34699 lineto
0.41562 0.34387 lineto
0.41678 0.34262 lineto
0.41794 0.34156 lineto
0.4191 0.3407 lineto
0.42026 0.34003 lineto
0.42142 0.33953 lineto
0.42258 0.33922 lineto
0.42374 0.33908 lineto
0.4249 0.33911 lineto
0.42606 0.3393 lineto
0.42722 0.33966 lineto
0.42838 0.34018 lineto
0.42954 0.34086 lineto
0.43186 0.34268 lineto
0.43418 0.34512 lineto
0.43882 0.35179 lineto
Mistroke
0.44346 0.36086 lineto
0.4481 0.37231 lineto
0.45738 0.40253 lineto
0.46666 0.44227 lineto
0.47594 0.48935 lineto
0.48058 0.51366 lineto
0.48522 0.53649 lineto
0.48986 0.55577 lineto
0.49218 0.56337 lineto
0.49334 0.56654 lineto
0.4945 0.56925 lineto
0.49566 0.57148 lineto
0.49682 0.57321 lineto
0.49798 0.57441 lineto
0.49915 0.57508 lineto
0.50031 0.57521 lineto
0.50147 0.5748 lineto
0.50263 0.57384 lineto
0.50379 0.57237 lineto
0.50611 0.56788 lineto
0.50843 0.56153 lineto
0.51307 0.54413 lineto
0.52235 0.49837 lineto
0.54091 0.40916 lineto
0.55019 0.37715 lineto
0.55483 0.3648 lineto
0.55947 0.35485 lineto
0.56179 0.35078 lineto
0.56411 0.3473 lineto
0.56643 0.34442 lineto
0.56875 0.34214 lineto
0.57107 0.34048 lineto
0.57223 0.33989 lineto
0.57339 0.33945 lineto
0.57455 0.33918 lineto
0.57571 0.33907 lineto
0.57687 0.33913 lineto
0.57803 0.33936 lineto
0.57919 0.33977 lineto
0.58035 0.34036 lineto
0.58151 0.34113 lineto
0.58267 0.34209 lineto
0.58499 0.34461 lineto
0.58731 0.34795 lineto
0.58963 0.35219 lineto
0.59195 0.35737 lineto
0.59659 0.37085 lineto
0.60123 0.38886 lineto
0.60587 0.41146 lineto
0.61051 0.4373 lineto
Mistroke
0.61283 0.45017 lineto
0.61515 0.46163 lineto
0.61631 0.46636 lineto
0.61747 0.47012 lineto
0.61863 0.47267 lineto
0.61979 0.47375 lineto
0.62095 0.47313 lineto
0.62211 0.47063 lineto
0.62327 0.4661 lineto
0.62443 0.45948 lineto
0.62675 0.44019 lineto
0.62907 0.41403 lineto
0.63371 0.3503 lineto
0.63835 0.28601 lineto
0.64299 0.23073 lineto
0.64763 0.18633 lineto
0.65227 0.15146 lineto
0.65691 0.12412 lineto
0.66155 0.10251 lineto
0.66619 0.08525 lineto
0.67083 0.07128 lineto
0.67547 0.05987 lineto
0.68011 0.05043 lineto
0.68939 0.03592 lineto
0.69867 0.02549 lineto
0.70795 0.01778 lineto
0.71723 0.01196 lineto
0.72651 0.00749 lineto
0.73579 0.00399 lineto
0.74043 0.00253 lineto
0.74507 0.00123 lineto
0.74739 0.00063 lineto
0.74855 0.00035 lineto
0.74972 7e-05 lineto
0.75204 0.00047 lineto
0.75436 0.00098 lineto
0.76364 0.00275 lineto
0.77292 0.0042 lineto
0.7822 0.00538 lineto
0.79148 0.00636 lineto
0.80076 0.00716 lineto
0.81932 0.00839 lineto
0.8286 0.00885 lineto
0.83788 0.00924 lineto
0.85644 0.00984 lineto
0.875 0.01027 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 52; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15915 0 0.0309 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.02254 -0.0125 0 1 Msboxa
[(-2)] 0.18169 -0.0125 0 1 Msboxa
[(-1)] 0.34085 -0.0125 0 1 Msboxa
[(1)] 0.65915 -0.0125 0 1 Msboxa
[(2)] 0.81831 -0.0125 0 1 Msboxa
[(3)] 0.97746 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.02254 -0.00625 moveto
0.02254 0.00625 lineto
stroke
0 setgray
[(-3)] 0.02254 -0.0125 0 1 Mshowa
0.18169 -0.00625 moveto
0.18169 0.00625 lineto
stroke
0 setgray
[(-2)] 0.18169 -0.0125 0 1 Mshowa
0.34085 -0.00625 moveto
0.34085 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34085 -0.0125 0 1 Mshowa
0.65915 -0.00625 moveto
0.65915 0.00625 lineto
stroke
0 setgray
[(1)] 0.65915 -0.0125 0 1 Mshowa
0.81831 -0.00625 moveto
0.81831 0.00625 lineto
stroke
0 setgray
[(2)] 0.81831 -0.0125 0 1 Mshowa
0.97746 -0.00625 moveto
0.97746 0.00625 lineto
stroke
0 setgray
[(3)] 0.97746 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
-0.01592 0.01113 moveto
-0.01327 0.01113 lineto
-0.01062 0.01113 lineto
-0.00798 0.01114 lineto
-0.00666 0.01114 lineto
-0.00533 0.01114 lineto
-0.00401 0.01114 lineto
-0.00269 0.01114 lineto
-0.00136 0.01114 lineto
-4e-05 0.01114 lineto
0.00128 0.01114 lineto
0.0026 0.01114 lineto
0.00393 0.01114 lineto
0.00525 0.01114 lineto
0.0079 0.01114 lineto
0.01054 0.01113 lineto
0.01319 0.01113 lineto
0.01583 0.01113 lineto
0.02112 0.01112 lineto
0.02641 0.01111 lineto
0.037 0.01108 lineto
0.04758 0.01105 lineto
0.05816 0.011 lineto
0.06874 0.01094 lineto
0.08991 0.01077 lineto
0.10049 0.01065 lineto
0.11107 0.01051 lineto
0.12166 0.01033 lineto
0.13224 0.01012 lineto
0.14282 0.00986 lineto
0.1534 0.00955 lineto
0.17457 0.0087 lineto
0.18515 0.00813 lineto
0.19573 0.00743 lineto
0.20632 0.00656 lineto
0.2169 0.00549 lineto
0.22748 0.00414 lineto
0.23806 0.00246 lineto
0.24335 0.00145 lineto
0.246 0.0009 lineto
0.24732 0.00061 lineto
0.24865 0.00031 lineto
0.24997 1e-05 lineto
0.25129 0.00031 lineto
0.25261 0.00064 lineto
0.25394 0.00097 lineto
0.25923 0.00243 lineto
0.26981 0.006 lineto
0.28039 0.01071 lineto
0.29098 0.01703 lineto
Mistroke
0.30156 0.02571 lineto
0.30685 0.0313 lineto
0.31214 0.03799 lineto
0.31743 0.04609 lineto
0.32272 0.05598 lineto
0.33331 0.08359 lineto
0.3386 0.10313 lineto
0.34389 0.12838 lineto
0.34918 0.16146 lineto
0.35447 0.20514 lineto
0.35976 0.26221 lineto
0.36505 0.33265 lineto
0.37034 0.40659 lineto
0.37299 0.43756 lineto
0.37431 0.44998 lineto
0.37564 0.45991 lineto
0.37696 0.46715 lineto
0.37828 0.47169 lineto
0.3796 0.47365 lineto
0.38093 0.47327 lineto
0.38225 0.47086 lineto
0.38357 0.46679 lineto
0.38489 0.46143 lineto
0.38622 0.45512 lineto
0.39151 0.42586 lineto
0.3968 0.39793 lineto
0.40209 0.3755 lineto
0.40474 0.36655 lineto
0.40738 0.35905 lineto
0.41003 0.35289 lineto
0.41267 0.34798 lineto
0.41532 0.34423 lineto
0.41797 0.34154 lineto
0.41929 0.34058 lineto
0.42061 0.33986 lineto
0.42193 0.33937 lineto
0.42326 0.33912 lineto
0.42458 0.33908 lineto
0.4259 0.33927 lineto
0.42722 0.33966 lineto
0.42855 0.34027 lineto
0.42987 0.34108 lineto
0.43119 0.34209 lineto
0.43384 0.34472 lineto
0.43648 0.34813 lineto
0.43913 0.35232 lineto
0.44442 0.36303 lineto
0.44971 0.37685 lineto
0.46029 0.41401 lineto
0.47088 0.46301 lineto
Mistroke
0.48146 0.51814 lineto
0.48675 0.54334 lineto
0.4894 0.55405 lineto
0.49204 0.56295 lineto
0.49337 0.56659 lineto
0.49469 0.56964 lineto
0.49601 0.57205 lineto
0.49733 0.5738 lineto
0.49866 0.57486 lineto
0.49998 0.57523 lineto
0.5013 0.57489 lineto
0.50262 0.57385 lineto
0.50395 0.57212 lineto
0.50527 0.56972 lineto
0.50792 0.56307 lineto
0.51056 0.55421 lineto
0.51321 0.54352 lineto
0.52379 0.49075 lineto
0.53437 0.4374 lineto
0.54495 0.39399 lineto
0.55025 0.37698 lineto
0.55554 0.36312 lineto
0.56083 0.35239 lineto
0.56347 0.34819 lineto
0.56612 0.34477 lineto
0.56877 0.34213 lineto
0.57009 0.34111 lineto
0.57141 0.34029 lineto
0.57273 0.33968 lineto
0.57406 0.33928 lineto
0.57538 0.33909 lineto
0.5767 0.33911 lineto
0.57802 0.33936 lineto
0.57935 0.33984 lineto
0.58067 0.34055 lineto
0.58199 0.34151 lineto
0.58332 0.34271 lineto
0.58464 0.34418 lineto
0.58728 0.34791 lineto
0.58993 0.3528 lineto
0.59258 0.35894 lineto
0.59787 0.37534 lineto
0.60316 0.39772 lineto
0.60845 0.42562 lineto
0.61374 0.45491 lineto
0.61506 0.46124 lineto
0.61639 0.46664 lineto
0.61771 0.47075 lineto
0.61903 0.47322 lineto
0.62035 0.47367 lineto
Mistroke
0.62168 0.47179 lineto
0.623 0.46734 lineto
0.62432 0.46018 lineto
0.62961 0.40713 lineto
0.63491 0.33324 lineto
0.6402 0.26272 lineto
0.64549 0.20553 lineto
0.65078 0.16176 lineto
0.65607 0.12861 lineto
0.66136 0.10331 lineto
0.66665 0.08373 lineto
0.67194 0.06834 lineto
0.67724 0.05607 lineto
0.68253 0.04616 lineto
0.68782 0.03805 lineto
0.69311 0.03135 lineto
0.70369 0.02105 lineto
0.71427 0.01365 lineto
0.72486 0.00821 lineto
0.73544 0.00411 lineto
0.74073 0.00245 lineto
0.74338 0.00169 lineto
0.74602 0.00098 lineto
0.74734 0.00065 lineto
0.74867 0.00032 lineto
0.74999 0 lineto
0.75131 0.0003 lineto
0.75264 0.0006 lineto
0.75396 0.00089 lineto
0.7566 0.00144 lineto
0.76719 0.00334 lineto
0.77777 0.00485 lineto
0.78835 0.00605 lineto
0.79893 0.00701 lineto
0.80952 0.00779 lineto
0.8201 0.00843 lineto
0.83068 0.00894 lineto
0.85185 0.00971 lineto
0.86243 0.01 lineto
0.87301 0.01023 lineto
0.88359 0.01042 lineto
0.89418 0.01058 lineto
0.91534 0.01082 lineto
0.92592 0.0109 lineto
0.93651 0.01097 lineto
0.94709 0.01103 lineto
0.95767 0.01107 lineto
0.96296 0.01108 lineto
0.96825 0.0111 lineto
0.97354 0.01111 lineto
Mistroke
0.97884 0.01112 lineto
0.98413 0.01113 lineto
0.98677 0.01113 lineto
0.98942 0.01113 lineto
0.99206 0.01114 lineto
0.99339 0.01114 lineto
0.99471 0.01114 lineto
0.99603 0.01114 lineto
0.99735 0.01114 lineto
1 0.01114 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = special2; inactive; startGroup; Cclosed; ]
(Code to generate the two animations)
:[font = text; inactive; ]
		This code was originally developed under Mathematica 1.2 which did not possess the ability to put two different plots side by side.
:[font = input; ]
Do[VectorPoleZeroPlot[
          (z^2 + 1)/((z-0.8)(z-0.9 Exp[I Pi/4])(z-0.9 Exp[-I  Pi/4])), 
           z, 0.9, Infinity, w, True,
                Dialogue -> False],
   {w,-Pi,Pi,Pi/4}] 
:[font = input; endGroup; endGroup; ]
Do[MagPhasePlot[(z^2 + 1)/((z-0.8)(z-0.9 Exp[I Pi/4])(z-0.9 Exp[-I  Pi/4])) 
                /. z -> Exp[I w], {w,-Pi-0.1,r}, PhaseRangeScale -> Null, 
                PlotRange -> {{-Pi,Pi},{0,20}}],
   {r,-Pi,Pi,Pi/4}]              
          
:[font = subsection; inactive; startGroup; Cclosed; ]
Figure 3:  Inverse z-Transform with Dialogue
:[font = input; startGroup; ]
InvZTransform[ { -8 z / ((z - 3)(3 z - 1)), 1/2, 2 },
				z, n, Dialogue -> All ]
:[font = print; inactive; ]
  -1        -8 z
Z   {-------------------}
  z  (-3 + z) (-1 + 3 z)
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1        -8 z
Z   {-------------------}
  z  (-3 + z) (-1 + 3 z)
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1         -8
Z   {------------------}
  z       3
     (1 - -) (-1 + 3 z)
          z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1         -8
Z   {-------------------}
  z       3        1
     (1 - -) (1 - ---) z
          z       3 z
-------------------------
            3
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
( after the term
:[font = print; inactive; ]
          -8
  -------------------
       3        1
  (1 - -) (1 - ---) z
       z       3 z
:[font = print; inactive; ]
  has been broken up into its partial
:[font = print; inactive; ]
  fractions representation
:[font = print; inactive; ]
    -9       3
  ------ + ------ )
       1        3
  -3 + -   -1 + -
       z        z
:[font = print; inactive; ]
  -1   -9       3
Z   {------ + ------}
  z       1        3
     -3 + -   -1 + -
          z        z
---------------------
          3
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1   -9        -1   3
Z   {------} + Z   {------}
  z       1      z       3
     -3 + -         -1 + -
          z              z
---------------------------
             3
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                 -1   -9
               Z   {-------}
                 z       1
                    1 - ---
   -1   3               3 z
-Z   {-----} - -------------
   z      3          3
      1 - -
          z
----------------------------
             3
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
   n                   1 n
3 3  Step[-1 - n] + 3 (-)  Step[n]
                       3
----------------------------------
                3
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
   n                   1 n
3 3  Step[-1 - n] + 3 (-)  Step[n]
                       3
----------------------------------
                3
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
3^n*Step[-1 - n] + (1/3)^n*Step[n]
;[o]
 n                 1 n
3  Step[-1 - n] + (-)  Step[n]
                   3
:[font = section; inactive; startGroup; Cclosed; ]
Conclusion
:[font = text; inactive; endGroup; ]
		This paper describes how Mathematica's notebook facility could be used by students to supplement classroom lectures and laboratory experience.  Not only can students solve homework problems using Mathematica, but they can document the solution as they go.  The signal processing packages extend Mathematica so that electrical engineering students can tackle rudimentary problems in signal processing and linear systems.  Notebooks can also serve as tutorials.  We have written four notebooks covering the topics of piecewise convolution, analog filter design, the Laplace transform, and the z-transform.  Although some schools are integrating Mathematica into their curricula, we hope that more schools encourage students to use it.
:[font = section; startGroup; Cclosed; ]
References
:[font = subsection; inactive; ]
[1] S. Wolfram.  Mathematica: A System for Doing Mathematics by Computer.  Addison-Wesley, 1988.
:[font = subsection; inactive; ]
[2] M. Slaney.  ``Interactive Signal Processing Documents''.  IEEE ASSP Magazine.  April, 1990.  vol. 7, no. 2, pp. 8-20.
:[font = subsection; inactive; ]
[3] B. Evans, J. McClellan, and W. McClure.  ``Symbolic z-Transforms Using DSP Knowledge Bases''.  IEEE International Conference on Acoustics, Speech, and Signal Processing.  April, 1990.  vol. D, pp. 1775-1778.
:[font = subsection; inactive; ]
[4] B. Evans and J. McClellan.  ``Symbolic Transforms with Applications to Signal Processing''.  Mathematica Journal.  Fall, 1990.  vol. 1, no. 2.  pp. 70-80.
:[font = subsection; inactive; ]
[5] R. Maeder.  Programming in Mathematica.  Addison-Wesley, 1989.
:[font = subsection; inactive; ]
[6] A. Oppenheim and A. Willsky.  Signals and Systems.  Prentice-Hall, 1983.
:[font = subsection; inactive; endGroup; ]
[7] A. Oppenheim and R. Schafer.  Discrete-Time Signal Processing.  Prentice-Hall, 1989.
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)