(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
Testing the Laplace Transform
Capabilities of the 
Signal Processing Packages
:[font = subtitle; inactive; ]

by Brian L. Evans and James H. McClellan
:[font = subsubtitle; inactive; ]

Digital Signal Processing Laboratory
School of Electrical Engineering
Georgia Institute of Technology
Atlanta, GA  30332-0250

EMAIL:  evans@eedsp.gatech.edu
:[font = text; inactive; ]
		This notebook tests the forward bilateral Laplace transform LaPlace and the inverse bilateral Laplace transform InvLaPlace.  These Laplace transform rule bases are a part of the analog signal processing packages.  A user, however, can use the Laplace transform rule bases without possessing any knowledge of signal processing.
:[font = text; inactive; ]
		This notebook should have automatically loaded the analog signal processing packages (see the Initialization section).   If Laplace transforms will be used frequently, then it might be a good idea to rebuild the kernel so that it includes the analog signal packages (see Mathematica's Dump command), since this loading process does take a few minutes under Mathematica 1.2.
:[font = text; inactive; ]
		One advantage of these Laplace rule bases is that the user can ask it (via the Dialogue option) to document the process by which it computes the transform.  Namely, LaPlace and InvLaPlace can completely justify their answers.
:[font = text; inactive; ]
		Remember that to expand a group of cells, just move the mouse to the downward pointing half arrow and double click.  In general, we have grouped cells so that each grouping will only occupy one screen (or less) if the notebook window is resized so that it spans the heighth of the screen.
:[font = input; inactive; center; ]
This notebook is not a tutorial on the
Laplace transform.
:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = input; initialization; startGroup; ]
*)
Needs[ "SignalProcessing`Analog`" ]
(*
:[font = print; inactive; startGroup; ]
Loading version 2.32 of the signal processing support\
 
  packages ...
:[font = print; inactive; ]
Support module has been loaded.
:[font = print; inactive; ]
The knowledge base of signal processing operators has\
 
  been loaded.
:[font = print; inactive; ]
Supporting routines for filter design are loaded.
:[font = print; inactive; ]
Region of convergence routines for the transform rule\
 
  bases are loaded.
:[font = print; inactive; ]
Piecewise convolution rules have been loaded.
:[font = print; inactive; ]
Supporting routines for transform rule bases are loaded.
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically
    loaded (the signal processing packages no longer rely
    on the definitions in these files).
:[font = print; inactive; ]
Loading version 2.32 of the analog signal processing\
 
  packages ...
:[font = print; inactive; ]
The one-dimensional analog filter design objects are\
 
  loaded.
:[font = print; inactive; ]
Supporting routines and objects for the Laplace transform\
 
  are loaded.
:[font = print; inactive; ]
The forward Laplace transform rule base LaPlace has been\
 
  loaded.
:[font = print; inactive; ]
The inverse Laplace transform rule base InvLaPlace has\
 
  been loaded.
:[font = print; inactive; ]
The supporting functions are loaded for symbolic Fourier\
 
  transforms.
:[font = print; inactive; ]
The continuous Fourier transform (CTFT) functions are\
 
  loaded.
:[font = print; inactive; ]
LSolve, a differential equation solver, is loaded.
:[font = print; inactive; ]
The analog signal analyzer is now loaded.
:[font = message; inactive; ]
Analog::loaded: 
   Routines, objects, and rules for the analog signal
    processing packages have been loaded successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
Analog signal processing extensions have been loaded.
:[font = print; inactive; ]
Good starting points are the objects ASPAnalyze and\
 
  LaPlace.
:[font = print; inactive; ]
Active packages are maintained in the variable\
 
  $ContextPath.
:[font = print; inactive; ]
  New signal primitives are in SPsignals.
:[font = print; inactive; ]
  New system primitives are in SPoperators.
:[font = print; inactive; ]
  New Mathematica functions are in SPfunctions.
:[font = print; inactive; ]
Note that all signal processing expressions will
:[font = print; inactive; ]
be automatically simplified.
:[font = print; inactive; endGroup; endGroup; endGroup; ]

:[font = section; inactive; startGroup; Cclosed; ]
References
:[font = subsection; inactive; ]
Ruel Churchill.  Operational Mathematics.  McGraw-Hill, NY.  1958.
:[font = subsection; inactive; ]
Fritz Oberhettinger and Larry Badii.  Tables of Laplace Transforms.  1973.
:[font = subsection; inactive; endGroup; ]
Alan Oppenheim and Allan Willsky.  Signals and Systems.  Prentice Hall, Englewood Cliffs (NJ).  1983.
:[font = section; inactive; startGroup; Cclosed; ]
Forward Laplace Transforms
:[font = text; inactive; startGroup; ]
		The forward Laplace transform rule base transforms a two-sided continuous-time function to the Laplace domain.  In these packages, the Laplace transform of the continuous-time function f(t) is F(s) = L{f(t)} such that
:[font = postscript; inactive; PostScript; locked; output; height = 94; pictureLeft = 62; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.541667 0.0833333 0.833333 0.0833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
gsave
0.0075 setlinewidth
0.375 0.925 moveto
0.3625 0.91667 lineto
0.35417 0.9 lineto
0.35417 0.76667 lineto
0.34583 0.75 lineto
0.33333 0.74167 lineto
stroke
gsave
/Plain findfont 14 scalefont setfont
[(L{f\(t\)} =)] 0.29167 0.83333 1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.41667 0.925 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.43333 0.925 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.40833 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.425 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(-)] 0.375 0.74167 0 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(f\(t\))] 0.45833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(e)] 0.58333 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(dt)] 0.70833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(-st)] 0.625 0.875 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(\(1\))] 0.875 0.83333 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; endGroup; ]
In order that a transform's inverse can be specified uniquely, LaPlace tracks the region of convergence of the transform.
:[font = subsection; inactive; startGroup; Cclosed; ]
Invoking the Forward Laplace Transform Rule Base
:[font = text; inactive; ]
		To invoke LaPlace, a user must specify the function and the time variable(s) to the rule base.  For example, the two-sided Laplace transform of f(t) = 1 is Delta[s]:
:[font = input; startGroup; ]

LaPlace[ 1, t ]
:[font = output; inactive; output; endGroup; ]
LTransData[Delta[s], Rminus[0], Rplus[0], LVariables[s]]
;[o]
LTransData[Delta[s], Rminus[0], Rplus[0], LVariables[s]]
:[font = text; inactive; ]

Notice that the Laplace transform rule base returns an object with a head of LTransData.  The slots of LTransData are the Laplace transform function, its region of convergence (two slots), and the Laplace transform variables.  In this case, LaPlace used "s" as the transform variable (the default). 
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Two-sided and one-sided transforms
:[font = text; inactive; ]
		The Laplace transform assumes that the time function is two-sided.  In order to specify a one-sided time function, the continuous step function CStep should appear in each multiplicative term.  For example, the Laplace transform of f(t) = { 1 for t > 0, 1/2 for t = 0, and 0 elsewhere } is 1/s:
:[font = input; startGroup; ]

LaPlace[ CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[s^(-1), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
           1
LTransData[-, Rminus[0], Rplus[Infinity], 
           s
 
  LVariables[s]]
:[font = text; inactive; ]

CStep[t] is the continuous step function.  The left-sided version of  this function, CStep[-t], has the following Laplace transform:
:[font = input; startGroup; ]

LaPlace[ CStep[-t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[-s^(-1), Rminus[DirectedInfinity[-1]], 
  Rplus[0], LVariables[s]]
;[o]
             1
LTransData[-(-), Rminus[-Infinity], Rplus[0], 
             s
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Optional arguments (options)
:[font = text; inactive; ]
		If a user supplies the Laplace transform variable, then the user can also specify options.  The default options are:
:[font = input; startGroup; ]

Options[LaPlace]
:[font = output; inactive; output; endGroup; ]
{Dialogue -> True, Simplify -> True, 
  TransformLookup -> {}}
;[o]
{Dialogue -> True, Simplify -> True, 
 
  TransformLookup -> {}}
:[font = text; inactive; ]

:[font = subsubtitle; inactive; startGroup; Cclosed; left; ]
-- Dialogue Option
:[font = text; inactive; ]
		If set to True or All, the Dialogue setting will cause LaPlace to report any assumptions being made about the parameters in the continuous-time function.  It will also report those functions which it could not transform.  Proper usage of the Dialogue option is:
:[font = input; startGroup; ]

LaPlace[ Exp[t], t, s, Dialogue -> True ]
:[font = message; inactive; startGroup; ]
Transform::incomplete: 
   The rule base could not compute the 
                                  t
    forward Laplace transform of E  with respect to t.
:[font = output; inactive; output; endGroup; endGroup; ]
MakeLObject[SignalProcessing`Analog`LaPlace`Private`mylapla\
    ce[E^t, t, s, {True, True, False, False, False, False, 
    False}, {t}, {s}, {Dialogue -> True, Dialogue -> True, 
    Simplify -> True}], s]
;[o]
-Incomplete Laplace Transform-
:[font = text; inactive; endGroup; ]

In this case, we have asked for the two-sided Laplace transform of Exp[t], which does not exist.  Since Dialogue is enabled (which is the default anyway), LaPlace reports that it cannot find the transform of Exp[t].  Whether Dialogue is enabled or not, the Laplace rule base will return an invalid Laplace transform object for those forward transform which do not exist.
:[font = subsubtitle; inactive; startGroup; Cclosed; left; ]
-- TransformLookup Option
:[font = text; inactive; ]
		The TransformLookup option allows users to specify their own transform pairs.  One consequence of this is that users can now to transforms of general functions like x[t] without having to define x[t] as a formula.  For example,
:[font = input; startGroup; ]
LaPlace[ a x[t], t, s, TransformLookup -> {x[t] :> X[s]} ]
:[font = output; inactive; output; endGroup; ]
LTransData[a*X[s], Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
LTransData[a X[s], Rminus[0], Rplus[Infinity], 
 
  LVariables[s]]
:[font = text; inactive; endGroup; ]
Here, we have let the Laplace transform of x[t] be X[s].
:[font = subsubtitle; inactive; startGroup; Cclosed; left; ]
-- Simplify Option
:[font = text; inactive; endGroup; endGroup; endGroup; ]
		The other option is Simplify.  If true, the signal processing simplification rules (SPSimplificationRules) are applied to the entire transform object (including the region of convergence information).   This rule base reduces expressions involving the abs, conj, imag, max, min, and real operators in Mathematica (Abs, Conjugate, Im, Max, Min, and Re, respectively).  The LaPlace rule base runs faster when this option is disabled, but the expressions for the limits on the region of convergence will not be simplified.
:[font = subsection; inactive; startGroup; Cclosed; ]
Organization of the Forward Laplace Transform Rule Base
:[font = text; inactive; ]
		The forward Laplace transform rule base transforms one-dimensional and multidimensional expressions.  The dimension of the transform is equal to the number of  time variables passed to LaPlace.  For each dimension, LaPlace calls a one-dimensional rule base is called.  The one-dimensional rule base, MyLaPlace, is an ordered collection of 95 rules:
:[font = input; initialization; startGroup; ]
*)
Length[SignalProcessing`Analog`LaPlace`Private`LaPlaceRules]
(*
:[font = output; inactive; output; endGroup; ]
97
;[o]
97
:[font = text; inactive; ]
These rules are grouped into six sections:
:[font = output; inactive; output; center; ]
MatrixForm[{"I.   multidimensional hooks     3 rules", 
   "II.  rational transform pairs  13 rules", 
   "III. non-rat. transform pairs  38 rules", 
   "IV.  transform properties      20 rules", 
   "V.   transforms of operators   12 rules", 
   "VI.  transform strategies       9 rules"}]
;[o]
I.   multidimensional hooks     3 rules
 
II.  rational transform pairs  13 rules
 
III. non-rat. transform pairs  38 rules
 
IV.  transform properties      20 rules
 
V.   transforms of operators   12 rules
 
VI.  transform strategies       9 rules
:[font = text; inactive; endGroup; ]
The multidimensional hooks are only necessary to maintain the region of convergence for non-separable multidimensional functions.  For the most part, the transform pairs and properties are adapted from tables in Bracewell's {The Fourier Transform and Its Applications} and Churchill's {Operational Mathematics}.   The Laplace transforms of operators were adapted from these sources as well as from {Tables of Laplace Transforms} by Oberhettinger and Badii.  The strategies were ad hoc rules to massage expressions into the right form for transformation.
:[font = subsection; inactive; startGroup; Cclosed; ]
Rational One-Dimensional Transforms
:[font = text; inactive; ]
		The Laplace transform of f(t) = 1 for t > 0  is rational.  That is, the Laplace transform function is a rational polynomial.
:[font = text; inactive; ]
		The Laplace rule base transforms time functions by using lookup tables.  The following four transforms require the use of one Laplace transform property --  they all use the fact that multiplying f(t) by an exponential function is the transform of f(t) shifted by -a.  The last two also invoke the additivity property.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Transforms requiring only one property
:[font = input; startGroup; ]

LaPlace[ t Exp[a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-a + s)^(-2), Rminus[Real[a]], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                   -2
LTransData[(-a + s)  , Rminus[Real[a]], Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ t^(n-1) Exp[a t] CStep[t] / Gamma[n], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-a + s)^(-n), Rminus[Real[a]], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                   -n
LTransData[(-a + s)  , Rminus[Real[a]], Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ ( Exp[a t] - Exp[b t] ) CStep[t] / ( a - b ), t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[1/((-a + s)*(-b + s)), Rminus[Max[Real[a], Real[b]]], Rplus[DirectedInfinity[1]], 
  LVariables[s]]
;[o]
                   1
LTransData[-----------------, Rminus[Max[Real[a], Real[b]]], Rplus[Infinity], LVariables[s]]
           (-a + s) (-b + s)
:[font = input; startGroup; ]

LaPlace[ ( a Exp[a t] - b Exp[b t] ) CStep[t] / ( a - b ), t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[s/((-a + s)*(-b + s)), Rminus[Max[Real[a], Real[b]]], Rplus[DirectedInfinity[1]], 
  LVariables[s]]
;[o]
                   s
LTransData[-----------------, Rminus[Max[Real[a], Real[b]]], Rplus[Infinity], LVariables[s]]
           (-a + s) (-b + s)
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Four common rational transforms
:[font = input; startGroup; ]
LaPlace[ t CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[s^(-2), Rminus[0], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
            -2
LTransData[s  , Rminus[0], Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]
LaPlace[ t CStep[t] - CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[-((-1 + s)/s^2), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             -1 + s
LTransData[-(------), Rminus[0], Rplus[Infinity], 
                2
               s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ t^(n - 1) CStep[t] / Gamma[n], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[s^(-n), Rminus[0], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
            -n
LTransData[s  , Rminus[0], Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Exp[a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(-a + s)^(-1), Rminus[Real[a]], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[Real[a]], Rplus[Infinity], LVariables[s]]
           -a + s
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Hyperbolic Functions
:[font = text; inactive; ]

		Mathematica automatically translates Sinh[a t] into ( - Exp[- a t] + Exp[a t] ) / 2 so that the Laplace transform rule base does not need a lookup rule for the hyperbolic sine.  This is also true for Cosh[a t], which is always rewritten as ( Exp[- a t] + Exp[a t] ) / 2.
:[font = input; startGroup; ]

LaPlace[ Sinh[a t] CStep[t] / a, t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-a^2 + s^2)^(-1), Rminus[Max[-Re[a], Re[a]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
              1
LTransData[--------, Rminus[Max[-Re[a], Re[a]]], 
             2    2
           -a  + s
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Cosh[a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[s/(-a^2 + s^2), Rminus[Max[-Re[a], Re[a]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
              s
LTransData[--------, Rminus[Max[-Re[a], Re[a]]], 
             2    2
           -a  + s
 
  Rplus[Infinity], LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Transforms of Sinusoids
:[font = text; inactive; ]

		Here are some examples of  transforms of  terms involving only sinusoidal functions:

:[font = input; startGroup; ]
LaPlace[ Sin[a t] CStep[t] / a, t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(a^2 + s^2)^(-1), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
              1
LTransData[-------, Rminus[0], Rplus[Infinity], 
            2    2
           a  + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Cos[a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[s/(a^2 + s^2), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
              s
LTransData[-------, Rminus[0], Rplus[Infinity], 
            2    2
           a  + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ ( 1 - Cos[a t] ) CStep[t] / a^2, t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(a^2*s + s^3)^(-1), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
               1
LTransData[---------, Rminus[0], Rplus[Infinity], 
            2      3
           a  s + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ ( a t - Sin[a t] ) CStep[t] / a^3, t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(a^2*s^2 + s^4)^(-1), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
               1
LTransData[----------, Rminus[0], Rplus[Infinity], 
            2  2    4
           a  s  + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ ( Sin[a t] - a t Cos[a t] ) CStep[t] / ( 2 a^3 ), t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(a^2 + s^2)^(-2), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             2    2 -2
LTransData[(a  + s )  , Rminus[0], Rplus[Infinity], 
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ t Sin[a t] CStep[t] / ( 2 a ), t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[s/(a^2 + s^2)^2, Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
               s
LTransData[----------, Rminus[0], Rplus[Infinity], 
             2    2 2
           (a  + s )
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ t Cos[a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[-(((a - s)*(a + s))/(a^2 + s^2)^2), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             (a - s) (a + s)
LTransData[-(---------------), Rminus[0], Rplus[Infinity], 
                 2    2 2
               (a  + s )
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Sinusoids Mixed With Other Functions
:[font = text; inactive; ]

		The next three examples involving continuous-time functions which are a mixture of sinusoidal and exponential terms.  The first two examples are damped sinusoids.
:[font = input; startGroup; ]

LaPlace[ Exp[a t] Sin[b t] CStep[t] / b, t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(b^2 + (-a + s)^2)^(-1), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                 1
LTransData[--------------, Rminus[Re[a]], 
            2           2
           b  + (-a + s)
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Exp[a t] Cos[b t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-a + s)/(b^2 + (-a + s)^2), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
               -a + s
LTransData[--------------, Rminus[Re[a]], Rplus[Infinity], 
            2           2
           b  + (-a + s)
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ ( Sin[a t] Cosh[a t] - Cos[a t] Sinh[a t] ) CStep[t],
		 t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(4*a^3)/(4*a^4 + s^4), 
  Rminus[Max[-Re[a], Re[a]]], Rplus[DirectedInfinity[1]], 
  LVariables[s]]
;[o]
                3
             4 a
LTransData[---------, Rminus[Max[-Re[a], Re[a]]], 
              4    4
           4 a  + s
 
  Rplus[Infinity], LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Other Rational Transforms
:[font = text; inactive; ]

		For the most part, rational transforms represent some combination of continuous-time exponential and sinusoidal functions.  Another example of this is the forward Laplace transform of a Laguerre polynomial of order n:
:[font = input; startGroup; ]
LaPlace[ LaguerreL[n, t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-1 + s)^n*s^(-1 - n), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                   n  -1 - n
LTransData[(-1 + s)  s      , Rminus[0], Rplus[Infinity], 
 
  LVariables[s]]
:[font = text; inactive; ]

One rational transform pair which does not contain sinusoidal or exponential terms is:
:[font = input; startGroup; ]

LaPlace[ (t / (2 a))^(k - 1/2) BesselJ[k - 1/2, a t] CStep[t] /
		  Gamma[k], t, s ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
LTransData[1/(Pi^(1/2)*(a^2 + s^2)^k), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                    1
LTransData[-------------------, Rminus[0], Rplus[Infinity], 
                      2    2 k
           Sqrt[Pi] (a  + s )
 
  LVariables[s]]
:[font = subsection; inactive; startGroup; Cclosed; ]
Non-rational One-Dimensional Transforms
:[font = text; inactive; ]

		More transform pairs exist for non-rational transforms than for rational ones.  In general, these non-rational transform pairs involve continuous-time Bessel and error functions as well as those of the continuous-time cosine, sine, and exponential integrals:
		
								Conventional							Mathematica
									Notation																	Code

									Ci	(t)																	CosIntegral	[t]	
									Si	(t)																	SinIntegral[t]
									Ei (t)																ExpIntegralEi[t]
									Erf(t)															Erf[t]	

									In(t)																	BesselI[n, t]																		
									Jn(t)																	BesselJ[n, t]
									Kn(t)															BesselK[n, t]
									Ln(t)																BesselL[n, t]


Here are several transform pairs involving these functions:
:[font = input; startGroup; ]

LaPlace[ ( 1 / Sqrt[Pi t] + a Exp[a^2 t] Erf[a Sqrt[t]] ) CStep[t],
		 t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[s^(1/2)/(-a^2 + s), Rminus[Max[0, Re[a^2]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
           Sqrt[s]                    2
LTransData[-------, Rminus[Max[0, Re[a ]]], Rplus[Infinity], 
             2
           -a  + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ -2 CosIntegral[t / k] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[Log[1 + k^2*s^2]/s, Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                    2  2
           Log[1 + k  s ]
LTransData[--------------, Rminus[0], Rplus[Infinity], 
                 s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ ( 2 Log[Pi] - 2 CosIntegral[Pi t] ) CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[Log[Pi^2 + s^2]/s, Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                 2    2
           Log[Pi  + s ]
LTransData[-------------, Rminus[0], Rplus[Infinity], 
                 s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ CosIntegral[a t + b] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[-(E^((b*s)/a)*a*Log[1 + s^2/a^2])/(2*s*Abs[a]), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                                 2
              (b s)/a           s
           -(E        a Log[1 + --])
                                 2
                                a
LTransData[-------------------------, Rminus[0], Rplus[Infinity], 
                  2 s Abs[a]
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ - ExpIntegralEi[- t / k] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[Log[1 + k*s]/s, Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
           Log[1 + k s]
LTransData[------------, Rminus[0], Rplus[Infinity], 
                s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Sin[k t] CStep[t] / t, t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[ArcTan[k/s], Rminus[Abs[Im[k]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                  k
LTransData[ArcTan[-], Rminus[Abs[Im[k]]], Rplus[Infinity], 
                  s
 
  LVariables[s]]
:[font = text; inactive; ]
Alternatively,
:[font = input; startGroup; ]
LaPlace[ k Sinc[k t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(k*ArcTan[k/s])/Abs[k], Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                    k
           k ArcTan[-]
                    s
LTransData[-----------, Rminus[0], Rplus[Infinity], 
             Abs[k]
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ SinIntegral[k t + b] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(E^((b*s)/k)*ArcTan[k/s])/s, Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
            (b s)/k        k
           E        ArcTan[-]
                           s
LTransData[------------------, Rminus[0], Rplus[Infinity], 
                   s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ CStep[t - k] / Sqrt[Pi t], t, s ]   (* incorrect *)
:[font = output; inactive; output; endGroup; ]
LTransData[s^(-1/2), Rminus[0], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
              1
LTransData[-------, Rminus[0], Rplus[Infinity], LVariables[s]]
           Sqrt[s]
:[font = input; startGroup; ]

LaPlace[ Sin[2 k Sqrt[t]] CStep[t] / ( Pi t ), t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[Erf[k/s^(1/2)], Rminus[DirectedInfinity[-1]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                  k
LTransData[Erf[-------], Rminus[-Infinity], Rplus[Infinity], 
               Sqrt[s]
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ BesselI[n, a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(s - (-a^2 + s^2)^(1/2))^n/
   (a^n*(-a^2 + s^2)^(1/2)), Rminus[Abs[Re[a]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                       2    2  n
           (s - Sqrt[-a  + s ])
LTransData[---------------------, Rminus[Abs[Re[a]]], 
              n        2    2
             a  Sqrt[-a  + s ]
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ 2 BesselK[0, 2 Sqrt[2 k t]] CStep[t] / Sqrt[Pi t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(E^(k/s)*BesselK[0, k/s])/s^(1/2), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
            k/s            k
           E    BesselK[0, -]
                           s
LTransData[------------------, Rminus[0], Rplus[Infinity], 
                Sqrt[s]
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ HermiteH[3, Sqrt[t]] CStep[t] / ( 3! Sqrt[Pi] ), t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(1 - s)/s^(5/2), Rminus[0], Rplus[DirectedInfinity[1]], 
  LVariables[s]]
;[o]
           1 - s
LTransData[-----, Rminus[0], Rplus[Infinity], LVariables[s]]
            5/2
           s
:[font = subsection; inactive; startGroup; Cclosed; ]
Properties
:[font = text; inactive; ]

		The LaPlace rule base implements the following properties:

Additivity																							L{a(t) + b(t)}			 = L{a(t)} + L{b(t)}
Homogeneity																						L{c a(t)}												= c L{a(t)
Shift-in-Time																						L{f(t - c)}											= exp(- c s) L{f(t)}
Multiplication-by-Exponential						exp(c t) L{f(t)}		= L{f(t)}, s -> s - c
Multiplication-by-Time																		L{t f(t)}														= - d/ds L{f(t)}
Sinusoidal Modulation																							
Reversal-in-Time																				L{f(-t)}															= L{f(t)}, s -> -s
Similarity																							L{f(c t}}													= L{f(t)} / |c|, s -> s/c
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Additivity
:[font = text; inactive; ]

		The Laplace transform of a(t) + b(t) is A(s), the Laplace transform of a(t), plus B(s), the Laplace transform of b(t).  The new region of convergence contains the intersection of the region of convergence of A(s) and B(s):
:[font = input; startGroup; ]

LaPlace[ Delta[t] + CStep[t - 1], t, s, Dialogue -> All ]
:[font = print; inactive; startGroup; ]
L  {CStep[-1 + t] + Delta[t]}
  t
which becomes
L  {CStep[-1 + t]} + L  {Delta[t]}
  t                    t
which becomes
L  {CStep[t]}
  t
------------- + Transform[1, -Infinity, Infinity]
      s
     E
which becomes
               1
Transform[1 + ----, 0, Infinity]
               s
              E  s
which becomes
               1
Transform[1 + ----, 0, Infinity]
               s
              E  s
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
LTransData[1 + 1/(E^s*s), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                1
LTransData[1 + ----, Rminus[0], Rplus[Infinity], 
                s
               E  s
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Homogeneity
:[font = text; inactive; ]

		This property moves all terms not dependent on the time variable outside of the Laplace transform operator with no effect on the region of convergence:

:[font = input; startGroup; ]
LaPlace[ A K CStep[t] / 2, t, s, Dialogue -> All ]
:[font = print; inactive; startGroup; ]
    A K CStep[t]
L  {------------}
  t      2
which becomes
A K L  {CStep[t]}
      t
-----------------
        2
which becomes
          A K
Transform[---, 0, Infinity]
          2 s
which becomes
          A K
Transform[---, 0, Infinity]
          2 s
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
LTransData[(A*K)/(2*s), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
           A K
LTransData[---, Rminus[0], Rplus[Infinity], LVariables[s]]
           2 s
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Shift-in-Time
:[font = input; startGroup; ]

LaPlace[ Exp[t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-1 + s)^(-1), Rminus[1], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[1], Rplus[Infinity], 
           -1 + s
 
  LVariables[s]]
:[font = input; startGroup; ]
LaPlace[ Exp[t - 7] CStep[t - 7], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[1/(E^(7*s)*(-1 + s)), Rminus[1], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                 1
LTransData[-------------, Rminus[1], Rplus[Infinity], 
            7 s
           E    (-1 + s)
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Multiplication-by-Exponential
:[font = text; inactive; ]

		The multiplication of f(t) by exp(a t)  shifts F(s), the Laplace transform of  f(t), to the right by a, and the region of convergence is shifted by the real part of a:
:[font = input; startGroup; ]

LaPlace[ Cos[t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[s/(1 + s^2), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             s
LTransData[------, Rminus[0], Rplus[Infinity], 
                2
           1 + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Exp[a t] Cos[t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(-a + s)/(1 + (-a + s)^2), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
              -a + s
LTransData[-------------, Rminus[Re[a]], Rplus[Infinity], 
                       2
           1 + (-a + s)
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Multiplication-by-Time 
:[font = text; inactive; ]

		Multiplication in time corresponds to differentiation in the Laplace domain with no effect on the region of convergence:
:[font = input; startGroup; ]

LaPlace[ Exp[a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-a + s)^(-1), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[Re[a]], Rplus[Infinity], 
           -a + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ t Exp[a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(-a + s)^(-2), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                   -2
LTransData[(-a + s)  , Rminus[Re[a]], Rplus[Infinity], 
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Sinusoidal Modulation
:[font = input; startGroup; ]

LaPlace[ BesselJ[v, a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-s + (a^2 + s^2)^(1/2))^v/
   (a^v*(a^2 + s^2)^(1/2)), Rminus[Abs[Im[a]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                       2    2  v
           (-s + Sqrt[a  + s ])
LTransData[---------------------, Rminus[Abs[Im[a]]], 
              v       2    2
             a  Sqrt[a  + s ]
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]
LaPlace[ Sin[a t] BesselJ[v, a t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[I/2*(-((I*a - s + (-2*I*a*s + s^2)^(1/2))^v/
        (a^v*(-2*I*a*s + s^2)^(1/2))) + 
     (-I*a - s + (2*I*a*s + s^2)^(1/2))^v/
      (a^v*(2*I*a*s + s^2)^(1/2))), Rminus[Abs[Im[a]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                                            2  v
           I    (I a - s + Sqrt[-2 I a s + s ])
LTransData[- (-(--------------------------------) + 
           2          v                  2
                     a  Sqrt[-2 I a s + s ]
 
                                 2  v
     (-I a - s + Sqrt[2 I a s + s ])
     --------------------------------), Rminus[Abs[Im[a]]], 
           v                 2
          a  Sqrt[2 I a s + s ]
 
  Rplus[Infinity], LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Reversal-in-Time
:[font = input; startGroup; ]

LaPlace[ Exp[t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-1 + s)^(-1), Rminus[1], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[1], Rplus[Infinity], 
           -1 + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Exp[-t] CStep[-t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(-1 - s)^(-1), Rminus[DirectedInfinity[-1]], 
  Rplus[-1], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[-Infinity], Rplus[-1], 
           -1 - s
 
  LVariables[s]]
:[font = input; startGroup; ]
LaPlace[ Exp[-t] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(1 + s)^(-1), Rminus[-1], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[-----, Rminus[-1], Rplus[Infinity], 
           1 + s
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Similarity
:[font = input; startGroup; ]

LaPlace[ Delta[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[1, Rminus[DirectedInfinity[-1]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
LTransData[1, Rminus[-Infinity], Rplus[Infinity], 
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Delta[a t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
LTransData[Abs[a]^(-1), Rminus[DirectedInfinity[-1]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[-Infinity], Rplus[Infinity], 
           Abs[a]
 
  LVariables[s]]
:[font = subsection; inactive; startGroup; Cclosed; ]
Transforms of Operators
:[font = text; inactive; ]
		The LaPlace rule base also transforms these operators:

Absolute Value			L{ f(abs(t)) } = L{ f(t) u(t) } + L{ f(-t) u(-t) }
Conjugation				L{ Conjugate{f(t)} } = Conjugate{ F( Conjugate(s) ) }
Convolution			    L{ Convolve   {a(t),  b(t)} } = A(s) B(s)
																												t
Derivative					L{ d/dt a(t) } = s F(s) - f(+0)
										    t
Integral						L{ 	/   f(r) dr } =  F(s) / s 
											0
Imaginary					L{ Im{f(t)} } =
																																															P
Periodic						L{ Periodic							f(t) }  = /  exp(-s t) f(t) dt   /  ( 1- exp(-P s) )
																									P, t														0
Real								L{ Re{f(t)} } =
Reverse						L{ Rev    f(t) } = 
																			t
Shift							L{ Shift					  f(t) } = Exp[- a s] F(s)
																			a, t

:[font = input; startGroup; ]

LaPlace[ Exp[-Abs[a t]], t, s ]
:[font = print; inactive; startGroup; ]
Rewriting the two-sided expression
 -Abs[t]
E
as a left-sided plus a right-sided function:
 t             CStep[t]
E  CStep[-t] + --------
                   t
                  E
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(2*a^2)/(a^2*Abs[a] - s^2*Abs[a]), 
  Rminus[Min[-a, a]], Rplus[Max[-a, a]], LVariables[s]]
;[o]
                      2
                   2 a
LTransData[---------------------, Rminus[Min[-a, a]], 
            2           2
           a  Abs[a] - s  Abs[a]
 
  Rplus[Max[-a, a]], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Conjugate[ Exp[a t] CStep[t] ], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[Conjugate[-(a + Conjugate[s])^(-1)], 
  Rminus[DirectedInfinity[-1]], Rplus[-Re[a]], LVariables[s]]
;[o]
                              1
LTransData[Conjugate[-(----------------)], 
                       a + Conjugate[s]
 
  Rminus[-Infinity], Rplus[-Re[a]], LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Convolve[All, All, t]
				 [Exp[a t] CStep[t], Exp[b t] CStep[t]],
		 t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[1/((-a + s)*(-b + s)), Rminus[Max[Re[a], Re[b]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                   1
LTransData[-----------------, Rminus[Max[Re[a], Re[b]]], 
           (-a + s) (-b + s)
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]
LaPlace[ Periodic[L, t][ Exp[a t] ] CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(E^(L*a) - E^(L*s))/((-1 + E^(L*s))*(a - s)), 
  Rminus[Re[a]], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                L a    L s
               E    - E
LTransData[-------------------, Rminus[Re[a]], 
                  L s
           (-1 + E   ) (a - s)
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]
LaPlace[ Rev[t][Exp[a t] CStep[t]], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[-(a + s)^(-1), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
               1
LTransData[-(-----), Rminus[Re[a]], Rplus[Infinity], 
             a + s
 
  LVariables[s]]
:[font = input; startGroup; ]

LaPlace[ Shift[L, t][Exp[a t] CStep[t]], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[1/(E^(L*s)*(-a + s)), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                 1
LTransData[-------------, Rminus[Re[a]], Rplus[Infinity], 
            L s
           E    (-a + s)
 
  LVariables[s]]
:[font = subsection; inactive; startGroup; Cclosed; ]
Strategies
:[font = text; inactive; ]
		The LaPlace rule base relies on these strategies:
		
(1)	Place affine exponential divided by another affine exponential into one exponential
(2)	Distribute product terms like (t + 1)(t + 2) into t^2 + 3 t + 2
(3) 	Expand out all terms in the numerators of the current expression
(4)	Expand out all terms in the current expression
(5)	Assume that the function is a two-sided function
(6)	Replace all signal processing operators and functions by their mathematical
		definitions
:[font = text; inactive; endGroup; ]
Although similarity is a property, placing the two similarity rules in the property section produced undesirable results, so these rules were moved to this (the last) section.
:[font = subsection; inactive; startGroup; Cclosed; ]
Multidimensional Transforms
:[font = text; inactive; ]

		The LaPlace rule base can find the Laplace transform of multidimensional functions.  Here is the Laplace transform of a two-dimensional separable function:
:[font = input; startGroup; ]

LaPlace[ Exp[a t1] Exp[b t2] CStep[t1,t2], {t1,t2}, {s1,s2} ]
:[font = output; inactive; output; endGroup; ]
LTransData[1/((-a + s1)*(-b + s2)), Rminus[{Re[a], Re[b]}], 
  Rplus[{DirectedInfinity[1], DirectedInfinity[1]}], LVariables[{s1, s2}]]
;[o]
                    1
LTransData[-------------------, Rminus[{Re[a], Re[b]}], 
           (-a + s1) (-b + s2)
 
  Rplus[{Infinity, Infinity}], LVariables[{s1, s2}]]
:[font = text; inactive; ]

Here is a Laplace transform of a non-separable continuous-time function.  This function only takes values along the line t1 = t2.  In this context, Delta[t1 -t2] behaves as a line impulse.  The two-dimensional Laplace transform actually reduces to the one-dimensional transform of Exp[a t] CStep[t] augmented by the substitution s = s1 + s2.  The difficulty here is maintaining the two-dimensional region of convergence:
:[font = input; startGroup; ]

LaPlace[ Exp[a t1] Delta[t1 - t2] CStep[t1,t2], {t1,t2} ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[(-a + s1 + s2)^(-1), Rminus[{Re[a], Re[a]}], 
  Rplus[{DirectedInfinity[1], DirectedInfinity[1]}], 
  LVariables[{s1, s2}]]
;[o]
                1
LTransData[------------, Rminus[{Re[a], Re[a]}], 
           -a + s1 + s2
 
  Rplus[{Infinity, Infinity}], LVariables[{s1, s2}]]
:[font = subsection; inactive; startGroup; Cclosed; ]
Transforms That LaPlace Cannot Find
:[font = text; inactive; ]

		It should be no surprise that the LaPlace rule base cannot compute the Laplace of every function that has one.  This one works now (but it did not use to work):
:[font = input; startGroup; ]

LaPlace[ ( Exp[b t] - Exp[a t] ) CStep[t] / (2 Sqrt[Pi t^3]),
		 t, s ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
LTransData[(-a + s)^(1/2) - (-b + s)^(1/2), 
  Rminus[Max[Re[a], Re[b]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
LTransData[Sqrt[-a + s] - Sqrt[-b + s], 
 
  Rminus[Max[Re[a], Re[b]]], Rplus[Infinity], 
 
  LVariables[s]]
:[font = section; inactive; startGroup; Cclosed; ]
Inverse Laplace Transforms
:[font = text; inactive; startGroup; ]

		The inverse Laplace transform rule base is InvLaPlace.  InvLaPlace returns the two-sided continuous-time function f(t) that represents the Laplace transform F(s): 
:[font = postscript; inactive; PostScript; locked; output; height = 94; pictureLeft = 71; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.583333 0.0833333 0.833333 0.0833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
gsave
0.0075 setlinewidth
0.41667 0.925 moveto
0.40417 0.91667 lineto
0.39583 0.9 lineto
0.39583 0.76667 lineto
0.3875 0.75 lineto
0.375 0.74167 lineto
stroke
newpath
0.39583 0.83333 0.01667 0 365.73 arc
stroke
gsave
/Plain findfont 14 scalefont setfont
[(L)] 0 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[({F\(s\)})] 0.08333 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(=)] 0.275 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(-1)] 0.03333 0.88333 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.49167 0.95833 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(a+jo)] 0.5 0.95833 1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(o)] 0.425 0.70833 -1 0 Mshowa
grestore
gsave
/Plain findfont 12 scalefont setfont
[(a-jo)] 0.43333 0.70833 1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(F\(s\))] 0.47917 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(e)] 0.60833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(ds)] 0.70833 0.83333 -1 0 Mshowa
grestore
gsave
/Plain findfont 10 scalefont setfont
[(st)] 0.65 0.875 -1 0 Mshowa
grestore
gsave
/Plain findfont 14 scalefont setfont
[(\(2\))] 0.91667 0.83333 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; endGroup; ]
[Oppenheim and Willsky, 1983].  This is an integral of a function of complex variable s (which is different from the forward Laplace transform definition which involves an integral of real variable t).  In this case, the contour of integration is a vertical line through (a, 0) connected with a semicircle of  infinite radius in the s-plane.
:[font = subsection; inactive; startGroup; Cclosed; ]
Invoking the Inverse Laplace Transform Rule Base
:[font = text; inactive; ]
		The calling sequence for InvLaPlace is similar to that for LaPlace:
:[font = input; startGroup; ]

InvLaPlace[ 1/s, s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]
;[o]
CStep[t]
:[font = text; inactive; ]

Again, the third argument is optional and defaults to t.  If the time variable is provided, then these options can also be used:
:[font = input; startGroup; ]

Options[ InvLaPlace ]
:[font = output; inactive; output; endGroup; ]
{Apart -> Rational, Dialogue -> True, Simplify -> True, 
  Terms -> 10, TransformLookup -> {}}
;[o]
{Apart -> Rational, Dialogue -> True, Simplify -> True, 
 
  Terms -> 10, TransformLookup -> {}}
:[font = text; inactive; ]

For the meaning of the Dialogue, TransformLookup, and Simplify options, see the Introduction to the Forward Laplace Transforms section.  The Dialogue -> All option will still cause the rule base to display each step of the transformation process. 
:[font = subsubtitle; inactive; startGroup; Cclosed; left; ]
-- Terms Option
:[font = text; inactive; endGroup; ]
		The Terms options specifies how many terms to use if a power series expansion is used.  Setting Terms to False disables the Power Series Strategy for that call to the rule base.  The power series strategy is only used if all other attempts an obtaining the inverse have been tried.
:[font = subsubtitle; inactive; startGroup; Cclosed; left; ]
-- Apart Option
:[font = text; inactive; endGroup; endGroup; ]
		This option is an attempt to work around the way that Mathematica does partial fractions decompositions.  Mathematica requires that the factors be rational numbers.  However, as engineers, there are times that we would like to perform this decomposition with real-valued roots, even though such an expansion violates rigorous mathematics.   When Apart -> Rational, then partial fractions decomposition only occurs when the roots are either rational numbers or symbols.  When Apart -> Real, then partial fractions will be carried out whenever each roots is a floating point number, a rational, or a symbol.  Unfortunately, Apart -> Real means that we have to work around the  Mathematica primitive Apart which results is a very slow partial fractions expansion.
:[font = subsection; inactive; startGroup; Cclosed; ]
Organization of the Rule Base
:[font = text; inactive; ]
		The inverse Laplace transform rule base InvLaPlace has the same overall structure as does the forward Laplace rule base LaPlace, except that the InvLaPlace has no multidimensional hooks since it does not invert transforms representing non-separable multidimensional functions.  Like LaPlace, InvLaPlace works for multidimensional signals as well as two-sided ones.  InvLaPlace calls a one-dimensional inverse Laplace transform rule base once per dimension of the inverse transform:
:[font = output; inactive; locked; output; center; ]
MatrixForm[{"I.   rational transform pairs  24 rules", 
   "II.  non-rat. transform pairs  26 rules", 
   "III. transform properties       8 rules", 
   "IV.  transforms of operators    0 rules", 
   "V.   transform strategies       9 rules"}]
;[o]
I.   rational transform pairs  24 rules
 
II.  non-rat. transform pairs  26 rules
 
III. transform properties       8 rules
 
IV.  transforms of operators    0 rules
 
V.   transform strategies       9 rules
:[font = text; inactive; ]

These one-dimensional Laplace transform rules are maintained in a list instead of being coded directed.  This was necessary because Mathematica does group related rules together--  this feature caused adverse side effects.  So, we made each rule delayed and put them into a list (which is never rearranged by Mathematica).  The length of that list is the number of rules in the one-dimensional Laplace transform rule base:
:[font = input; initialization; startGroup; ]
*)

Length[ SignalProcessing`Analog`InvLaPlace`Private`InvLaPlaceRules ]
(*
:[font = output; inactive; output; endGroup; ]
69
;[o]
69
:[font = text; inactive; ]

		Although this one-dimensional rule base has fewer rules overall than its forward Laplace counterpart, it employs more strategies.  The three new strategies are:
:[font = text; inactive; ]

(1)	normalize the denominator
(2)  approximate the inverse transform using a power series
(3)  partial fraction decomposition
:[font = text; inactive; endGroup; ]

Normalize the denominator means to convert denominators into the form a + b s + c t^2 + ... + d s^(n-1) + s^n. The power series approximation is a Taylor series expansion (in positive powers of s).  The partial fraction decomposition breaks down terms with polynomial denominators into first and second order sections so that they can be more easily inverse transformed.
:[font = subsection; inactive; startGroup; Cclosed; ]
Rational One-Dimensional Transforms
:[font = text; inactive; startGroup; Cclosed; ]

		Inverse transform of a constant:
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ c, s, t ]
:[font = output; inactive; output; endGroup; endGroup; ]
c*Delta[t]
;[o]
c Delta[t]
:[font = text; inactive; startGroup; Cclosed; ]
		The next six examples are inverse transformed by the same transform pair (rule):
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ 1/s, s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]
;[o]
CStep[t]
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ 1/s^(3/2), s, t ]
:[font = output; inactive; output; endGroup; ]
(2*t^(1/2)*CStep[t])/Pi^(1/2)
;[o]
2 Sqrt[t] CStep[t]
------------------
     Sqrt[Pi]
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1/s^Pi, s, t ]
:[font = output; inactive; output; endGroup; ]
(t^(-1 + Pi)*CStep[t])/Gamma[Pi]
;[o]
 -1 + Pi
t        CStep[t]
-----------------
    Gamma[Pi]
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ( s - a ), s, t ]
:[font = output; inactive; output; endGroup; ]
E^(a*t)*CStep[t]
;[o]
 a t
E    CStep[t]
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ( s - a )^2, s, t ]
:[font = output; inactive; output; endGroup; ]
E^(a*t)*t*CStep[t]
;[o]
 a t
E    t CStep[t]
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ( s - a )^Pi, s, t ]
:[font = output; inactive; output; endGroup; endGroup; ]
(E^(a*t)*t^(-1 + Pi)*CStep[t])/Gamma[Pi]
;[o]
 a t  -1 + Pi
E    t        CStep[t]
----------------------
      Gamma[Pi]
:[font = text; inactive; startGroup; Cclosed; ]
		Multiple poles (handled by partial fractions expansion):
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ((s - a)(s - b)), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
        1
-----------------
(-a + s) (-b + s)
in order to break it up into first and
second order sections:
       1                  1
---------------- - ----------------
(a - b) (-a + s)   (a - b) (-b + s)
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
((E^(a*t) - E^(b*t))*CStep[t])/(a - b)
;[o]
  a t    b t
(E    - E   ) CStep[t]
----------------------
        a - b
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ((s - a)(s - b)(s - c)), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
            1
--------------------------
(-a + s) (-b + s) (-c + s)
in order to break it up into first and
second order sections:
                 1                                    1
-(--------------------------------) + ---------------------------------- - 
     2                                           2
  (-a  + a b + a c - b c) (-a + s)    (-(a b) + b  + a c - b c) (-b + s)
 
                  1
  ----------------------------------
                         2
  (-(a b) + a c + b c - c ) (-c + s)
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; endGroup; ]
(E^(a*t)*CStep[t])/((a - b)*(a - c)) + (E^(b*t)*CStep[t])/((-a + b)*(b - c)) + 
  (E^(c*t)*CStep[t])/((-a + c)*(-b + c))
;[o]
  a t               b t                 c t
 E    CStep[t]     E    CStep[t]       E    CStep[t]
--------------- + ---------------- + -----------------
(a - b) (a - c)   (-a + b) (b - c)   (-a + c) (-b + c)
:[font = text; inactive; startGroup; Cclosed; ]
		Multiple complex-valued poles
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ (s^2 + 3)/(s^2 + 2 s + 2), s, t ]
:[font = print; inactive; startGroup; ]
( After performing partial fraction expansion on
:[font = print; inactive; ]
          2
     3 + s
  ------------
             2
  2 + 2 s + s
:[font = print; inactive; ]
  in order to break it up into first and
:[font = print; inactive; ]
  second order sections:
:[font = print; inactive; ]
        1 - 2 s
  1 + ------------ . )
                 2
      2 + 2 s + s
:[font = output; inactive; output; endGroup; endGroup; ]
(-2*CStep[t]*Cos[t])/E^t + Delta[t] + 
  (3*CStep[t]*Sin[t])/E^t
;[o]
-2 CStep[t] Cos[t]              3 CStep[t] Sin[t]
------------------ + Delta[t] + -----------------
         t                              t
        E                              E
:[font = input; ]
myapart[ fun_, s_ ] :=
	Block [ {newfun, s0},
	         newfun = fun /. s -> s0;
	         rootlist = Sort[ Solve[ newfun == 0, s0 ] ];
	         numroots = Length[rootlist];
	         denom = Product[ s0 /. rootlist[[i]],
	         		          {i, 1, numroots} ];
	         denom ]
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ 1/(s^2 + 2 s + 2)^2, s, t,
			Dialogue -> All ]
:[font = print; inactive; startGroup; ]
  -1             2 -2
L   {(2 + 2 s + s )  }
  s
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1             2 -2
L   {(2 + 2 s + s )  }
  s
:[font = print; inactive; ]
which becomes
:[font = message; inactive; ]
Infinity::indt: 
                             -Infinity
   Indeterminate expression s          encountered.
:[font = message; inactive; ]
                                 1
Power::infy: Infinite expression - encountered.
                                 0
:[font = message; inactive; ]
Infinity::indt: 
   Indeterminate expression 0 ComplexInfinity
     encountered.
:[font = print; inactive; ]
  -1
L   {Indeterminate}
  s
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
Indeterminate
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
Indeterminate
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
Indeterminate
;[o]
Indeterminate
:[font = text; inactive; startGroup; Cclosed; ]
		Laplace transforms which represent pure sinusoids in the time domain:
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ( s^2 + a^2 ), s, t ]
:[font = output; inactive; output; endGroup; ]
(CStep[t]*Sin[a*t])/a
;[o]
CStep[t] Sin[a t]
-----------------
        a
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ s / ( s^2 + a^2 ), s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]*Cos[a*t]
;[o]
CStep[t] Cos[a t]
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ 1 / ( s^2 - a^2 ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
   1
--------
  2    2
-a  + s
in order to break it up into first and
second order sections:
     1              1
------------ - -----------
2 a (-a + s)   2 a (a + s)
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
(-CStep[t] + E^(2*a*t)*CStep[t])/(2*E^(a*t)*a)
;[o]
             2 a t
-CStep[t] + E      CStep[t]
---------------------------
            a t
         2 E    a
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ s / ( s^2 - a^2 ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
   s
--------
  2    2
-a  + s
in order to break it up into first and
second order sections:
    1            1
---------- + ---------
2 (-a + s)   2 (a + s)
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
((1 + E^(2*a*t))*CStep[t])/(2*E^(a*t))
;[o]
      2 a t
(1 + E     ) CStep[t]
---------------------
          a t
       2 E
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ( s^2 ( s^2 + a^2 ) ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
     1
------------
 2   2    2
s  (a  + s )
in order to break it up into first and
second order sections:
  1          1
----- - ------------
 2  2    2   2    2
a  s    a  (a  + s )
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
(CStep[t]*(a*t - Sin[a*t]))/a^3
;[o]
CStep[t] (a t - Sin[a t])
-------------------------
            3
           a
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ( s^2 + a^2 )^2, s, t ]
:[font = output; inactive; output; endGroup; ]
(CStep[t]*(-(a*t*Cos[a*t]) + Sin[a*t]))/(2*a^3)
;[o]
CStep[t] (-(a t Cos[a t]) + Sin[a t])
-------------------------------------
                   3
                2 a
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ s^2 / ( s^2 + a^2 )^2, s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
     2
    s
----------
  2    2 2
(a  + s )
in order to break it up into first and
second order sections:
       2
      a            1
-(----------) + -------
    2    2 2     2    2
  (a  + s )     a  + s
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
(CStep[t]*(a*t*Cos[a*t] + Sin[a*t]))/(2*a)
;[o]
CStep[t] (a t Cos[a t] + Sin[a t])
----------------------------------
               2 a
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ ( s^2 - a^2 ) / ( s^2 + a^2 )^2, s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
   2    2
 -a  + s
----------
  2    2 2
(a  + s )
in order to break it up into first and
second order sections:
      2
  -2 a          1
---------- + -------
  2    2 2    2    2
(a  + s )    a  + s
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; endGroup; ]
t*CStep[t]*Cos[a*t]
;[o]
t CStep[t] Cos[a t]
:[font = text; inactive; startGroup; Cclosed; ]
		Laplace transforms which represent damped sinusoids in the time domain:

:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 1 / ( (s - a)^2 + b^2 ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
      1
--------------
 2           2
b  + (-a + s)
in order to break it up into first and
second order sections:
         1
--------------------
 2    2            2
a  + b  - 2 a s + s
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
(E^(a*t)*CStep[t]*Sin[b*t])/b
;[o]
 a t
E    CStep[t] Sin[b t]
----------------------
          b
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ (s - a) / ( (s - a)^2 + b^2 ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
    -a + s
--------------
 2           2
b  + (-a + s)
in order to break it up into first and
second order sections:
       -a + s
--------------------
 2    2            2
a  + b  - 2 a s + s
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
E^(a*t)*CStep[t]*Cos[b*t]
;[o]
 a t
E    CStep[t] Cos[b t]
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ 3 a^2 / ( s^3 + a^3 ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
    2
 3 a
-------
 3    3
a  + s
in order to break it up into first and
second order sections:
  1        2 a - s
----- + -------------
a + s    2          2
        a  - a s + s
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
CStep[t]/E^(a*t) - E^((a*t)/2)*CStep[t]*Cos[(3^(1/2)*a*t)/2] + 
  (3*E^((a*t)/2)*CStep[t]*Sin[(3^(1/2)*a*t)/2])/3^(1/2)
;[o]
CStep[t]    (a t)/2              Sqrt[3] a t
-------- - E        CStep[t] Cos[-----------] + 
   a t                                2
  E
 
     (a t)/2              Sqrt[3] a t
  3 E        CStep[t] Sin[-----------]
                               2
  ------------------------------------
                Sqrt[3]
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ 4 a^3 / ( s^4 + 4 a^4 ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
     3
  4 a
---------
   4    4
4 a  + s
in order to break it up into first and
second order sections:
          s                   s
      a - -               a + -
          2                   2
----------------- + -----------------
   2            2      2            2
2 a  - 2 a s + s    2 a  + 2 a s + s
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
-(CStep[t]*(-Cos[a*t] + E^(2*a*t)*Cos[a*t] - Sin[a*t] - E^(2*a*t)*Sin[a*t]))/
  (2*E^(a*t))
;[o]
                         2 a t                        2 a t
-(CStep[t] (-Cos[a t] + E      Cos[a t] - Sin[a t] - E      Sin[a t]))
----------------------------------------------------------------------
                                   a t
                                2 E
:[font = input; startGroup; Cclosed; ]

InvLaPlace[ s / ( s^4 - a^4 ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
   s
--------
  4    4
-a  + s
in order to break it up into first and
second order sections:
      1              1               s
------------- + ------------ - --------------
   2               2              2   2    2
4 a  (-a + s)   4 a  (a + s)   2 a  (a  + s )
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
(CStep[t]*(1 + E^(2*a*t) - 2*E^(a*t)*Cos[a*t]))/(4*E^(a*t)*a^2)
;[o]
               2 a t      a t
CStep[t] (1 + E      - 2 E    Cos[a t])
---------------------------------------
                  a t  2
               4 E    a
:[font = subsection; inactive; startGroup; Cclosed; ]
Non-rational One-Dimensional Transforms
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Square Root Forms
:[font = text; inactive; startGroup; Cclosed; ]

		Here is a detailed example of an inverse transform involving square root.
:[font = input; ]

InvLaPlace[ (b^2 - a^2) / ((s - a^2)(Sqrt[s] + b)), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
           1
-----------------------
                 2
(b + Sqrt[s]) (-a  + s)
in order to break it up into first and
second order sections:
                1                                 1
-(------------------------------) - ----------------------------- + 
       2                                 2
  (-2 a  - 2 a b) (-a + Sqrt[s])    (-2 a  + 2 a b) (a + Sqrt[s])
 
             1
  ------------------------
     2    2
  (-a  + b ) (b + Sqrt[s])
Taking the inverse Laplace transform ...
:[font = output; inactive; output; ]
CStep[t]*(E^(a^2*t)*b - E^(b^2*t)*b - E^(a^2*t)*a*Erf[a*t^(1/2)] + 
    E^(b^2*t)*b*Erf[b*t^(1/2)])
;[o]
            2         2         2                        2
           a  t      b  t      a  t                     b  t
CStep[t] (E     b - E     b - E     a Erf[a Sqrt[t]] + E     b Erf[b Sqrt[t]])
:[font = text; inactive; ]

Mathematica does not have a complementary error function erfc, where erfc(x) = 1 - erf(x).  The last inverse transform can be rearranged as the following times a step function:
:[font = input; startGroup; ]

Exp[a^2 t] ( b - a Erf[a Sqrt[t]] ) - b Exp[b^2 t] ( 1 - Erf[b Sqrt[t]] )
:[font = output; inactive; output; endGroup; ]
E^(a^2*t)*(b - a*Erf[a*t^(1/2)]) - E^(b^2*t)*b*(1 - Erf[b*t^(1/2)])
;[o]
  2                              2
 a  t                           b  t
E     (b - a Erf[a Sqrt[t]]) - E     b (1 - Erf[b Sqrt[t]])
:[font = text; inactive; ]

We can verify this transform pair by passing it back through the forward Laplace transform:
:[font = input; startGroup; ]

LaPlace[ %23 CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(a^2 - b^2)/(a^2*b + a^2*s^(1/2) - b*s - s^(3/2)), 
  Rminus[Max[Re[a^2], Re[b^2]]], Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                       2    2
                      a  - b                              2       2
LTransData[------------------------------, Rminus[Max[Re[a ], Re[b ]]], 
            2      2                  3/2
           a  b + a  Sqrt[s] - b s - s
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]

Expand[ ( s - a^2 ) ( Sqrt[s] + b ) ]
:[font = output; inactive; output; endGroup; endGroup; ]
-(a^2*b) - a^2*s^(1/2) + b*s + s^(3/2)
;[o]
   2       2                  3/2
-(a  b) - a  Sqrt[s] + b s + s
:[font = text; inactive; startGroup; Cclosed; ]
		The following four inverse transforms are transformed by the same transform pair (the last inverse transform pair gives the general case):
:[font = input; startGroup; ]

InvLaPlace[ 1 / ( Sqrt[s] (s + 4) ), s, t ]
:[font = output; inactive; output; endGroup; ]
(-I/2*CStep[t]*Erf[2*I*t^(1/2)])/E^(4*t)
;[o]
-I
-- CStep[t] Erf[2 I Sqrt[t]]
2
----------------------------
             4 t
            E
:[font = input; startGroup; ]

InvLaPlace[ 1 / ( Sqrt[s] (s - a^2) ), s, t ]
:[font = output; inactive; output; endGroup; ]
(E^(a^2*t)*CStep[t]*Erf[a*t^(1/2)])/a
;[o]
  2
 a  t
E     CStep[t] Erf[a Sqrt[t]]
-----------------------------
              a
:[font = input; startGroup; ]
InvLaPlace[ 1 / ( Sqrt[s] (s + a^2) ), s, t ]
:[font = output; inactive; output; endGroup; ]
(-I*CStep[t]*Erf[I*a*t^(1/2)])/(E^(a^2*t)*a)
;[o]
-I CStep[t] Erf[I a Sqrt[t]]
----------------------------
            2
           a  t
          E     a
:[font = input; startGroup; ]

InvLaPlace[ 1 / ( Sqrt[s + b] (s + a) ), s, t ]
:[font = output; inactive; output; endGroup; endGroup; ]
(E^((-a + b)*t)*CStep[t]*Erf[(-a + b)^(1/2)*t^(1/2)])/(-a + b)^(1/2)
;[o]
 (-a + b) t
E           CStep[t] Erf[Sqrt[-a + b] Sqrt[t]]
----------------------------------------------
                 Sqrt[-a + b]
:[font = text; inactive; startGroup; Cclosed; ]
		The following three inverse transforms are transformed by the same transform pair (the last inverse transform pair gives the general case):
:[font = input; startGroup; ]

InvLaPlace[ Sqrt[s] / ( s + 2 ), s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]*(1/(Pi^(1/2)*t^(1/2)) - ((-2)^(1/2)*Erf[(-2)^(1/2)*t^(1/2)])/E^(2*t))
;[o]
                 1           Sqrt[-2] Erf[Sqrt[-2] Sqrt[t]]
CStep[t] (---------------- - ------------------------------)
          Sqrt[Pi] Sqrt[t]                 2 t
                                          E
:[font = input; startGroup; ]

InvLaPlace[ Sqrt[s] / ( s - 4 ), s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]*(1/(Pi^(1/2)*t^(1/2)) - 2*E^(4*t)*Erf[2*t^(1/2)])
;[o]
                 1              4 t
CStep[t] (---------------- - 2 E    Erf[2 Sqrt[t]])
          Sqrt[Pi] Sqrt[t]
:[font = input; startGroup; ]

InvLaPlace[ Sqrt[s + b] / (s + c), s, t ]
:[font = output; inactive; output; endGroup; endGroup; ]
CStep[t]*(1/(Pi^(1/2)*t^(1/2)) - 
    E^((b - c)*t)*(b - c)^(1/2)*Erf[(b - c)^(1/2)*t^(1/2)])
;[o]
                 1            (b - c) t
CStep[t] (---------------- - E          Sqrt[b - c] Erf[Sqrt[b - c] Sqrt[t]])
          Sqrt[Pi] Sqrt[t]
:[font = text; inactive; startGroup; Cclosed; ]
		Here are several unrelated examples:

:[font = input; startGroup; ]
InvLaPlace[ 1 / ( Sqrt[s] + a ), s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]*(1/(Pi^(1/2)*t^(1/2)) - E^(a^2*t)*a*(1 - Erf[a*t^(1/2)]))
;[o]
                               2
                 1            a  t
CStep[t] (---------------- - E     a (1 - Erf[a Sqrt[t]]))
          Sqrt[Pi] Sqrt[t]
:[font = input; startGroup; ]

InvLaPlace[ 1 / ( Sqrt[s] ( Sqrt[s] + a ) ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
          1
---------------------
(a + Sqrt[s]) Sqrt[s]
in order to break it up into first and
second order sections:
         1               1
-(---------------) + ---------
  a (a + Sqrt[s])    a Sqrt[s]
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
-(E^(a^2*t)*CStep[t]*(-1 + Erf[a*t^(1/2)]))
;[o]
    2
   a  t
-(E     CStep[t] (-1 + Erf[a Sqrt[t]]))
:[font = input; startGroup; ]

InvLaPlace[ 1 / ((s + a) Sqrt[s + b]), s, t ]
:[font = output; inactive; output; endGroup; ]
(CStep[t]*Erf[(-a + b)^(1/2)*t^(1/2)])/(E^(a*t)*(-a + b)^(1/2))
;[o]
CStep[t] Erf[Sqrt[-a + b] Sqrt[t]]
----------------------------------
         a t
        E    Sqrt[-a + b]
:[font = input; startGroup; ]

InvLaPlace[ (b^2 - a^2) / ( Sqrt[s] (s - a^2) (Sqrt[s] + b) ), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
               1
-------------------------------
                         2
(b + Sqrt[s]) Sqrt[s] (-a  + s)
in order to break it up into first and
second order sections:
              1                                1
------------------------------ - ----------------------------- + 
    3      2                         3      2
(2 a  + 2 a  b) (-a + Sqrt[s])   (2 a  - 2 a  b) (a + Sqrt[s])
 
              1                    1
  ------------------------- - ------------
    2      3                   2
  (a  b - b ) (b + Sqrt[s])   a  b Sqrt[s]
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; ]
-((CStep[t]*(E^(a^2*t)*a - E^(b^2*t)*a - E^(a^2*t)*b*Erf[a*t^(1/2)] + 
        E^(b^2*t)*a*Erf[b*t^(1/2)]))/a)
;[o]
              2         2         2                        2
             a  t      b  t      a  t                     b  t
  CStep[t] (E     a - E     a - E     b Erf[a Sqrt[t]] + E     a Erf[b Sqrt[t]])
-(------------------------------------------------------------------------------)
                                        a
:[font = input; startGroup; ]

InvLaPlace[ 1 / ( Sqrt[(s + a)(s + b)] ), s, t ]
:[font = output; inactive; output; endGroup; ]
(BesselI[0, ((a - b)*t)/2]*CStep[t])/E^(((a + b)*t)/2)
;[o]
           (a - b) t
BesselI[0, ---------] CStep[t]
               2
------------------------------
         ((a + b) t)/2
        E
:[font = input; startGroup; ]

InvLaPlace[ ( Sqrt[s^2 + a^2] - s )^2 / Sqrt[s^2 + a^2], s, t ]
:[font = output; inactive; output; endGroup; ]
a^2*BesselJ[2, a*t]*CStep[t]
;[o]
 2
a  BesselJ[2, a t] CStep[t]
:[font = input; startGroup; ]

InvLaPlace[ ( s - Sqrt[s^2 - a^2] )^Pi / Sqrt[s^2 - a^2], s, t ]
:[font = output; inactive; output; endGroup; ]
a^Pi*BesselI[Pi, a*t]*CStep[t]
;[o]
 Pi
a   BesselI[Pi, a t] CStep[t]
:[font = input; startGroup; ]

InvLaPlace[ 1 / Sqrt[ s^2 + a^2 ], s, t ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
BesselJ[0, a*t]*CStep[t]
;[o]
BesselJ[0, a t] CStep[t]
:[font = subsection; inactive; startGroup; Cclosed; ]
Properties
:[font = text; inactive; ]

		The LaPlace rule base implements the following properties:

Additivity																							Linv{A(s) + B(s)}			 = Linv{A(s)} + Linv{B(s)}
Homogeneity																						Linv{c A(s)}														= c L{A(s)}
Multiplication-by-Exponential						Linv{exp(c s) F(s)}		= Linv{F(s)}, t -> t + c
Similarity																							Linv{F(c s}}														= Linv{F(s)} / |c|, s -> s/c
Pole-in-Denominator																			Linv{F(s)/(s + a)}				= exp(- a t) Linv{F(s - a) / s}
Multiplication-by-Frequency									Linv{s F(s)}														= df(t)/dt + f(0+)
																																																																								t																																																																					
Division-by-Frequency																		Linv{F(s)/s}															=  	/  f(r) dr
																																																																					0
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Additivity
:[font = text; inactive; ]

		The Laplace transform of A(s) + B(s) is a(t), the inverse Laplace transform of A(s), plus b(t), the inverse Laplace transform of B(s):
:[font = input; startGroup; ]

InvLaPlace[ 1 + Exp[-s] / s, s, t, Dialogue -> All ]
:[font = print; inactive; ]
  -1      1
L   {1 + ----}
  s       s
         E  s
becomes
  -1        -1  1
L   {1} + L   {----}
  s         s   s
               E  s
becomes
              -1 1
Delta[t] + {L   {-}}
              s  s  t -> -1 + t
becomes
Delta[t] + {CStep[t]}
                     t -> -1 + t
becomes
CStep[-1 + t] + Delta[t]
becomes
CStep[-1 + t] + Delta[t]
:[font = output; inactive; output; endGroup; endGroup; ]
CStep[-1 + t] + Delta[t]
;[o]
CStep[-1 + t] + Delta[t]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Homogeneity
:[font = text; inactive; ]

		This property moves all terms not dependent on the time variable outside of the Laplace transform operator with no effect on the region of convergence:

:[font = input; startGroup; ]
InvLaPlace[ A K / (2 s), s, t ]
:[font = output; inactive; output; endGroup; endGroup; ]
(A*K*CStep[t])/2
;[o]
A K CStep[t]
------------
     2
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Multiplication-by-Exponential
:[font = text; inactive; ]

		The multiplication of f(t) by exp(a t)  shifts F(s), the Laplace transform of  f(t), to the right by a, and the region of convergence is shifted by the real part of a:
:[font = input; startGroup; ]

InvLaPlace[ s / ( 1 + s^2 ), s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]*Cos[t]
;[o]
CStep[t] Cos[t]
:[font = input; startGroup; ]

InvLaPlace[ Exp[-a s] s / ( 1 + s^2 ), s, t ]
:[font = output; inactive; output; endGroup; endGroup; ]
CStep[-a + t]*Cos[-a + t]
;[o]
CStep[-a + t] Cos[-a + t]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Similarity
:[font = input; startGroup; ]

InvLaPlace[ 1 / ((s + a) Sqrt[s + b]), s, t ]
:[font = output; inactive; output; endGroup; ]
(CStep[t]*Erf[(-a + b)^(1/2)*t^(1/2)])/(E^(a*t)*(-a + b)^(1/2))
;[o]
CStep[t] Erf[Sqrt[-a + b] Sqrt[t]]
----------------------------------
         a t
        E    Sqrt[-a + b]
:[font = input; startGroup; ]

InvLaPlace[ 1 / ((c s + a) Sqrt[c s + b]), s, t ]
:[font = output; inactive; output; endGroup; endGroup; ]
(CStep[t/c]*Erf[((-a + b)^(1/2)*t^(1/2))/c^(1/2)])/
  (E^((a*t)/c)*(-a + b)^(1/2)*Abs[c])
;[o]
      t      Sqrt[-a + b] Sqrt[t]
CStep[-] Erf[--------------------]
      c            Sqrt[c]
----------------------------------
    (a t)/c
   E        Sqrt[-a + b] Abs[c]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Pole-in-Denominator
:[font = input; startGroup; ]

InvLaPlace[ 1 / ( s - 1 ), s, t ]
:[font = output; inactive; output; endGroup; ]
E^t*CStep[t]
;[o]
 t
E  CStep[t]
:[font = input; startGroup; ]
InvLaPlace[ Log[1 + s], s, t ]
:[font = output; inactive; output; endGroup; ]
-(CStep[t]/(E^t*t))
;[o]
  CStep[t]
-(--------)
     t
    E  t
:[font = input; startGroup; ]

InvLaPlace[ Log[1 + s] / (( s + a )(s + b)), s, t ]
:[font = print; inactive; ]
Performing partial fraction expansion on
  Log[1 + s]
---------------
(a + s) (b + s)
in order to break it up into first and
second order sections:
   Log[1 + s]         Log[1 + s]
---------------- - ----------------
(-a + b) (a + s)   (-a + b) (b + s)
Taking the inverse Laplace transform ...
:[font = output; inactive; output; endGroup; endGroup; ]
(CStep[t]*(-ExpIntegralEi[(-1 + a)*t] + Log[1 - a]))/(E^(a*t)*(-a + b)) - 
  (CStep[t]*(-ExpIntegralEi[(-1 + b)*t] + Log[1 - b]))/(E^(b*t)*(-a + b))
;[o]
CStep[t] (-ExpIntegralEi[(-1 + a) t] + Log[1 - a])
-------------------------------------------------- - 
                   a t
                  E    (-a + b)
 
  CStep[t] (-ExpIntegralEi[(-1 + b) t] + Log[1 - b])
  --------------------------------------------------
                     b t
                    E    (-a + b)
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Multiplication-by-Frequency
:[font = text; inactive; ]

		Multiplication in frequency corresponds to differentiation in the time domain:
:[font = input; startGroup; ]

InvLaPlace[ 1 / Sqrt[(s + a)(s - a)], s, t ]
:[font = output; inactive; output; endGroup; ]
BesselI[0, -(a*t)]*CStep[t]
;[o]
BesselI[0, -(a t)] CStep[t]
:[font = input; startGroup; ]

InvLaPlace[ s / Sqrt[(s + a)(s - a)], s, t ]
:[font = output; inactive; output; endGroup; ]
-(a*(BesselI[-1, -(a*t)] + BesselI[1, -(a*t)])*CStep[t])/2 + Delta[t]
;[o]
-(a (BesselI[-1, -(a t)] + BesselI[1, -(a t)]) CStep[t])
-------------------------------------------------------- + Delta[t]
                           2
:[font = input; startGroup; ]

LaPlace[ -a BesselI[1, - a t] CStep[t] + Delta[t], t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[s/(-a^2 + s^2)^(1/2), Rminus[Abs[Re[-a]]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                 s
LTransData[--------------, Rminus[Abs[Re[-a]]], Rplus[Infinity], LVariables[s]]
                  2    2
           Sqrt[-a  + s ]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Division-by-Frequency
:[font = text; inactive; ]

		Multiplication in frequency corresponds to differentiation in the time domain:
:[font = input; startGroup; ]

InvLaPlace[ 1 / Sqrt[(s + a)(s - a)], s, t ]
:[font = output; inactive; output; endGroup; ]
BesselI[0, -(a*t)]*CStep[t]
;[o]
BesselI[0, -(a t)] CStep[t]
:[font = input; startGroup; ]

InvLaPlace[ 1 / (s Sqrt[(s + a)(s - a)]), s, t ]
:[font = output; inactive; output; endGroup; ]
CStep[t]*Integrate[BesselI[0, -(a*tau3)], {tau3, 0, t}]
;[o]
CStep[t] Integrate[BesselI[0, -(a tau3)], {tau3, 0, t}]
:[font = text; inactive; endGroup; endGroup; ]

This is the integration of the Bessel function Io(- a t) with respect to t. 
:[font = subsection; inactive; startGroup; Cclosed; ]
Strategies
:[font = text; inactive; ]

		The rule base employs the following strategies:
:[font = text; inactive; ]

Partial Fractions
Normalize the Denominator
Factor the Denominator
Distribute
Expand Numerators
Expand All Terms
Assume a Two-Sided Transform
Replace Signal Processing Primitives with Mathematica Ones
Power Series Expansion

:[font = subsubsection; inactive; startGroup; Cclosed; ]
Partial Fractions Decomposition
:[font = text; inactive; ]
		The key strategy is partial fractions decomposition which can be used for more than just s-domain polynomials.  They are also useful in transforming F(s)/s forms as well as G(s)/((s + a)(s + b)) forms, where F(s) and G(s) are not necessarily rational polynomials in s.  Partial fractions is handled by the Mathematica primitive Apart.  It is encoded as three rules--  one for rational polynomials, one for denominator poles, and one in this section of the rule base.
:[font = text; inactive; ]
		The philosophy underlying Apart is to perform partial fractions on a ratio of two rational polynomials, so it does not handle real-valued coefficients (so we have added the Apart option to InvLaPlace).  In Mathematica 1.2, the Apart function is not robust because it does not handle repeated complex-valued roots in the denominator.  For example,
:[font = input; startGroup; ]
Apart[ (s^2 - 1) / ( s^2 + 2 s + 2 )^2, s ]
:[font = output; inactive; output; endGroup; ]
(-3 - 2*s)/(2 + 2*s + s^2)^2 + (2 + 2*s + s^2)^(-1)
;[o]
   -3 - 2 s            1
--------------- + ------------
            2 2              2
(2 + 2 s + s )    2 + 2 s + s
:[font = text; inactive; ]
But this is really not the complete partial fractions decomposition.  Rather, this is:
:[font = input; startGroup; ]
MyApart[ (s^2 - 1) / ( s^2 + 2 s + 2 )^2, s ]
:[font = output; inactive; output; endGroup; ]
(1/4 + I/2)/(1 - I + s)^2 + -I/4/(1 - I + s) + 
  (1/4 - I/2)/(1 + I + s)^2 + I/4/(1 + I + s)
;[o]
   1   I          -I          1   I           I
   - + -          --          - - -           -
   4   2          4           4   2           4
------------ + --------- + ------------ + ---------
           2   1 - I + s              2   1 + I + s
(1 - I + s)                (1 + I + s)
:[font = text; inactive; ]
		Now, let's try to compute the inverse Laplace transform:
:[font = input; startGroup; Cclosed; ]
InvLaPlace[ (s^2 - 1) / ( s^2 + 2 s + 2 )^2, s, t ]
:[font = print; inactive; startGroup; ]
( After performing partial fraction expansion on
:[font = print; inactive; ]
            2
      -1 + s
  ---------------
              2 2
  (2 + 2 s + s )
:[font = print; inactive; ]
  into its exact roots:
:[font = print; inactive; ]
     -3 - 2 s            1
  --------------- + ------------ . )
              2 2              2
  (2 + 2 s + s )    2 + 2 s + s
:[font = print; inactive; ]
( After performing partial fraction expansion on
:[font = print; inactive; ]
     -3 - 2 s
  ---------------
              2 2
  (2 + 2 s + s )
:[font = print; inactive; ]
  into its exact roots:
:[font = print; inactive; ]
     1   I           I          1   I          -I
     - + -           -          - - -          --
     4   2           4          4   2          4
  ------------ + --------- + ------------ + ---------
             2   1 - I + s              2   1 + I + s
  (1 - I + s)                (1 + I + s)
 
   . )
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
(E^((-1 - I)*t)*(-I*CStep[t] + I*E^(2*I*t)*CStep[t] + 
      (1 - 2*I)*t*CStep[t] + 
      (1 + 2*I)*E^(2*I*t)*t*CStep[t] + 
      4*E^(I*t)*CStep[t]*Sin[t]))/4
;[o]
  (-1 - I) t                   2 I t
(E           (-I CStep[t] + I E      CStep[t] + 
 
      (1 - 2 I) t CStep[t] + 
 
                 2 I t
      (1 + 2 I) E      t CStep[t] + 
 
         I t
      4 E    CStep[t] Sin[t])) / 4
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Power Series Expansion
:[font = text; inactive; endGroup; endGroup; ]
		One strategy-- power series expansion-- is only applied when all other attempts at the inverse transform have failed.  In general, the expansion is a Taylor series expansion about s = 0 (positive powers of s).  The number of terms in the expansion is controlled by the Terms options (see the Introduction to this section).
:[font = subsection; inactive; startGroup; Cclosed; ]
Multidimensional Transforms
:[font = text; inactive; ]

		The multidimensional inverse Laplace transform only works for separable functions.
:[font = input; startGroup; ]

InvLaPlace[ 1 / ((s1 + a)(s2 + b)), {s1, s2} ]
:[font = output; inactive; output; endGroup; ]
E^(-(a*t1) - b*t2)*CStep[t1]*CStep[t2]
;[o]
 -(a t1) - b t2
E               CStep[t1] CStep[t2]
:[font = input; startGroup; ]
InvLaPlace[ 1 / Sqrt[(s1 + a)(s2 + b)], {s1, s2}, {u1, u2} ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
(E^(-(a*u1) - b*u2)*CStep[u1]*CStep[u2])/(Pi*u1^(1/2)*u2^(1/2))
;[o]
 -(a u1) - b u2
E               CStep[u1] CStep[u2]
-----------------------------------
       Pi Sqrt[u1] Sqrt[u2]
:[font = section; inactive; startGroup; Cclosed; ]
Solving Differential Equations
:[font = text; inactive; ]

		The Mathematica object LSolve uses the Laplace transform rule bases to solve linear constant coefficient differential equations.   LSolve introduces the partial Laplace transform which expresses the Laplace transform of y'(t) as  s Y(s) - y(0)  when y(t) is unknown.
:[font = subsection; inactive; startGroup; Cclosed; ]
Differential Equation With Zero-Valued Initial Conditions
:[font = text; inactive; ]

		The first example is a second-order linear constant-coefficient differential equation whose initial conditions are zero:  y'(0) = y(0) = 0.  The Mathematica object LSolve requires two arguments:  the differential equation to be solved and what to solve for.
:[font = input; startGroup; ]

LSolve[ y''[t] + 3/2 y'[t] + 1/2 y[t] == Exp[a t] CStep[t], y[t] ]
:[font = output; inactive; output; endGroup; ]
(4*CStep[t/2])/(E^(t/2)*(-1 - 2*a)) - (2*CStep[t])/(E^t*(-1 - a)) - 
  (2*E^(a*t)*CStep[t])/(-1 - 3*a - 2*a^2)
;[o]
          t
  4 CStep[-]                       a t
          2       2 CStep[t]    2 E    CStep[t]
--------------- - ----------- - ---------------
 t/2               t                          2
E    (-1 - 2 a)   E  (-1 - a)   -1 - 3 a - 2 a
:[font = text; inactive; ]

Implied here is that we are looking for the solution to the differential equation when t > 0.  Therefore, we can drop the continuous-time step functions since they are 1 for t > 0.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Verifying a Solution
:[font = text; inactive; ]

We can now use Mathematica to verify the solution, which we assign to the function ysol:
:[font = input; initialization; startGroup; ]
*)

ysol =	4 Exp[-t/2] / (-1 - 2 a) -
		2 Exp[-t] / (-1 - a) -
		2 Exp[a t] / (-1 - 3 a - 2 a^2 )
(*
:[font = output; inactive; output; endGroup; ]
4/(E^(t/2)*(-1 - 2*a)) - 2/(E^t*(-1 - a)) - 
  (2*E^(a*t))/(-1 - 3*a - 2*a^2)
;[o]
                                       a t
       4               2            2 E
--------------- - ----------- - ---------------
 t/2               t                          2
E    (-1 - 2 a)   E  (-1 - a)   -1 - 3 a - 2 a
:[font = text; inactive; ]

 We can now check to make sure that the initial conditions are valid.  First, we check to see if y(0+) = 0:
:[font = input; startGroup; ]
ysol /. t -> 0

:[font = output; inactive; output; endGroup; ]
4/(-1 - 2*a) - 2/(-1 - a) - 2/(-1 - 3*a - 2*a^2)
;[o]
   4         2             2
-------- - ------ - ---------------
-1 - 2 a   -1 - a                 2
                    -1 - 3 a - 2 a
:[font = text; inactive; ]

This may not look like zero but it actually is:

:[font = input; startGroup; ]

Simplify[ ysol /. t -> 0 ]
:[font = output; inactive; output; endGroup; ]
0
;[o]
0
:[font = text; inactive; ]

Second, we can check to make sure that y'(0+) equals zero:
:[font = input; initialization; startGroup; ]
*)

Simplify[ D[ ysol, t ] /. t -> 0 ]
(*
:[font = output; inactive; output; endGroup; ]
0
;[o]
0
:[font = text; inactive; ]

Next, we can try to verify that the solution satisfies the differential equation:
:[font = input; startGroup; ]

ysolprime = D[ ysol, t];
ysoldblprime = D[ ysolprime, t];

Simplify[ ysoldblprime + 3/2 ysolprime + 1/2 ysol ]
:[font = output; inactive; output; endGroup; endGroup; ]
E^(a*t)
;[o]
 a t
E
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Analyzing a Solution
:[font = text; inactive; ]

		Now that we shown that the solution is correct, we can analyze the solution.  First, there are certain values of the free parameter a which yield an unbounded (and hence invalid) solution.  This occurs when any of the denominator terms become zero, which happens when a = -1/2 and when a = -1.  This can be seen from inspection, but Mathematica can determine these values in the general case.  First, we convert the solution from its form of Plus[term1, term2, term3] to a list of the form List[term1, term2, term3] by using Apply and then solve the cases where each denominator is zero using Solve:
:[font = input; startGroup; ]

Map[ Solve[Denominator[#1] == 0, a]&, Apply[List, ysol] ]
:[font = output; inactive; output; endGroup; endGroup; ]
{{{a -> -1/2}}, {{a -> -1}}, {{a -> -1}, {a -> -1/2}}}
;[o]
          1                                      1
{{{a -> -(-)}}, {{a -> -1}}, {{a -> -1}, {a -> -(-)}}}
          2                                      2
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Interpreting a Solution
:[font = text; inactive; ]

		In this case, ysol is assigned to the solution of the differential equation automatically by the notebook.  To plot the solution, then, we simplify plot ysol for different values of a:
:[font = input; startGroup; ]

Plot3D[ ysol, {t, 0, 1}, {a, 0, 1}, AxesLabel -> { "t", "a", " " } ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(0.2)] 0.16235 0.27062 0.987329 1 Msboxa
[(0.4)] 0.27294 0.22711 0.903932 1 Msboxa
[(0.6)] 0.38903 0.18145 0.820535 1 Msboxa
[(0.8)] 0.51104 0.13348 0.737139 1 Msboxa
[(1)] 0.63943 0.08304 0.653742 1 Msboxa
[(t)] 0.2914 0.15947 0.862234 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(0.2)] 0.71626 0.17936 -1 0.369305 Msboxa
[(0.4)] 0.77029 0.26211 -1 0.349436 Msboxa
[(0.6)] 0.81979 0.33791 -1 0.331596 Msboxa
[(0.8)] 0.8653 0.40761 -1 0.315489 Msboxa
[(1)] 0.90729 0.47191 -1 0.300874 Msboxa
[(a)] 0.85193 0.28164 -1 0.340282 Msboxa
[(0)] 0.05375 0.32922 1 -0.390596 Msboxa
[(0.1)] 0.04731 0.36959 1 -0.382083 Msboxa
[(0.2)] 0.04068 0.41116 1 -0.37329 Msboxa
[(0.3)] 0.03384 0.45399 1 -0.364202 Msboxa
[(0.4)] 0.0268 0.49815 1 -0.354806 Msboxa
[( )] -0.01735 0.44567 1 -0.370357 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.16653 0.27486 moveto
0.1749 0.28333 lineto
stroke
0 setgray
[(0.2)] 0.16235 0.27062 0.987329 1 Mshowa
0.27693 0.23152 moveto
0.28492 0.24035 lineto
stroke
0 setgray
[(0.4)] 0.27294 0.22711 0.903932 1 Mshowa
0.39281 0.18605 moveto
0.40036 0.19525 lineto
stroke
0 setgray
[(0.6)] 0.38903 0.18145 0.820535 1 Mshowa
0.51457 0.13827 moveto
0.52164 0.14786 lineto
stroke
0 setgray
[(0.8)] 0.51104 0.13348 0.737139 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(1)] 0.63943 0.08304 0.653742 1 Mshowa
0 setgray
[(t)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71067 0.18142 moveto
0.69951 0.18555 lineto
stroke
0 setgray
[(0.2)] 0.71626 0.17936 -1 0.369305 Mshowa
0.76468 0.26407 moveto
0.75344 0.268 lineto
stroke
0 setgray
[(0.4)] 0.77029 0.26211 -1 0.349436 Mshowa
0.81414 0.33978 moveto
0.80284 0.34353 lineto
stroke
0 setgray
[(0.6)] 0.81979 0.33791 -1 0.331596 Mshowa
0.85963 0.4094 moveto
0.84827 0.41298 lineto
stroke
0 setgray
[(0.8)] 0.8653 0.40761 -1 0.315489 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(1)] 0.90729 0.47191 -1 0.300874 Mshowa
0 setgray
[(a)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.05287 0.36746 moveto
0.06399 0.36321 lineto
stroke
0 setgray
[(0.1)] 0.04731 0.36959 1 -0.382083 Mshowa
0.04625 0.40908 moveto
0.05741 0.40492 lineto
stroke
0 setgray
[(0.2)] 0.04068 0.41116 1 -0.37329 Mshowa
0.03944 0.45196 moveto
0.05062 0.44788 lineto
stroke
0 setgray
[(0.3)] 0.03384 0.45399 1 -0.364202 Mshowa
0.03241 0.49616 moveto
0.04363 0.49217 lineto
stroke
0 setgray
[(0.4)] 0.0268 0.49815 1 -0.354806 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.11905 setgray
0.0015 setlinewidth
0.37373 0.6125 0.39332 0.63074 0.42605 0.62184 0.40673 0.60335 Metetra
0.12317 setgray
0.40673 0.60335 0.42605 0.62184 0.45922 0.61464 0.44018 0.5959 Metetra
0.13534 setgray
0.44018 0.5959 0.45922 0.61464 0.49291 0.6091 0.47414 0.59009 Metetra
0.15528 setgray
0.47414 0.59009 0.49291 0.6091 0.52719 0.60522 0.5087 0.58593 Metetra
0.18279 setgray
0.5087 0.58593 0.52719 0.60522 0.56213 0.60302 0.54392 0.5834 Metetra
0.21768 setgray
0.54392 0.5834 0.56213 0.60302 0.59782 0.60252 0.57989 0.58253 Metetra
0.25984 setgray
0.57989 0.58253 0.59782 0.60252 0.63435 0.60377 0.61669 0.58333 Metetra
0.30917 setgray
0.61669 0.58333 0.63435 0.60377 0.6718 0.60684 0.65441 0.58587 Metetra
0.36565 setgray
0.65441 0.58587 0.6718 0.60684 0.71027 0.61181 0.69316 0.59021 Metetra
0.42928 setgray
0.69316 0.59021 0.71027 0.61181 0.74989 0.61879 0.73304 0.59644 Metetra
0.50009 setgray
0.73304 0.59644 0.74989 0.61879 0.79077 0.62792 0.77417 0.60466 Metetra
0.57817 setgray
0.77417 0.60466 0.79077 0.62792 0.83305 0.63937 0.81668 0.61502 Metetra
0.66366 setgray
0.81668 0.61502 0.83305 0.63937 0.8769 0.65332 0.86072 0.62767 Metetra
0.75672 setgray
0.86072 0.62767 0.8769 0.65332 0.9225 0.67001 0.90647 0.64281 Metetra
0.11905 setgray
0.35364 0.59379 0.37373 0.6125 0.40673 0.60335 0.38692 0.58438 Metetra
0.12316 setgray
0.38692 0.58438 0.40673 0.60335 0.44018 0.5959 0.42064 0.57667 Metetra
0.13528 setgray
0.42064 0.57667 0.44018 0.5959 0.47414 0.59009 0.45488 0.57059 Metetra
0.15509 setgray
0.45488 0.57059 0.47414 0.59009 0.5087 0.58593 0.48972 0.56613 Metetra
0.18232 setgray
0.48972 0.56613 0.5087 0.58593 0.54392 0.5834 0.52522 0.56326 Metetra
0.21676 setgray
0.52522 0.56326 0.54392 0.5834 0.57989 0.58253 0.56147 0.562 Metetra
0.25823 setgray
0.56147 0.562 0.57989 0.58253 0.61669 0.58333 0.59855 0.56235 Metetra
0.3066 setgray
0.59855 0.56235 0.61669 0.58333 0.65441 0.58587 0.63656 0.56435 Metetra
0.36178 setgray
0.63656 0.56435 0.65441 0.58587 0.69316 0.59021 0.67559 0.56806 Metetra
0.42369 setgray
0.67559 0.56806 0.69316 0.59021 0.73304 0.59644 0.71574 0.57353 Metetra
0.49234 setgray
0.71574 0.57353 0.73304 0.59644 0.77417 0.60466 0.75712 0.58086 Metetra
0.56773 setgray
0.75712 0.58086 0.77417 0.60466 0.81668 0.61502 0.79988 0.59015 Metetra
0.64993 setgray
0.79988 0.59015 0.81668 0.61502 0.86072 0.62767 0.84413 0.60153 Metetra
0.73901 setgray
0.84413 0.60153 0.86072 0.62767 0.90647 0.64281 0.89005 0.61516 Metetra
0.11905 setgray
0.33302 0.57459 0.35364 0.59379 0.38692 0.58438 0.36658 0.56492 Metetra
0.12316 setgray
0.36658 0.56492 0.38692 0.58438 0.42064 0.57667 0.40059 0.55693 Metetra
0.13522 setgray
0.40059 0.55693 0.42064 0.57667 0.45488 0.57059 0.43511 0.55057 Metetra
0.15489 setgray
0.43511 0.55057 0.45488 0.57059 0.48972 0.56613 0.47023 0.54579 Metetra
0.18186 setgray
0.47023 0.54579 0.48972 0.56613 0.52522 0.56326 0.50601 0.54258 Metetra
0.21585 setgray
0.50601 0.54258 0.52522 0.56326 0.56147 0.562 0.54255 0.54091 Metetra
0.25666 setgray
0.54255 0.54091 0.56147 0.562 0.59855 0.56235 0.57992 0.5408 Metetra
0.30408 setgray
0.57992 0.5408 0.59855 0.56235 0.63656 0.56435 0.61822 0.54226 Metetra
0.35799 setgray
0.61822 0.54226 0.63656 0.56435 0.67559 0.56806 0.65753 0.54533 Metetra
0.41825 setgray
0.65753 0.54533 0.67559 0.56806 0.71574 0.57353 0.69796 0.55005 Metetra
0.48481 setgray
0.69796 0.55005 0.71574 0.57353 0.75712 0.58086 0.73962 0.55648 Metetra
0.55761 setgray
0.73962 0.55648 0.75712 0.58086 0.79988 0.59015 0.78263 0.56472 Metetra
0.63666 setgray
0.78263 0.56472 0.79988 0.59015 0.84413 0.60153 0.82711 0.57485 Metetra
0.72197 setgray
0.82711 0.57485 0.84413 0.60153 0.89005 0.61516 0.87323 0.58701 Metetra
0.11905 setgray
0.31185 0.55488 0.33302 0.57459 0.36658 0.56492 0.34571 0.54493 Metetra
0.12315 setgray
0.34571 0.54493 0.36658 0.56492 0.40059 0.55693 0.38 0.53666 Metetra
0.13517 setgray
0.38 0.53666 0.40059 0.55693 0.43511 0.55057 0.41481 0.53 Metetra
0.1547 setgray
0.41481 0.53 0.43511 0.55057 0.47023 0.54579 0.45021 0.5249 Metetra
0.1814 setgray
0.45021 0.5249 0.47023 0.54579 0.50601 0.54258 0.48628 0.52133 Metetra
0.21496 setgray
0.48628 0.52133 0.50601 0.54258 0.54255 0.54091 0.52311 0.51925 Metetra
0.25511 setgray
0.52311 0.51925 0.54255 0.54091 0.57992 0.5408 0.56078 0.51867 Metetra
0.30161 setgray
0.56078 0.51867 0.57992 0.5408 0.61822 0.54226 0.59936 0.51958 Metetra
0.35428 setgray
0.59936 0.51958 0.61822 0.54226 0.65753 0.54533 0.63897 0.522 Metetra
0.41295 setgray
0.63897 0.522 0.65753 0.54533 0.69796 0.55005 0.67969 0.52596 Metetra
0.47749 setgray
0.67969 0.52596 0.69796 0.55005 0.73962 0.55648 0.72163 0.5315 Metetra
0.54781 setgray
0.72163 0.5315 0.73962 0.55648 0.78263 0.56472 0.76491 0.53869 Metetra
0.62384 setgray
0.76491 0.53869 0.78263 0.56472 0.82711 0.57485 0.80965 0.5476 Metetra
0.70555 setgray
0.80965 0.5476 0.82711 0.57485 0.87323 0.58701 0.85598 0.55832 Metetra
0.11905 setgray
0.29012 0.53465 0.31185 0.55488 0.34571 0.54493 0.32427 0.52441 Metetra
0.12314 setgray
0.32427 0.52441 0.34571 0.54493 0.38 0.53666 0.35885 0.51585 Metetra
0.13511 setgray
0.35885 0.51585 0.38 0.53666 0.41481 0.53 0.39394 0.50888 Metetra
0.15451 setgray
0.39394 0.50888 0.41481 0.53 0.45021 0.5249 0.42963 0.50344 Metetra
0.18095 setgray
0.42963 0.50344 0.45021 0.5249 0.48628 0.52133 0.466 0.49949 Metetra
0.21408 setgray
0.466 0.49949 0.48628 0.52133 0.52311 0.51925 0.50312 0.497 Metetra
0.25358 setgray
0.50312 0.497 0.52311 0.51925 0.56078 0.51867 0.54109 0.49593 Metetra
0.29918 setgray
0.54109 0.49593 0.56078 0.51867 0.59936 0.51958 0.57998 0.49627 Metetra
0.35065 setgray
0.57998 0.49627 0.59936 0.51958 0.63897 0.522 0.61988 0.49804 Metetra
0.40777 setgray
0.61988 0.49804 0.63897 0.522 0.67969 0.52596 0.6609 0.50124 Metetra
0.47037 setgray
0.6609 0.50124 0.67969 0.52596 0.72163 0.5315 0.70314 0.50589 Metetra
0.53831 setgray
0.70314 0.50589 0.72163 0.5315 0.76491 0.53869 0.7467 0.51205 Metetra
0.61146 setgray
0.7467 0.51205 0.76491 0.53869 0.80965 0.5476 0.7917 0.51975 Metetra
0.68974 setgray
0.7917 0.51975 0.80965 0.5476 0.85598 0.55832 0.83828 0.52907 Metetra
0.11905 setgray
0.26781 0.51387 0.29012 0.53465 0.32427 0.52441 0.30224 0.50333 Metetra
0.12313 setgray
0.30224 0.50333 0.32427 0.52441 0.35885 0.51585 0.33711 0.49446 Metetra
0.13505 setgray
0.33711 0.49446 0.35885 0.51585 0.39394 0.50888 0.3725 0.48717 Metetra
0.15432 setgray
0.3725 0.48717 0.39394 0.50888 0.42963 0.50344 0.40849 0.48138 Metetra
0.1805 setgray
0.40849 0.48138 0.42963 0.50344 0.466 0.49949 0.44515 0.47704 Metetra
0.21321 setgray
0.44515 0.47704 0.466 0.49949 0.50312 0.497 0.48257 0.47411 Metetra
0.25208 setgray
0.48257 0.47411 0.50312 0.497 0.54109 0.49593 0.52084 0.47254 Metetra
0.2968 setgray
0.52084 0.47254 0.54109 0.49593 0.57998 0.49627 0.56003 0.47232 Metetra
0.3471 setgray
0.56003 0.47232 0.57998 0.49627 0.61988 0.49804 0.60025 0.47342 Metetra
0.40272 setgray
0.60025 0.47342 0.61988 0.49804 0.6609 0.50124 0.64158 0.47585 Metetra
0.46345 setgray
0.64158 0.47585 0.6609 0.50124 0.70314 0.50589 0.68412 0.47962 Metetra
0.5291 setgray
0.68412 0.47962 0.70314 0.50589 0.7467 0.51205 0.72797 0.48475 Metetra
0.59949 setgray
0.72797 0.48475 0.7467 0.51205 0.7917 0.51975 0.77326 0.49126 Metetra
0.67451 setgray
0.77326 0.49126 0.7917 0.51975 0.83828 0.52907 0.8201 0.49921 Metetra
0.11905 setgray
0.24487 0.49252 0.26781 0.51387 0.30224 0.50333 0.27961 0.48166 Metetra
0.12313 setgray
0.27961 0.48166 0.30224 0.50333 0.33711 0.49446 0.31477 0.47247 Metetra
0.135 setgray
0.31477 0.47247 0.33711 0.49446 0.3725 0.48717 0.35046 0.46484 Metetra
0.15413 setgray
0.35046 0.46484 0.3725 0.48717 0.40849 0.48138 0.38674 0.45869 Metetra
0.18006 setgray
0.38674 0.45869 0.40849 0.48138 0.44515 0.47704 0.4237 0.45396 Metetra
0.21235 setgray
0.4237 0.45396 0.44515 0.47704 0.48257 0.47411 0.46142 0.45057 Metetra
0.2506 setgray
0.46142 0.45057 0.48257 0.47411 0.52084 0.47254 0.5 0.44849 Metetra
0.29447 setgray
0.5 0.44849 0.52084 0.47254 0.56003 0.47232 0.53951 0.44768 Metetra
0.34363 setgray
0.53951 0.44768 0.56003 0.47232 0.60025 0.47342 0.58004 0.44811 Metetra
0.3978 setgray
0.58004 0.44811 0.60025 0.47342 0.64158 0.47585 0.62169 0.44977 Metetra
0.45672 setgray
0.62169 0.44977 0.64158 0.47585 0.68412 0.47962 0.66454 0.45265 Metetra
0.52016 setgray
0.66454 0.45265 0.68412 0.47962 0.72797 0.48475 0.70871 0.45675 Metetra
0.58793 setgray
0.70871 0.45675 0.72797 0.48475 0.77326 0.49126 0.75429 0.46209 Metetra
0.65984 setgray
0.75429 0.46209 0.77326 0.49126 0.8201 0.49921 0.80141 0.46869 Metetra
0.11905 setgray
0.2213 0.47057 0.24487 0.49252 0.27961 0.48166 0.25634 0.45939 Metetra
0.12312 setgray
0.25634 0.45939 0.27961 0.48166 0.31477 0.47247 0.2918 0.44986 Metetra
0.13494 setgray
0.2918 0.44986 0.31477 0.47247 0.35046 0.46484 0.32778 0.44188 Metetra
0.15395 setgray
0.32778 0.44188 0.35046 0.46484 0.38674 0.45869 0.36436 0.43536 Metetra
0.17962 setgray
0.36436 0.43536 0.38674 0.45869 0.4237 0.45396 0.40163 0.4302 Metetra
0.2115 setgray
0.40163 0.4302 0.4237 0.45396 0.46142 0.45057 0.43966 0.42635 Metetra
0.24915 setgray
0.43966 0.42635 0.46142 0.45057 0.5 0.44849 0.47855 0.42374 Metetra
0.29218 setgray
0.47855 0.42374 0.5 0.44849 0.53951 0.44768 0.51838 0.42233 Metetra
0.34023 setgray
0.51838 0.42233 0.53951 0.44768 0.58004 0.44811 0.55923 0.42208 Metetra
0.393 setgray
0.55923 0.42208 0.58004 0.44811 0.62169 0.44977 0.6012 0.42296 Metetra
0.45017 setgray
0.6012 0.42296 0.62169 0.44977 0.66454 0.45265 0.64438 0.42494 Metetra
0.5115 setgray
0.64438 0.42494 0.66454 0.45265 0.70871 0.45675 0.68887 0.42802 Metetra
0.57675 setgray
0.68887 0.42802 0.70871 0.45675 0.75429 0.46209 0.73478 0.4322 Metetra
0.6457 setgray
0.73478 0.4322 0.75429 0.46209 0.80141 0.46869 0.7822 0.43746 Metetra
0.11905 setgray
0.19707 0.44801 0.2213 0.47057 0.25634 0.45939 0.23241 0.43648 Metetra
0.12311 setgray
0.23241 0.43648 0.25634 0.45939 0.2918 0.44986 0.26817 0.4266 Metetra
0.13489 setgray
0.26817 0.4266 0.2918 0.44986 0.32778 0.44188 0.30445 0.41826 Metetra
0.15376 setgray
0.30445 0.41826 0.32778 0.44188 0.36436 0.43536 0.34133 0.41134 Metetra
0.17919 setgray
0.34133 0.41134 0.36436 0.43536 0.40163 0.4302 0.3789 0.40575 Metetra
0.21066 setgray
0.3789 0.40575 0.40163 0.4302 0.43966 0.42635 0.41725 0.40141 Metetra
0.24772 setgray
0.41725 0.40141 0.43966 0.42635 0.47855 0.42374 0.45646 0.39826 Metetra
0.28993 setgray
0.45646 0.39826 0.47855 0.42374 0.51838 0.42233 0.49661 0.39624 Metetra
0.33691 setgray
0.49661 0.39624 0.51838 0.42233 0.55923 0.42208 0.53779 0.39529 Metetra
0.38831 setgray
0.53779 0.39529 0.55923 0.42208 0.6012 0.42296 0.5801 0.39538 Metetra
0.44381 setgray
0.5801 0.39538 0.6012 0.42296 0.64438 0.42494 0.62362 0.39647 Metetra
0.5031 setgray
0.62362 0.39647 0.64438 0.42494 0.68887 0.42802 0.66845 0.39853 Metetra
0.56594 setgray
0.66845 0.39853 0.68887 0.42802 0.73478 0.4322 0.71468 0.40154 Metetra
0.63207 setgray
0.71468 0.40154 0.73478 0.4322 0.7822 0.43746 0.76243 0.4055 Metetra
0.11905 setgray
0.17214 0.4248 0.19707 0.44801 0.23241 0.43648 0.20779 0.41291 Metetra
0.12311 setgray
0.20779 0.41291 0.23241 0.43648 0.26817 0.4266 0.24385 0.40267 Metetra
0.13483 setgray
0.24385 0.40267 0.26817 0.4266 0.30445 0.41826 0.28043 0.39394 Metetra
0.15358 setgray
0.28043 0.39394 0.30445 0.41826 0.34133 0.41134 0.31762 0.38661 Metetra
0.17876 setgray
0.31762 0.38661 0.34133 0.41134 0.3789 0.40575 0.3555 0.38057 Metetra
0.20983 setgray
0.3555 0.38057 0.3789 0.40575 0.41725 0.40141 0.39416 0.37573 Metetra
0.24631 setgray
0.39416 0.37573 0.41725 0.40141 0.45646 0.39826 0.43369 0.37202 Metetra
0.28772 setgray
0.43369 0.37202 0.45646 0.39826 0.49661 0.39624 0.47418 0.36937 Metetra
0.33366 setgray
0.47418 0.36937 0.49661 0.39624 0.53779 0.39529 0.5157 0.36771 Metetra
0.38374 setgray
0.5157 0.36771 0.53779 0.39529 0.5801 0.39538 0.55835 0.367 Metetra
0.43761 setgray
0.55835 0.367 0.5801 0.39538 0.62362 0.39647 0.60222 0.36718 Metetra
0.49496 setgray
0.60222 0.36718 0.62362 0.39647 0.66845 0.39853 0.64739 0.36821 Metetra
0.55548 setgray
0.64739 0.36821 0.66845 0.39853 0.71468 0.40154 0.69398 0.37007 Metetra
0.61893 setgray
0.69398 0.37007 0.71468 0.40154 0.76243 0.4055 0.74207 0.37273 Metetra
0.11905 setgray
0.14648 0.40091 0.17214 0.4248 0.20779 0.41291 0.18244 0.38865 Metetra
0.1231 setgray
0.18244 0.38865 0.20779 0.41291 0.24385 0.40267 0.21881 0.37803 Metetra
0.13478 setgray
0.21881 0.37803 0.24385 0.40267 0.28043 0.39394 0.2557 0.3689 Metetra
0.15339 setgray
0.2557 0.3689 0.28043 0.39394 0.31762 0.38661 0.29319 0.36113 Metetra
0.17833 setgray
0.29319 0.36113 0.31762 0.38661 0.3555 0.38057 0.33139 0.35462 Metetra
0.20902 setgray
0.33139 0.35462 0.3555 0.38057 0.39416 0.37573 0.37037 0.34927 Metetra
0.24492 setgray
0.37037 0.34927 0.39416 0.37573 0.43369 0.37202 0.41023 0.34499 Metetra
0.28556 setgray
0.41023 0.34499 0.43369 0.37202 0.47418 0.36937 0.45105 0.34169 Metetra
0.33048 setgray
0.45105 0.34169 0.47418 0.36937 0.5157 0.36771 0.49291 0.3393 Metetra
0.37928 setgray
0.49291 0.3393 0.5157 0.36771 0.55835 0.367 0.53592 0.33777 Metetra
0.43158 setgray
0.53592 0.33777 0.55835 0.367 0.60222 0.36718 0.58014 0.33703 Metetra
0.48705 setgray
0.58014 0.33703 0.60222 0.36718 0.64739 0.36821 0.62568 0.33704 Metetra
0.54537 setgray
0.62568 0.33704 0.64739 0.36821 0.69398 0.37007 0.67263 0.33775 Metetra
0.60625 setgray
0.67263 0.33775 0.69398 0.37007 0.74207 0.37273 0.72108 0.33912 Metetra
0.11905 setgray
0.12007 0.37632 0.14648 0.40091 0.18244 0.38865 0.15634 0.36367 Metetra
0.12309 setgray
0.15634 0.36367 0.18244 0.38865 0.21881 0.37803 0.19302 0.35264 Metetra
0.13472 setgray
0.19302 0.35264 0.21881 0.37803 0.2557 0.3689 0.23022 0.34309 Metetra
0.15321 setgray
0.23022 0.34309 0.2557 0.3689 0.29319 0.36113 0.26802 0.33488 Metetra
0.17791 setgray
0.26802 0.33488 0.29319 0.36113 0.33139 0.35462 0.30653 0.32788 Metetra
0.20822 setgray
0.30653 0.32788 0.33139 0.35462 0.37037 0.34927 0.34584 0.32199 Metetra
0.24356 setgray
0.34584 0.32199 0.37037 0.34927 0.41023 0.34499 0.38603 0.31711 Metetra
0.28343 setgray
0.38603 0.31711 0.41023 0.34499 0.45105 0.34169 0.42719 0.31315 Metetra
0.32736 setgray
0.42719 0.31315 0.45105 0.34169 0.49291 0.3393 0.46941 0.31002 Metetra
0.37493 setgray
0.46941 0.31002 0.49291 0.3393 0.53592 0.33777 0.51277 0.30765 Metetra
0.42572 setgray
0.51277 0.30765 0.53592 0.33777 0.58014 0.33703 0.55737 0.30599 Metetra
0.47938 setgray
0.55737 0.30599 0.58014 0.33703 0.62568 0.33704 0.60328 0.30496 Metetra
0.53559 setgray
0.60328 0.30496 0.62568 0.33704 0.67263 0.33775 0.65061 0.30451 Metetra
0.59403 setgray
0.65061 0.30451 0.67263 0.33775 0.72108 0.33912 0.69944 0.3046 Metetra
0.11905 setgray
0.09287 0.35099 0.12007 0.37632 0.15634 0.36367 0.12946 0.33793 Metetra
0.12309 setgray
0.12946 0.33793 0.15634 0.36367 0.19302 0.35264 0.16645 0.32649 Metetra
0.13467 setgray
0.16645 0.32649 0.19302 0.35264 0.23022 0.34309 0.20395 0.3165 Metetra
0.15304 setgray
0.20395 0.3165 0.23022 0.34309 0.26802 0.33488 0.24207 0.30782 Metetra
0.1775 setgray
0.24207 0.30782 0.26802 0.33488 0.30653 0.32788 0.2809 0.30031 Metetra
0.20742 setgray
0.2809 0.30031 0.30653 0.32788 0.34584 0.32199 0.32053 0.29386 Metetra
0.24222 setgray
0.32053 0.29386 0.34584 0.32199 0.38603 0.31711 0.36106 0.28836 Metetra
0.28134 setgray
0.36106 0.28836 0.38603 0.31711 0.42719 0.31315 0.40256 0.28371 Metetra
0.32432 setgray
0.40256 0.28371 0.42719 0.31315 0.46941 0.31002 0.44514 0.27982 Metetra
0.37068 setgray
0.44514 0.27982 0.46941 0.31002 0.51277 0.30765 0.48888 0.2766 Metetra
0.42001 setgray
0.48888 0.2766 0.51277 0.30765 0.55737 0.30599 0.53385 0.274 Metetra
0.47194 setgray
0.53385 0.274 0.55737 0.30599 0.60328 0.30496 0.58016 0.27192 Metetra
0.52612 setgray
0.58016 0.27192 0.60328 0.30496 0.65061 0.30451 0.62788 0.27032 Metetra
0.58223 setgray
0.62788 0.27032 0.65061 0.30451 0.69944 0.3046 0.67711 0.26912 Metetra
0.11905 setgray
0.06484 0.32489 0.09287 0.35099 0.12946 0.33793 0.10175 0.31141 Metetra
0.12308 setgray
0.10175 0.31141 0.12946 0.33793 0.16645 0.32649 0.13905 0.29952 Metetra
0.13461 setgray
0.13905 0.29952 0.16645 0.32649 0.20395 0.3165 0.17686 0.28908 Metetra
0.15286 setgray
0.17686 0.28908 0.20395 0.3165 0.24207 0.30782 0.2153 0.2799 Metetra
0.17709 setgray
0.2153 0.2799 0.24207 0.30782 0.2809 0.30031 0.25445 0.27186 Metetra
0.20664 setgray
0.25445 0.27186 0.2809 0.30031 0.32053 0.29386 0.29441 0.26483 Metetra
0.24089 setgray
0.29441 0.26483 0.32053 0.29386 0.36106 0.28836 0.33528 0.25869 Metetra
0.2793 setgray
0.33528 0.25869 0.36106 0.28836 0.40256 0.28371 0.37714 0.25333 Metetra
0.32133 setgray
0.37714 0.25333 0.40256 0.28371 0.44514 0.27982 0.42008 0.24865 Metetra
0.36653 setgray
0.42008 0.24865 0.44514 0.27982 0.48888 0.2766 0.46419 0.24457 Metetra
0.41445 setgray
0.46419 0.24457 0.48888 0.2766 0.53385 0.274 0.50956 0.241 Metetra
0.46472 setgray
0.50956 0.241 0.53385 0.274 0.58016 0.27192 0.55627 0.23787 Metetra
0.51696 setgray
0.55627 0.23787 0.58016 0.27192 0.62788 0.27032 0.6044 0.2351 Metetra
0.57085 setgray
0.6044 0.2351 0.62788 0.27032 0.67711 0.26912 0.65405 0.23262 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.16653 0.27486 moveto
0.1749 0.28333 lineto
stroke
0 setgray
[(0.2)] 0.16235 0.27062 0.987329 1 Mshowa
0.27693 0.23152 moveto
0.28492 0.24035 lineto
stroke
0 setgray
[(0.4)] 0.27294 0.22711 0.903932 1 Mshowa
0.39281 0.18605 moveto
0.40036 0.19525 lineto
stroke
0 setgray
[(0.6)] 0.38903 0.18145 0.820535 1 Mshowa
0.51457 0.13827 moveto
0.52164 0.14786 lineto
stroke
0 setgray
[(0.8)] 0.51104 0.13348 0.737139 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(1)] 0.63943 0.08304 0.653742 1 Mshowa
0 setgray
[(t)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71067 0.18142 moveto
0.69951 0.18555 lineto
stroke
0 setgray
[(0.2)] 0.71626 0.17936 -1 0.369305 Mshowa
0.76468 0.26407 moveto
0.75344 0.268 lineto
stroke
0 setgray
[(0.4)] 0.77029 0.26211 -1 0.349436 Mshowa
0.81414 0.33978 moveto
0.80284 0.34353 lineto
stroke
0 setgray
[(0.6)] 0.81979 0.33791 -1 0.331596 Mshowa
0.85963 0.4094 moveto
0.84827 0.41298 lineto
stroke
0 setgray
[(0.8)] 0.8653 0.40761 -1 0.315489 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(1)] 0.90729 0.47191 -1 0.300874 Mshowa
0 setgray
[(a)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.05287 0.36746 moveto
0.06399 0.36321 lineto
stroke
0 setgray
[(0.1)] 0.04731 0.36959 1 -0.382083 Mshowa
0.04625 0.40908 moveto
0.05741 0.40492 lineto
stroke
0 setgray
[(0.2)] 0.04068 0.41116 1 -0.37329 Mshowa
0.03944 0.45196 moveto
0.05062 0.44788 lineto
stroke
0 setgray
[(0.3)] 0.03384 0.45399 1 -0.364202 Mshowa
0.03241 0.49616 moveto
0.04363 0.49217 lineto
stroke
0 setgray
[(0.4)] 0.0268 0.49815 1 -0.354806 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-SurfaceGraphics-
:[font = text; inactive; ]

Alternatively, we could set a to a constant value and plot y(t).  For a = -2, y(t) is plotted below:
:[font = input; startGroup; ]

Plot[ Release[ysol /. a -> -2], {t, 0, 2}, AxesLabel -> { "t", "y(t)" } ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.47619 0.01472 2.53658 [
[(0.5)] 0.2619 0.00222 0 1 Msboxa
[(1)] 0.5 0.00222 0 1 Msboxa
[(1.5)] 0.7381 0.00222 0 1 Msboxa
[(2)] 0.97619 0.00222 0 1 Msboxa
[(t)] 1.00625 0.01472 -1 0 Msboxa
[(0.05)] 0.01131 0.14154 1 0 Msboxa
[(0.1)] 0.01131 0.26837 1 0 Msboxa
[(0.15)] 0.01131 0.3952 1 0 Msboxa
[(0.2)] 0.01131 0.52203 1 0 Msboxa
[(y\(t\))] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.2619 0.00847 moveto
0.2619 0.02097 lineto
stroke
0 setgray
[(0.5)] 0.2619 0.00222 0 1 Mshowa
0.5 0.00847 moveto
0.5 0.02097 lineto
stroke
0 setgray
[(1)] 0.5 0.00222 0 1 Mshowa
0.7381 0.00847 moveto
0.7381 0.02097 lineto
stroke
0 setgray
[(1.5)] 0.7381 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(2)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.01472 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.14154 moveto
0.03006 0.14154 lineto
stroke
0 setgray
[(0.05)] 0.01131 0.14154 1 0 Mshowa
0.01756 0.26837 moveto
0.03006 0.26837 lineto
stroke
0 setgray
[(0.1)] 0.01131 0.26837 1 0 Mshowa
0.01756 0.3952 moveto
0.03006 0.3952 lineto
stroke
0 setgray
[(0.15)] 0.01131 0.3952 1 0 Mshowa
0.01756 0.52203 moveto
0.03006 0.52203 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.52203 1 0 Mshowa
0 setgray
[(y\(t\))] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02505 0.01472 lineto
0.02629 0.01475 lineto
0.02753 0.01479 lineto
0.02877 0.01485 lineto
0.03001 0.01493 lineto
0.03125 0.01502 lineto
0.03373 0.01525 lineto
0.03869 0.01591 lineto
0.04365 0.01681 lineto
0.05357 0.01932 lineto
0.06349 0.02271 lineto
0.08333 0.03186 lineto
0.10317 0.04376 lineto
0.14286 0.07411 lineto
0.18254 0.11074 lineto
0.22222 0.15127 lineto
0.2619 0.19378 lineto
0.30159 0.23681 lineto
0.34127 0.27921 lineto
0.38095 0.32014 lineto
0.42063 0.35895 lineto
0.46032 0.39521 lineto
0.5 0.42862 lineto
0.53968 0.45899 lineto
0.57937 0.48624 lineto
0.61905 0.51035 lineto
0.65873 0.53138 lineto
0.69841 0.5494 lineto
0.7381 0.56453 lineto
0.77778 0.57691 lineto
0.81746 0.5867 lineto
0.8373 0.59068 lineto
0.85714 0.59407 lineto
0.87698 0.5969 lineto
0.89683 0.59918 lineto
0.91667 0.60094 lineto
0.93651 0.60221 lineto
0.94643 0.60266 lineto
0.95139 0.60284 lineto
0.95635 0.60299 lineto
0.96131 0.60312 lineto
0.96627 0.60321 lineto
0.96875 0.60325 lineto
0.97123 0.60328 lineto
0.97371 0.6033 lineto
0.97619 0.60332 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsection; inactive; startGroup; Cclosed; ]
Differential Equation With Initial Conditions
:[font = text; inactive; ]

		The analysis carried out for a differential equation with zero-valued initial conditions applies to those with non-zero initial conditions.  Here is the same differential equation with y'(0) = 1/2 and y(0) = 4:
:[font = input; startGroup; ]

LSolve[ y''[t] + 3/2 y'[t] + 1/2 y[t] == Exp[a t] CStep[t],
		y[t], y'[0] -> 1/2, y[0] -> 4 ]
:[font = output; inactive; output; endGroup; ]
((-10 - 36*a)*CStep[t/2])/(2*E^(t/2)*(-1 - 2*a)) + 
  ((3 + 5*a)*CStep[t])/(E^t*(-1 - a)) - (2*E^(a*t)*CStep[t])/(-1 - 3*a - 2*a^2)
;[o]
                   t
(-10 - 36 a) CStep[-]                           a t
                   2    (3 + 5 a) CStep[t]   2 E    CStep[t]
--------------------- + ------------------ - ---------------
     t/2                    t                              2
  2 E    (-1 - 2 a)        E  (-1 - a)       -1 - 3 a - 2 a
:[font = text; inactive; ]

Again, implied here is that we want the solution to the differential equation when t > 0.  So once again, we will drop the step functions since they are 1 for t > 0.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Verifying a Solution
:[font = text; inactive; ]

We can now use Mathematica to verify the solution, which we assign to the function ysol:
:[font = input; initialization; startGroup; ]
*)

yicsol =	(5 + 18 a) Exp[-t/2] / (1 + 2 a) +
			(3 + 5 a) Exp[-t] / (-1 - a) -
			2 Exp[a t] / (-1 - 3 a - 2 a^2 )
(*
:[font = output; inactive; output; endGroup; ]
(3 + 5*a)/(E^t*(-1 - a)) + 
  (5 + 18*a)/(E^(t/2)*(1 + 2*a)) - 
  (2*E^(a*t))/(-1 - 3*a - 2*a^2)
;[o]
                                      a t
  3 + 5 a        5 + 18 a          2 E
----------- + -------------- - ---------------
 t             t/2                           2
E  (-1 - a)   E    (1 + 2 a)   -1 - 3 a - 2 a
:[font = text; inactive; ]

 We can now check to make sure that the initial conditions are valid.  First, we check to see if y(0+) = 4:
:[font = input; startGroup; ]
yicsol /. t -> 0

:[font = output; inactive; output; endGroup; ]
(3 + 5*a)/(-1 - a) + (5 + 18*a)/(1 + 2*a) - 2/(-1 - 3*a - 2*a^2)
;[o]
3 + 5 a   5 + 18 a          2
------- + -------- - ---------------
-1 - a    1 + 2 a                  2
                     -1 - 3 a - 2 a
:[font = text; inactive; ]

This may not look like four but it actually is:

:[font = input; startGroup; ]

Simplify[ yicsol /. t -> 0 ]
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = text; inactive; ]

Second, we can check to make sure that ysol'(0+) equals 1/2:
:[font = input; initialization; startGroup; ]
*)

Simplify[ D[ yicsol, t ] /. t -> 0 ]
(*
:[font = output; inactive; output; endGroup; ]
1/2
;[o]
1
-
2
:[font = text; inactive; ]

Next, we can try to verify that the solution satisfies the differential equation:
:[font = input; startGroup; ]

yicsolprime = D[ yicsol, t];
yicsoldblprime = D[ yicsolprime, t];

Simplify[ yicsoldblprime + 3/2 yicsolprime + 1/2 yicsol ]
:[font = output; inactive; output; endGroup; endGroup; ]
E^(a*t)
;[o]
 a t
E
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Analyzing a Solution
:[font = text; inactive; ]

		Now that we shown that the solution is correct, we can analyze the solution.  First, there are certain values of the free parameter a which yield an unbounded (and hence invalid) solution.  This occurs when any of the denominator terms become zero, which happens when a = -1/2 and when a = -1.  This can be seen from inspection, but Mathematica can determine these values in the general case. Again, we convert the solution from its form of Plus[term1, term2, term3] to a list of the form List[term1, term2, term3] by using Apply and then solve the cases where each denominator is zero using Solve:
:[font = input; startGroup; ]

Map[ Solve[Denominator[#1] == 0, a]&, Apply[List, yicsol] ]
:[font = output; inactive; output; endGroup; endGroup; ]
{{{a -> -1}}, {{a -> -1/2}}, {{a -> -1}, {a -> -1/2}}}
;[o]
                       1                         1
{{{a -> -1}}, {{a -> -(-)}}, {{a -> -1}, {a -> -(-)}}}
                       2                         2
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Interpreting a Solution
:[font = text; inactive; ]

		In this case, ysol is assigned to the solution of the differential equation automatically by the notebook.  To plot the solution, then, we simplify plot ysol for different values of a:
:[font = input; startGroup; ]

Plot3D[ yicsol, {t, 0, 1}, {a, 0, 1}, AxesLabel -> { "t", "a", " " } ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(0.2)] 0.16235 0.27062 0.987329 1 Msboxa
[(0.4)] 0.27294 0.22711 0.903932 1 Msboxa
[(0.6)] 0.38903 0.18145 0.820535 1 Msboxa
[(0.8)] 0.51104 0.13348 0.737139 1 Msboxa
[(1)] 0.63943 0.08304 0.653742 1 Msboxa
[(t)] 0.2914 0.15947 0.862234 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(0.2)] 0.71626 0.17936 -1 0.369305 Msboxa
[(0.4)] 0.77029 0.26211 -1 0.349436 Msboxa
[(0.6)] 0.81979 0.33791 -1 0.331596 Msboxa
[(0.8)] 0.8653 0.40761 -1 0.315489 Msboxa
[(1)] 0.90729 0.47191 -1 0.300874 Msboxa
[(a)] 0.85193 0.28164 -1 0.340282 Msboxa
[(3.95)] 0.04997 0.35293 1 -0.385599 Msboxa
[(4)] 0.04069 0.41111 1 -0.373302 Msboxa
[(4.05)] 0.031 0.47178 1 -0.360421 Msboxa
[(4.1)] 0.0209 0.53512 1 -0.346914 Msboxa
[( )] -0.01735 0.44567 1 -0.370357 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.16653 0.27486 moveto
0.1749 0.28333 lineto
stroke
0 setgray
[(0.2)] 0.16235 0.27062 0.987329 1 Mshowa
0.27693 0.23152 moveto
0.28492 0.24035 lineto
stroke
0 setgray
[(0.4)] 0.27294 0.22711 0.903932 1 Mshowa
0.39281 0.18605 moveto
0.40036 0.19525 lineto
stroke
0 setgray
[(0.6)] 0.38903 0.18145 0.820535 1 Mshowa
0.51457 0.13827 moveto
0.52164 0.14786 lineto
stroke
0 setgray
[(0.8)] 0.51104 0.13348 0.737139 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(1)] 0.63943 0.08304 0.653742 1 Mshowa
0 setgray
[(t)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71067 0.18142 moveto
0.69951 0.18555 lineto
stroke
0 setgray
[(0.2)] 0.71626 0.17936 -1 0.369305 Mshowa
0.76468 0.26407 moveto
0.75344 0.268 lineto
stroke
0 setgray
[(0.4)] 0.77029 0.26211 -1 0.349436 Mshowa
0.81414 0.33978 moveto
0.80284 0.34353 lineto
stroke
0 setgray
[(0.6)] 0.81979 0.33791 -1 0.331596 Mshowa
0.85963 0.4094 moveto
0.84827 0.41298 lineto
stroke
0 setgray
[(0.8)] 0.8653 0.40761 -1 0.315489 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(1)] 0.90729 0.47191 -1 0.300874 Mshowa
0 setgray
[(a)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05552 0.35079 moveto
0.06663 0.34651 lineto
stroke
0 setgray
[(3.95)] 0.04997 0.35293 1 -0.385599 Mshowa
0.04626 0.40902 moveto
0.05742 0.40486 lineto
stroke
0 setgray
[(4)] 0.04069 0.41111 1 -0.373302 Mshowa
0.0366 0.46976 moveto
0.0478 0.46573 lineto
stroke
0 setgray
[(4.05)] 0.031 0.47178 1 -0.360421 Mshowa
0.02652 0.53317 moveto
0.03777 0.52927 lineto
stroke
0 setgray
[(4.1)] 0.0209 0.53512 1 -0.346914 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.44635 setgray
0.0015 setlinewidth
0.3706 0.68782 0.39071 0.70554 0.42341 0.73047 0.40336 0.71274 Metetra
0.59135 setgray
0.40336 0.71274 0.42341 0.73047 0.45744 0.74752 0.43753 0.72971 Metetra
0.70051 setgray
0.43753 0.72971 0.45744 0.74752 0.49256 0.75747 0.47286 0.73946 Metetra
0.77885 setgray
0.47286 0.73946 0.49256 0.75747 0.52859 0.76118 0.50915 0.74281 Metetra
0.83106 setgray
0.50915 0.74281 0.52859 0.76118 0.56535 0.75956 0.54622 0.74064 Metetra
0.86154 setgray
0.54622 0.74064 0.56535 0.75956 0.60271 0.75354 0.58391 0.73387 Metetra
0.87441 setgray
0.58391 0.73387 0.60271 0.75354 0.64058 0.7441 0.62213 0.72341 Metetra
0.87357 setgray
0.62213 0.72341 0.64058 0.7441 0.67891 0.73216 0.6608 0.71018 Metetra
0.8627 setgray
0.6608 0.71018 0.67891 0.73216 0.71768 0.71866 0.69989 0.69506 Metetra
0.84526 setgray
0.69989 0.69506 0.71768 0.71866 0.75693 0.70449 0.73941 0.67889 Metetra
0.82458 setgray
0.73941 0.67889 0.75693 0.70449 0.79674 0.69052 0.77941 0.6625 Metetra
0.80381 setgray
0.77941 0.6625 0.79674 0.69052 0.83721 0.6776 0.81998 0.64669 Metetra
0.78599 setgray
0.81998 0.64669 0.83721 0.6776 0.87852 0.66657 0.86126 0.63221 Metetra
0.77403 setgray
0.86126 0.63221 0.87852 0.66657 0.92089 0.65827 0.90342 0.6198 Metetra
0.44635 setgray
0.34995 0.66963 0.3706 0.68782 0.40336 0.71274 0.38277 0.69454 Metetra
0.59133 setgray
0.38277 0.69454 0.40336 0.71274 0.43753 0.72971 0.41708 0.71142 Metetra
0.70035 setgray
0.41708 0.71142 0.43753 0.72971 0.47286 0.73946 0.45262 0.72095 Metetra
0.7783 setgray
0.45262 0.72095 0.47286 0.73946 0.50915 0.74281 0.48917 0.72393 Metetra
0.82975 setgray
0.48917 0.72393 0.50915 0.74281 0.54622 0.74064 0.52655 0.72121 Metetra
0.85895 setgray
0.52655 0.72121 0.54622 0.74064 0.58391 0.73387 0.5646 0.71367 Metetra
0.8699 setgray
0.5646 0.71367 0.58391 0.73387 0.62213 0.72341 0.60317 0.7022 Metetra
0.86634 setgray
0.60317 0.7022 0.62213 0.72341 0.6608 0.71018 0.6422 0.68767 Metetra
0.85178 setgray
0.6422 0.68767 0.6608 0.71018 0.69989 0.69506 0.68163 0.67094 Metetra
0.82954 setgray
0.68163 0.67094 0.69989 0.69506 0.73941 0.67889 0.72145 0.65281 Metetra
0.80276 setgray
0.72145 0.65281 0.73941 0.67889 0.77941 0.6625 0.76168 0.63406 Metetra
0.77441 setgray
0.76168 0.63406 0.77941 0.6625 0.81998 0.64669 0.80239 0.61544 Metetra
0.74731 setgray
0.80239 0.61544 0.81998 0.64669 0.86126 0.63221 0.84369 0.59764 Metetra
0.72417 setgray
0.84369 0.59764 0.86126 0.63221 0.90342 0.6198 0.88571 0.58134 Metetra
0.44635 setgray
0.32876 0.65096 0.34995 0.66963 0.38277 0.69454 0.36163 0.67585 Metetra
0.59131 setgray
0.36163 0.67585 0.38277 0.69454 0.41708 0.71142 0.39606 0.69261 Metetra
0.70019 setgray
0.39606 0.69261 0.41708 0.71142 0.45262 0.72095 0.43181 0.70192 Metetra
0.77776 setgray
0.43181 0.70192 0.45262 0.72095 0.48917 0.72393 0.46863 0.70452 Metetra
0.82845 setgray
0.46863 0.70452 0.48917 0.72393 0.52655 0.72121 0.50634 0.70124 Metetra
0.8564 setgray
0.50634 0.70124 0.52655 0.72121 0.5646 0.71367 0.54474 0.69292 Metetra
0.86546 setgray
0.54474 0.69292 0.5646 0.71367 0.60317 0.7022 0.58369 0.68043 Metetra
0.85924 setgray
0.58369 0.68043 0.60317 0.7022 0.6422 0.68767 0.6231 0.66461 Metetra
0.84111 setgray
0.6231 0.66461 0.6422 0.68767 0.68163 0.67094 0.66289 0.64628 Metetra
0.81422 setgray
0.66289 0.64628 0.68163 0.67094 0.72145 0.65281 0.70304 0.62622 Metetra
0.78156 setgray
0.70304 0.62622 0.72145 0.65281 0.76168 0.63406 0.74354 0.60516 Metetra
0.74593 setgray
0.74354 0.60516 0.76168 0.63406 0.80239 0.61544 0.78443 0.58381 Metetra
0.70996 setgray
0.78443 0.58381 0.80239 0.61544 0.84369 0.59764 0.8258 0.56282 Metetra
0.67618 setgray
0.8258 0.56282 0.84369 0.59764 0.88571 0.58134 0.86775 0.5428 Metetra
0.44635 setgray
0.30699 0.63177 0.32876 0.65096 0.36163 0.67585 0.33989 0.65664 Metetra
0.59129 setgray
0.33989 0.65664 0.36163 0.67585 0.39606 0.69261 0.37445 0.67329 Metetra
0.70003 setgray
0.37445 0.67329 0.39606 0.69261 0.43181 0.70192 0.41041 0.68235 Metetra
0.77722 setgray
0.41041 0.68235 0.43181 0.70192 0.46863 0.70452 0.44751 0.68456 Metetra
0.82716 setgray
0.44751 0.68456 0.46863 0.70452 0.50634 0.70124 0.48554 0.6807 Metetra
0.85388 setgray
0.48554 0.6807 0.50634 0.70124 0.54474 0.69292 0.52431 0.6716 Metetra
0.86109 setgray
0.52431 0.6716 0.54474 0.69292 0.58369 0.68043 0.56366 0.65808 Metetra
0.85228 setgray
0.56366 0.65808 0.58369 0.68043 0.6231 0.66461 0.60347 0.64097 Metetra
0.83066 setgray
0.60347 0.64097 0.6231 0.66461 0.66289 0.64628 0.64365 0.62105 Metetra
0.79928 setgray
0.64365 0.62105 0.66289 0.64628 0.70304 0.62622 0.68415 0.59908 Metetra
0.76095 setgray
0.68415 0.59908 0.70304 0.62622 0.74354 0.60516 0.72495 0.57576 Metetra
0.71832 setgray
0.72495 0.57576 0.74354 0.60516 0.78443 0.58381 0.76608 0.55177 Metetra
0.67388 setgray
0.76608 0.55177 0.78443 0.58381 0.8258 0.56282 0.80757 0.5277 Metetra
0.62996 setgray
0.80757 0.5277 0.8258 0.56282 0.86775 0.5428 0.84951 0.50414 Metetra
0.44635 setgray
0.28463 0.61207 0.30699 0.63177 0.33989 0.65664 0.31756 0.63689 Metetra
0.59127 setgray
0.31756 0.63689 0.33989 0.65664 0.37445 0.67329 0.35224 0.65341 Metetra
0.69987 setgray
0.35224 0.65341 0.37445 0.67329 0.41041 0.68235 0.38839 0.66222 Metetra
0.77668 setgray
0.38839 0.66222 0.41041 0.68235 0.44751 0.68456 0.42577 0.66403 Metetra
0.82589 setgray
0.42577 0.66403 0.44751 0.68456 0.48554 0.6807 0.46414 0.65958 Metetra
0.85139 setgray
0.46414 0.65958 0.48554 0.6807 0.52431 0.6716 0.50329 0.64968 Metetra
0.8568 setgray
0.50329 0.64968 0.52431 0.6716 0.56366 0.65808 0.54305 0.63512 Metetra
0.84545 setgray
0.54305 0.63512 0.56366 0.65808 0.60347 0.64097 0.58328 0.61671 Metetra
0.82045 setgray
0.58328 0.61671 0.60347 0.64097 0.64365 0.62105 0.62388 0.59522 Metetra
0.78471 setgray
0.62388 0.59522 0.64365 0.62105 0.68415 0.59908 0.66476 0.57137 Metetra
0.74091 setgray
0.66476 0.57137 0.68415 0.59908 0.72495 0.57576 0.70591 0.54584 Metetra
0.69156 setgray
0.70591 0.54584 0.72495 0.57576 0.76608 0.55177 0.7473 0.51927 Metetra
0.63901 setgray
0.7473 0.51927 0.76608 0.55177 0.80757 0.5277 0.78897 0.49224 Metetra
0.58545 setgray
0.78897 0.49224 0.80757 0.5277 0.84951 0.50414 0.83097 0.4653 Metetra
0.44635 setgray
0.26164 0.59181 0.28463 0.61207 0.31756 0.63689 0.29458 0.61659 Metetra
0.59125 setgray
0.29458 0.61659 0.31756 0.63689 0.35224 0.65341 0.32938 0.63296 Metetra
0.69971 setgray
0.32938 0.63296 0.35224 0.65341 0.38839 0.66222 0.36573 0.64151 Metetra
0.77614 setgray
0.36573 0.64151 0.38839 0.66222 0.42577 0.66403 0.40339 0.64289 Metetra
0.82463 setgray
0.40339 0.64289 0.42577 0.66403 0.46414 0.65958 0.4421 0.63784 Metetra
0.84894 setgray
0.4421 0.63784 0.46414 0.65958 0.50329 0.64968 0.48165 0.62713 Metetra
0.85257 setgray
0.48165 0.62713 0.50329 0.64968 0.54305 0.63512 0.52184 0.61153 Metetra
0.83874 setgray
0.52184 0.61153 0.54305 0.63512 0.58328 0.61671 0.56251 0.59183 Metetra
0.81046 setgray
0.56251 0.59183 0.58328 0.61671 0.62388 0.59522 0.60355 0.56876 Metetra
0.7705 setgray
0.60355 0.56876 0.62388 0.59522 0.66476 0.57137 0.64486 0.54305 Metetra
0.72142 setgray
0.64486 0.54305 0.66476 0.57137 0.70591 0.54584 0.68638 0.51535 Metetra
0.66562 setgray
0.68638 0.51535 0.70591 0.54584 0.7473 0.51927 0.72809 0.48628 Metetra
0.60532 setgray
0.72809 0.48628 0.7473 0.51927 0.78897 0.49224 0.76999 0.4564 Metetra
0.54257 setgray
0.76999 0.4564 0.78897 0.49224 0.83097 0.4653 0.8121 0.42621 Metetra
0.44635 setgray
0.238 0.57098 0.26164 0.59181 0.29458 0.61659 0.27095 0.59569 Metetra
0.59123 setgray
0.27095 0.59569 0.29458 0.61659 0.32938 0.63296 0.30585 0.61192 Metetra
0.69955 setgray
0.30585 0.61192 0.32938 0.63296 0.36573 0.64151 0.34241 0.62019 Metetra
0.77562 setgray
0.34241 0.62019 0.36573 0.64151 0.40339 0.64289 0.38035 0.62113 Metetra
0.82338 setgray
0.38035 0.62113 0.40339 0.64289 0.4421 0.63784 0.41941 0.61546 Metetra
0.84652 setgray
0.41941 0.61546 0.4421 0.63784 0.48165 0.62713 0.45936 0.60392 Metetra
0.84841 setgray
0.45936 0.60392 0.48165 0.62713 0.52184 0.61153 0.5 0.58727 Metetra
0.83217 setgray
0.5 0.58727 0.52184 0.61153 0.56251 0.59183 0.54114 0.56627 Metetra
0.80069 setgray
0.54114 0.56627 0.56251 0.59183 0.60355 0.56876 0.58265 0.54164 Metetra
0.75664 setgray
0.58265 0.54164 0.60355 0.56876 0.64486 0.54305 0.62441 0.51409 Metetra
0.70247 setgray
0.62441 0.51409 0.64486 0.54305 0.68638 0.51535 0.66635 0.48426 Metetra
0.64048 setgray
0.66635 0.48426 0.68638 0.51535 0.72809 0.48628 0.70842 0.45275 Metetra
0.57275 setgray
0.70842 0.45275 0.72809 0.48628 0.76999 0.4564 0.75059 0.42011 Metetra
0.50125 setgray
0.75059 0.42011 0.76999 0.4564 0.8121 0.42621 0.79288 0.38683 Metetra
0.44635 setgray
0.21369 0.54956 0.238 0.57098 0.27095 0.59569 0.24663 0.57419 Metetra
0.59121 setgray
0.24663 0.57419 0.27095 0.59569 0.30585 0.61192 0.28162 0.59025 Metetra
0.69939 setgray
0.28162 0.59025 0.30585 0.61192 0.34241 0.62019 0.31838 0.59822 Metetra
0.77509 setgray
0.31838 0.59822 0.34241 0.62019 0.38035 0.62113 0.3566 0.59872 Metetra
0.82215 setgray
0.3566 0.59872 0.38035 0.62113 0.41941 0.61546 0.39603 0.59241 Metetra
0.84413 setgray
0.39603 0.59241 0.41941 0.61546 0.45936 0.60392 0.4364 0.58003 Metetra
0.84431 setgray
0.4364 0.58003 0.45936 0.60392 0.5 0.58727 0.4775 0.56232 Metetra
0.82572 setgray
0.4775 0.56232 0.5 0.58727 0.54114 0.56627 0.51914 0.54001 Metetra
0.79113 setgray
0.51914 0.54001 0.54114 0.56627 0.58265 0.54164 0.56114 0.51383 Metetra
0.74311 setgray
0.56114 0.51383 0.58265 0.54164 0.62441 0.51409 0.60339 0.48445 Metetra
0.68404 setgray
0.60339 0.48445 0.62441 0.51409 0.66635 0.48426 0.64578 0.45253 Metetra
0.61609 setgray
0.64578 0.45253 0.66635 0.48426 0.70842 0.45275 0.68825 0.41864 Metetra
0.54127 setgray
0.68825 0.41864 0.70842 0.45275 0.75059 0.42011 0.73076 0.38333 Metetra
0.46143 setgray
0.73076 0.38333 0.75059 0.42011 0.79288 0.38683 0.77328 0.34709 Metetra
0.44635 setgray
0.18867 0.52752 0.21369 0.54956 0.24663 0.57419 0.22159 0.55206 Metetra
0.59119 setgray
0.22159 0.55206 0.24663 0.57419 0.28162 0.59025 0.25667 0.56792 Metetra
0.69924 setgray
0.25667 0.56792 0.28162 0.59025 0.31838 0.59822 0.29361 0.57558 Metetra
0.77457 setgray
0.29361 0.57558 0.31838 0.59822 0.3566 0.59872 0.33213 0.57561 Metetra
0.82093 setgray
0.33213 0.57561 0.3566 0.59872 0.39603 0.59241 0.37192 0.56866 Metetra
0.84178 setgray
0.37192 0.56866 0.39603 0.59241 0.4364 0.58003 0.41273 0.55543 Metetra
0.84028 setgray
0.41273 0.55543 0.4364 0.58003 0.4775 0.56232 0.45432 0.53664 Metetra
0.81938 setgray
0.45432 0.53664 0.4775 0.56232 0.51914 0.54001 0.49647 0.51302 Metetra
0.78177 setgray
0.49647 0.51302 0.51914 0.54001 0.56114 0.51383 0.539 0.48528 Metetra
0.72992 setgray
0.539 0.48528 0.56114 0.51383 0.60339 0.48445 0.58177 0.4541 Metetra
0.66611 setgray
0.58177 0.4541 0.60339 0.48445 0.64578 0.45253 0.62466 0.42012 Metetra
0.59244 setgray
0.62466 0.42012 0.64578 0.45253 0.68825 0.41864 0.66757 0.38391 Metetra
0.51083 setgray
0.66757 0.38391 0.68825 0.41864 0.73076 0.38333 0.71046 0.34602 Metetra
0.42305 setgray
0.71046 0.34602 0.73076 0.38333 0.77328 0.34709 0.75328 0.30693 Metetra
0.44635 setgray
0.16292 0.50482 0.18867 0.52752 0.22159 0.55206 0.19579 0.52925 Metetra
0.59117 setgray
0.19579 0.52925 0.22159 0.55206 0.25667 0.56792 0.23095 0.54492 Metetra
0.69908 setgray
0.23095 0.54492 0.25667 0.56792 0.29361 0.57558 0.26808 0.55225 Metetra
0.77405 setgray
0.26808 0.55225 0.29361 0.57558 0.33213 0.57561 0.30689 0.55179 Metetra
0.81972 setgray
0.30689 0.55179 0.33213 0.57561 0.37192 0.56866 0.34706 0.54417 Metetra
0.83945 setgray
0.34706 0.54417 0.37192 0.56866 0.41273 0.55543 0.38832 0.53007 Metetra
0.83632 setgray
0.38832 0.53007 0.41273 0.55543 0.45432 0.53664 0.43041 0.51019 Metetra
0.81317 setgray
0.43041 0.51019 0.45432 0.53664 0.49647 0.51302 0.4731 0.48525 Metetra
0.77261 setgray
0.4731 0.48525 0.49647 0.51302 0.539 0.48528 0.5162 0.45596 Metetra
0.71705 setgray
0.5162 0.45596 0.539 0.48528 0.58177 0.4541 0.55952 0.42299 Metetra
0.64867 setgray
0.55952 0.42299 0.58177 0.4541 0.62466 0.42012 0.60294 0.38698 Metetra
0.5695 setgray
0.60294 0.38698 0.62466 0.42012 0.66757 0.38391 0.64635 0.34851 Metetra
0.4814 setgray
0.64635 0.34851 0.66757 0.38391 0.71046 0.34602 0.68967 0.30812 Metetra
0.38605 setgray
0.68967 0.30812 0.71046 0.34602 0.75328 0.30693 0.73284 0.2663 Metetra
0.44635 setgray
0.13639 0.48145 0.16292 0.50482 0.19579 0.52925 0.16921 0.50575 Metetra
0.59115 setgray
0.16921 0.50575 0.19579 0.52925 0.23095 0.54492 0.20443 0.5212 Metetra
0.69893 setgray
0.20443 0.5212 0.23095 0.54492 0.26808 0.55225 0.24175 0.52818 Metetra
0.77354 setgray
0.24175 0.52818 0.26808 0.55225 0.30689 0.55179 0.28085 0.52722 Metetra
0.81853 setgray
0.28085 0.52722 0.30689 0.55179 0.34706 0.54417 0.32141 0.51891 Metetra
0.83716 setgray
0.32141 0.51891 0.34706 0.54417 0.38832 0.53007 0.36313 0.50391 Metetra
0.83242 setgray
0.36313 0.50391 0.38832 0.53007 0.43041 0.51019 0.40575 0.48293 Metetra
0.80707 setgray
0.40575 0.48293 0.43041 0.51019 0.4731 0.48525 0.44901 0.45667 Metetra
0.76365 setgray
0.44901 0.45667 0.4731 0.48525 0.5162 0.45596 0.49269 0.42583 Metetra
0.70449 setgray
0.49269 0.42583 0.5162 0.45596 0.55952 0.42299 0.53661 0.39109 Metetra
0.6317 setgray
0.53661 0.39109 0.55952 0.42299 0.60294 0.38698 0.58061 0.35308 Metetra
0.54725 setgray
0.58061 0.35308 0.60294 0.38698 0.64635 0.34851 0.62456 0.3124 Metetra
0.45292 setgray
0.62456 0.3124 0.64635 0.34851 0.68967 0.30812 0.66837 0.26959 Metetra
0.35036 setgray
0.66837 0.26959 0.68967 0.30812 0.73284 0.2663 0.71195 0.22513 Metetra
0.44635 setgray
0.10907 0.45737 0.13639 0.48145 0.16921 0.50575 0.1418 0.48152 Metetra
0.59113 setgray
0.1418 0.48152 0.16921 0.50575 0.20443 0.5212 0.17708 0.49673 Metetra
0.69877 setgray
0.17708 0.49673 0.20443 0.5212 0.24175 0.52818 0.21458 0.50335 Metetra
0.77303 setgray
0.21458 0.50335 0.24175 0.52818 0.28085 0.52722 0.25397 0.50186 Metetra
0.81735 setgray
0.25397 0.50186 0.28085 0.52722 0.32141 0.51891 0.29492 0.49284 Metetra
0.83489 setgray
0.29492 0.49284 0.32141 0.51891 0.36313 0.50391 0.33713 0.47694 Metetra
0.82858 setgray
0.33713 0.47694 0.36313 0.50391 0.40575 0.48293 0.38029 0.45484 Metetra
0.80109 setgray
0.38029 0.45484 0.40575 0.48293 0.44901 0.45667 0.42415 0.42724 Metetra
0.75489 setgray
0.42415 0.42724 0.44901 0.45667 0.49269 0.42583 0.46846 0.39485 Metetra
0.69223 setgray
0.46846 0.39485 0.49269 0.42583 0.53661 0.39109 0.51301 0.35834 Metetra
0.61518 setgray
0.51301 0.35834 0.53661 0.39109 0.58061 0.35308 0.55763 0.31836 Metetra
0.52565 setgray
0.55763 0.31836 0.58061 0.35308 0.62456 0.3124 0.60217 0.27551 Metetra
0.42538 setgray
0.60217 0.27551 0.62456 0.3124 0.66837 0.26959 0.64651 0.23035 Metetra
0.31594 setgray
0.64651 0.23035 0.66837 0.26959 0.71195 0.22513 0.69057 0.18337 Metetra
0.44635 setgray
0.08089 0.43254 0.10907 0.45737 0.1418 0.48152 0.11353 0.45653 Metetra
0.59111 setgray
0.11353 0.45653 0.1418 0.48152 0.17708 0.49673 0.14885 0.47148 Metetra
0.69862 setgray
0.14885 0.47148 0.17708 0.49673 0.21458 0.50335 0.18652 0.4777 Metetra
0.77253 setgray
0.18652 0.4777 0.21458 0.50335 0.25397 0.50186 0.2262 0.47566 Metetra
0.81618 setgray
0.2262 0.47566 0.25397 0.50186 0.29492 0.49284 0.26756 0.46592 Metetra
0.83266 setgray
0.26756 0.46592 0.29492 0.49284 0.33713 0.47694 0.31027 0.44909 Metetra
0.8248 setgray
0.31027 0.44909 0.33713 0.47694 0.38029 0.45484 0.354 0.42585 Metetra
0.79522 setgray
0.354 0.42585 0.38029 0.45484 0.42415 0.42724 0.39849 0.39691 Metetra
0.7463 setgray
0.39849 0.39691 0.42415 0.42724 0.46846 0.39485 0.44345 0.36297 Metetra
0.68026 setgray
0.44345 0.36297 0.46846 0.39485 0.51301 0.35834 0.48868 0.32471 Metetra
0.59911 setgray
0.48868 0.32471 0.51301 0.35834 0.55763 0.31836 0.53396 0.28278 Metetra
0.5047 setgray
0.53396 0.28278 0.55763 0.31836 0.60217 0.27551 0.57914 0.23781 Metetra
0.39872 setgray
0.57914 0.23781 0.60217 0.27551 0.64651 0.23035 0.62408 0.19036 Metetra
0.28274 setgray
0.62408 0.19036 0.64651 0.23035 0.69057 0.18337 0.66867 0.14095 Metetra
0.44635 setgray
0.05184 0.40694 0.08089 0.43254 0.11353 0.45653 0.08435 0.43074 Metetra
0.59109 setgray
0.08435 0.43074 0.11353 0.45653 0.14885 0.47148 0.11969 0.4454 Metetra
0.69847 setgray
0.11969 0.4454 0.14885 0.47148 0.18652 0.4777 0.15753 0.45122 Metetra
0.77203 setgray
0.15753 0.45122 0.18652 0.4777 0.2262 0.47566 0.19752 0.4486 Metetra
0.81502 setgray
0.19752 0.4486 0.2262 0.47566 0.26756 0.46592 0.23929 0.4381 Metetra
0.83045 setgray
0.23929 0.4381 0.26756 0.46592 0.31027 0.44909 0.28251 0.42032 Metetra
0.82108 setgray
0.28251 0.42032 0.31027 0.44909 0.354 0.42585 0.32684 0.39594 Metetra
0.78945 setgray
0.32684 0.39594 0.354 0.42585 0.39849 0.39691 0.37198 0.36564 Metetra
0.7379 setgray
0.37198 0.36564 0.39849 0.39691 0.44345 0.36297 0.41764 0.33014 Metetra
0.66858 setgray
0.41764 0.33014 0.44345 0.36297 0.48868 0.32471 0.46358 0.29013 Metetra
0.58346 setgray
0.46358 0.29013 0.48868 0.32471 0.53396 0.28278 0.50958 0.24629 Metetra
0.48436 setgray
0.50958 0.24629 0.53396 0.28278 0.57914 0.23781 0.55545 0.19924 Metetra
0.37293 setgray
0.55545 0.19924 0.57914 0.23781 0.62408 0.19036 0.60104 0.14956 Metetra
0.25069 setgray
0.60104 0.14956 0.62408 0.19036 0.66867 0.14095 0.64622 0.09781 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.16653 0.27486 moveto
0.1749 0.28333 lineto
stroke
0 setgray
[(0.2)] 0.16235 0.27062 0.987329 1 Mshowa
0.27693 0.23152 moveto
0.28492 0.24035 lineto
stroke
0 setgray
[(0.4)] 0.27294 0.22711 0.903932 1 Mshowa
0.39281 0.18605 moveto
0.40036 0.19525 lineto
stroke
0 setgray
[(0.6)] 0.38903 0.18145 0.820535 1 Mshowa
0.51457 0.13827 moveto
0.52164 0.14786 lineto
stroke
0 setgray
[(0.8)] 0.51104 0.13348 0.737139 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(1)] 0.63943 0.08304 0.653742 1 Mshowa
0 setgray
[(t)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71067 0.18142 moveto
0.69951 0.18555 lineto
stroke
0 setgray
[(0.2)] 0.71626 0.17936 -1 0.369305 Mshowa
0.76468 0.26407 moveto
0.75344 0.268 lineto
stroke
0 setgray
[(0.4)] 0.77029 0.26211 -1 0.349436 Mshowa
0.81414 0.33978 moveto
0.80284 0.34353 lineto
stroke
0 setgray
[(0.6)] 0.81979 0.33791 -1 0.331596 Mshowa
0.85963 0.4094 moveto
0.84827 0.41298 lineto
stroke
0 setgray
[(0.8)] 0.8653 0.40761 -1 0.315489 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(1)] 0.90729 0.47191 -1 0.300874 Mshowa
0 setgray
[(a)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05552 0.35079 moveto
0.06663 0.34651 lineto
stroke
0 setgray
[(3.95)] 0.04997 0.35293 1 -0.385599 Mshowa
0.04626 0.40902 moveto
0.05742 0.40486 lineto
stroke
0 setgray
[(4)] 0.04069 0.41111 1 -0.373302 Mshowa
0.0366 0.46976 moveto
0.0478 0.46573 lineto
stroke
0 setgray
[(4.05)] 0.031 0.47178 1 -0.360421 Mshowa
0.02652 0.53317 moveto
0.03777 0.52927 lineto
stroke
0 setgray
[(4.1)] 0.0209 0.53512 1 -0.346914 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-SurfaceGraphics-
:[font = text; inactive; ]

Alternatively, we could set a to a constant value and plot y(t).  For a = -2, y(t) is plotted below:
:[font = input; startGroup; ]

Plot[ Release[yicsol /. a -> -2], {t, 0, 2}, AxesLabel -> { "t", "y(t)" } ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.47619 -1.38206 0.48731 [
[(0.5)] 0.2619 0.06738 0 1 Msboxa
[(1)] 0.5 0.06738 0 1 Msboxa
[(1.5)] 0.7381 0.06738 0 1 Msboxa
[(2)] 0.97619 0.06738 0 1 Msboxa
[(t)] 1.00625 0.07988 -1 0 Msboxa
[(3.2)] 0.01131 0.17734 1 0 Msboxa
[(3.4)] 0.01131 0.2748 1 0 Msboxa
[(3.6)] 0.01131 0.37226 1 0 Msboxa
[(3.8)] 0.01131 0.46972 1 0 Msboxa
[(4)] 0.01131 0.56719 1 0 Msboxa
[(y\(t\))] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.07988 moveto
1 0.07988 lineto
stroke
0.2619 0.07363 moveto
0.2619 0.08613 lineto
stroke
0 setgray
[(0.5)] 0.2619 0.06738 0 1 Mshowa
0.5 0.07363 moveto
0.5 0.08613 lineto
stroke
0 setgray
[(1)] 0.5 0.06738 0 1 Mshowa
0.7381 0.07363 moveto
0.7381 0.08613 lineto
stroke
0 setgray
[(1.5)] 0.7381 0.06738 0 1 Mshowa
0.97619 0.07363 moveto
0.97619 0.08613 lineto
stroke
0 setgray
[(2)] 0.97619 0.06738 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.07988 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.17734 moveto
0.03006 0.17734 lineto
stroke
0 setgray
[(3.2)] 0.01131 0.17734 1 0 Mshowa
0.01756 0.2748 moveto
0.03006 0.2748 lineto
stroke
0 setgray
[(3.4)] 0.01131 0.2748 1 0 Mshowa
0.01756 0.37226 moveto
0.03006 0.37226 lineto
stroke
0 setgray
[(3.6)] 0.01131 0.37226 1 0 Mshowa
0.01756 0.46972 moveto
0.03006 0.46972 lineto
stroke
0 setgray
[(3.8)] 0.01131 0.46972 1 0 Mshowa
0.01756 0.56719 moveto
0.03006 0.56719 lineto
stroke
0 setgray
[(4)] 0.01131 0.56719 1 0 Mshowa
0 setgray
[(y\(t\))] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.56719 moveto
0.04365 0.5766 lineto
0.06349 0.58455 lineto
0.08333 0.59106 lineto
0.10317 0.59615 lineto
0.12302 0.59986 lineto
0.13294 0.60121 lineto
0.1379 0.60175 lineto
0.14286 0.60222 lineto
0.14782 0.6026 lineto
0.15278 0.6029 lineto
0.15526 0.60302 lineto
0.15774 0.60312 lineto
0.16022 0.6032 lineto
0.1627 0.60326 lineto
0.16394 0.60328 lineto
0.16518 0.6033 lineto
0.16642 0.60331 lineto
0.16766 0.60332 lineto
0.1689 0.60332 lineto
0.17014 0.60332 lineto
0.17138 0.60331 lineto
0.17262 0.6033 lineto
0.17386 0.60328 lineto
0.1751 0.60326 lineto
0.17758 0.6032 lineto
0.18006 0.60312 lineto
0.18254 0.60302 lineto
0.1875 0.60277 lineto
0.19246 0.60244 lineto
0.20238 0.60155 lineto
0.2123 0.60037 lineto
0.22222 0.59889 lineto
0.24206 0.59508 lineto
0.2619 0.59016 lineto
0.30159 0.57719 lineto
0.34127 0.56035 lineto
0.38095 0.53998 lineto
0.42063 0.51645 lineto
0.46032 0.49009 lineto
0.5 0.46122 lineto
0.53968 0.43016 lineto
0.57937 0.39721 lineto
0.61905 0.36263 lineto
0.65873 0.32668 lineto
0.69841 0.2896 lineto
0.7381 0.25161 lineto
0.77778 0.21291 lineto
0.81746 0.17368 lineto
0.85714 0.13411 lineto
Mistroke
0.89683 0.09433 lineto
0.93651 0.05449 lineto
0.97619 0.01472 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = section; inactive; startGroup; Cclosed; ]
Analysis
:[font = subsection; inactive; startGroup; Cclosed; ]
Stability Analysis
:[font = text; inactive; ]
		Since the Laplace transform tracks the region of convergence, the object Stable can often tell if a signal is stable if its Laplace transform's region of convergence is a subset of (0, Infinity).
:[font = input; startGroup; ]
LaPlace[ Exp[a t] CStep[t], t]
:[font = output; inactive; output; endGroup; ]
LTransData[(-a + s)^(-1), Rminus[Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
             1
LTransData[------, Rminus[Re[a]], Rplus[Infinity], 
           -a + s
 
  LVariables[s]]
:[font = input; startGroup; ]
Stable[%]
:[font = output; inactive; output; endGroup; ]
Re[a] < 0
;[o]
Re[a] < 0
:[font = text; inactive; ]
This, of course, extends to multiple dimensions:
:[font = input; startGroup; ]
LaPlace[ Exp[a t1] Exp[b t2] CStep[t1, t2], {t1, t2} ]
:[font = output; inactive; output; endGroup; ]
LTransData[1/((-a + s1)*(-b + s2)), Rminus[{Re[a], Re[b]}], 
  Rplus[{DirectedInfinity[1], DirectedInfinity[1]}], 
  LVariables[{s1, s2}]]
;[o]
                    1
LTransData[-------------------, Rminus[{Re[a], Re[b]}], 
           (-a + s1) (-b + s2)
 
  Rplus[{Infinity, Infinity}], LVariables[{s1, s2}]]
:[font = input; startGroup; ]
Stable[%]
:[font = output; inactive; output; endGroup; endGroup; ]
Re[a] < 0 && Re[b] < 0
;[o]
Re[a] < 0 && Re[b] < 0
:[font = subsection; inactive; startGroup; Cclosed; ]
General Analysis
:[font = text; inactive; ]
		The analog signal processing packages provide ASPAnalyze which is a high level analysis tool.  It plots time-domain expressions and displays the poles and zeros of the expression's transform.  It checks stability of the signal.  It plots the magnitude and frequency responses.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example 1
:[font = input; startGroup; ]
ASPAnalyze[ Delta[t + 1] + Delta[t - 1], t, -2, 2 ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.2381 0.01472 0.5886 [
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-2)] 0.02381 0.00222 0 1 Msboxa
[(-1)] 0.2619 0.00222 0 1 Msboxa
[(1)] 0.7381 0.00222 0 1 Msboxa
[(2)] 0.97619 0.00222 0 1 Msboxa
[(t)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.4875 0.13244 1 0 Msboxa
[(0.4)] 0.4875 0.25016 1 0 Msboxa
[(0.6)] 0.4875 0.36788 1 0 Msboxa
[(0.8)] 0.4875 0.4856 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-2)] 0.02381 0.00222 0 1 Mshowa
0.2619 0.00847 moveto
0.2619 0.02097 lineto
stroke
0 setgray
[(-1)] 0.2619 0.00222 0 1 Mshowa
0.7381 0.00847 moveto
0.7381 0.02097 lineto
stroke
0 setgray
[(1)] 0.7381 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(2)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
gsave
0.004 setlinewidth
0.7381 0.01472 moveto
0.7381 0.60332 lineto
0.71429 0.42674 lineto
0.7619 0.42674 lineto
0.7381 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.2619 0.01472 moveto
0.2619 0.60332 lineto
0.2381 0.42674 lineto
0.28571 0.42674 lineto
0.2619 0.60332 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
Delta[-1 + t] + Delta[1 + t]
:[font = print; inactive; ]
has the following Laplace transform:
:[font = print; inactive; ]
 -s    s
E   + E
:[font = print; inactive; ]
The strip of convergence is:
:[font = print; inactive; ]
-Infinity < Re(s) < Infinity
:[font = print; inactive; ]
The system is stable.
:[font = message; inactive; ]
PoleZeroPlot::notrational: 
   Transform is not a rational polynomial.
:[font = message; inactive; ]
Solve::ifun: 
   Warning: inverse functions are being used by Solve, so
    some solutions may not be found.
:[font = message; inactive; ]
Solve::ifun: 
   Warning: inverse functions are being used by Solve, so
    some solutions may not be found.
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {1.5708 I, -1.5708 I}
:[font = print; inactive; ]
The poles are:   {}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 1 0.30902 0.15738 [
[(-0.4)] 0.1 0.29652 0 1 Msboxa
[(-0.2)] 0.3 0.29652 0 1 Msboxa
[(0.2)] 0.7 0.29652 0 1 Msboxa
[(0.4)] 0.9 0.29652 0 1 Msboxa
[(Re s)] 1.00625 0.30902 -1 0 Msboxa
[(-1.5)] 0.4875 0.07295 1 0 Msboxa
[(-1)] 0.4875 0.15164 1 0 Msboxa
[(-0.5)] 0.4875 0.23033 1 0 Msboxa
[(0.5)] 0.4875 0.38771 1 0 Msboxa
[(1)] 0.4875 0.4664 1 0 Msboxa
[(1.5)] 0.4875 0.54509 1 0 Msboxa
[(Im s)] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.1 0.30277 moveto
0.1 0.31527 lineto
stroke
0 setgray
[(-0.4)] 0.1 0.29652 0 1 Mshowa
0.3 0.30277 moveto
0.3 0.31527 lineto
stroke
0 setgray
[(-0.2)] 0.3 0.29652 0 1 Mshowa
0.7 0.30277 moveto
0.7 0.31527 lineto
stroke
0 setgray
[(0.2)] 0.7 0.29652 0 1 Mshowa
0.9 0.30277 moveto
0.9 0.31527 lineto
stroke
0 setgray
[(0.4)] 0.9 0.29652 0 1 Mshowa
0 setgray
[(Re s)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07295 moveto
0.50625 0.07295 lineto
stroke
0 setgray
[(-1.5)] 0.4875 0.07295 1 0 Mshowa
0.49375 0.15164 moveto
0.50625 0.15164 lineto
stroke
0 setgray
[(-1)] 0.4875 0.15164 1 0 Mshowa
0.49375 0.23033 moveto
0.50625 0.23033 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.23033 1 0 Mshowa
0.49375 0.38771 moveto
0.50625 0.38771 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.38771 1 0 Mshowa
0.49375 0.4664 moveto
0.50625 0.4664 lineto
stroke
0 setgray
[(1)] 0.4875 0.4664 1 0 Mshowa
0.49375 0.54509 moveto
0.50625 0.54509 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.54509 1 0 Mshowa
0 setgray
[(Im s)] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.008 setlinewidth
0.5 0.30902 Mdot
grestore
gsave
0.008 setlinewidth
0.5 0.30902 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.0618 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.55623 0 0 Mshowa
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.30902 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
Delta[-1 + t] + Delta[1 + t]
:[font = print; inactive; ]
has the following frequency response:
:[font = print; inactive; ]
 -I w    I w
E     + E
:[font = message; inactive; ]
ASPAnalyze::notinteresting: 
   Could not determine the important section of the
    frequency response.
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.46353 0.00773 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.45103 0 1 Msboxa
[(-0.7)] 0.16667 0.45103 0 1 Msboxa
[(-0.3)] 0.35714 0.45103 0 1 Msboxa
[(0.3)] 0.64286 0.45103 0 1 Msboxa
[(0.7)] 0.83333 0.45103 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.46353 -1 0 Msboxa
[(-60)] 0.4875 0 1 0 Msboxa
[(-50)] 0.4875 0.07725 1 0 Msboxa
[(-40)] 0.4875 0.15451 1 0 Msboxa
[(-30)] 0.4875 0.23176 1 0 Msboxa
[(-20)] 0.4875 0.30902 1 0 Msboxa
[(-10)] 0.4875 0.38627 1 0 Msboxa
[(10)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.46353 moveto
1 0.46353 lineto
stroke
0.02381 0.45728 moveto
0.02381 0.46978 lineto
stroke
0 setgray
[(-1)] 0.02381 0.45103 0 1 Mshowa
0.16667 0.45728 moveto
0.16667 0.46978 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.45103 0 1 Mshowa
0.35714 0.45728 moveto
0.35714 0.46978 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.45103 0 1 Mshowa
0.64286 0.45728 moveto
0.64286 0.46978 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.45103 0 1 Mshowa
0.83333 0.45728 moveto
0.83333 0.46978 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.45103 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.46353 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-60)] 0.4875 0 1 0 Mshowa
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(-50)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(-40)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(-30)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(-20)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(-10)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(10)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.5097 moveto
0.04888 0.50961 lineto
0.07125 0.5095 lineto
0.10981 0.50926 lineto
0.14229 0.50898 lineto
0.17036 0.50864 lineto
0.19508 0.50826 lineto
0.21715 0.50784 lineto
0.25527 0.50684 lineto
0.28746 0.50565 lineto
0.3153 0.50425 lineto
0.33983 0.50264 lineto
0.36176 0.50081 lineto
0.38158 0.49874 lineto
0.39967 0.49643 lineto
0.41631 0.49384 lineto
0.4317 0.49097 lineto
0.45943 0.48424 lineto
0.48388 0.47596 lineto
0.50574 0.46569 lineto
0.5255 0.4527 lineto
0.53472 0.44481 lineto
0.54355 0.43567 lineto
0.55201 0.42486 lineto
0.56014 0.41176 lineto
0.56796 0.39524 lineto
0.5755 0.37303 lineto
0.57917 0.35829 lineto
0.58098 0.34947 lineto
0.58277 0.33931 lineto
0.58455 0.32731 lineto
0.58632 0.31268 lineto
0.58806 0.29392 lineto
0.5898 0.26778 lineto
0.59152 0.22434 lineto
0.59322 0.06229 lineto
0.59492 0.21113 lineto
0.59659 0.26119 lineto
0.59826 0.28953 lineto
0.59991 0.30939 lineto
0.60317 0.33712 lineto
0.60638 0.35665 lineto
0.60955 0.37172 lineto
0.61573 0.39431 lineto
0.62174 0.41105 lineto
0.62757 0.42428 lineto
0.63877 0.4444 lineto
0.6494 0.45928 lineto
0.6595 0.47086 lineto
0.67834 0.48761 lineto
Mistroke
0.69561 0.49864 lineto
0.70373 0.50256 lineto
0.71154 0.50558 lineto
0.71534 0.50679 lineto
0.71907 0.50779 lineto
0.72274 0.50861 lineto
0.72634 0.50924 lineto
0.72811 0.50948 lineto
0.72988 0.50968 lineto
0.73162 0.50984 lineto
0.73249 0.5099 lineto
0.73336 0.50995 lineto
0.73422 0.50999 lineto
0.73507 0.51002 lineto
0.73593 0.51003 lineto
0.73678 0.51004 lineto
0.73762 0.51003 lineto
0.73847 0.51001 lineto
0.73931 0.50999 lineto
0.74014 0.50995 lineto
0.74181 0.50983 lineto
0.74346 0.50968 lineto
0.74509 0.50947 lineto
0.74672 0.50922 lineto
0.74992 0.50859 lineto
0.75309 0.50777 lineto
0.75926 0.50555 lineto
0.76526 0.50252 lineto
0.7711 0.49858 lineto
0.77677 0.49364 lineto
0.78229 0.48754 lineto
0.78766 0.48002 lineto
0.7929 0.47074 lineto
0.79801 0.45913 lineto
0.803 0.4442 lineto
0.80545 0.43495 lineto
0.80787 0.424 lineto
0.81026 0.4107 lineto
0.81263 0.39387 lineto
0.81497 0.3711 lineto
0.81613 0.35586 lineto
0.81728 0.33606 lineto
0.81785 0.32341 lineto
0.81842 0.30778 lineto
0.819 0.28736 lineto
0.81956 0.25785 lineto
0.82013 0.20388 lineto
0.8207 0.10677 lineto
0.82126 0.22975 lineto
0.82183 0.27066 lineto
Mistroke
0.82239 0.29589 lineto
0.82295 0.31417 lineto
0.82351 0.32851 lineto
0.82406 0.34031 lineto
0.82517 0.35905 lineto
0.82628 0.37364 lineto
0.82847 0.39568 lineto
0.83063 0.4121 lineto
0.8349 0.43589 lineto
0.83908 0.45287 lineto
0.84318 0.46583 lineto
0.8472 0.47607 lineto
0.85114 0.48433 lineto
0.8588 0.49648 lineto
0.86253 0.50085 lineto
0.86619 0.50428 lineto
0.86979 0.50687 lineto
0.87157 0.50786 lineto
0.87333 0.50866 lineto
0.87508 0.50928 lineto
0.87594 0.50952 lineto
0.87681 0.50971 lineto
0.87767 0.50986 lineto
0.8781 0.50992 lineto
0.87852 0.50996 lineto
0.87895 0.51 lineto
0.87938 0.51002 lineto
0.8798 0.51003 lineto
0.88023 0.51004 lineto
0.88065 0.51003 lineto
0.88107 0.51001 lineto
0.8815 0.50998 lineto
0.88192 0.50993 lineto
0.88276 0.50981 lineto
0.88359 0.50965 lineto
0.88442 0.50944 lineto
0.88525 0.50919 lineto
0.8869 0.50854 lineto
0.88854 0.5077 lineto
0.89016 0.50668 lineto
0.89337 0.50403 lineto
0.89653 0.50053 lineto
0.89964 0.49607 lineto
0.9027 0.49053 lineto
0.90572 0.4837 lineto
0.9087 0.4753 lineto
0.91164 0.46486 lineto
0.91453 0.45163 lineto
0.91738 0.43422 lineto
0.9202 0.40963 lineto
Mistroke
0.92159 0.39247 lineto
0.92229 0.38182 lineto
0.92298 0.3691 lineto
0.92366 0.35335 lineto
0.92401 0.3438 lineto
0.92435 0.33265 lineto
0.92469 0.31926 lineto
0.92503 0.3025 lineto
0.92572 0.24619 lineto
0.92606 0.17431 lineto
0.9264 0.16867 lineto
0.92673 0.24432 lineto
0.92707 0.27897 lineto
0.92741 0.3017 lineto
0.92775 0.31863 lineto
0.92842 0.34337 lineto
0.92909 0.36136 lineto
0.92976 0.3755 lineto
0.93109 0.39701 lineto
0.93241 0.41314 lineto
0.93373 0.42598 lineto
0.93633 0.44561 lineto
0.9389 0.46021 lineto
0.94394 0.48071 lineto
0.94642 0.4881 lineto
0.94887 0.4941 lineto
0.95129 0.49895 lineto
0.95368 0.5028 lineto
0.95605 0.50577 lineto
0.95722 0.50694 lineto
0.95838 0.50792 lineto
0.95954 0.50871 lineto
0.96012 0.50903 lineto
0.9607 0.50931 lineto
0.96127 0.50955 lineto
0.96184 0.50973 lineto
0.96213 0.50981 lineto
0.96241 0.50988 lineto
0.9627 0.50993 lineto
0.96298 0.50997 lineto
0.96327 0.51001 lineto
0.96355 0.51003 lineto
0.96383 0.51004 lineto
0.96411 0.51004 lineto
0.9644 0.51002 lineto
0.96468 0.51 lineto
0.96496 0.50996 lineto
0.96524 0.50992 lineto
0.9658 0.50979 lineto
0.96636 0.50962 lineto
Mistroke
0.96748 0.50914 lineto
0.96859 0.50848 lineto
0.96969 0.50764 lineto
0.97188 0.50536 lineto
0.97405 0.50226 lineto
0.97619 0.49826 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.01472 0.00327 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.00222 0 1 Msboxa
[(-0.7)] 0.16667 0.00222 0 1 Msboxa
[(-0.3)] 0.35714 0.00222 0 1 Msboxa
[(0.3)] 0.64286 0.00222 0 1 Msboxa
[(0.7)] 0.83333 0.00222 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.01472 -1 0 Msboxa
[(25)] 0.4875 0.09647 1 0 Msboxa
[(50)] 0.4875 0.17822 1 0 Msboxa
[(75)] 0.4875 0.25997 1 0 Msboxa
[(100)] 0.4875 0.34172 1 0 Msboxa
[(125)] 0.4875 0.42347 1 0 Msboxa
[(150)] 0.4875 0.50522 1 0 Msboxa
[(175)] 0.4875 0.58697 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-1)] 0.02381 0.00222 0 1 Mshowa
0.16667 0.00847 moveto
0.16667 0.02097 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.00222 0 1 Mshowa
0.35714 0.00847 moveto
0.35714 0.02097 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.00222 0 1 Mshowa
0.64286 0.00847 moveto
0.64286 0.02097 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.00222 0 1 Mshowa
0.83333 0.00847 moveto
0.83333 0.02097 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.00222 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.09647 moveto
0.50625 0.09647 lineto
stroke
0 setgray
[(25)] 0.4875 0.09647 1 0 Mshowa
0.49375 0.17822 moveto
0.50625 0.17822 lineto
stroke
0 setgray
[(50)] 0.4875 0.17822 1 0 Mshowa
0.49375 0.25997 moveto
0.50625 0.25997 lineto
stroke
0 setgray
[(75)] 0.4875 0.25997 1 0 Mshowa
0.49375 0.34172 moveto
0.50625 0.34172 lineto
stroke
0 setgray
[(100)] 0.4875 0.34172 1 0 Mshowa
0.49375 0.42347 moveto
0.50625 0.42347 lineto
stroke
0 setgray
[(125)] 0.4875 0.42347 1 0 Mshowa
0.49375 0.50522 moveto
0.50625 0.50522 lineto
stroke
0 setgray
[(150)] 0.4875 0.50522 1 0 Mshowa
0.49375 0.58697 moveto
0.50625 0.58697 lineto
stroke
0 setgray
[(175)] 0.4875 0.58697 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.36176 0.01472 lineto
0.48388 0.01472 lineto
0.56014 0.01472 lineto
0.5755 0.01472 lineto
0.58277 0.01472 lineto
0.58632 0.01472 lineto
0.5898 0.01472 lineto
0.59152 0.01472 lineto
0.59322 0.01472 lineto
0.59492 0.60332 lineto
0.59659 0.60332 lineto
0.60317 0.60332 lineto
0.61573 0.60332 lineto
0.6595 0.60332 lineto
0.69561 0.60332 lineto
0.72634 0.60332 lineto
0.75309 0.60332 lineto
0.77677 0.60332 lineto
0.79801 0.60332 lineto
0.80787 0.60332 lineto
0.81263 0.60332 lineto
0.81497 0.60332 lineto
0.81728 0.60332 lineto
0.81842 0.60332 lineto
0.819 0.60332 lineto
0.81956 0.60332 lineto
0.82013 0.60332 lineto
0.8207 0.01472 lineto
0.82183 0.01472 lineto
0.82628 0.01472 lineto
0.8349 0.01472 lineto
0.85114 0.01472 lineto
0.86619 0.01472 lineto
0.88023 0.01472 lineto
0.89337 0.01472 lineto
0.90572 0.01472 lineto
0.91738 0.01472 lineto
0.92298 0.01472 lineto
0.92435 0.01472 lineto
0.92503 0.01472 lineto
0.92538 0.01472 lineto
0.92572 0.01472 lineto
0.92606 0.01472 lineto
0.9264 0.60332 lineto
0.92673 0.60332 lineto
0.92707 0.60332 lineto
0.92842 0.60332 lineto
0.9389 0.60332 lineto
0.94887 0.60332 lineto
Mistroke
0.95838 0.60332 lineto
0.96748 0.60332 lineto
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[E^(-s) + E^s, Rminus[DirectedInfinity[-1]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
            -s    s
LTransData[E   + E , Rminus[-Infinity], Rplus[Infinity], 
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example 2
:[font = input; startGroup; ]
ASPAnalyze[ t Exp[- a t] Cos[3 Pi t / 16] CStep[t], t ]
:[font = print; inactive; ]
For plotting only, these symbols will
:[font = print; inactive; ]
be assigned a value of 1: {a}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.02381 0.09774 1.5776 [
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-20)] 0.02381 0.08524 0 1 Msboxa
[(-10)] 0.2619 0.08524 0 1 Msboxa
[(10)] 0.7381 0.08524 0 1 Msboxa
[(20)] 0.97619 0.08524 0 1 Msboxa
[(t)] 1.00625 0.09774 -1 0 Msboxa
[(-0.05)] 0.4875 0.01886 1 0 Msboxa
[(0.05)] 0.4875 0.17662 1 0 Msboxa
[(0.1)] 0.4875 0.2555 1 0 Msboxa
[(0.15)] 0.4875 0.33438 1 0 Msboxa
[(0.2)] 0.4875 0.41326 1 0 Msboxa
[(0.25)] 0.4875 0.49214 1 0 Msboxa
[(0.3)] 0.4875 0.57102 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.09774 moveto
1 0.09774 lineto
stroke
0.02381 0.09149 moveto
0.02381 0.10399 lineto
stroke
0 setgray
[(-20)] 0.02381 0.08524 0 1 Mshowa
0.2619 0.09149 moveto
0.2619 0.10399 lineto
stroke
0 setgray
[(-10)] 0.2619 0.08524 0 1 Mshowa
0.7381 0.09149 moveto
0.7381 0.10399 lineto
stroke
0 setgray
[(10)] 0.7381 0.08524 0 1 Mshowa
0.97619 0.09149 moveto
0.97619 0.10399 lineto
stroke
0 setgray
[(20)] 0.97619 0.08524 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.09774 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.01886 moveto
0.50625 0.01886 lineto
stroke
0 setgray
[(-0.05)] 0.4875 0.01886 1 0 Mshowa
0.49375 0.17662 moveto
0.50625 0.17662 lineto
stroke
0 setgray
[(0.05)] 0.4875 0.17662 1 0 Mshowa
0.49375 0.2555 moveto
0.50625 0.2555 lineto
stroke
0 setgray
[(0.1)] 0.4875 0.2555 1 0 Mshowa
0.49375 0.33438 moveto
0.50625 0.33438 lineto
stroke
0 setgray
[(0.15)] 0.4875 0.33438 1 0 Mshowa
0.49375 0.41326 moveto
0.50625 0.41326 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.41326 1 0 Mshowa
0.49375 0.49214 moveto
0.50625 0.49214 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.49214 1 0 Mshowa
0.49375 0.57102 moveto
0.50625 0.57102 lineto
stroke
0 setgray
[(0.3)] 0.4875 0.57102 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.09774 moveto
0.06349 0.09774 lineto
0.10317 0.09774 lineto
0.14286 0.09774 lineto
0.18254 0.09774 lineto
0.22222 0.09774 lineto
0.2619 0.09774 lineto
0.30159 0.09774 lineto
0.34127 0.09774 lineto
0.38095 0.09774 lineto
0.42063 0.09774 lineto
0.44048 0.09774 lineto
0.46032 0.09774 lineto
0.47024 0.09774 lineto
0.48016 0.09774 lineto
0.48512 0.09774 lineto
0.49008 0.09774 lineto
0.49256 0.09774 lineto
0.49504 0.09774 lineto
0.49628 0.09774 lineto
0.49752 0.09774 lineto
0.49876 0.09774 lineto
0.5 0.09774 lineto
0.50248 0.24554 lineto
0.50496 0.36259 lineto
0.50744 0.45234 lineto
0.50868 0.48801 lineto
0.50992 0.5181 lineto
0.51116 0.54298 lineto
0.5124 0.56304 lineto
0.51364 0.57865 lineto
0.51488 0.59015 lineto
0.51612 0.59788 lineto
0.51736 0.60217 lineto
0.5186 0.60332 lineto
0.51984 0.60163 lineto
0.52108 0.59738 lineto
0.52232 0.59084 lineto
0.52356 0.58224 lineto
0.5248 0.57184 lineto
0.52976 0.51637 lineto
0.53968 0.37365 lineto
0.5496 0.23561 lineto
0.55952 0.12948 lineto
0.56448 0.09075 lineto
0.56944 0.06121 lineto
0.5744 0.03997 lineto
0.57688 0.03213 lineto
0.57937 0.02595 lineto
0.58185 0.02128 lineto
Mistroke
0.58309 0.01947 lineto
0.58433 0.01797 lineto
0.58557 0.01678 lineto
0.58681 0.01588 lineto
0.58805 0.01525 lineto
0.58929 0.01486 lineto
0.59053 0.01472 lineto
0.59177 0.01479 lineto
0.59301 0.01506 lineto
0.59425 0.01552 lineto
0.59673 0.01695 lineto
0.59921 0.01896 lineto
0.60417 0.02434 lineto
0.60913 0.03094 lineto
0.61905 0.04562 lineto
0.63889 0.07196 lineto
0.64881 0.08142 lineto
0.65377 0.08515 lineto
0.65873 0.08828 lineto
0.66865 0.09292 lineto
0.67361 0.09457 lineto
0.67857 0.09584 lineto
0.68353 0.09681 lineto
0.68849 0.09752 lineto
0.69345 0.09802 lineto
0.69593 0.09821 lineto
0.69841 0.09836 lineto
0.70089 0.09848 lineto
0.70337 0.09857 lineto
0.70461 0.0986 lineto
0.70585 0.09863 lineto
0.70709 0.09866 lineto
0.70833 0.09868 lineto
0.70957 0.09869 lineto
0.71081 0.09871 lineto
0.71205 0.09871 lineto
0.71329 0.09872 lineto
0.71453 0.09872 lineto
0.71577 0.09871 lineto
0.71701 0.09871 lineto
0.71825 0.0987 lineto
0.7381 0.09841 lineto
0.74802 0.09823 lineto
0.75794 0.09808 lineto
0.76786 0.09796 lineto
0.77778 0.09787 lineto
0.78274 0.09784 lineto
0.7877 0.09782 lineto
0.79266 0.09779 lineto
0.79762 0.09778 lineto
Mistroke
0.80258 0.09777 lineto
0.80754 0.09776 lineto
0.8125 0.09775 lineto
0.81498 0.09775 lineto
0.81746 0.09774 lineto
0.82242 0.09774 lineto
0.8249 0.09774 lineto
0.82738 0.09774 lineto
0.82986 0.09774 lineto
0.8311 0.09774 lineto
0.83234 0.09774 lineto
0.83358 0.09774 lineto
0.83482 0.09774 lineto
0.83606 0.09774 lineto
0.8373 0.09774 lineto
0.83854 0.09774 lineto
0.83978 0.09774 lineto
0.84102 0.09774 lineto
0.84226 0.09774 lineto
0.8435 0.09774 lineto
0.84474 0.09774 lineto
0.84598 0.09774 lineto
0.84722 0.09774 lineto
0.85714 0.09774 lineto
0.86706 0.09774 lineto
0.87698 0.09774 lineto
0.8869 0.09774 lineto
0.89683 0.09774 lineto
0.90179 0.09774 lineto
0.90675 0.09774 lineto
0.91171 0.09774 lineto
0.91667 0.09774 lineto
0.92163 0.09774 lineto
0.92659 0.09774 lineto
0.93155 0.09774 lineto
0.93651 0.09774 lineto
0.93899 0.09774 lineto
0.94147 0.09774 lineto
0.94643 0.09774 lineto
0.94891 0.09774 lineto
0.95139 0.09774 lineto
0.95387 0.09774 lineto
0.95635 0.09774 lineto
0.95759 0.09774 lineto
0.95883 0.09774 lineto
0.96007 0.09774 lineto
0.96131 0.09774 lineto
0.96255 0.09774 lineto
0.96379 0.09774 lineto
0.96503 0.09774 lineto
Mistroke
0.96627 0.09774 lineto
0.96751 0.09774 lineto
0.96875 0.09774 lineto
0.96999 0.09774 lineto
0.97123 0.09774 lineto
0.97619 0.09774 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
               3 Pi t
t CStep[t] Cos[------]
                 16
----------------------
          a t
         E
:[font = print; inactive; ]
has the following Laplace transform:
:[font = print; inactive; ]
                2
      -2 (a + s)               1
-(------------------- + ----------------)
       2                    2
   9 Pi           2 2   9 Pi           2
  (----- + (a + s) )    ----- + (a + s)
    256                  256
:[font = print; inactive; ]
The strip of convergence is:
:[font = print; inactive; ]
-Re[a] < Re(s) < Infinity
:[font = print; inactive; ]
The system is stable if Re[a] > 0
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {-1.58905, -0.410951}
:[font = print; inactive; ]
The poles are:   {-1. + 0.589049 I, -1. - 0.589049 I, 
 
   -1. + 0.589049 I, -1. - 0.589049 I}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 173; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
1 0.50345 0.30902 0.41968 [
[(-1.75)] 0.11897 0.29652 0 1 Msboxa
[(-1.5)] 0.24483 0.29652 0 1 Msboxa
[(-1.25)] 0.37069 0.29652 0 1 Msboxa
[(-1)] 0.49655 0.29652 0 1 Msboxa
[(-0.75)] 0.62242 0.29652 0 1 Msboxa
[(-0.5)] 0.74828 0.29652 0 1 Msboxa
[(-0.25)] 0.87414 0.29652 0 1 Msboxa
[(Re s)] 1.00625 0.30902 -1 0 Msboxa
[(-0.6)] 0.9875 0.05721 1 0 Msboxa
[(-0.4)] 0.9875 0.14114 1 0 Msboxa
[(-0.2)] 0.9875 0.22508 1 0 Msboxa
[(0.2)] 0.9875 0.39295 1 0 Msboxa
[(0.4)] 0.9875 0.47689 1 0 Msboxa
[(0.6)] 0.9875 0.56083 1 0 Msboxa
[(Im s)] 1 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.00725 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.11897 0.30277 moveto
0.11897 0.31527 lineto
stroke
0 setgray
[(-1.75)] 0.11897 0.29652 0 1 Mshowa
0.24483 0.30277 moveto
0.24483 0.31527 lineto
stroke
0 setgray
[(-1.5)] 0.24483 0.29652 0 1 Mshowa
0.37069 0.30277 moveto
0.37069 0.31527 lineto
stroke
0 setgray
[(-1.25)] 0.37069 0.29652 0 1 Mshowa
0.49655 0.30277 moveto
0.49655 0.31527 lineto
stroke
0 setgray
[(-1)] 0.49655 0.29652 0 1 Mshowa
0.62242 0.30277 moveto
0.62242 0.31527 lineto
stroke
0 setgray
[(-0.75)] 0.62242 0.29652 0 1 Mshowa
0.74828 0.30277 moveto
0.74828 0.31527 lineto
stroke
0 setgray
[(-0.5)] 0.74828 0.29652 0 1 Mshowa
0.87414 0.30277 moveto
0.87414 0.31527 lineto
stroke
0 setgray
[(-0.25)] 0.87414 0.29652 0 1 Mshowa
0 setgray
[(Re s)] 1.00625 0.30902 -1 0 Mshowa
1 0 moveto
1 0.61803 lineto
stroke
0.99375 0.05721 moveto
1.00625 0.05721 lineto
stroke
0 setgray
[(-0.6)] 0.9875 0.05721 1 0 Mshowa
0.99375 0.14114 moveto
1.00625 0.14114 lineto
stroke
0 setgray
[(-0.4)] 0.9875 0.14114 1 0 Mshowa
0.99375 0.22508 moveto
1.00625 0.22508 lineto
stroke
0 setgray
[(-0.2)] 0.9875 0.22508 1 0 Mshowa
0.99375 0.39295 moveto
1.00625 0.39295 lineto
stroke
0 setgray
[(0.2)] 0.9875 0.39295 1 0 Mshowa
0.99375 0.47689 moveto
1.00625 0.47689 lineto
stroke
0 setgray
[(0.4)] 0.9875 0.47689 1 0 Mshowa
0.99375 0.56083 moveto
1.00625 0.56083 lineto
stroke
0 setgray
[(0.6)] 0.9875 0.56083 1 0 Mshowa
0 setgray
[(Im s)] 1 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
[ 0.05 0.05 ] 0 setdash
0.004 setlinewidth
0.49655 0 moveto
0.49655 0.61803 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
1 0.30902 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.2 0.30902 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.79311 0.30902 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(*X*)] 0.49655 0.0618 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(*X*)] 0.49655 0.55623 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
               3 Pi t
t CStep[t] Cos[------]
                 16
----------------------
          a t
         E
:[font = print; inactive; ]
has the following frequency response:
:[font = print; inactive; ]
                                      2
          1                2 (a + I w)
-(------------------ - ---------------------)
      2                     2
  9 Pi             2    9 Pi             2 2
  ----- + (a + I w)    (----- + (a + I w) )
   256                   256
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.41202 0.0103 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.39952 0 1 Msboxa
[(-0.7)] 0.16667 0.39952 0 1 Msboxa
[(-0.3)] 0.35714 0.39952 0 1 Msboxa
[(0.3)] 0.64286 0.39952 0 1 Msboxa
[(0.7)] 0.83333 0.39952 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.41202 -1 0 Msboxa
[(-40)] 0.4875 0 1 0 Msboxa
[(-30)] 0.4875 0.10301 1 0 Msboxa
[(-20)] 0.4875 0.20601 1 0 Msboxa
[(-10)] 0.4875 0.30902 1 0 Msboxa
[(10)] 0.4875 0.51503 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.41202 moveto
1 0.41202 lineto
stroke
0.02381 0.40577 moveto
0.02381 0.41827 lineto
stroke
0 setgray
[(-1)] 0.02381 0.39952 0 1 Mshowa
0.16667 0.40577 moveto
0.16667 0.41827 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.39952 0 1 Mshowa
0.35714 0.40577 moveto
0.35714 0.41827 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.39952 0 1 Mshowa
0.64286 0.40577 moveto
0.64286 0.41827 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.39952 0 1 Mshowa
0.83333 0.40577 moveto
0.83333 0.41827 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.39952 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.41202 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-40)] 0.4875 0 1 0 Mshowa
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(-30)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(-20)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(-10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(10)] 0.4875 0.51503 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.3227 moveto
0.36176 0.34868 lineto
0.38158 0.35086 lineto
0.39967 0.35252 lineto
0.40816 0.35314 lineto
0.41631 0.35363 lineto
0.42027 0.35382 lineto
0.42415 0.35398 lineto
0.42796 0.3541 lineto
0.4317 0.35419 lineto
0.43538 0.35425 lineto
0.43899 0.35428 lineto
0.44254 0.35427 lineto
0.44603 0.35423 lineto
0.44946 0.35416 lineto
0.45284 0.35406 lineto
0.45616 0.35392 lineto
0.45943 0.35376 lineto
0.46582 0.35334 lineto
0.47202 0.35281 lineto
0.48388 0.35142 lineto
0.4951 0.34962 lineto
0.50574 0.34746 lineto
0.5255 0.3422 lineto
0.54355 0.33595 lineto
0.56014 0.329 lineto
0.61573 0.29803 lineto
0.6595 0.26726 lineto
0.69561 0.23921 lineto
0.72634 0.21419 lineto
0.75309 0.19187 lineto
0.77677 0.17183 lineto
0.79801 0.15372 lineto
0.81728 0.13721 lineto
0.8349 0.12206 lineto
0.85114 0.10808 lineto
0.86619 0.0951 lineto
0.88023 0.08298 lineto
0.89337 0.07163 lineto
0.90572 0.06096 lineto
0.91738 0.05088 lineto
0.92842 0.04133 lineto
0.9389 0.03227 lineto
0.94887 0.02365 lineto
0.95838 0.01542 lineto
0.96748 0.00755 lineto
0.97619 1e-05 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.60241 0.00349 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.58991 0 1 Msboxa
[(-0.7)] 0.16667 0.58991 0 1 Msboxa
[(-0.3)] 0.35714 0.58991 0 1 Msboxa
[(0.3)] 0.64286 0.58991 0 1 Msboxa
[(0.7)] 0.83333 0.58991 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.60241 -1 0 Msboxa
[(-150)] 0.4875 0.07912 1 0 Msboxa
[(-125)] 0.4875 0.16633 1 0 Msboxa
[(-100)] 0.4875 0.25355 1 0 Msboxa
[(-75)] 0.4875 0.34076 1 0 Msboxa
[(-50)] 0.4875 0.42798 1 0 Msboxa
[(-25)] 0.4875 0.51519 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.60241 moveto
1 0.60241 lineto
stroke
0.02381 0.59616 moveto
0.02381 0.60866 lineto
stroke
0 setgray
[(-1)] 0.02381 0.58991 0 1 Mshowa
0.16667 0.59616 moveto
0.16667 0.60866 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.58991 0 1 Mshowa
0.35714 0.59616 moveto
0.35714 0.60866 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.58991 0 1 Mshowa
0.64286 0.59616 moveto
0.64286 0.60866 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.58991 0 1 Mshowa
0.83333 0.59616 moveto
0.83333 0.60866 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.58991 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.60241 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07912 moveto
0.50625 0.07912 lineto
stroke
0 setgray
[(-150)] 0.4875 0.07912 1 0 Mshowa
0.49375 0.16633 moveto
0.50625 0.16633 lineto
stroke
0 setgray
[(-125)] 0.4875 0.16633 1 0 Mshowa
0.49375 0.25355 moveto
0.50625 0.25355 lineto
stroke
0 setgray
[(-100)] 0.4875 0.25355 1 0 Mshowa
0.49375 0.34076 moveto
0.50625 0.34076 lineto
stroke
0 setgray
[(-75)] 0.4875 0.34076 1 0 Mshowa
0.49375 0.42798 moveto
0.50625 0.42798 lineto
stroke
0 setgray
[(-50)] 0.4875 0.42798 1 0 Mshowa
0.49375 0.51519 moveto
0.50625 0.51519 lineto
stroke
0 setgray
[(-25)] 0.4875 0.51519 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.04888 0.60316 lineto
0.07125 0.6029 lineto
0.09142 0.60254 lineto
0.10981 0.60206 lineto
0.12669 0.60148 lineto
0.14229 0.60077 lineto
0.1568 0.59995 lineto
0.17036 0.59899 lineto
0.19508 0.5967 lineto
0.21715 0.59389 lineto
0.23709 0.59057 lineto
0.25527 0.58674 lineto
0.28746 0.57765 lineto
0.3153 0.56682 lineto
0.33983 0.55449 lineto
0.36176 0.54091 lineto
0.39967 0.51101 lineto
0.4317 0.47893 lineto
0.48388 0.41402 lineto
0.56014 0.30325 lineto
0.61573 0.22676 lineto
0.6595 0.17594 lineto
0.69561 0.14117 lineto
0.72634 0.11633 lineto
0.75309 0.09786 lineto
0.77677 0.08363 lineto
0.79801 0.07235 lineto
0.81728 0.06319 lineto
0.8349 0.05562 lineto
0.85114 0.04924 lineto
0.86619 0.04381 lineto
0.88023 0.03911 lineto
0.89337 0.03502 lineto
0.90572 0.03142 lineto
0.91738 0.02822 lineto
0.92842 0.02537 lineto
0.9389 0.02281 lineto
0.94887 0.02049 lineto
0.95838 0.01839 lineto
0.96748 0.01647 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
LTransData[-((-2*(a + s)^2)/
      ((9*Pi^2)/256 + (a + s)^2)^2 + 
     ((9*Pi^2)/256 + (a + s)^2)^(-1)), Rminus[-Re[a]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                           2
                 -2 (a + s)               1
LTransData[-(------------------- + ----------------), 
                  2                    2
              9 Pi           2 2   9 Pi           2
             (----- + (a + s) )    ----- + (a + s)
               256                  256
 
  Rminus[-Re[a]], Rplus[Infinity], LVariables[s]]
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)