(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
Symbolic Transforms
with Applications to
Signal Processing
:[font = subtitle; inactive; ]

by Brian L. Evans and James H. McClellan
:[font = subsubtitle; inactive; ]

Digital Signal Processing Laboratory
School of Electrical Engineering
Georgia Institute of Technology
Atlanta, GA  30332-0250

EMAIL:  evans@eedsp.gatech.edu
:[font = text; inactive; ]

		This notebook contains the examples presented in the paper entitled "Symbolic Transforms with Applications to Signal Processing," which appears the second issue of the first volume of The Mathematica Journal.  This paper describes packages which perform basic operations common in both digital and analog signal processing. In adapting the paper to Notebook form, we have included an additional section that summarizes the latest changes to the signal processing packages.   Other notebooks besides this one describe the signal processing packages in more detail:  convolution, analog filter design, DTFT, and z-transforms. 
:[font = text; inactive; ]
		The major improvement of these packages since the Mathematica Journal paper was published is that the 10 symbolic transform rule bases can now justify their answers by displaying each step of the transform process (which is enabled by using the Dialogue -> All option).  Examples of this are included throughout this notebook (e.g., "Z-transform" subsection under the "DSP Examples" section).  Two other key improvements is that users can also specify their own transform pairs and that assumptions made on free parameters are displayed when dialogue is fully enabled.
:[font = text; inactive; ]
		Another significant improvement since the article is that users can give their own transform pairs using the TransformLookup option.  One use is to specify the transforms of abstract (undefined) signals, e.g. TransformLookup -> { x[n] :> X[s] } in the case of the forward Laplace transform rule base LaPlace.
:[font = text; inactive; ]
WARNING:  This notebook will automatically load in the signal processing packages (see the Initialization Section for the exact commands) which under Mathematica 1.2 may take as long 5 minutes.
:[font = text; inactive; ]
	As a reminder, in order to open a section below, just move the mouse to the downward-pointing arrow and double click. To get help information for any command, place the cursor in an input cell and type ?Command (like ?ZTransform).
:[font = special1; inactive; ]
Table of Contents
:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = input; initialization; startGroup; ]
*)

Needs[ "SignalProcessing`Analog`" ]
(*
:[font = print; inactive; startGroup; ]
Loading version 2.2 of the signal processing support\
 
  packages ...
:[font = print; inactive; ]
Support module has been loaded.
:[font = print; inactive; ]
The knowledge base of signal processing operators has\
 
  been loaded.
:[font = print; inactive; ]
Supporting routines for filter design are loaded.
:[font = print; inactive; ]
Region of convergence routines for the transform rule\
 
  bases are loaded.
:[font = print; inactive; ]
Piecewise convolution rules have been loaded.
:[font = print; inactive; ]
Supporting routines for transform rule bases are loaded.
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically
    loaded (the signal processing packages no longer rely
    on the definitions in these files).
:[font = print; inactive; ]
Loading version 2.2 of the analog signal processing\
 
  packages ...
:[font = print; inactive; ]
The one-dimensional analog filter design objects are\
 
  loaded.
:[font = print; inactive; ]
Supporting routines and objects for the Laplace transform\
 
  are loaded.
:[font = print; inactive; ]
The forward Laplace transform rule base LaPlace has been\
 
  loaded.
:[font = print; inactive; ]
The inverse Laplace transform rule base InvLaPlace has\
 
  been loaded.
:[font = print; inactive; ]
The supporting functions are loaded for symbolic Fourier\
 
  transforms.
:[font = print; inactive; ]
The continuous Fourier transform (CTFT) functions are\
 
  loaded.
:[font = print; inactive; ]
LSolve, a differential equation solver, is loaded.
:[font = print; inactive; ]
The analog signal analyzer is now loaded.
:[font = message; inactive; ]
Analog::loaded: 
   Routines, objects, and rules for the analog signal
    processing packages have been loaded successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
Analog signal processing extensions have been loaded.
:[font = print; inactive; ]
Good starting points are the objects ASPAnalyze and\
 
  LaPlace.
:[font = print; inactive; ]
Active packages are maintained in the variable\
 
  $ContextPath.
:[font = print; inactive; ]
  New signal primitives are in SPsignals.
:[font = print; inactive; ]
  New system primitives are in SPoperators.
:[font = print; inactive; ]
  New Mathematica functions are in SPfunctions.
:[font = print; inactive; ]
Note that all signal processing expressions will
:[font = print; inactive; ]
be automatically simplified.
:[font = print; inactive; endGroup; endGroup; ]

:[font = input; initialization; startGroup; ]
*)

Needs[ "SignalProcessing`Digital`" ]
(*
:[font = print; inactive; startGroup; ]
Loading version 2.2 of the signal processing support\
 
  packages ...
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically
    loaded (the signal processing packages no longer rely
    on the definitions in these files).
:[font = print; inactive; ]
Loading version 2.2 of the digital signal processing\
 
  packages ...
:[font = print; inactive; ]
Supporting routines for the z-transform rule bases are\
 
  loaded.
:[font = print; inactive; ]
The forward z-transform rules have been loaded.
:[font = print; inactive; ]
The inverse z-transform rules have been loaded.
:[font = print; inactive; ]
The discrete-time Fourier transform (DTFT) rule bases are\
 
  loaded.
:[font = print; inactive; ]
Correlation functions are now loaded.
:[font = print; inactive; ]
ZSolve, a difference equation solver, is loaded.
:[font = print; inactive; ]
The digital signal analyzer is now loaded.
:[font = print; inactive; ]
The discrete Fourier transform (DFT) rule bases are\
 
  loaded.
:[font = message; inactive; ]
Digital::loaded: 
   Routines, objects, and rules for the digital signal
    processing packages have been loaded successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
Digital signal processing extensions have been loaded.
:[font = print; inactive; ]
Good starting points are the objects DSPAnalyze and\
 
  ZTransform.
:[font = print; inactive; ]
Active packages are maintained in the variable\
 
  $ContextPath.
:[font = print; inactive; ]
  New signal primitives are in SPsignals.
:[font = print; inactive; ]
  New system primitives are in SPoperators.
:[font = print; inactive; ]
  New Mathematica functions are in SPfunctions.
:[font = print; inactive; ]
Note that all signal processing expressions will
:[font = print; inactive; ]
be automatically simplified.
:[font = print; inactive; endGroup; endGroup; endGroup; ]

:[font = section; inactive; startGroup; Cclosed; ]
Introduction
:[font = subsection; inactive; startGroup; ]
Abstract
:[font = text; inactive; endGroup; ]
		The examples illustrate the abilities of the signal processing packages.  These packages implement many of the basic operations in both digital and analog signal processing.  This hierarchical set of packages performs basic analyses of functions (signals) and operators (systems).  For the most part, these packages are based on transform theory, which is a powerful tool for analyzing linear, shift-invariant operators.  All the transforms were implemented using the same structure for encoding knowledge about transforms.
		The packages include the z, Laplace, Fourier, discrete-time Fourier, and discrete Fourier transforms, for both one-dimensional and multidimensional signals.  In the case of the z and Laplace transforms, the bilateral form of the transform is used, because that is the common practice in signal processing.  However, these packages should be useful in a number of fields where transform analysis is needed.
		These packages can perform a variety of different operations for symbolic, graphic, and numerical analysis of signals and systems.  Symbolic analyses include simplifying expressions and reasoning about properties of signals like stability.  Plotting capabilities include discrete-time plots, magnitude frequency responses, and phase frequency responses.  Another plotting feature is the presentation of pole-zero diagrams, including the region of  convergence, for z and Laplace transforms.
:[font = subsection; inactive; startGroup; ]
For Further Information
:[font = text; inactive; endGroup; endGroup; ]
		The companion notebook to this one is entitled "LaPlaceTest".  It is an overview of the forward and inverse Laplace transform rule bases, complete with over 100 examples.  There is also a section on how to use the linear constant coefficient differential equation solver using LSolve, which relies on the Laplace transform rule bases.
		For those with a signal processing background, these signal processing packages are discussed in a book entitled {Symbolic and Knowledge-Based Signal Processing} which will be published by Prentice-Hall in the Spring of 1991.
:[font = section; inactive; startGroup; Cclosed; ]
Digital Signal Processing Examples
:[font = subsection; inactive; startGroup; Cclosed; ]
z-Transform Examples
:[font = subsubsection; inactive; startGroup; Cclosed; ]
How to call the forward z-transform
:[font = input; startGroup; ]
?ZTransform
:[font = info; inactive; endGroup; endGroup; ]
ZTransform[e,n] or ZTransform[e,n,z] gives the z-transform of the
   expression e, which is a function of n, by returning an object of
   three slots which is tagged by ZTransData:  <z-transform>,
   <rminus>, <rplus>, and <z-variables>.  The Region of Convergence
   (ROC) is <rminus> < |z| < <rplus>.  Note that the returned ROC is
   either the actual ROC or a subset of the actual ROC. In two
   dimensions, ZTransform[e, {n1, n2}, {z1, z2}], is the same as
   ZTransform [ ZTransform [e, n1, z1], n2, z2 ].  This notation
   extends naturally to higher dimensions.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Forward z-Transform Examples
:[font = input; startGroup; ]
ZTransform[ (1/3)^Abs[n], n, z, Dialogue -> True ]
:[font = print; inactive; ]
Rewriting the two-sided expression
 1 Abs[n]
(-)
 3
as a left-sided plus a right-sided sequence:
Step[-1 - n]    1 n
------------ + (-)  Step[n]
     1 n        3
    (-)
     3
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 1/(3*z))^(-1) + z/(3*(1 - z/3)), Rminus[1/3], 
  Rplus[3], ZVariables[z]]
;[o]
              1          z             1
ZTransData[------- + ---------, Rminus[-], Rplus[3], ZVariables[z]]
                1           z          3
           1 - ---   3 (1 - -)
               3 z          3
:[font = input; startGroup; ]
ZTransform[ (1/3)^Abs[n], n, z, Dialogue -> False ]
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 1/(3*z))^(-1) + z/(3*(1 - z/3)), Rminus[1/3], 
  Rplus[3], ZVariables[z]]
;[o]
              1          z             1
ZTransData[------- + ---------, Rminus[-], Rplus[3], ZVariables[z]]
                1           z          3
           1 - ---   3 (1 - -)
               3 z          3
:[font = input; startGroup; Cclosed; ]
ZTransform[ (1/3)^Abs[n], n, z, Dialogue -> All ]
:[font = print; inactive; ]
     1 Abs[n]
Z  {(-)      }
  n  3
which becomes
( after the two-sided expression
   1 Abs[n]
  (-)
   3
  has been rewritten as a left-sided 
  plus a right sided sequence
  Step[-1 - n]    1 n
  ------------ + (-)  Step[n] )
       1 n        3
      (-)
       3
    Step[-1 - n]    1 n
Z  {------------ + (-)  Step[n]}
  n      1 n        3
        (-)
         3
which becomes
    Step[-1 - n]         1 n
Z  {------------} + Z  {(-)  Step[n]}
  n      1 n          n  3
        (-)
         3
which becomes
                                              Step[-n]
{Z  {Step[n]}}                        + z Z  {---------}
   n          z -> 3 z and scale ROC        n  1 -1 + n
                                              (-)
                                               3
which becomes
        Step[n]
z {Z  {---------}}                       + 
     n  1 -1 - n  z -> 1/z and flip ROC 
       (-)
        3
 
               1     1
  Transform[-------, -, Infinity]
                 1   3
            1 - ---
                3 z
which becomes
   {Z  {Step[n]}}
      n          z -> 3 z and scale ROC 
z {-------------------------------------}
                     3                   z -> 1/z
 
                                  1     1
                   + Transform[-------, -, Infinity]
     and flip ROC                   1   3
                               1 - ---
                                   3 z
which becomes
             1          z      1
Transform[------- + ---------, -, 3]
               1           z   3
          1 - ---   3 (1 - -)
              3 z          3
which becomes
             1          z      1
Transform[------- + ---------, -, 3]
               1           z   3
          1 - ---   3 (1 - -)
              3 z          3
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 1/(3*z))^(-1) + z/(3*(1 - z/3)), 
  Rminus[1/3], Rplus[3], ZVariables[z]]
;[o]
              1          z             1
ZTransData[------- + ---------, Rminus[-], Rplus[3], 
                1           z          3
           1 - ---   3 (1 - -)
               3 z          3
 
  ZVariables[z]]
:[font = input; startGroup; ]
ZTransform[ a^n1 b^n2 Step[n1,n2], {n1,n2} ]
:[font = output; inactive; output; endGroup; endGroup; ]
ZTransData[1/((1 - a/z1)*(1 - b/z2)), Rminus[{Abs[a], Abs[b]}], 
  Rplus[{DirectedInfinity[1], DirectedInfinity[1]}], 
  ZVariables[{z1, z2}]]
;[o]
                   1
ZTransData[-----------------, Rminus[{Abs[a], Abs[b]}], 
                a        b
           (1 - --) (1 - --)
                z1       z2
 
  Rplus[{Infinity, Infinity}], ZVariables[{z1, z2}]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
How to call the inverse z-transform
:[font = input; startGroup; ]
?InvZTransform
:[font = info; inactive; endGroup; endGroup; ]
InvZTransform[e,z] or InvZTransform[e,z,n] gives the inverse
   z-transform of e.  Here, e can be a function of z, a list, or a
   z-transform object (see ZTransData).  As a list, e should contain
   three elements:  F[z], rminus, and rplus, such that the region of
   convergence is rminus < |z| < rplus.   If e is a z-transform
   object, then the inverse z-transform is simply InvZTransform[e]
   because e contains all necessary information. If the returned
   expression is not the form you desire, then apply Simplify[],
   Cancel[], Together[], etc., to the expression.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Inverse z-Transform Examples
:[font = input; startGroup; Cclosed; ]

ZTransform[ (1/3)^Abs[n], n, z ]
:[font = print; inactive; ]
Rewriting the two-sided expression
 1 Abs[n]
(-)
 3
as a left-sided plus a right-sided sequence:
Step[-1 - n]    1 n
------------ + (-)  Step[n]
     1 n        3
    (-)
     3
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 1/(3*z))^(-1) + z/(3*(1 - z/3)), Rminus[1/3], 
  Rplus[3], ZVariables[z]]
;[o]
              1          z             1
ZTransData[------- + ---------, Rminus[-], Rplus[3], ZVariables[z]]
                1           z          3
           1 - ---   3 (1 - -)
               3 z          3
:[font = input; startGroup; ]

InvZTransform[ ZTransform[ (1/3)^Abs[n], n, z, Dialogue -> False ] ]
:[font = output; inactive; output; endGroup; ]
3^n*Step[-1 - n] + (1/3)^n*Step[n]
;[o]
 n                 1 n
3  Step[-1 - n] + (-)  Step[n]
                   3
:[font = input; startGroup; Cclosed; ]

InvZTransform[ Log[1 + a z^-3], z, n, Dialogue -> All ]
:[font = print; inactive; ]
  -1         a
Z   {Log[1 + --]}
  z           3
             z
becomes
                -1         a
Upsample     [Z   {Log[1 + -]}]
        3,0,n   z          z
becomes
               n   -1         1
Upsample     [a  Z   {Log[1 + -]}]
        3,0,n      z          z
becomes
                  n  n
              (-1)  a  Step[-1 + n]
Upsample     [---------------------]
        3,0,n           n
becomes
                  n  n
              (-1)  a  Step[-1 + n]
Upsample     [---------------------]
        3,0,n           n
:[font = output; inactive; output; endGroup; ]
Upsample[3, 0, n][((-1)^n*a^n*Step[-1 + n])/n]
;[o]
                  n  n
              (-1)  a  Step[-1 + n]
Upsample     [---------------------]
        3,0,n           n
:[font = input; startGroup; Cclosed; ]

InvZTransform[ Exp[Tan[z]], z, n, Terms -> 6 ]
:[font = print; inactive; ]
Breaking up the expression
 Tan[z]
E
into its series representation:
         2    3      4       5
        z    z    3 z    37 z        6
1 + z + -- + -- + ---- + ----- + O[z]
        2    2     8      120
The inverse z-transform will now be applied to the first 6 terms.
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
Impulse[n] + Impulse[1 + n] + Impulse[2 + n]/2 + Impulse[3 + n]/2 + 
  (3*Impulse[4 + n])/8 + (37*Impulse[5 + n])/120
;[o]
                              Impulse[2 + n]   Impulse[3 + n]
Impulse[n] + Impulse[1 + n] + -------------- + -------------- + 
                                    2                2
 
  3 Impulse[4 + n]   37 Impulse[5 + n]
  ---------------- + -----------------
         8                  120
:[font = subsection; inactive; startGroup; Cclosed; ]
DTFT Example
:[font = input; startGroup; ]

?DTFTransform
:[font = info; inactive; endGroup; ]
DTFTransform[function, in variable(s), out variable(s), options]
   returns the discrete-time Fourier transform of the input
   function. Note that this transform may rely on the z-transform
   and the substitution z = Exp[I w], which is not valid if the
   region of convergence does not include the unit circle.  Also
   note that only the first two arguments are required.
:[font = input; startGroup; ]

DTFTransform[ Sinc[n], n, w ]
:[font = output; inactive; output; endGroup; ]
DTFTData[Pi*(-CStep[-1 + w] + CStep[1 + w]), FVariables[w]]
;[o]
DTFTData[Pi (-CStep[-1 + w] + CStep[1 + w]), FVariables[w]]
:[font = input; startGroup; ]

DTFTransform[ 5 Sinc[n], n, w, Dialogue -> All ]
:[font = print; inactive; ]
DTFT  {5 Sinc[n]}
     n
becomes
5 DTFT  {Sinc[n]}
       n
becomes
5 Pi (-CStep[-1 + w] + CStep[1 + w])
becomes
5 Pi (-CStep[-1 + w] + CStep[1 + w])
:[font = output; inactive; output; endGroup; ]
DTFTData[5*Pi*(-CStep[-1 + w] + CStep[1 + w]), FVariables[w]]
;[o]
DTFTData[5 Pi (-CStep[-1 + w] + CStep[1 + w]), FVariables[w]]
:[font = input; startGroup; ]

InvDTFTransform[ DTFTransform[ Sinc[n], n, w ] ]
:[font = output; inactive; output; endGroup; endGroup; ]
Sinc[n]
;[o]
Sinc[n]
:[font = subsection; inactive; startGroup; Cclosed; ]
DFT Example
:[font = input; startGroup; ]

?DFTransform
:[font = info; inactive; endGroup; ]
DFTransform[function, NumberOfPoints, TimeVariables,
   FourierVariables, options] returns the DFT of function, where
   function is a function of TimeVariables defined from 0 to
   NumberOfPoints - 1.  A side effect of this function is that the
   symbols in the arguments NumberOfPoints and TimeVariables will be
   associated with the data type Integer via AssociateDataType. 
   Note that only the first two arguments are required and that
   DFTransform calls DTFTransform.
:[font = input; startGroup; ]

DFTransform[ Exp[I 2 n], 10, n, k ]
:[font = output; inactive; output; endGroup; ]
DFTData[E^(9*I + (-9*I)/10*Pi*k)*Dirichlet[10, -2 + (Pi*k)/5], 
  Start[0], Finish[9], KVariables[k]]
;[o]
         9 I + (-9 I)/10 Pi k                    Pi k
DFTData[E                     Dirichlet[10, -2 + ----], Start[0], 
                                                  5
 
  Finish[9], KVariables[k]]
:[font = input; startGroup; ]

?InvDFTransform
:[font = info; inactive; endGroup; ]
InvDFTransform[function, NumberOfPoints, FourierVariables,
   TimeVariables, options] takes the inverse DFT of function, where
   function is a function of FourierVariables defined from 0 to
   NumberOfPoints - 1.  Note that only the first two arguments are
   required and that InvDFTransform calls InvDTFTransform.
:[font = input; startGroup; ]

InvDFTransform[ DFTransform[ Exp[I 2 n], 10, n, k ] ]
:[font = output; inactive; output; endGroup; ]
E^(9*I + 2*I*(-9/2 + n))*Pulse[10, n]
;[o]
 9 I + 2 I (-(9/2) + n)
E                       Pulse   [n]
                              10
:[font = text; inactive; ]
This expression is the same as Exp[I 2 n] for n = 0 ... 9:
:[font = input; startGroup; ]

MyCollectAll[ InvDFTransform[ DFTransform[Exp[I 2 n], 10, n, k] ], n ]
:[font = output; inactive; output; endGroup; endGroup; ]
E^(2*I*n)*Pulse[10, n]
;[o]
 2 I n
E      Pulse   [n]
             10
:[font = subsection; inactive; startGroup; Cclosed; ]
Stability Analysis Example
:[font = input; startGroup; ]
?Stable
:[font = info; inactive; endGroup; ]
Stable[transexpr] returns True if the transform transexpr represents
   a stable time-domain signal.
:[font = input; startGroup; ]
Stable[ ZTransform[ a^n1 b^n2 Step[n1,n2], {n1,n2} ] ]
:[font = output; inactive; output; endGroup; endGroup; ]
Abs[a] < 1 && Abs[b] < 1
;[o]
Abs[a] < 1 && Abs[b] < 1
:[font = subsection; inactive; startGroup; Cclosed; ]
Solving a Difference Equation
:[font = input; startGroup; ]

?ZSolve
:[font = info; inactive; endGroup; ]
ZSolve[ diffequ == drivingfun, y[n] ] solves the difference equation
   diffequ = drivingfun, where diffequ is a linear constant
   coefficient difference equation and drivingfun is the driving
   function (a function of n).  Thus, diffequ has the form a0 y[n] +
   a1 y[n - 1] + ....  By using options, one can specify initial
   values; e.g., ZSolve[ y[n] + 3/2 y[n-1] + 1/2 y[n-2] == (1/4)^n
   Step[n], y[n], y[-1] -> 4, y[-2] -> 10 ].
:[font = input; initialization; startGroup; ]
*)

diffequ = y[n] - 3/2 y[n-1] + 1/2 y[n-2]
(*
:[font = output; inactive; output; endGroup; ]
y[-2 + n]/2 - (3*y[-1 + n])/2 + y[n]
;[o]
y[-2 + n]   3 y[-1 + n]
--------- - ----------- + y[n]
    2            2
:[font = input; initialization; startGroup; ]
*)

ZSolve[ diffequ == (1/4)^n Step[n],
		 y[n], y[-1] -> 4, y[-2] -> 10 ]
(*
:[font = message; inactive; startGroup; ]
ZSolve::redundant: 
   Same initial index is assigned two different values.
:[font = print; inactive; ]
Solving for y[n] in the difference equation
:[font = print; inactive; ]
augmented by the initial conditions:
:[font = print; inactive; ]
  y[-2 + n]   3 y[-1 + n]
  --------- - ----------- + y[n] = 
      2            2
 
                                            1 n
  -11 Impulse[1 + n] + 10 Impulse[2 + n] + (-)  Step[n]
                                            4
:[font = print; inactive; ]
After taking the z-transform of both sides and
:[font = print; inactive; ]
solving for the z-transform of y[n]:
:[font = print; inactive; ]
            30   108
      -80 - -- + ---
             2    z
            z
  -(-------------------)
      -5   7    14   8
    -z   + -- - -- + --
            4    3    2
           z    z    z
:[font = print; inactive; ]
Inverse transforming this gives y[n]:
:[font = output; inactive; output; endGroup; endGroup; ]
4*Impulse[1 + n] + 10*Impulse[2 + n] + (2*Step[n])/3 + 
  ((1/4)^n*Step[n])/3 + (1/2)^n*Step[n]
;[o]
                                       2 Step[n]
4 Impulse[1 + n] + 10 Impulse[2 + n] + --------- + 
                                           3
 
   1 n
  (-)  Step[n]
   4              1 n
  ------------ + (-)  Step[n]
       3          2
:[font = input; ]

y[n_] := ( 2 + (1/4)^n + 3 (1/2)^n ) / 3
:[font = input; startGroup; ]
y[-1]
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = input; startGroup; ]
y[-2]
:[font = output; inactive; output; endGroup; ]
10
;[o]
10
:[font = input; startGroup; ]
Table [ diffequ == (1/4)^n Step[n], {n, 0, 5} ]
:[font = output; inactive; output; endGroup; endGroup; ]
{True, True, True, True, True, True}
;[o]
{True, True, True, True, True, True}
:[font = subsection; inactive; startGroup; Cclosed; ]
Digital Signal Analyzer
:[font = input; startGroup; ]

?DSPAnalyze
:[font = info; inactive; endGroup; ]
DSPAnalyze[f], DSPAnalyze[f,n], and DSPAnalyze[f,n,start,end] will
   plot f[n] from n = Floor[start] to n = Ceiling[end], print its
   z-transform, indicate conditions for stability, display the
   pole-zero diagram, and plot the magnitude and phase responses. 
   For the version of this routine which works for two-dimensional
   functions, n is a two-element list of variables (like {n1, n2})
   and start as well as end are also two-element lists indicating
   the range of the time-domain graph.
:[font = input; startGroup; ]

DSPAnalyze[ Upsample[3,n][Sinc[n]], n, -20, 20 ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.02381 0.10943 0.49388 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-20)] 0.02381 0.09693 0 1 Msboxa
[(-10)] 0.2619 0.09693 0 1 Msboxa
[(10)] 0.7381 0.09693 0 1 Msboxa
[(20)] 0.97619 0.09693 0 1 Msboxa
[(n)] 1.00625 0.10943 -1 0 Msboxa
[(-0.2)] 0.4875 0.01066 1 0 Msboxa
[(0.2)] 0.4875 0.20821 1 0 Msboxa
[(0.4)] 0.4875 0.30699 1 0 Msboxa
[(0.6)] 0.4875 0.40577 1 0 Msboxa
[(0.8)] 0.4875 0.50454 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.10943 moveto
1 0.10943 lineto
stroke
0.02381 0.10318 moveto
0.02381 0.11568 lineto
stroke
0 setgray
[(-20)] 0.02381 0.09693 0 1 Mshowa
0.2619 0.10318 moveto
0.2619 0.11568 lineto
stroke
0 setgray
[(-10)] 0.2619 0.09693 0 1 Mshowa
0.7381 0.10318 moveto
0.7381 0.11568 lineto
stroke
0 setgray
[(10)] 0.7381 0.09693 0 1 Mshowa
0.97619 0.10318 moveto
0.97619 0.11568 lineto
stroke
0 setgray
[(20)] 0.97619 0.09693 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.10943 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.01066 moveto
0.50625 0.01066 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.01066 1 0 Mshowa
0.49375 0.20821 moveto
0.50625 0.20821 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.20821 1 0 Mshowa
0.49375 0.30699 moveto
0.50625 0.30699 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.30699 1 0 Mshowa
0.49375 0.40577 moveto
0.50625 0.40577 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.40577 1 0 Mshowa
0.49375 0.50454 moveto
0.50625 0.50454 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.50454 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.10943 moveto
0.02381 0.10943 lineto
stroke
0.008 setlinewidth
0.02381 0.10943 Mdot
0.004 setlinewidth
0.04762 0.10943 moveto
0.04762 0.10943 lineto
stroke
0.008 setlinewidth
0.04762 0.10943 Mdot
0.004 setlinewidth
0.07143 0.10943 moveto
0.07143 0.08643 lineto
stroke
0.008 setlinewidth
0.07143 0.08643 Mdot
0.004 setlinewidth
0.09524 0.10943 moveto
0.09524 0.10943 lineto
stroke
0.008 setlinewidth
0.09524 0.10943 Mdot
0.004 setlinewidth
0.11905 0.10943 moveto
0.11905 0.10943 lineto
stroke
0.008 setlinewidth
0.11905 0.10943 Mdot
0.004 setlinewidth
0.14286 0.10943 moveto
0.14286 0.01472 lineto
stroke
0.008 setlinewidth
0.14286 0.01472 Mdot
0.004 setlinewidth
0.16667 0.10943 moveto
0.16667 0.10943 lineto
stroke
0.008 setlinewidth
0.16667 0.10943 Mdot
0.004 setlinewidth
0.19048 0.10943 moveto
0.19048 0.10943 lineto
stroke
0.008 setlinewidth
0.19048 0.10943 Mdot
0.004 setlinewidth
0.21429 0.10943 moveto
0.21429 0.01599 lineto
stroke
0.008 setlinewidth
0.21429 0.01599 Mdot
0.004 setlinewidth
0.2381 0.10943 moveto
0.2381 0.10943 lineto
stroke
0.008 setlinewidth
0.2381 0.10943 Mdot
0.004 setlinewidth
0.2619 0.10943 moveto
0.2619 0.10943 lineto
stroke
0.008 setlinewidth
0.2619 0.10943 Mdot
0.004 setlinewidth
0.28571 0.10943 moveto
0.28571 0.13267 lineto
stroke
0.008 setlinewidth
0.28571 0.13267 Mdot
0.004 setlinewidth
0.30952 0.10943 moveto
0.30952 0.10943 lineto
stroke
0.008 setlinewidth
0.30952 0.10943 Mdot
0.004 setlinewidth
0.33333 0.10943 moveto
0.33333 0.10943 lineto
stroke
0.008 setlinewidth
0.33333 0.10943 Mdot
0.004 setlinewidth
0.35714 0.10943 moveto
0.35714 0.33398 lineto
stroke
0.008 setlinewidth
0.35714 0.33398 Mdot
0.004 setlinewidth
0.38095 0.10943 moveto
0.38095 0.10943 lineto
stroke
0.008 setlinewidth
0.38095 0.10943 Mdot
0.004 setlinewidth
0.40476 0.10943 moveto
0.40476 0.10943 lineto
stroke
0.008 setlinewidth
0.40476 0.10943 Mdot
0.004 setlinewidth
0.42857 0.10943 moveto
0.42857 0.52502 lineto
stroke
0.008 setlinewidth
0.42857 0.52502 Mdot
0.004 setlinewidth
0.45238 0.10943 moveto
0.45238 0.10943 lineto
stroke
0.008 setlinewidth
0.45238 0.10943 Mdot
0.004 setlinewidth
0.47619 0.10943 moveto
0.47619 0.10943 lineto
stroke
0.008 setlinewidth
0.47619 0.10943 Mdot
0.004 setlinewidth
0.5 0.10943 moveto
0.5 0.60332 lineto
stroke
0.008 setlinewidth
0.5 0.60332 Mdot
0.004 setlinewidth
0.52381 0.10943 moveto
0.52381 0.10943 lineto
stroke
0.008 setlinewidth
0.52381 0.10943 Mdot
0.004 setlinewidth
0.54762 0.10943 moveto
0.54762 0.10943 lineto
stroke
0.008 setlinewidth
0.54762 0.10943 Mdot
0.004 setlinewidth
0.57143 0.10943 moveto
0.57143 0.52502 lineto
stroke
0.008 setlinewidth
0.57143 0.52502 Mdot
0.004 setlinewidth
0.59524 0.10943 moveto
0.59524 0.10943 lineto
stroke
0.008 setlinewidth
0.59524 0.10943 Mdot
0.004 setlinewidth
0.61905 0.10943 moveto
0.61905 0.10943 lineto
stroke
0.008 setlinewidth
0.61905 0.10943 Mdot
0.004 setlinewidth
0.64286 0.10943 moveto
0.64286 0.33398 lineto
stroke
0.008 setlinewidth
0.64286 0.33398 Mdot
0.004 setlinewidth
0.66667 0.10943 moveto
0.66667 0.10943 lineto
stroke
0.008 setlinewidth
0.66667 0.10943 Mdot
0.004 setlinewidth
0.69048 0.10943 moveto
0.69048 0.10943 lineto
stroke
0.008 setlinewidth
0.69048 0.10943 Mdot
0.004 setlinewidth
0.71429 0.10943 moveto
0.71429 0.13267 lineto
stroke
0.008 setlinewidth
0.71429 0.13267 Mdot
0.004 setlinewidth
0.7381 0.10943 moveto
0.7381 0.10943 lineto
stroke
0.008 setlinewidth
0.7381 0.10943 Mdot
0.004 setlinewidth
0.7619 0.10943 moveto
0.7619 0.10943 lineto
stroke
0.008 setlinewidth
0.7619 0.10943 Mdot
0.004 setlinewidth
0.78571 0.10943 moveto
0.78571 0.01599 lineto
stroke
0.008 setlinewidth
0.78571 0.01599 Mdot
0.004 setlinewidth
0.80952 0.10943 moveto
0.80952 0.10943 lineto
stroke
0.008 setlinewidth
0.80952 0.10943 Mdot
0.004 setlinewidth
0.83333 0.10943 moveto
0.83333 0.10943 lineto
stroke
0.008 setlinewidth
0.83333 0.10943 Mdot
0.004 setlinewidth
0.85714 0.10943 moveto
0.85714 0.01472 lineto
stroke
0.008 setlinewidth
0.85714 0.01472 Mdot
0.004 setlinewidth
0.88095 0.10943 moveto
0.88095 0.10943 lineto
stroke
0.008 setlinewidth
0.88095 0.10943 Mdot
0.004 setlinewidth
0.90476 0.10943 moveto
0.90476 0.10943 lineto
stroke
0.008 setlinewidth
0.90476 0.10943 Mdot
0.004 setlinewidth
0.92857 0.10943 moveto
0.92857 0.08643 lineto
stroke
0.008 setlinewidth
0.92857 0.08643 Mdot
0.004 setlinewidth
0.95238 0.10943 moveto
0.95238 0.10943 lineto
stroke
0.008 setlinewidth
0.95238 0.10943 Mdot
0.004 setlinewidth
0.97619 0.10943 moveto
0.97619 0.10943 lineto
stroke
0.008 setlinewidth
0.97619 0.10943 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = message; inactive; ]
                                 1
Power::infy: Infinite expression - encountered.
                                 0
:[font = print; inactive; ]
             1
The function - does not have a valid z-transform with respect to n
             n
             1
The function - does not have a valid z-transform with respect to n
             n
Upsample     [Sinc[n]]
        3,0,n
has the following frequency response:
ScaleAxis   [Pi (-CStep[-1 + w] + CStep[1 + w])]
         3,w
:[font = message; inactive; ]
ZTransform::notvalid: The forward z-transform could not be found.
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.18736 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(0.5)] 0.4875 0.10839 1 0 Msboxa
[(1)] 0.4875 0.20207 1 0 Msboxa
[(1.5)] 0.4875 0.29575 1 0 Msboxa
[(2)] 0.4875 0.38943 1 0 Msboxa
[(2.5)] 0.4875 0.48311 1 0 Msboxa
[(3)] 0.4875 0.57679 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10839 moveto
0.50625 0.10839 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.10839 1 0 Mshowa
0.49375 0.20207 moveto
0.50625 0.20207 lineto
stroke
0 setgray
[(1)] 0.4875 0.20207 1 0 Mshowa
0.49375 0.29575 moveto
0.50625 0.29575 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.29575 1 0 Mshowa
0.49375 0.38943 moveto
0.50625 0.38943 lineto
stroke
0 setgray
[(2)] 0.4875 0.38943 1 0 Mshowa
0.49375 0.48311 moveto
0.50625 0.48311 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.48311 1 0 Mshowa
0.49375 0.57679 moveto
0.50625 0.57679 lineto
stroke
0 setgray
[(3)] 0.4875 0.57679 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.03373 0.60332 lineto
0.04365 0.60332 lineto
0.04613 0.60332 lineto
0.04737 0.60332 lineto
0.04861 0.60332 lineto
0.04985 0.01472 lineto
0.05109 0.01472 lineto
0.05357 0.01472 lineto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.12302 0.01472 lineto
0.13294 0.01472 lineto
0.14286 0.01472 lineto
0.14782 0.01472 lineto
0.1503 0.01472 lineto
0.15278 0.01472 lineto
0.15402 0.01472 lineto
0.15526 0.01472 lineto
0.1565 0.01472 lineto
0.15774 0.60332 lineto
0.15898 0.60332 lineto
0.16022 0.60332 lineto
0.1627 0.60332 lineto
0.18254 0.60332 lineto
0.19246 0.60332 lineto
0.19742 0.60332 lineto
0.20238 0.60332 lineto
0.20486 0.60332 lineto
0.2061 0.60332 lineto
0.20734 0.60332 lineto
0.20858 0.01472 lineto
0.20982 0.01472 lineto
0.2123 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.28175 0.01472 lineto
0.29167 0.01472 lineto
0.30159 0.01472 lineto
0.30655 0.01472 lineto
0.30903 0.01472 lineto
0.31151 0.01472 lineto
0.31275 0.01472 lineto
0.31399 0.01472 lineto
0.31523 0.01472 lineto
0.31647 0.60332 lineto
0.31895 0.60332 lineto
0.32143 0.60332 lineto
0.34127 0.60332 lineto
0.35119 0.60332 lineto
Mistroke
0.35615 0.60332 lineto
0.36111 0.60332 lineto
0.36359 0.60332 lineto
0.36483 0.60332 lineto
0.36607 0.60332 lineto
0.36731 0.01472 lineto
0.36855 0.01472 lineto
0.37103 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.44048 0.01472 lineto
0.4504 0.01472 lineto
0.46032 0.01472 lineto
0.46528 0.01472 lineto
0.47024 0.01472 lineto
0.47148 0.01472 lineto
0.47272 0.01472 lineto
0.47396 0.01472 lineto
0.4752 0.60332 lineto
0.47768 0.60332 lineto
0.48016 0.60332 lineto
0.5 0.60332 lineto
0.50992 0.60332 lineto
0.51984 0.60332 lineto
0.52232 0.60332 lineto
0.52356 0.60332 lineto
0.5248 0.60332 lineto
0.52604 0.01472 lineto
0.52728 0.01472 lineto
0.52976 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.59921 0.01472 lineto
0.60913 0.01472 lineto
0.61905 0.01472 lineto
0.62401 0.01472 lineto
0.62649 0.01472 lineto
0.62897 0.01472 lineto
0.63021 0.01472 lineto
0.63145 0.01472 lineto
0.63269 0.01472 lineto
0.63393 0.60332 lineto
0.63517 0.60332 lineto
0.63641 0.60332 lineto
0.63889 0.60332 lineto
0.65873 0.60332 lineto
0.66865 0.60332 lineto
0.67361 0.60332 lineto
0.67857 0.60332 lineto
0.68105 0.60332 lineto
Mistroke
0.68229 0.60332 lineto
0.68353 0.60332 lineto
0.68477 0.01472 lineto
0.68601 0.01472 lineto
0.68725 0.01472 lineto
0.68849 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.75794 0.01472 lineto
0.76786 0.01472 lineto
0.77778 0.01472 lineto
0.78274 0.01472 lineto
0.78522 0.01472 lineto
0.7877 0.01472 lineto
0.78894 0.01472 lineto
0.79018 0.01472 lineto
0.79142 0.01472 lineto
0.79266 0.60332 lineto
0.79514 0.60332 lineto
0.79762 0.60332 lineto
0.81746 0.60332 lineto
0.82738 0.60332 lineto
0.8373 0.60332 lineto
0.83978 0.60332 lineto
0.84102 0.60332 lineto
0.84226 0.60332 lineto
0.8435 0.01472 lineto
0.84474 0.01472 lineto
0.84722 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.91667 0.01472 lineto
0.92659 0.01472 lineto
0.93651 0.01472 lineto
0.94147 0.01472 lineto
0.94395 0.01472 lineto
0.94643 0.01472 lineto
0.94767 0.01472 lineto
0.94891 0.01472 lineto
0.95015 0.01472 lineto
0.95139 0.60332 lineto
0.95263 0.60332 lineto
0.95387 0.60332 lineto
0.95635 0.60332 lineto
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
MakeZObject[SubstituteForT[ZForm, 
   ScaleT[ZForm, SubT[ZForm, 
     SubstituteForT[ZForm, SignalProcessing`Digital`ZTransform`Priv\
        ate`MyZTransform[n^(-1), n, z, 
       {False, False, False, False, False}, {n}, {z}, 
       {Dialogue -> True}], z, E^I*z], 
     SubstituteForT[ZForm, SignalProcessing`Digital`ZTransform`Priv\
        ate`MyZTransform[n^(-1), n, z, 
       {False, False, False, False, False}, {n}, {z}, 
       {Dialogue -> True}], z, E^(-I)*z]], I/2], z, z^3], z]
;[o]
-Incomplete z-Transform-
:[font = input; startGroup; Cclosed; ]

DSPAnalyze[ (n1 + n2)! (1/2)^n1 (4/5)^n2 Step[n1,n2] / (n1! n2!),
			{n1,n2} ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(Discrete-Time Domain Analysis)] 0.5 1.00625 0 -1 Msboxa
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(2)] 0.17438 0.26589 0.978063 1 Msboxa
[(4)] 0.29825 0.21715 0.8854 1 Msboxa
[(6)] 0.42902 0.16572 0.792736 1 Msboxa
[(8)] 0.56728 0.11138 0.700073 1 Msboxa
[(n1)] 0.2914 0.15947 0.862234 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(2)] 0.72251 0.18893 -1 0.366986 Msboxa
[(4)] 0.78167 0.27952 -1 0.345307 Msboxa
[(6)] 0.83538 0.36178 -1 0.326047 Msboxa
[(8)] 0.88437 0.43681 -1 0.308822 Msboxa
[(n2)] 0.85193 0.28164 -1 0.340282 Msboxa
[(0)] 0.05376 0.32919 1 -0.390602 Msboxa
[(5)] 0.04185 0.40379 1 -0.374851 Msboxa
[(10)] 0.02929 0.48255 1 -0.358128 Msboxa
[( )] -0.01735 0.44567 1 -0.370357 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 1.00625 0 -1 Mshowa
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.17854 0.27014 moveto
0.18687 0.27865 lineto
stroke
0 setgray
[(2)] 0.17438 0.26589 0.978063 1 Mshowa
0.3022 0.22161 moveto
0.31009 0.23052 lineto
stroke
0 setgray
[(4)] 0.29825 0.21715 0.8854 1 Mshowa
0.43272 0.17039 moveto
0.44012 0.17972 lineto
stroke
0 setgray
[(6)] 0.42902 0.16572 0.792736 1 Mshowa
0.5707 0.11626 moveto
0.57753 0.12601 lineto
stroke
0 setgray
[(8)] 0.56728 0.11138 0.700073 1 Mshowa
0 setgray
[(n1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71692 0.19098 moveto
0.70574 0.19508 lineto
stroke
0 setgray
[(2)] 0.72251 0.18893 -1 0.366986 Mshowa
0.77604 0.28146 moveto
0.76479 0.28535 lineto
stroke
0 setgray
[(4)] 0.78167 0.27952 -1 0.345307 Mshowa
0.82972 0.36363 moveto
0.8184 0.36732 lineto
stroke
0 setgray
[(6)] 0.83538 0.36178 -1 0.326047 Mshowa
0.87869 0.43857 moveto
0.86731 0.44208 lineto
stroke
0 setgray
[(8)] 0.88437 0.43681 -1 0.308822 Mshowa
0 setgray
[(n2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32703 moveto
0.07039 0.3227 lineto
stroke
0 setgray
[(0)] 0.05376 0.32919 1 -0.390602 Mshowa
0.04743 0.4017 moveto
0.05858 0.39752 lineto
stroke
0 setgray
[(5)] 0.04185 0.40379 1 -0.374851 Mshowa
0.03489 0.48054 moveto
0.0461 0.47653 lineto
stroke
0 setgray
[(10)] 0.02929 0.48255 1 -0.358128 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.12925 setgray
0.0015 setlinewidth
0.3586 0.60081 0.39326 0.63251 0.45076 0.62394 0.41686 0.59237 Metetra
0.17138 setgray
0.41686 0.59237 0.45076 0.62394 0.51003 0.6264 0.4769 0.59288 Metetra
0.25313 setgray
0.4769 0.59288 0.51003 0.6264 0.57186 0.6403 0.53933 0.59966 Metetra
0.36114 setgray
0.53933 0.59966 0.57186 0.6403 0.63689 0.66098 0.60448 0.60674 Metetra
0.46918 setgray
0.60448 0.60674 0.63689 0.66098 0.7052 0.68069 0.6722 0.60789 Metetra
0.55224 setgray
0.6722 0.60789 0.7052 0.68069 0.77624 0.69159 0.7419 0.59907 Metetra
0.59586 setgray
0.7419 0.59907 0.77624 0.69159 0.84901 0.68849 0.81296 0.57934 Metetra
0.59808 setgray
0.81296 0.57934 0.84901 0.68849 0.9225 0.67001 0.8849 0.55033 Metetra
0.13219 setgray
0.32233 0.5678 0.3586 0.60081 0.41686 0.59237 0.38136 0.55923 Metetra
0.17688 setgray
0.38136 0.55923 0.41686 0.59237 0.4769 0.59288 0.44221 0.55675 Metetra
0.24868 setgray
0.44221 0.55675 0.4769 0.59288 0.53933 0.59966 0.50536 0.5557 Metetra
0.32677 setgray
0.50536 0.5557 0.53933 0.59966 0.60448 0.60674 0.57091 0.55066 Metetra
0.38877 setgray
0.57091 0.55066 0.60448 0.60674 0.6722 0.60789 0.6386 0.53817 Metetra
0.42148 setgray
0.6386 0.53817 0.6722 0.60789 0.7419 0.59907 0.70798 0.51752 Metetra
0.42313 setgray
0.70798 0.51752 0.7419 0.59907 0.81296 0.57934 0.77872 0.49008 Metetra
0.4 setgray
0.77872 0.49008 0.81296 0.57934 0.8849 0.55033 0.85071 0.45818 Metetra
0.13597 setgray
0.28431 0.53342 0.32233 0.5678 0.38136 0.55923 0.34414 0.52426 Metetra
0.18146 setgray
0.34414 0.52426 0.38136 0.55923 0.44221 0.55675 0.40589 0.51772 Metetra
0.23926 setgray
0.40589 0.51772 0.44221 0.55675 0.50536 0.5557 0.46991 0.50866 Metetra
0.28761 setgray
0.46991 0.50866 0.50536 0.5557 0.57091 0.55066 0.53612 0.49373 Metetra
0.31331 setgray
0.53612 0.49373 0.57091 0.55066 0.6386 0.53817 0.60424 0.47232 Metetra
0.3146 setgray
0.60424 0.47232 0.6386 0.53817 0.70798 0.51752 0.67401 0.44569 Metetra
0.29723 setgray
0.67401 0.44569 0.70798 0.51752 0.77872 0.49008 0.74531 0.41581 Metetra
0.26943 setgray
0.74531 0.41581 0.77872 0.49008 0.85071 0.45818 0.81821 0.38444 Metetra
0.14083 setgray
0.24443 0.49762 0.28431 0.53342 0.34414 0.52426 0.3051 0.48713 Metetra
0.18425 setgray
0.3051 0.48713 0.34414 0.52426 0.40589 0.51772 0.36788 0.47551 Metetra
0.22445 setgray
0.36788 0.47551 0.40589 0.51772 0.46991 0.50866 0.43292 0.45897 Metetra
0.24608 setgray
0.43292 0.45897 0.46991 0.50866 0.53612 0.49373 0.5 0.43689 Metetra
0.24714 setgray
0.5 0.43689 0.53612 0.49373 0.60424 0.47232 0.5689 0.41056 Metetra
0.23348 setgray
0.5689 0.41056 0.60424 0.47232 0.67401 0.44569 0.63951 0.38179 Metetra
0.21265 setgray
0.63951 0.38179 0.67401 0.44569 0.74531 0.41581 0.71187 0.35199 Metetra
0.19062 setgray
0.71187 0.35199 0.74531 0.41581 0.81821 0.38444 0.78612 0.32203 Metetra
0.14708 setgray
0.20251 0.46034 0.24443 0.49762 0.3051 0.48713 0.26414 0.44739 Metetra
0.18403 setgray
0.26414 0.44739 0.3051 0.48713 0.36788 0.47551 0.32811 0.42997 Metetra
0.2044 setgray
0.32811 0.42997 0.36788 0.47551 0.43292 0.45897 0.39427 0.40728 Metetra
0.20538 setgray
0.39427 0.40728 0.43292 0.45897 0.5 0.43689 0.46236 0.38087 Metetra
0.19386 setgray
0.46236 0.38087 0.5 0.43689 0.5689 0.41056 0.53226 0.35258 Metetra
0.17752 setgray
0.53226 0.35258 0.5689 0.41056 0.63951 0.38179 0.60399 0.32361 Metetra
0.16147 setgray
0.60399 0.32361 0.63951 0.38179 0.71187 0.35199 0.67767 0.29455 Metetra
0.14815 setgray
0.67767 0.29455 0.71187 0.35199 0.78612 0.32203 0.75346 0.26551 Metetra
0.15512 setgray
0.15837 0.42157 0.20251 0.46034 0.26414 0.44739 0.22118 0.40447 Metetra
0.17912 setgray
0.22118 0.40447 0.26414 0.44739 0.32811 0.42997 0.28647 0.38121 Metetra
0.1802 setgray
0.28647 0.38121 0.32811 0.42997 0.39427 0.40728 0.35379 0.35435 Metetra
0.1693 setgray
0.35379 0.35435 0.39427 0.40728 0.46236 0.38087 0.42296 0.32607 Metetra
0.15558 setgray
0.42296 0.32607 0.46236 0.38087 0.53226 0.35258 0.49399 0.29744 Metetra
0.14356 setgray
0.49399 0.29744 0.53226 0.35258 0.60399 0.32361 0.56701 0.26877 Metetra
0.13458 setgray
0.56701 0.26877 0.60399 0.32361 0.67767 0.29455 0.64214 0.24 Metetra
0.12847 setgray
0.64214 0.24 0.67767 0.29455 0.75346 0.26551 0.71955 0.21092 Metetra
0.16545 setgray
0.11179 0.38128 0.15837 0.42157 0.22118 0.40447 0.17619 0.35764 Metetra
0.16737 setgray
0.17619 0.35764 0.22118 0.40447 0.28647 0.38121 0.24282 0.32966 Metetra
0.1544 setgray
0.24282 0.32966 0.28647 0.38121 0.35379 0.35435 0.31125 0.30094 Metetra
0.14154 setgray
0.31125 0.30094 0.35379 0.35435 0.42296 0.32607 0.38151 0.27233 Metetra
0.1323 setgray
0.38151 0.27233 0.42296 0.32607 0.49399 0.29744 0.45377 0.24375 Metetra
0.12647 setgray
0.45377 0.24375 0.49399 0.29744 0.56701 0.26877 0.52816 0.21492 Metetra
0.12305 setgray
0.52816 0.21492 0.56701 0.26877 0.64214 0.24 0.60483 0.18559 Metetra
0.12113 setgray
0.60483 0.18559 0.64214 0.24 0.71955 0.21092 0.68391 0.15557 Metetra
0.17872 setgray
0.06253 0.33949 0.11179 0.38128 0.17619 0.35764 0.12917 0.3061 Metetra
0.14634 setgray
0.12917 0.3061 0.17619 0.35764 0.24282 0.32966 0.19691 0.27624 Metetra
0.1315 setgray
0.19691 0.27624 0.24282 0.32966 0.31125 0.30094 0.26633 0.24754 Metetra
0.12469 setgray
0.26633 0.24754 0.31125 0.30094 0.38151 0.27233 0.33772 0.21892 Metetra
0.12157 setgray
0.33772 0.21892 0.38151 0.27233 0.45377 0.24375 0.41127 0.18985 Metetra
0.12014 setgray
0.41127 0.18985 0.45377 0.24375 0.52816 0.21492 0.48713 0.16006 Metetra
0.11949 setgray
0.48713 0.16006 0.52816 0.21492 0.60483 0.18559 0.5654 0.12941 Metetra
0.11919 setgray
0.5654 0.12941 0.60483 0.18559 0.68391 0.15557 0.64622 0.09781 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.17854 0.27014 moveto
0.18687 0.27865 lineto
stroke
0 setgray
[(2)] 0.17438 0.26589 0.978063 1 Mshowa
0.3022 0.22161 moveto
0.31009 0.23052 lineto
stroke
0 setgray
[(4)] 0.29825 0.21715 0.8854 1 Mshowa
0.43272 0.17039 moveto
0.44012 0.17972 lineto
stroke
0 setgray
[(6)] 0.42902 0.16572 0.792736 1 Mshowa
0.5707 0.11626 moveto
0.57753 0.12601 lineto
stroke
0 setgray
[(8)] 0.56728 0.11138 0.700073 1 Mshowa
0 setgray
[(n1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71692 0.19098 moveto
0.70574 0.19508 lineto
stroke
0 setgray
[(2)] 0.72251 0.18893 -1 0.366986 Mshowa
0.77604 0.28146 moveto
0.76479 0.28535 lineto
stroke
0 setgray
[(4)] 0.78167 0.27952 -1 0.345307 Mshowa
0.82972 0.36363 moveto
0.8184 0.36732 lineto
stroke
0 setgray
[(6)] 0.83538 0.36178 -1 0.326047 Mshowa
0.87869 0.43857 moveto
0.86731 0.44208 lineto
stroke
0 setgray
[(8)] 0.88437 0.43681 -1 0.308822 Mshowa
0 setgray
[(n2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32703 moveto
0.07039 0.3227 lineto
stroke
0 setgray
[(0)] 0.05376 0.32919 1 -0.390602 Mshowa
0.04743 0.4017 moveto
0.05858 0.39752 lineto
stroke
0 setgray
[(5)] 0.04185 0.40379 1 -0.374851 Mshowa
0.03489 0.48054 moveto
0.0461 0.47653 lineto
stroke
0 setgray
[(10)] 0.02929 0.48255 1 -0.358128 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
 1 n1  4 n2
(-)   (-)   (n1 + n2)! Step[n1] Step[n2]
 2     5
----------------------------------------
                n1! n2!
has the following z-transform:
     -10
-------------
      5    8
-10 + -- + --
      z1   z2
The region of convergence is:
1
- < |z1| < Infinity
2
         1
4 Abs[--------]
           1
      1 - ----
          2 z1
--------------- < |z2| < Infinity
       5
                                 z1
                        8 Abs[---------]
                              -1 + 2 z1
The system is stable if ---------------- < 1
                               5
 
The zeroes are:  {}
                               I w
                    -5. 2.71828
The poles are:   {-------------------}
                                  I w
                  8. - 10. 2.71828
 
The zeroes are:  {}
                               I w
                    -8. 2.71828
The poles are:   {-------------------}
                                  I w
                  5. - 10. 2.71828
By substituting into the z-transform,
the frequency response is
           -10
-------------------------
         -I w1      -I w2
-10 + 5 E      + 8 E
 
 1 n1  4 n2
(-)   (-)   (n1 + n2)! Step[n1] Step[n2]
 2     5
----------------------------------------
                n1! n2!
has the following frequency response:
                1
---------------------------------
      -I w1             -I w2
     E               4 E
(1 - ------) (1 - --------------)
       2                  -I w1
                         E
                  5 (1 - ------)
                           2
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 179; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.63492 
MathPictureStart
% Scaling calculations
0.29592 0.27211 0.31746 0.27211 [
[(Pole Root Map)] 0.5 0.64117 0 -1 Msboxa
[(-1)] 0.02381 0.30496 0 1 Msboxa
[(-0.5)] 0.15986 0.30496 0 1 Msboxa
[(0.5)] 0.43197 0.30496 0 1 Msboxa
[(1)] 0.56803 0.30496 0 1 Msboxa
[(1.5)] 0.70408 0.30496 0 1 Msboxa
[(2)] 0.84014 0.30496 0 1 Msboxa
[(2.5)] 0.97619 0.30496 0 1 Msboxa
[(Re z1)] 1.00625 0.31746 -1 0 Msboxa
[(-1)] 0.28342 0.04535 1 0 Msboxa
[(-0.5)] 0.28342 0.18141 1 0 Msboxa
[(0.5)] 0.28342 0.45351 1 0 Msboxa
[(1)] 0.28342 0.58957 1 0 Msboxa
[(Im z1)] 0.29592 0.64117 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.63592 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Pole Root Map)] 0.5 0.64117 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.31746 moveto
1 0.31746 lineto
stroke
0.02381 0.31121 moveto
0.02381 0.32371 lineto
stroke
0 setgray
[(-1)] 0.02381 0.30496 0 1 Mshowa
0.15986 0.31121 moveto
0.15986 0.32371 lineto
stroke
0 setgray
[(-0.5)] 0.15986 0.30496 0 1 Mshowa
0.43197 0.31121 moveto
0.43197 0.32371 lineto
stroke
0 setgray
[(0.5)] 0.43197 0.30496 0 1 Mshowa
0.56803 0.31121 moveto
0.56803 0.32371 lineto
stroke
0 setgray
[(1)] 0.56803 0.30496 0 1 Mshowa
0.70408 0.31121 moveto
0.70408 0.32371 lineto
stroke
0 setgray
[(1.5)] 0.70408 0.30496 0 1 Mshowa
0.84014 0.31121 moveto
0.84014 0.32371 lineto
stroke
0 setgray
[(2)] 0.84014 0.30496 0 1 Mshowa
0.97619 0.31121 moveto
0.97619 0.32371 lineto
stroke
0 setgray
[(2.5)] 0.97619 0.30496 0 1 Mshowa
0 setgray
[(Re z1)] 1.00625 0.31746 -1 0 Mshowa
0.29592 0 moveto
0.29592 0.63492 lineto
stroke
0.28967 0.04535 moveto
0.30217 0.04535 lineto
stroke
0 setgray
[(-1)] 0.28342 0.04535 1 0 Mshowa
0.28967 0.18141 moveto
0.30217 0.18141 lineto
stroke
0 setgray
[(-0.5)] 0.28342 0.18141 1 0 Mshowa
0.28967 0.45351 moveto
0.30217 0.45351 lineto
stroke
0 setgray
[(0.5)] 0.28342 0.45351 1 0 Mshowa
0.28967 0.58957 moveto
0.30217 0.58957 lineto
stroke
0 setgray
[(1)] 0.28342 0.58957 1 0 Mshowa
0 setgray
[(Im z1)] 0.29592 0.64117 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.634919 lineto
0 0.634919 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.43197 0.31746 moveto
0.43197 0.31857 lineto
0.43195 0.31969 lineto
0.43193 0.3208 lineto
0.4319 0.32191 lineto
0.43186 0.32302 lineto
0.43181 0.32414 lineto
0.43168 0.32636 lineto
0.43152 0.32858 lineto
0.43132 0.3308 lineto
0.43081 0.33522 lineto
0.43016 0.33962 lineto
0.42936 0.344 lineto
0.42734 0.35267 lineto
0.42475 0.36119 lineto
0.42162 0.36953 lineto
0.41374 0.38549 lineto
0.40386 0.40028 lineto
0.39212 0.41366 lineto
0.37874 0.4254 lineto
0.36395 0.43529 lineto
0.35609 0.43948 lineto
0.34798 0.44316 lineto
0.33965 0.44629 lineto
0.33113 0.44888 lineto
0.32246 0.4509 lineto
0.31808 0.4517 lineto
0.31368 0.45235 lineto
0.30925 0.45286 lineto
0.30704 0.45306 lineto
0.30482 0.45322 lineto
0.30259 0.45335 lineto
0.30148 0.4534 lineto
0.30037 0.45344 lineto
0.29926 0.45347 lineto
0.29814 0.4535 lineto
0.29703 0.45351 lineto
0.29592 0.45351 lineto
0.29481 0.45351 lineto
0.29369 0.4535 lineto
0.29258 0.45347 lineto
0.29147 0.45344 lineto
0.28924 0.45335 lineto
0.28702 0.45322 lineto
0.2848 0.45306 lineto
0.28258 0.45286 lineto
0.27816 0.45235 lineto
0.27376 0.4517 lineto
0.26938 0.4509 lineto
0.2607 0.44888 lineto
Mistroke
0.25219 0.44629 lineto
0.24385 0.44316 lineto
0.22789 0.43529 lineto
0.21309 0.4254 lineto
0.19971 0.41366 lineto
0.18798 0.40028 lineto
0.17809 0.38549 lineto
0.17022 0.36953 lineto
0.16708 0.36119 lineto
0.1645 0.35267 lineto
0.16248 0.344 lineto
0.16168 0.33962 lineto
0.16103 0.33522 lineto
0.16052 0.3308 lineto
0.16032 0.32858 lineto
0.16016 0.32636 lineto
0.16003 0.32414 lineto
0.15998 0.32302 lineto
0.15994 0.32191 lineto
0.1599 0.3208 lineto
0.15988 0.31969 lineto
0.15987 0.31857 lineto
0.15986 0.31746 lineto
0.15987 0.31635 lineto
0.15988 0.31523 lineto
0.1599 0.31412 lineto
0.15994 0.31301 lineto
0.16003 0.31078 lineto
0.16016 0.30856 lineto
0.16032 0.30634 lineto
0.16052 0.30412 lineto
0.16103 0.2997 lineto
0.16168 0.2953 lineto
0.16248 0.29092 lineto
0.1645 0.28225 lineto
0.16708 0.27373 lineto
0.17022 0.26539 lineto
0.17809 0.24943 lineto
0.18798 0.23464 lineto
0.19971 0.22125 lineto
0.21309 0.20952 lineto
0.22789 0.19963 lineto
0.23574 0.19544 lineto
0.24385 0.19176 lineto
0.25219 0.18863 lineto
0.2607 0.18604 lineto
0.26938 0.18402 lineto
0.27376 0.18322 lineto
0.27816 0.18257 lineto
0.28258 0.18206 lineto
Mistroke
0.2848 0.18186 lineto
0.28702 0.1817 lineto
0.28924 0.18157 lineto
0.29035 0.18152 lineto
0.29147 0.18148 lineto
0.29258 0.18145 lineto
0.29369 0.18142 lineto
0.29481 0.18141 lineto
0.29592 0.18141 lineto
0.29703 0.18141 lineto
0.29814 0.18142 lineto
0.29926 0.18145 lineto
0.30037 0.18148 lineto
0.30259 0.18157 lineto
0.30482 0.1817 lineto
0.30704 0.18186 lineto
0.30925 0.18206 lineto
0.31368 0.18257 lineto
0.31808 0.18322 lineto
0.32246 0.18402 lineto
0.33113 0.18604 lineto
0.33965 0.18863 lineto
0.34798 0.19176 lineto
0.36395 0.19963 lineto
0.37874 0.20952 lineto
0.39212 0.22125 lineto
0.40386 0.23464 lineto
0.41374 0.24943 lineto
0.41794 0.25728 lineto
0.42162 0.26539 lineto
0.42475 0.27373 lineto
0.42734 0.28225 lineto
0.42936 0.29092 lineto
0.43016 0.2953 lineto
0.43081 0.2997 lineto
0.43132 0.30412 lineto
0.43152 0.30634 lineto
0.43168 0.30856 lineto
0.43181 0.31078 lineto
0.43186 0.3119 lineto
0.4319 0.31301 lineto
0.43193 0.31412 lineto
0.43195 0.31523 lineto
0.43197 0.31635 lineto
0.43197 0.31746 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.01 setlinewidth
0.56803 0.31746 moveto
0.56802 0.31969 lineto
0.56799 0.32191 lineto
0.56795 0.32414 lineto
0.56788 0.32636 lineto
0.5678 0.32859 lineto
0.5677 0.33081 lineto
0.56744 0.33526 lineto
0.56712 0.3397 lineto
0.56672 0.34413 lineto
0.5657 0.35298 lineto
0.56439 0.36179 lineto
0.5628 0.37055 lineto
0.55876 0.38789 lineto
0.55359 0.40493 lineto
0.54731 0.42159 lineto
0.53157 0.45351 lineto
0.5118 0.48311 lineto
0.48833 0.50987 lineto
0.46157 0.53334 lineto
0.43197 0.55311 lineto
0.41627 0.56151 lineto
0.40005 0.56886 lineto
0.38338 0.57513 lineto
0.36635 0.5803 lineto
0.349 0.58434 lineto
0.34024 0.58593 lineto
0.33144 0.58724 lineto
0.32259 0.58826 lineto
0.31816 0.58866 lineto
0.31372 0.58899 lineto
0.30927 0.58924 lineto
0.30705 0.58934 lineto
0.30482 0.58942 lineto
0.3026 0.58949 lineto
0.30037 0.58953 lineto
0.29814 0.58956 lineto
0.29592 0.58957 lineto
0.29369 0.58956 lineto
0.29147 0.58953 lineto
0.28924 0.58949 lineto
0.28702 0.58942 lineto
0.28257 0.58924 lineto
0.27812 0.58899 lineto
0.27368 0.58866 lineto
0.26925 0.58826 lineto
0.2604 0.58724 lineto
0.25159 0.58593 lineto
0.24283 0.58434 lineto
0.22549 0.5803 lineto
Mistroke
0.20845 0.57513 lineto
0.19179 0.56886 lineto
0.15986 0.55311 lineto
0.13027 0.53334 lineto
0.10351 0.50987 lineto
0.08004 0.48311 lineto
0.06027 0.45351 lineto
0.04452 0.42159 lineto
0.03825 0.40493 lineto
0.03308 0.38789 lineto
0.02904 0.37055 lineto
0.02744 0.36179 lineto
0.02614 0.35298 lineto
0.02512 0.34413 lineto
0.02472 0.3397 lineto
0.02439 0.33526 lineto
0.02414 0.33081 lineto
0.02404 0.32859 lineto
0.02396 0.32636 lineto
0.02389 0.32414 lineto
0.02385 0.32191 lineto
0.02382 0.31969 lineto
0.02381 0.31746 lineto
0.02382 0.31523 lineto
0.02385 0.31301 lineto
0.02389 0.31078 lineto
0.02396 0.30856 lineto
0.02414 0.30411 lineto
0.02439 0.29966 lineto
0.02472 0.29522 lineto
0.02512 0.29079 lineto
0.02614 0.28194 lineto
0.02744 0.27313 lineto
0.02904 0.26437 lineto
0.03308 0.24703 lineto
0.03825 0.22999 lineto
0.04452 0.21333 lineto
0.06027 0.18141 lineto
0.08004 0.15181 lineto
0.10351 0.12505 lineto
0.13027 0.10158 lineto
0.15986 0.08181 lineto
0.17557 0.07341 lineto
0.19179 0.06606 lineto
0.20845 0.05979 lineto
0.22549 0.05462 lineto
0.24283 0.05058 lineto
0.25159 0.04899 lineto
0.2604 0.04768 lineto
0.26925 0.04666 lineto
Mistroke
0.27368 0.04626 lineto
0.27812 0.04593 lineto
0.28257 0.04568 lineto
0.28479 0.04558 lineto
0.28702 0.0455 lineto
0.28924 0.04543 lineto
0.29147 0.04539 lineto
0.29369 0.04536 lineto
0.29592 0.04535 lineto
0.29814 0.04536 lineto
0.30037 0.04539 lineto
0.3026 0.04543 lineto
0.30482 0.0455 lineto
0.30927 0.04568 lineto
0.31372 0.04593 lineto
0.31816 0.04626 lineto
0.32259 0.04666 lineto
0.33144 0.04768 lineto
0.34024 0.04899 lineto
0.349 0.05058 lineto
0.36635 0.05462 lineto
0.38338 0.05979 lineto
0.40005 0.06606 lineto
0.43197 0.08181 lineto
0.46157 0.10158 lineto
0.48833 0.12505 lineto
0.5118 0.15181 lineto
0.53157 0.18141 lineto
0.53997 0.19711 lineto
0.54731 0.21333 lineto
0.55359 0.22999 lineto
0.55876 0.24703 lineto
0.5628 0.26437 lineto
0.56439 0.27313 lineto
0.5657 0.28194 lineto
0.56672 0.29079 lineto
0.56712 0.29522 lineto
0.56744 0.29966 lineto
0.5677 0.30411 lineto
0.5678 0.30633 lineto
0.56788 0.30856 lineto
0.56795 0.31078 lineto
0.56799 0.31301 lineto
0.56802 0.31523 lineto
0.56803 0.31746 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.005 setlinewidth
0.97619 0.31746 moveto
0.97537 0.29523 lineto
0.97293 0.27318 lineto
0.9689 0.25148 lineto
0.96335 0.23029 lineto
0.95637 0.20978 lineto
0.94805 0.19008 lineto
0.92789 0.15353 lineto
0.90394 0.12133 lineto
0.87731 0.09382 lineto
0.84905 0.07105 lineto
0.82009 0.05284 lineto
0.79121 0.03883 lineto
0.76299 0.02856 lineto
0.74927 0.02468 lineto
0.73587 0.02155 lineto
0.72281 0.01911 lineto
0.71012 0.0173 lineto
0.69782 0.01607 lineto
0.68592 0.01536 lineto
0.67443 0.01512 lineto
0.66334 0.0153 lineto
0.65267 0.01586 lineto
0.6424 0.01676 lineto
0.62305 0.01942 lineto
0.61395 0.02111 lineto
0.60522 0.02301 lineto
0.58884 0.02731 lineto
0.56 0.03737 lineto
0.53574 0.0485 lineto
0.51531 0.06002 lineto
0.48341 0.08263 lineto
0.46023 0.1035 lineto
0.43002 0.13869 lineto
0.41209 0.16614 lineto
0.3931 0.20524 lineto
0.38392 0.2317 lineto
0.37888 0.25109 lineto
0.37587 0.26628 lineto
0.37398 0.27883 lineto
0.37331 0.28443 lineto
0.37278 0.28969 lineto
0.37236 0.29469 lineto
0.37204 0.29947 lineto
0.3718 0.3041 lineto
0.37171 0.30637 lineto
0.37163 0.30862 lineto
0.37158 0.31084 lineto
0.37155 0.31195 lineto
0.37154 0.31306 lineto
Mistroke
0.37152 0.31416 lineto
0.37152 0.31471 lineto
0.37151 0.31526 lineto
0.37151 0.31581 lineto
0.37151 0.31609 lineto
0.37151 0.31636 lineto
0.37151 0.31664 lineto
0.3715 0.31691 lineto
0.3715 0.31718 lineto
0.3715 0.31746 lineto
0.3715 0.31773 lineto
0.3715 0.31801 lineto
0.37151 0.31828 lineto
0.37151 0.31856 lineto
0.37151 0.31911 lineto
0.37151 0.31966 lineto
0.37152 0.32021 lineto
0.37152 0.32076 lineto
0.37154 0.32186 lineto
0.37155 0.32297 lineto
0.37158 0.32408 lineto
0.37163 0.3263 lineto
0.37171 0.32855 lineto
0.3718 0.33082 lineto
0.37204 0.33545 lineto
0.37236 0.34023 lineto
0.37278 0.34523 lineto
0.37398 0.35609 lineto
0.37587 0.36864 lineto
0.37888 0.38383 lineto
0.38392 0.40322 lineto
0.3931 0.42968 lineto
0.40072 0.44712 lineto
0.41209 0.46878 lineto
0.43002 0.49623 lineto
0.44303 0.51275 lineto
0.46023 0.53142 lineto
0.48341 0.55229 lineto
0.51531 0.5749 lineto
0.53574 0.58642 lineto
0.56 0.59755 lineto
0.58884 0.60761 lineto
0.60522 0.61191 lineto
0.61395 0.61381 lineto
0.62305 0.6155 lineto
0.63253 0.61697 lineto
0.6424 0.61816 lineto
0.65267 0.61906 lineto
0.66334 0.61962 lineto
0.67443 0.6198 lineto
Mistroke
0.68592 0.61956 lineto
0.69782 0.61885 lineto
0.71012 0.61762 lineto
0.72281 0.61581 lineto
0.73587 0.61337 lineto
0.76299 0.60636 lineto
0.79121 0.59609 lineto
0.82009 0.58208 lineto
0.84905 0.56386 lineto
0.87731 0.5411 lineto
0.90394 0.51359 lineto
0.92789 0.48139 lineto
0.93851 0.46362 lineto
0.94805 0.44484 lineto
0.95637 0.42513 lineto
0.96335 0.40462 lineto
0.9689 0.38344 lineto
0.97293 0.36174 lineto
0.97537 0.33969 lineto
0.97619 0.31746 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 217; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.76923 
MathPictureStart
% Scaling calculations
0.39011 0.3663 0.38462 0.3663 [
[(Pole Root Map)] 0.5 0.77548 0 -1 Msboxa
[(-1)] 0.02381 0.37212 0 1 Msboxa
[(-0.5)] 0.20696 0.37212 0 1 Msboxa
[(0.5)] 0.57326 0.37212 0 1 Msboxa
[(1)] 0.75641 0.37212 0 1 Msboxa
[(1.5)] 0.93956 0.37212 0 1 Msboxa
[(Re z2)] 1.00625 0.38462 -1 0 Msboxa
[(-1)] 0.37761 0.01832 1 0 Msboxa
[(-0.5)] 0.37761 0.20147 1 0 Msboxa
[(0.5)] 0.37761 0.56777 1 0 Msboxa
[(1)] 0.37761 0.75092 1 0 Msboxa
[(Im z2)] 0.39011 0.77548 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.77023 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Pole Root Map)] 0.5 0.77548 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.38462 moveto
1 0.38462 lineto
stroke
0.02381 0.37837 moveto
0.02381 0.39087 lineto
stroke
0 setgray
[(-1)] 0.02381 0.37212 0 1 Mshowa
0.20696 0.37837 moveto
0.20696 0.39087 lineto
stroke
0 setgray
[(-0.5)] 0.20696 0.37212 0 1 Mshowa
0.57326 0.37837 moveto
0.57326 0.39087 lineto
stroke
0 setgray
[(0.5)] 0.57326 0.37212 0 1 Mshowa
0.75641 0.37837 moveto
0.75641 0.39087 lineto
stroke
0 setgray
[(1)] 0.75641 0.37212 0 1 Mshowa
0.93956 0.37837 moveto
0.93956 0.39087 lineto
stroke
0 setgray
[(1.5)] 0.93956 0.37212 0 1 Mshowa
0 setgray
[(Re z2)] 1.00625 0.38462 -1 0 Mshowa
0.39011 0 moveto
0.39011 0.76923 lineto
stroke
0.38386 0.01832 moveto
0.39636 0.01832 lineto
stroke
0 setgray
[(-1)] 0.37761 0.01832 1 0 Mshowa
0.38386 0.20147 moveto
0.39636 0.20147 lineto
stroke
0 setgray
[(-0.5)] 0.37761 0.20147 1 0 Mshowa
0.38386 0.56777 moveto
0.39636 0.56777 lineto
stroke
0 setgray
[(0.5)] 0.37761 0.56777 1 0 Mshowa
0.38386 0.75092 moveto
0.39636 0.75092 lineto
stroke
0 setgray
[(1)] 0.37761 0.75092 1 0 Mshowa
0 setgray
[(Im z2)] 0.39011 0.77548 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.769231 lineto
0 0.769231 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
0.01 setlinewidth
0.75641 0.38462 moveto
0.7564 0.38761 lineto
0.75636 0.39061 lineto
0.7563 0.3936 lineto
0.75621 0.3966 lineto
0.7561 0.3996 lineto
0.75597 0.40259 lineto
0.75563 0.40857 lineto
0.75519 0.41455 lineto
0.75465 0.42052 lineto
0.75328 0.43243 lineto
0.75152 0.44428 lineto
0.74937 0.45608 lineto
0.74393 0.47942 lineto
0.73697 0.50236 lineto
0.72853 0.52479 lineto
0.70734 0.56777 lineto
0.68072 0.6076 lineto
0.64912 0.64363 lineto
0.6131 0.67522 lineto
0.57326 0.70184 lineto
0.55212 0.71314 lineto
0.53029 0.72303 lineto
0.50785 0.73148 lineto
0.48492 0.73843 lineto
0.46157 0.74388 lineto
0.44978 0.74602 lineto
0.43792 0.74778 lineto
0.42601 0.74915 lineto
0.42004 0.74969 lineto
0.41407 0.75013 lineto
0.40808 0.75047 lineto
0.40509 0.75061 lineto
0.40209 0.75072 lineto
0.3991 0.75081 lineto
0.3961 0.75087 lineto
0.39311 0.7509 lineto
0.39011 0.75092 lineto
0.38711 0.7509 lineto
0.38412 0.75087 lineto
0.38112 0.75081 lineto
0.37812 0.75072 lineto
0.37214 0.75047 lineto
0.36615 0.75013 lineto
0.36018 0.74969 lineto
0.35421 0.74915 lineto
0.3423 0.74778 lineto
0.33044 0.74602 lineto
0.31865 0.74388 lineto
0.2953 0.73843 lineto
Mistroke
0.27237 0.73148 lineto
0.24993 0.72303 lineto
0.20696 0.70184 lineto
0.16712 0.67522 lineto
0.1311 0.64363 lineto
0.0995 0.6076 lineto
0.07288 0.56777 lineto
0.05169 0.52479 lineto
0.04325 0.50236 lineto
0.03629 0.47942 lineto
0.03085 0.45608 lineto
0.0287 0.44428 lineto
0.02694 0.43243 lineto
0.02557 0.42052 lineto
0.02503 0.41455 lineto
0.02459 0.40857 lineto
0.02425 0.40259 lineto
0.02412 0.3996 lineto
0.02401 0.3966 lineto
0.02392 0.3936 lineto
0.02386 0.39061 lineto
0.02382 0.38761 lineto
0.02381 0.38462 lineto
0.02382 0.38162 lineto
0.02386 0.37862 lineto
0.02392 0.37563 lineto
0.02401 0.37263 lineto
0.02425 0.36664 lineto
0.02459 0.36066 lineto
0.02503 0.35468 lineto
0.02557 0.34871 lineto
0.02694 0.3368 lineto
0.0287 0.32495 lineto
0.03085 0.31315 lineto
0.03629 0.28981 lineto
0.04325 0.26687 lineto
0.05169 0.24444 lineto
0.07288 0.20147 lineto
0.0995 0.16163 lineto
0.1311 0.1256 lineto
0.16712 0.09401 lineto
0.20696 0.06739 lineto
0.2281 0.05609 lineto
0.24993 0.0462 lineto
0.27237 0.03775 lineto
0.2953 0.0308 lineto
0.31865 0.02535 lineto
0.33044 0.02321 lineto
0.3423 0.02145 lineto
0.35421 0.02008 lineto
Mistroke
0.36018 0.01954 lineto
0.36615 0.0191 lineto
0.37214 0.01876 lineto
0.37513 0.01862 lineto
0.37812 0.01851 lineto
0.38112 0.01843 lineto
0.38412 0.01836 lineto
0.38711 0.01833 lineto
0.39011 0.01832 lineto
0.39311 0.01833 lineto
0.3961 0.01836 lineto
0.3991 0.01843 lineto
0.40209 0.01851 lineto
0.40808 0.01876 lineto
0.41407 0.0191 lineto
0.42004 0.01954 lineto
0.42601 0.02008 lineto
0.43792 0.02145 lineto
0.44978 0.02321 lineto
0.46157 0.02535 lineto
0.48492 0.0308 lineto
0.50785 0.03775 lineto
0.53029 0.0462 lineto
0.57326 0.06739 lineto
0.6131 0.09401 lineto
0.64912 0.1256 lineto
0.68072 0.16163 lineto
0.70734 0.20147 lineto
0.71863 0.2226 lineto
0.72853 0.24444 lineto
0.73697 0.26687 lineto
0.74393 0.28981 lineto
0.74937 0.31315 lineto
0.75152 0.32495 lineto
0.75328 0.3368 lineto
0.75465 0.34871 lineto
0.75519 0.35468 lineto
0.75563 0.36066 lineto
0.75597 0.36664 lineto
0.7561 0.36964 lineto
0.75621 0.37263 lineto
0.7563 0.37563 lineto
0.75636 0.37862 lineto
0.7564 0.38162 lineto
0.75641 0.38462 lineto
Mfstroke
grestore
grestore
gsave
gsave
0.005 setlinewidth
0.97619 0.38462 moveto
0.97613 0.37982 lineto
0.97596 0.37503 lineto
0.97566 0.37025 lineto
0.97525 0.36548 lineto
0.97472 0.36073 lineto
0.97408 0.356 lineto
0.97246 0.34661 lineto
0.97039 0.33735 lineto
0.96788 0.32826 lineto
0.96165 0.31065 lineto
0.9539 0.29399 lineto
0.94482 0.27844 lineto
0.92347 0.25112 lineto
0.89922 0.22921 lineto
0.88649 0.2203 lineto
0.87359 0.21268 lineto
0.86066 0.20631 lineto
0.84782 0.2011 lineto
0.83518 0.19697 lineto
0.82282 0.19382 lineto
0.81677 0.19259 lineto
0.81081 0.19157 lineto
0.80495 0.19075 lineto
0.79919 0.19012 lineto
0.79635 0.18987 lineto
0.79354 0.18967 lineto
0.79076 0.18951 lineto
0.78801 0.18939 lineto
0.78528 0.18931 lineto
0.78258 0.18926 lineto
0.77992 0.18926 lineto
0.77728 0.18929 lineto
0.77467 0.18935 lineto
0.77209 0.18945 lineto
0.76701 0.18974 lineto
0.76452 0.18994 lineto
0.76206 0.19016 lineto
0.75722 0.19069 lineto
0.7479 0.19205 lineto
0.73905 0.19378 lineto
0.72268 0.19811 lineto
0.708 0.20334 lineto
0.68315 0.21543 lineto
0.66333 0.22854 lineto
0.6475 0.24183 lineto
0.62454 0.2674 lineto
0.60946 0.29082 lineto
0.59942 0.31211 lineto
0.59575 0.32208 lineto
Mistroke
0.59278 0.33168 lineto
0.59041 0.34096 lineto
0.58856 0.34999 lineto
0.58718 0.35882 lineto
0.58665 0.36318 lineto
0.58622 0.3675 lineto
0.58589 0.3718 lineto
0.58576 0.37394 lineto
0.58566 0.37608 lineto
0.58557 0.37822 lineto
0.58554 0.37929 lineto
0.58552 0.38035 lineto
0.5855 0.38142 lineto
0.58549 0.38195 lineto
0.58548 0.38248 lineto
0.58548 0.38302 lineto
0.58547 0.38355 lineto
0.58547 0.38408 lineto
0.58547 0.38462 lineto
0.58547 0.38515 lineto
0.58547 0.38568 lineto
0.58548 0.38621 lineto
0.58548 0.38675 lineto
0.5855 0.38781 lineto
0.58552 0.38888 lineto
0.58554 0.38994 lineto
0.58557 0.39101 lineto
0.58566 0.39315 lineto
0.58576 0.39529 lineto
0.58589 0.39743 lineto
0.58622 0.40173 lineto
0.58665 0.40605 lineto
0.58718 0.41041 lineto
0.58856 0.41924 lineto
0.59041 0.42827 lineto
0.59278 0.43755 lineto
0.59942 0.45712 lineto
0.60946 0.47842 lineto
0.62454 0.50183 lineto
0.63479 0.51438 lineto
0.6475 0.5274 lineto
0.66333 0.54069 lineto
0.68315 0.5538 lineto
0.69488 0.56005 lineto
0.708 0.56589 lineto
0.72268 0.57112 lineto
0.73064 0.57342 lineto
0.73905 0.57545 lineto
0.7479 0.57718 lineto
0.75722 0.57854 lineto
Mistroke
0.76206 0.57907 lineto
0.76452 0.57929 lineto
0.76701 0.57949 lineto
0.76953 0.57965 lineto
0.77209 0.57978 lineto
0.77467 0.57988 lineto
0.77728 0.57994 lineto
0.77992 0.57997 lineto
0.78258 0.57997 lineto
0.78528 0.57992 lineto
0.78801 0.57984 lineto
0.79076 0.57972 lineto
0.79354 0.57956 lineto
0.79635 0.57936 lineto
0.79919 0.57911 lineto
0.81081 0.57766 lineto
0.81677 0.57664 lineto
0.82282 0.57541 lineto
0.83518 0.57226 lineto
0.84782 0.56813 lineto
0.86066 0.56292 lineto
0.87359 0.55655 lineto
0.89922 0.54002 lineto
0.92347 0.51811 lineto
0.94482 0.49079 lineto
0.9539 0.47524 lineto
0.96165 0.45858 lineto
0.96496 0.44989 lineto
0.96788 0.44098 lineto
0.97039 0.43188 lineto
0.97246 0.42262 lineto
0.97408 0.41324 lineto
0.97472 0.4085 lineto
0.97525 0.40375 lineto
0.97566 0.39898 lineto
0.97596 0.3942 lineto
0.97613 0.38941 lineto
0.97619 0.38462 lineto
Mfstroke
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(Magnitude Response \(dB\))] 0.5 1.00625 0 -1 Msboxa
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(2)] 0.22713 0.24513 0.937996 1 Msboxa
[(4)] 0.41092 0.17284 0.805265 1 Msboxa
[(6)] 0.60991 0.09464 0.672535 1 Msboxa
[(w1)] 0.2914 0.15947 0.862234 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(2)] 0.74881 0.2292 -1 0.357287 Msboxa
[(4)] 0.82841 0.3511 -1 0.328525 Msboxa
[(6)] 0.89811 0.45785 -1 0.304048 Msboxa
[(w2)] 0.85193 0.28164 -1 0.340282 Msboxa
[(0)] 0.04708 0.37105 1 -0.381773 Msboxa
[(10)] 0.03751 0.43102 1 -0.369079 Msboxa
[(20)] 0.02752 0.49363 1 -0.355767 Msboxa
[( )] -0.01735 0.44567 1 -0.370357 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 1.00625 0 -1 Mshowa
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.2312 0.24947 moveto
0.23935 0.25816 lineto
stroke
0 setgray
[(2)] 0.22713 0.24513 0.937996 1 Mshowa
0.41465 0.17748 moveto
0.42212 0.18675 lineto
stroke
0 setgray
[(4)] 0.41092 0.17284 0.805265 1 Mshowa
0.61324 0.09958 moveto
0.61988 0.10945 lineto
stroke
0 setgray
[(6)] 0.60991 0.09464 0.672535 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.7432 0.2312 moveto
0.73199 0.23521 lineto
stroke
0 setgray
[(2)] 0.74881 0.2292 -1 0.357287 Mshowa
0.82275 0.35296 moveto
0.81144 0.35668 lineto
stroke
0 setgray
[(4)] 0.82841 0.3511 -1 0.328525 Mshowa
0.89242 0.45959 moveto
0.88103 0.46305 lineto
stroke
0 setgray
[(6)] 0.89811 0.45785 -1 0.304048 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05264 0.36893 moveto
0.06376 0.36469 lineto
stroke
0 setgray
[(0)] 0.04708 0.37105 1 -0.381773 Mshowa
0.04309 0.42896 moveto
0.05426 0.42484 lineto
stroke
0 setgray
[(10)] 0.03751 0.43102 1 -0.369079 Mshowa
0.03313 0.49164 moveto
0.04434 0.48765 lineto
stroke
0 setgray
[(20)] 0.02752 0.49363 1 -0.355767 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.46955 setgray
0.0015 setlinewidth
0.37037 0.6933 0.38999 0.72617 0.42386 0.71189 0.40328 0.71522 Metetra
0.60158 setgray
0.40328 0.71522 0.42386 0.71189 0.45818 0.69237 0.43663 0.77497 Metetra
0.88095 setgray
0.43663 0.77497 0.45818 0.69237 0.49276 0.67303 0.47325 0.69464 Metetra
0.59804 setgray
0.47325 0.69464 0.49276 0.67303 0.52764 0.65561 0.50889 0.65294 Metetra
0.46779 setgray
0.50889 0.65294 0.52764 0.65561 0.5629 0.64029 0.54453 0.62518 Metetra
0.39522 setgray
0.54453 0.62518 0.5629 0.64029 0.59861 0.62695 0.58045 0.60373 Metetra
0.34964 setgray
0.58045 0.60373 0.59861 0.62695 0.63487 0.61548 0.6168 0.58615 Metetra
0.32103 setgray
0.6168 0.58615 0.63487 0.61548 0.67174 0.60586 0.65367 0.57141 Metetra
0.30514 setgray
0.65367 0.57141 0.67174 0.60586 0.70932 0.59814 0.69116 0.55907 Metetra
0.30008 setgray
0.69116 0.55907 0.70932 0.59814 0.74773 0.59249 0.72938 0.54902 Metetra
0.30533 setgray
0.72938 0.54902 0.74773 0.59249 0.78706 0.58908 0.76844 0.54144 Metetra
0.32145 setgray
0.76844 0.54144 0.78706 0.58908 0.82744 0.58776 0.80852 0.53681 Metetra
0.35033 setgray
0.80852 0.53681 0.82744 0.58776 0.86874 0.58676 0.84991 0.53629 Metetra
0.39629 setgray
0.84991 0.53629 0.86874 0.58676 0.91024 0.58035 0.89317 0.54257 Metetra
0.38423 setgray
0.35067 0.65494 0.37037 0.6933 0.40328 0.71522 0.38388 0.66509 Metetra
0.46941 setgray
0.38388 0.66509 0.40328 0.71522 0.43663 0.77497 0.41817 0.67022 Metetra
0.53282 setgray
0.41817 0.67022 0.43663 0.77497 0.47325 0.69464 0.45377 0.64434 Metetra
0.46843 setgray
0.45377 0.64434 0.47325 0.69464 0.50889 0.65294 0.48955 0.61343 Metetra
0.38346 setgray
0.48955 0.61343 0.50889 0.65294 0.54453 0.62518 0.52543 0.58821 Metetra
0.32269 setgray
0.52543 0.58821 0.54453 0.62518 0.58045 0.60373 0.56158 0.5675 Metetra
0.28153 setgray
0.56158 0.5675 0.58045 0.60373 0.6168 0.58615 0.59815 0.55005 Metetra
0.25487 setgray
0.59815 0.55005 0.6168 0.58615 0.65367 0.57141 0.63523 0.53517 Metetra
0.23983 setgray
0.63523 0.53517 0.65367 0.57141 0.69116 0.55907 0.67291 0.52252 Metetra
0.235 setgray
0.67291 0.52252 0.69116 0.55907 0.72938 0.54902 0.7113 0.51202 Metetra
0.23994 setgray
0.7113 0.51202 0.72938 0.54902 0.76844 0.54144 0.75052 0.50381 Metetra
0.25508 setgray
0.75052 0.50381 0.76844 0.54144 0.80852 0.53681 0.79072 0.49826 Metetra
0.28188 setgray
0.79072 0.49826 0.80852 0.53681 0.84991 0.53629 0.83214 0.49615 Metetra
0.32322 setgray
0.83214 0.49615 0.84991 0.53629 0.89317 0.54257 0.87512 0.49887 Metetra
0.32325 setgray
0.33039 0.62178 0.35067 0.65494 0.38388 0.66509 0.36403 0.62213 Metetra
0.36885 setgray
0.36403 0.62213 0.38388 0.66509 0.41817 0.67022 0.39868 0.61401 Metetra
0.37903 setgray
0.39868 0.61401 0.41817 0.67022 0.45377 0.64434 0.43415 0.59453 Metetra
0.34227 setgray
0.43415 0.59453 0.45377 0.64434 0.48955 0.61343 0.46997 0.57196 Metetra
0.29319 setgray
0.46997 0.57196 0.48955 0.61343 0.52543 0.58821 0.50603 0.55105 Metetra
0.25177 setgray
0.50603 0.55105 0.52543 0.58821 0.56158 0.5675 0.54243 0.53256 Metetra
0.22139 setgray
0.54243 0.53256 0.56158 0.5675 0.59815 0.55005 0.57926 0.51635 Metetra
0.20141 setgray
0.57926 0.51635 0.59815 0.55005 0.63523 0.53517 0.61662 0.50217 Metetra
0.19087 setgray
0.61662 0.50217 0.63523 0.53517 0.67291 0.52252 0.65459 0.48991 Metetra
0.18919 setgray
0.65459 0.48991 0.67291 0.52252 0.7113 0.51202 0.69326 0.47956 Metetra
0.1963 setgray
0.69326 0.47956 0.7113 0.51202 0.75052 0.50381 0.73276 0.47123 Metetra
0.21257 setgray
0.73276 0.47123 0.75052 0.50381 0.79072 0.49826 0.7732 0.46517 Metetra
0.23884 setgray
0.7732 0.46517 0.79072 0.49826 0.83214 0.49615 0.81476 0.46166 Metetra
0.27606 setgray
0.81476 0.46166 0.83214 0.49615 0.87512 0.49887 0.85754 0.46053 Metetra
0.28196 setgray
0.30946 0.59267 0.33039 0.62178 0.36403 0.62213 0.34349 0.58751 Metetra
0.30566 setgray
0.34349 0.58751 0.36403 0.62213 0.39868 0.61401 0.37844 0.57508 Metetra
0.29919 setgray
0.37844 0.57508 0.39868 0.61401 0.43415 0.59453 0.41404 0.55664 Metetra
0.26812 setgray
0.41404 0.55664 0.43415 0.59453 0.46997 0.57196 0.45001 0.53677 Metetra
0.23181 setgray
0.45001 0.53677 0.46997 0.57196 0.50603 0.55105 0.4863 0.51798 Metetra
0.20077 setgray
0.4863 0.51798 0.50603 0.55105 0.54243 0.53256 0.52297 0.50091 Metetra
0.17786 setgray
0.52297 0.50091 0.54243 0.53256 0.57926 0.51635 0.56009 0.48563 Metetra
0.16334 setgray
0.56009 0.48563 0.57926 0.51635 0.61662 0.50217 0.59776 0.47207 Metetra
0.15695 setgray
0.59776 0.47207 0.61662 0.50217 0.65459 0.48991 0.63605 0.46022 Metetra
0.15851 setgray
0.63605 0.46022 0.65459 0.48991 0.69326 0.47956 0.67506 0.45008 Metetra
0.16807 setgray
0.67506 0.45008 0.69326 0.47956 0.73276 0.47123 0.71489 0.44175 Metetra
0.18587 setgray
0.71489 0.44175 0.73276 0.47123 0.7732 0.46517 0.75565 0.43531 Metetra
0.21209 setgray
0.75565 0.43531 0.7732 0.46517 0.81476 0.46166 0.79744 0.43057 Metetra
0.24582 setgray
0.79744 0.43057 0.81476 0.46166 0.85754 0.46053 0.84021 0.42632 Metetra
0.25522 setgray
0.28787 0.56638 0.30946 0.59267 0.34349 0.58751 0.32229 0.55753 Metetra
0.26466 setgray
0.32229 0.55753 0.34349 0.58751 0.37844 0.57508 0.35755 0.54279 Metetra
0.24985 setgray
0.35755 0.54279 0.37844 0.57508 0.41404 0.55664 0.39338 0.52453 Metetra
0.22096 setgray
0.39338 0.52453 0.41404 0.55664 0.45001 0.53677 0.42958 0.5058 Metetra
0.19093 setgray
0.42958 0.5058 0.45001 0.53677 0.4863 0.51798 0.46613 0.48811 Metetra
0.16608 setgray
0.46613 0.48811 0.4863 0.51798 0.52297 0.50091 0.5031 0.47191 Metetra
0.14836 setgray
0.5031 0.47191 0.52297 0.50091 0.56009 0.48563 0.54054 0.45727 Metetra
0.13812 setgray
0.54054 0.45727 0.56009 0.48563 0.59776 0.47207 0.57855 0.4442 Metetra
0.13531 setgray
0.57855 0.4442 0.59776 0.47207 0.63605 0.46022 0.6172 0.43269 Metetra
0.13988 setgray
0.6172 0.43269 0.63605 0.46022 0.67506 0.45008 0.65658 0.42278 Metetra
0.15191 setgray
0.65658 0.42278 0.67506 0.45008 0.71489 0.44175 0.69679 0.41449 Metetra
0.17139 setgray
0.69679 0.41449 0.71489 0.44175 0.75565 0.43531 0.73792 0.40772 Metetra
0.19775 setgray
0.73792 0.40772 0.75565 0.43531 0.79744 0.43057 0.78 0.40183 Metetra
0.22833 setgray
0.78 0.40183 0.79744 0.43057 0.84021 0.42632 0.82289 0.39491 Metetra
0.24012 setgray
0.26556 0.54223 0.28787 0.56638 0.32229 0.55753 0.3004 0.53054 Metetra
0.23888 setgray
0.3004 0.53054 0.32229 0.55753 0.35755 0.54279 0.33601 0.51419 Metetra
0.21874 setgray
0.33601 0.51419 0.35755 0.54279 0.39338 0.52453 0.37212 0.49583 Metetra
0.19097 setgray
0.37212 0.49583 0.39338 0.52453 0.42958 0.5058 0.4086 0.47765 Metetra
0.16478 setgray
0.4086 0.47765 0.42958 0.5058 0.46613 0.48811 0.44546 0.4606 Metetra
0.14418 setgray
0.44546 0.4606 0.46613 0.48811 0.5031 0.47191 0.48275 0.44496 Metetra
0.13041 setgray
0.48275 0.44496 0.5031 0.47191 0.54054 0.45727 0.52054 0.4308 Metetra
0.12373 setgray
0.52054 0.4308 0.54054 0.45727 0.57855 0.4442 0.55891 0.41812 Metetra
0.12413 setgray
0.55891 0.41812 0.57855 0.4442 0.6172 0.43269 0.59795 0.40694 Metetra
0.13161 setgray
0.59795 0.40694 0.6172 0.43269 0.65658 0.42278 0.63774 0.39727 Metetra
0.14617 setgray
0.63774 0.39727 0.65658 0.42278 0.69679 0.41449 0.67837 0.38906 Metetra
0.1675 setgray
0.67837 0.38906 0.69679 0.41449 0.73792 0.40772 0.71991 0.38199 Metetra
0.19415 setgray
0.71991 0.38199 0.73792 0.40772 0.78 0.40183 0.76235 0.37498 Metetra
0.22162 setgray
0.76235 0.37498 0.78 0.40183 0.82289 0.39491 0.80545 0.36558 Metetra
0.23524 setgray
0.24248 0.5199 0.26556 0.54223 0.3004 0.53054 0.27778 0.50575 Metetra
0.22502 setgray
0.27778 0.50575 0.3004 0.53054 0.33601 0.51419 0.31377 0.48809 Metetra
0.2009 setgray
0.31377 0.48809 0.33601 0.51419 0.37212 0.49583 0.35021 0.46952 Metetra
0.17381 setgray
0.35021 0.46952 0.37212 0.49583 0.4086 0.47765 0.38701 0.45161 Metetra
0.15033 setgray
0.38701 0.45161 0.4086 0.47765 0.44546 0.4606 0.4242 0.43495 Metetra
0.13301 setgray
0.4242 0.43495 0.44546 0.4606 0.48275 0.44496 0.46184 0.41972 Metetra
0.12254 setgray
0.46184 0.41972 0.48275 0.44496 0.52054 0.4308 0.5 0.40594 Metetra
0.11905 setgray
0.5 0.40594 0.52054 0.4308 0.55891 0.41812 0.53876 0.39363 Metetra
0.12254 setgray
0.53876 0.39363 0.55891 0.41812 0.59795 0.40694 0.57822 0.38279 Metetra
0.13301 setgray
0.57822 0.38279 0.59795 0.40694 0.63774 0.39727 0.61845 0.37342 Metetra
0.15033 setgray
0.61845 0.37342 0.63774 0.39727 0.67837 0.38906 0.65954 0.36537 Metetra
0.17381 setgray
0.65954 0.36537 0.67837 0.38906 0.71991 0.38199 0.70155 0.35805 Metetra
0.2009 setgray
0.70155 0.35805 0.71991 0.38199 0.76235 0.37498 0.74439 0.34983 Metetra
0.22502 setgray
0.74439 0.34983 0.76235 0.37498 0.80545 0.36558 0.78778 0.33797 Metetra
0.24012 setgray
0.21854 0.4993 0.24248 0.5199 0.27778 0.50575 0.25436 0.48281 Metetra
0.22162 setgray
0.25436 0.48281 0.27778 0.50575 0.31377 0.48809 0.29078 0.46397 Metetra
0.19415 setgray
0.29078 0.46397 0.31377 0.48809 0.35021 0.46952 0.32759 0.44512 Metetra
0.1675 setgray
0.32759 0.44512 0.35021 0.46952 0.38701 0.45161 0.36474 0.42733 Metetra
0.14617 setgray
0.36474 0.42733 0.38701 0.45161 0.4242 0.43495 0.40229 0.41095 Metetra
0.13161 setgray
0.40229 0.41095 0.4242 0.43495 0.46184 0.41972 0.4403 0.39605 Metetra
0.12413 setgray
0.4403 0.39605 0.46184 0.41972 0.5 0.40594 0.47886 0.38263 Metetra
0.12373 setgray
0.47886 0.38263 0.5 0.40594 0.53876 0.39363 0.51804 0.3707 Metetra
0.13041 setgray
0.51804 0.3707 0.53876 0.39363 0.57822 0.38279 0.55794 0.36029 Metetra
0.14418 setgray
0.55794 0.36029 0.57822 0.38279 0.61845 0.37342 0.59865 0.35135 Metetra
0.16478 setgray
0.59865 0.35135 0.61845 0.37342 0.65954 0.36537 0.64026 0.34361 Metetra
0.19097 setgray
0.64026 0.34361 0.65954 0.36537 0.70155 0.35805 0.68278 0.33609 Metetra
0.21874 setgray
0.68278 0.33609 0.70155 0.35805 0.74439 0.34983 0.72608 0.3265 Metetra
0.23888 setgray
0.72608 0.3265 0.74439 0.34983 0.78778 0.33797 0.76981 0.31196 Metetra
0.25522 setgray
0.19363 0.48056 0.21854 0.4993 0.25436 0.48281 0.23005 0.46167 Metetra
0.22833 setgray
0.23005 0.46167 0.25436 0.48281 0.29078 0.46397 0.26694 0.44168 Metetra
0.19775 setgray
0.26694 0.44168 0.29078 0.46397 0.32759 0.44512 0.30416 0.4225 Metetra
0.17139 setgray
0.30416 0.4225 0.32759 0.44512 0.36474 0.42733 0.3417 0.40475 Metetra
0.15191 setgray
0.3417 0.40475 0.36474 0.42733 0.40229 0.41095 0.37964 0.38858 Metetra
0.13988 setgray
0.37964 0.38858 0.40229 0.41095 0.4403 0.39605 0.41805 0.37398 Metetra
0.13531 setgray
0.41805 0.37398 0.4403 0.39605 0.47886 0.38263 0.45703 0.36095 Metetra
0.13812 setgray
0.45703 0.36095 0.47886 0.38263 0.51804 0.3707 0.49666 0.3495 Metetra
0.14836 setgray
0.49666 0.3495 0.51804 0.3707 0.55794 0.36029 0.53705 0.33969 Metetra
0.16608 setgray
0.53705 0.33969 0.55794 0.36029 0.59865 0.35135 0.57828 0.33143 Metetra
0.19093 setgray
0.57828 0.33143 0.59865 0.35135 0.64026 0.34361 0.62045 0.32429 Metetra
0.22096 setgray
0.62045 0.32429 0.64026 0.34361 0.68278 0.33609 0.66356 0.31671 Metetra
0.24985 setgray
0.66356 0.31671 0.68278 0.33609 0.72608 0.3265 0.70737 0.30539 Metetra
0.26466 setgray
0.70737 0.30539 0.72608 0.3265 0.76981 0.31196 0.75149 0.28768 Metetra
0.28196 setgray
0.16761 0.46407 0.19363 0.48056 0.23005 0.46167 0.20473 0.44252 Metetra
0.24582 setgray
0.20473 0.44252 0.23005 0.46167 0.26694 0.44168 0.24216 0.42133 Metetra
0.21209 setgray
0.24216 0.42133 0.26694 0.44168 0.30416 0.4225 0.27982 0.40176 Metetra
0.18587 setgray
0.27982 0.40176 0.30416 0.4225 0.3417 0.40475 0.31779 0.38401 Metetra
0.16807 setgray
0.31779 0.38401 0.3417 0.40475 0.37964 0.38858 0.35615 0.36802 Metetra
0.15851 setgray
0.35615 0.36802 0.37964 0.38858 0.41805 0.37398 0.39499 0.35376 Metetra
0.15695 setgray
0.39499 0.35376 0.41805 0.37398 0.45703 0.36095 0.43442 0.3412 Metetra
0.16334 setgray
0.43442 0.3412 0.45703 0.36095 0.49666 0.3495 0.47454 0.33043 Metetra
0.17786 setgray
0.47454 0.33043 0.49666 0.3495 0.53705 0.33969 0.51544 0.32153 Metetra
0.20077 setgray
0.51544 0.32153 0.53705 0.33969 0.57828 0.33143 0.55725 0.31448 Metetra
0.23181 setgray
0.55725 0.31448 0.57828 0.33143 0.62045 0.32429 0.60007 0.30859 Metetra
0.26812 setgray
0.60007 0.30859 0.62045 0.32429 0.66356 0.31671 0.64385 0.30123 Metetra
0.29919 setgray
0.64385 0.30123 0.66356 0.31671 0.70737 0.30539 0.68823 0.28737 Metetra
0.30566 setgray
0.68823 0.28737 0.70737 0.30539 0.75149 0.28768 0.73278 0.26552 Metetra
0.32325 setgray
0.14026 0.45063 0.16761 0.46407 0.20473 0.44252 0.17823 0.42588 Metetra
0.27606 setgray
0.17823 0.42588 0.20473 0.44252 0.24216 0.42133 0.21627 0.40338 Metetra
0.23884 setgray
0.21627 0.40338 0.24216 0.42133 0.27982 0.40176 0.25443 0.38335 Metetra
0.21257 setgray
0.25443 0.38335 0.27982 0.40176 0.31779 0.38401 0.29287 0.36554 Metetra
0.1963 setgray
0.29287 0.36554 0.31779 0.38401 0.35615 0.36802 0.33168 0.34974 Metetra
0.18919 setgray
0.33168 0.34974 0.35615 0.36802 0.39499 0.35376 0.371 0.33586 Metetra
0.19087 setgray
0.371 0.33586 0.39499 0.35376 0.43442 0.3412 0.41091 0.32395 Metetra
0.20141 setgray
0.41091 0.32395 0.43442 0.3412 0.47454 0.33043 0.45153 0.31416 Metetra
0.22139 setgray
0.45153 0.31416 0.47454 0.33043 0.51544 0.32153 0.493 0.30679 Metetra
0.25177 setgray
0.493 0.30679 0.51544 0.32153 0.55725 0.31448 0.53545 0.30206 Metetra
0.29319 setgray
0.53545 0.30206 0.55725 0.31448 0.60007 0.30859 0.57904 0.29918 Metetra
0.34227 setgray
0.57904 0.29918 0.60007 0.30859 0.64385 0.30123 0.62368 0.29301 Metetra
0.37903 setgray
0.62368 0.29301 0.64385 0.30123 0.68823 0.28737 0.66867 0.2744 Metetra
0.36885 setgray
0.66867 0.2744 0.68823 0.28737 0.73278 0.26552 0.71364 0.24627 Metetra
0.38423 setgray
0.1112 0.44162 0.14026 0.45063 0.17823 0.42588 0.15027 0.41287 Metetra
0.32322 setgray
0.15027 0.41287 0.17823 0.42588 0.21627 0.40338 0.18902 0.38885 Metetra
0.28188 setgray
0.18902 0.38885 0.21627 0.40338 0.25443 0.38335 0.22776 0.36822 Metetra
0.25508 setgray
0.22776 0.36822 0.25443 0.38335 0.29287 0.36554 0.26673 0.35024 Metetra
0.23994 setgray
0.26673 0.35024 0.29287 0.36554 0.33168 0.34974 0.30606 0.33455 Metetra
0.235 setgray
0.30606 0.33455 0.33168 0.34974 0.371 0.33586 0.34589 0.32106 Metetra
0.23983 setgray
0.34589 0.32106 0.371 0.33586 0.41091 0.32395 0.38633 0.30989 Metetra
0.25487 setgray
0.38633 0.30989 0.41091 0.32395 0.45153 0.31416 0.4275 0.30145 Metetra
0.28153 setgray
0.4275 0.30145 0.45153 0.31416 0.493 0.30679 0.46956 0.29654 Metetra
0.32269 setgray
0.46956 0.29654 0.493 0.30679 0.53545 0.30206 0.51272 0.2966 Metetra
0.38346 setgray
0.51272 0.2966 0.53545 0.30206 0.57904 0.29918 0.55731 0.30307 Metetra
0.46843 setgray
0.55731 0.30307 0.57904 0.29918 0.62368 0.29301 0.60326 0.30421 Metetra
0.53282 setgray
0.60326 0.30421 0.62368 0.29301 0.66867 0.2744 0.64875 0.27077 Metetra
0.46941 setgray
0.64875 0.27077 0.66867 0.2744 0.71364 0.24627 0.69408 0.23138 Metetra
0.46955 setgray
0.08002 0.43851 0.1112 0.44162 0.15027 0.41287 0.12032 0.40595 Metetra
0.39629 setgray
0.12032 0.40595 0.15027 0.41287 0.18902 0.38885 0.15993 0.38018 Metetra
0.35033 setgray
0.15993 0.38018 0.18902 0.38885 0.22776 0.36822 0.19941 0.35852 Metetra
0.32145 setgray
0.19941 0.35852 0.22776 0.36822 0.26673 0.35024 0.23904 0.33984 Metetra
0.30533 setgray
0.23904 0.33984 0.26673 0.35024 0.30606 0.33455 0.27902 0.32364 Metetra
0.30008 setgray
0.27902 0.32364 0.30606 0.33455 0.34589 0.32106 0.31947 0.30981 Metetra
0.30514 setgray
0.31947 0.30981 0.34589 0.32106 0.38633 0.30989 0.36053 0.2985 Metetra
0.32103 setgray
0.36053 0.2985 0.38633 0.30989 0.4275 0.30145 0.40233 0.29024 Metetra
0.34964 setgray
0.40233 0.29024 0.4275 0.30145 0.46956 0.29654 0.44501 0.28623 Metetra
0.39522 setgray
0.44501 0.28623 0.46956 0.29654 0.51272 0.2966 0.48882 0.28927 Metetra
0.46779 setgray
0.48882 0.28927 0.51272 0.2966 0.55731 0.30307 0.53428 0.30814 Metetra
0.59804 setgray
0.53428 0.30814 0.55731 0.30307 0.60326 0.30421 0.58313 0.37171 Metetra
0.88095 setgray
0.58313 0.37171 0.60326 0.30421 0.64875 0.27077 0.62813 0.27565 Metetra
0.60158 setgray
0.62813 0.27565 0.64875 0.27077 0.69408 0.23138 0.67403 0.22234 Metetra
0.53384 setgray
0.04823 0.42971 0.08002 0.43851 0.12032 0.40595 0.08734 0.41027 Metetra
0.51359 setgray
0.08734 0.41027 0.12032 0.40595 0.15993 0.38018 0.12771 0.38496 Metetra
0.47194 setgray
0.12771 0.38496 0.15993 0.38018 0.19941 0.35852 0.16844 0.35976 Metetra
0.43167 setgray
0.16844 0.35976 0.19941 0.35852 0.23904 0.33984 0.20932 0.33659 Metetra
0.40017 setgray
0.20932 0.33659 0.23904 0.33984 0.27902 0.32364 0.25045 0.31565 Metetra
0.37829 setgray
0.25045 0.31565 0.27902 0.32364 0.31947 0.30981 0.29196 0.29677 Metetra
0.3655 setgray
0.29196 0.29677 0.31947 0.30981 0.36053 0.2985 0.33398 0.27984 Metetra
0.3613 setgray
0.33398 0.27984 0.36053 0.2985 0.40233 0.29024 0.37661 0.2648 Metetra
0.3655 setgray
0.37661 0.2648 0.40233 0.29024 0.44501 0.28623 0.41999 0.25173 Metetra
0.37829 setgray
0.41999 0.25173 0.44501 0.28623 0.48882 0.28927 0.46424 0.24079 Metetra
0.40017 setgray
0.46424 0.24079 0.48882 0.28927 0.53428 0.30814 0.50953 0.23216 Metetra
0.43167 setgray
0.50953 0.23216 0.53428 0.30814 0.58313 0.37171 0.55601 0.22567 Metetra
0.47194 setgray
0.55601 0.22567 0.58313 0.37171 0.62813 0.27565 0.60378 0.21939 Metetra
0.51359 setgray
0.60378 0.21939 0.62813 0.27565 0.67403 0.22234 0.65256 0.20703 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.2312 0.24947 moveto
0.23935 0.25816 lineto
stroke
0 setgray
[(2)] 0.22713 0.24513 0.937996 1 Mshowa
0.41465 0.17748 moveto
0.42212 0.18675 lineto
stroke
0 setgray
[(4)] 0.41092 0.17284 0.805265 1 Mshowa
0.61324 0.09958 moveto
0.61988 0.10945 lineto
stroke
0 setgray
[(6)] 0.60991 0.09464 0.672535 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.7432 0.2312 moveto
0.73199 0.23521 lineto
stroke
0 setgray
[(2)] 0.74881 0.2292 -1 0.357287 Mshowa
0.82275 0.35296 moveto
0.81144 0.35668 lineto
stroke
0 setgray
[(4)] 0.82841 0.3511 -1 0.328525 Mshowa
0.89242 0.45959 moveto
0.88103 0.46305 lineto
stroke
0 setgray
[(6)] 0.89811 0.45785 -1 0.304048 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05264 0.36893 moveto
0.06376 0.36469 lineto
stroke
0 setgray
[(0)] 0.04708 0.37105 1 -0.381773 Mshowa
0.04309 0.42896 moveto
0.05426 0.42484 lineto
stroke
0 setgray
[(10)] 0.03751 0.43102 1 -0.369079 Mshowa
0.03313 0.49164 moveto
0.04434 0.48765 lineto
stroke
0 setgray
[(20)] 0.02752 0.49363 1 -0.355767 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(Phase Response \(degrees\))] 0.5 1.00625 0 -1 Msboxa
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(2)] 0.22713 0.24513 0.937996 1 Msboxa
[(4)] 0.41092 0.17284 0.805265 1 Msboxa
[(6)] 0.60991 0.09464 0.672535 1 Msboxa
[(w1)] 0.2914 0.15947 0.862234 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(2)] 0.74881 0.2292 -1 0.357287 Msboxa
[(4)] 0.82841 0.3511 -1 0.328525 Msboxa
[(6)] 0.89811 0.45785 -1 0.304048 Msboxa
[(w2)] 0.85193 0.28164 -1 0.340282 Msboxa
[(-100)] 0.0498 0.35397 1 -0.385381 Msboxa
[(0)] 0.04029 0.41361 1 -0.372771 Msboxa
[(100)] 0.03035 0.47588 1 -0.359549 Msboxa
[( )] -0.01735 0.44567 1 -0.370357 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 1.00625 0 -1 Mshowa
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.2312 0.24947 moveto
0.23935 0.25816 lineto
stroke
0 setgray
[(2)] 0.22713 0.24513 0.937996 1 Mshowa
0.41465 0.17748 moveto
0.42212 0.18675 lineto
stroke
0 setgray
[(4)] 0.41092 0.17284 0.805265 1 Mshowa
0.61324 0.09958 moveto
0.61988 0.10945 lineto
stroke
0 setgray
[(6)] 0.60991 0.09464 0.672535 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.7432 0.2312 moveto
0.73199 0.23521 lineto
stroke
0 setgray
[(2)] 0.74881 0.2292 -1 0.357287 Mshowa
0.82275 0.35296 moveto
0.81144 0.35668 lineto
stroke
0 setgray
[(4)] 0.82841 0.3511 -1 0.328525 Mshowa
0.89242 0.45959 moveto
0.88103 0.46305 lineto
stroke
0 setgray
[(6)] 0.89811 0.45785 -1 0.304048 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05536 0.35183 moveto
0.06647 0.34754 lineto
stroke
0 setgray
[(-100)] 0.0498 0.35397 1 -0.385381 Mshowa
0.04586 0.41153 moveto
0.05702 0.40737 lineto
stroke
0 setgray
[(0)] 0.04029 0.41361 1 -0.372771 Mshowa
0.03595 0.47386 moveto
0.04715 0.46983 lineto
stroke
0 setgray
[(100)] 0.03035 0.47588 1 -0.359549 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.74512 setgray
0.0015 setlinewidth
0.3676 0.75992 0.38703 0.81073 0.42602 0.62285 0.40183 0.76235 Metetra
0.79305 setgray
0.40183 0.76235 0.42602 0.62285 0.45901 0.63061 0.44008 0.60087 Metetra
0.15723 setgray
0.44008 0.60087 0.45901 0.63061 0.49285 0.63481 0.47373 0.638 Metetra
0.3619 setgray
0.47373 0.638 0.49285 0.63481 0.52747 0.6369 0.50885 0.63896 Metetra
0.40938 setgray
0.50885 0.63896 0.52747 0.6369 0.56285 0.63782 0.54471 0.63735 Metetra
0.44604 setgray
0.54471 0.63735 0.56285 0.63782 0.59898 0.63812 0.58128 0.63503 Metetra
0.47993 setgray
0.58128 0.63503 0.59898 0.63812 0.63587 0.63815 0.61859 0.63239 Metetra
0.51273 setgray
0.61859 0.63239 0.63587 0.63815 0.67357 0.63818 0.65666 0.62958 Metetra
0.54505 setgray
0.65666 0.62958 0.67357 0.63818 0.71212 0.6385 0.6955 0.62667 Metetra
0.57718 setgray
0.6955 0.62667 0.71212 0.6385 0.75159 0.63948 0.73514 0.6237 Metetra
0.60931 setgray
0.73514 0.6237 0.75159 0.63948 0.79209 0.64179 0.77562 0.62071 Metetra
0.64164 setgray
0.77562 0.62071 0.79209 0.64179 0.83384 0.64659 0.81697 0.61779 Metetra
0.67446 setgray
0.81697 0.61779 0.83384 0.64659 0.8772 0.65574 0.85923 0.61509 Metetra
0.70837 setgray
0.85923 0.61509 0.8772 0.65574 0.9225 0.67001 0.90252 0.61307 Metetra
0.66824 setgray
0.34735 0.72326 0.3676 0.75992 0.40183 0.76235 0.38222 0.70936 Metetra
0.65179 setgray
0.38222 0.70936 0.40183 0.76235 0.44008 0.60087 0.41788 0.68088 Metetra
0.5766 setgray
0.41788 0.68088 0.44008 0.60087 0.47373 0.638 0.45365 0.65248 Metetra
0.50205 setgray
0.45365 0.65248 0.47373 0.638 0.50885 0.63896 0.48947 0.63813 Metetra
0.48602 setgray
0.48947 0.63813 0.50885 0.63896 0.54471 0.63735 0.52578 0.62947 Metetra
0.49404 setgray
0.52578 0.62947 0.54471 0.63735 0.58128 0.63503 0.56272 0.62283 Metetra
0.51089 setgray
0.56272 0.62283 0.58128 0.63503 0.61859 0.63239 0.60036 0.61702 Metetra
0.53157 setgray
0.60036 0.61702 0.61859 0.63239 0.65666 0.62958 0.63872 0.61156 Metetra
0.55405 setgray
0.63872 0.61156 0.65666 0.62958 0.6955 0.62667 0.67783 0.60617 Metetra
0.57725 setgray
0.67783 0.60617 0.6955 0.62667 0.73514 0.6237 0.71769 0.60067 Metetra
0.60046 setgray
0.71769 0.60067 0.73514 0.6237 0.77562 0.62071 0.75832 0.59488 Metetra
0.62292 setgray
0.75832 0.59488 0.77562 0.62071 0.81697 0.61779 0.79971 0.58851 Metetra
0.64358 setgray
0.79971 0.58851 0.81697 0.61779 0.85923 0.61509 0.8418 0.58102 Metetra
0.66037 setgray
0.8418 0.58102 0.85923 0.61509 0.90252 0.61307 0.88439 0.57105 Metetra
0.61555 setgray
0.32647 0.69198 0.34735 0.72326 0.38222 0.70936 0.36164 0.67543 Metetra
0.58961 setgray
0.36164 0.67543 0.38222 0.70936 0.41788 0.68088 0.39735 0.65392 Metetra
0.54415 setgray
0.39735 0.65392 0.41788 0.68088 0.45365 0.65248 0.43327 0.63473 Metetra
0.50885 setgray
0.43327 0.63473 0.45365 0.65248 0.48947 0.63813 0.46947 0.62112 Metetra
0.49713 setgray
0.46947 0.62112 0.48947 0.63813 0.52578 0.62947 0.50615 0.61111 Metetra
0.50076 setgray
0.50615 0.61111 0.52578 0.62947 0.56272 0.62283 0.54344 0.60292 Metetra
0.51239 setgray
0.54344 0.60292 0.56272 0.62283 0.60036 0.61702 0.5814 0.59561 Metetra
0.52814 setgray
0.5814 0.59561 0.60036 0.61702 0.63872 0.61156 0.62007 0.58869 Metetra
0.54593 setgray
0.62007 0.58869 0.63872 0.61156 0.67783 0.60617 0.65947 0.58182 Metetra
0.56445 setgray
0.65947 0.58182 0.67783 0.60617 0.71769 0.60067 0.69961 0.57474 Metetra
0.58266 setgray
0.69961 0.57474 0.71769 0.60067 0.75832 0.59488 0.74048 0.56714 Metetra
0.59938 setgray
0.74048 0.56714 0.75832 0.59488 0.79971 0.58851 0.78205 0.55858 Metetra
0.61292 setgray
0.78205 0.55858 0.79971 0.58851 0.8418 0.58102 0.82421 0.54826 Metetra
0.62026 setgray
0.82421 0.54826 0.8418 0.58102 0.88439 0.57105 0.86673 0.53461 Metetra
0.57172 setgray
0.30506 0.66229 0.32647 0.69198 0.36164 0.67543 0.34049 0.64525 Metetra
0.54513 setgray
0.34049 0.64525 0.36164 0.67543 0.39735 0.65392 0.37634 0.62671 Metetra
0.51314 setgray
0.37634 0.62671 0.39735 0.65392 0.43327 0.63473 0.41248 0.6107 Metetra
0.49224 setgray
0.41248 0.6107 0.43327 0.63473 0.46947 0.62112 0.44897 0.59817 Metetra
0.48622 setgray
0.44897 0.59817 0.46947 0.62112 0.50615 0.61111 0.48597 0.58803 Metetra
0.4906 setgray
0.48597 0.58803 0.50615 0.61111 0.54344 0.60292 0.52358 0.57924 Metetra
0.50107 setgray
0.52358 0.57924 0.54344 0.60292 0.5814 0.59561 0.56186 0.57114 Metetra
0.5149 setgray
0.56186 0.57114 0.5814 0.59561 0.62007 0.58869 0.60084 0.5633 Metetra
0.53034 setgray
0.60084 0.5633 0.62007 0.58869 0.65947 0.58182 0.64055 0.55541 Metetra
0.54614 setgray
0.64055 0.55541 0.65947 0.58182 0.69961 0.57474 0.68098 0.54716 Metetra
0.56112 setgray
0.68098 0.54716 0.69961 0.57474 0.74048 0.56714 0.72213 0.53818 Metetra
0.57387 setgray
0.72213 0.53818 0.74048 0.56714 0.78205 0.55858 0.76394 0.52794 Metetra
0.58235 setgray
0.76394 0.52794 0.78205 0.55858 0.82421 0.54826 0.8063 0.51553 Metetra
0.58323 setgray
0.8063 0.51553 0.82421 0.54826 0.86673 0.53461 0.84898 0.4997 Metetra
0.53172 setgray
0.28314 0.63293 0.30506 0.66229 0.34049 0.64525 0.31881 0.61585 Metetra
0.50631 setgray
0.31881 0.61585 0.34049 0.64525 0.37634 0.62671 0.35485 0.59895 Metetra
0.48243 setgray
0.35485 0.59895 0.37634 0.62671 0.41248 0.6107 0.3912 0.58455 Metetra
0.46946 setgray
0.3912 0.58455 0.41248 0.6107 0.44897 0.59817 0.42797 0.57271 Metetra
0.46761 setgray
0.42797 0.57271 0.44897 0.59817 0.48597 0.58803 0.46527 0.5626 Metetra
0.47347 setgray
0.46527 0.5626 0.48597 0.58803 0.52358 0.57924 0.50319 0.55349 Metetra
0.48399 setgray
0.50319 0.55349 0.52358 0.57924 0.56186 0.57114 0.54178 0.54486 Metetra
0.49707 setgray
0.54178 0.54486 0.56186 0.57114 0.60084 0.5633 0.58108 0.53635 Metetra
0.51122 setgray
0.58108 0.53635 0.60084 0.5633 0.64055 0.55541 0.6211 0.52764 Metetra
0.52524 setgray
0.6211 0.52764 0.64055 0.55541 0.68098 0.54716 0.66185 0.51842 Metetra
0.53785 setgray
0.66185 0.51842 0.68098 0.54716 0.72213 0.53818 0.7033 0.50825 Metetra
0.54748 setgray
0.7033 0.50825 0.72213 0.53818 0.76394 0.52794 0.74539 0.49654 Metetra
0.55182 setgray
0.74539 0.49654 0.76394 0.52794 0.8063 0.51553 0.788 0.48239 Metetra
0.5476 setgray
0.788 0.48239 0.8063 0.51553 0.84898 0.4997 0.83093 0.46499 Metetra
0.49352 setgray
0.26072 0.60339 0.28314 0.63293 0.31881 0.61585 0.29663 0.58638 Metetra
0.46986 setgray
0.29663 0.58638 0.31881 0.61585 0.35485 0.59895 0.33286 0.57058 Metetra
0.45185 setgray
0.33286 0.57058 0.35485 0.59895 0.3912 0.58455 0.36943 0.55716 Metetra
0.44429 setgray
0.36943 0.55716 0.3912 0.58455 0.42797 0.57271 0.40645 0.54577 Metetra
0.44571 setgray
0.40645 0.54577 0.42797 0.57271 0.46527 0.5626 0.44404 0.5357 Metetra
0.45314 setgray
0.44404 0.5357 0.46527 0.5626 0.50319 0.55349 0.48226 0.52636 Metetra
0.46415 setgray
0.48226 0.52636 0.50319 0.55349 0.54178 0.54486 0.52116 0.51732 Metetra
0.47702 setgray
0.52116 0.51732 0.54178 0.54486 0.58108 0.53635 0.56078 0.50826 Metetra
0.49043 setgray
0.56078 0.50826 0.58108 0.53635 0.6211 0.52764 0.60113 0.49885 Metetra
0.50316 setgray
0.60113 0.49885 0.6211 0.52764 0.66185 0.51842 0.64221 0.48874 Metetra
0.51386 setgray
0.64221 0.48874 0.66185 0.51842 0.7033 0.50825 0.68398 0.47746 Metetra
0.52075 setgray
0.68398 0.47746 0.7033 0.50825 0.74539 0.49654 0.72637 0.46434 Metetra
0.52131 setgray
0.72637 0.46434 0.74539 0.49654 0.788 0.48239 0.76925 0.44858 Metetra
0.51257 setgray
0.76925 0.44858 0.788 0.48239 0.83093 0.46499 0.8125 0.4299 Metetra
0.45605 setgray
0.23779 0.57337 0.26072 0.60339 0.29663 0.58638 0.27392 0.55653 Metetra
0.43449 setgray
0.27392 0.55653 0.29663 0.58638 0.33286 0.57058 0.31035 0.54155 Metetra
0.42131 setgray
0.31035 0.54155 0.33286 0.57058 0.36943 0.55716 0.34714 0.52883 Metetra
0.41804 setgray
0.34714 0.52883 0.36943 0.55716 0.40645 0.54577 0.38441 0.51778 Metetra
0.42228 setgray
0.38441 0.51778 0.40645 0.54577 0.44404 0.5357 0.42227 0.50774 Metetra
0.43129 setgray
0.42227 0.50774 0.44404 0.5357 0.48226 0.52636 0.46078 0.49821 Metetra
0.44305 setgray
0.46078 0.49821 0.48226 0.52636 0.52116 0.51732 0.5 0.48883 Metetra
0.45605 setgray
0.5 0.48883 0.52116 0.51732 0.56078 0.50826 0.53994 0.47927 Metetra
0.46905 setgray
0.53994 0.47927 0.56078 0.50826 0.60113 0.49885 0.58063 0.46922 Metetra
0.48081 setgray
0.58063 0.46922 0.60113 0.49885 0.64221 0.48874 0.62205 0.45827 Metetra
0.48983 setgray
0.62205 0.45827 0.64221 0.48874 0.68398 0.47746 0.66415 0.44588 Metetra
0.49406 setgray
0.66415 0.44588 0.68398 0.47746 0.72637 0.46434 0.70686 0.43133 Metetra
0.49079 setgray
0.70686 0.43133 0.72637 0.46434 0.76925 0.44858 0.75005 0.41395 Metetra
0.47761 setgray
0.75005 0.41395 0.76925 0.44858 0.8125 0.4299 0.79364 0.39415 Metetra
0.41858 setgray
0.21435 0.54269 0.23779 0.57337 0.27392 0.55653 0.2507 0.52609 Metetra
0.39953 setgray
0.2507 0.52609 0.27392 0.55653 0.31035 0.54155 0.28731 0.51184 Metetra
0.39079 setgray
0.28731 0.51184 0.31035 0.54155 0.34714 0.52883 0.3243 0.49969 Metetra
0.39135 setgray
0.3243 0.49969 0.34714 0.52883 0.38441 0.51778 0.36182 0.48892 Metetra
0.39824 setgray
0.36182 0.48892 0.38441 0.51778 0.42227 0.50774 0.39994 0.47892 Metetra
0.40894 setgray
0.39994 0.47892 0.42227 0.50774 0.46078 0.49821 0.43875 0.46925 Metetra
0.42167 setgray
0.43875 0.46925 0.46078 0.49821 0.5 0.48883 0.47828 0.45958 Metetra
0.43508 setgray
0.47828 0.45958 0.5 0.48883 0.53994 0.47927 0.51855 0.44959 Metetra
0.44795 setgray
0.51855 0.44959 0.53994 0.47927 0.58063 0.46922 0.55958 0.43893 Metetra
0.45897 setgray
0.55958 0.43893 0.58063 0.46922 0.62205 0.45827 0.60135 0.42714 Metetra
0.46639 setgray
0.60135 0.42714 0.62205 0.45827 0.66415 0.44588 0.64381 0.41358 Metetra
0.46782 setgray
0.64381 0.41358 0.66415 0.44588 0.70686 0.43133 0.68685 0.39745 Metetra
0.46025 setgray
0.68685 0.39745 0.70686 0.43133 0.75005 0.41395 0.73034 0.37834 Metetra
0.44224 setgray
0.73034 0.37834 0.75005 0.41395 0.79364 0.39415 0.77431 0.3575 Metetra
0.38038 setgray
0.1904 0.51114 0.21435 0.54269 0.2507 0.52609 0.22693 0.49494 Metetra
0.3645 setgray
0.22693 0.49494 0.2507 0.52609 0.28731 0.51184 0.26371 0.48141 Metetra
0.36028 setgray
0.26371 0.48141 0.28731 0.51184 0.3243 0.49969 0.3009 0.46981 Metetra
0.36462 setgray
0.3009 0.46981 0.3243 0.49969 0.36182 0.48892 0.33864 0.45933 Metetra
0.37425 setgray
0.33864 0.45933 0.36182 0.48892 0.39994 0.47892 0.37703 0.44942 Metetra
0.38687 setgray
0.37703 0.44942 0.39994 0.47892 0.43875 0.46925 0.41613 0.43967 Metetra
0.40088 setgray
0.41613 0.43967 0.43875 0.46925 0.47828 0.45958 0.45597 0.42978 Metetra
0.41503 setgray
0.45597 0.42978 0.47828 0.45958 0.51855 0.44959 0.49658 0.41942 Metetra
0.42811 setgray
0.49658 0.41942 0.51855 0.44959 0.55958 0.43893 0.53797 0.4082 Metetra
0.43863 setgray
0.53797 0.4082 0.55958 0.43893 0.60135 0.42714 0.5801 0.39555 Metetra
0.44449 setgray
0.5801 0.39555 0.60135 0.42714 0.64381 0.41358 0.62293 0.38068 Metetra
0.44264 setgray
0.62293 0.38068 0.64381 0.41358 0.68685 0.39745 0.6663 0.36266 Metetra
0.42967 setgray
0.6663 0.36266 0.68685 0.39745 0.73034 0.37834 0.71012 0.34154 Metetra
0.40579 setgray
0.71012 0.34154 0.73034 0.37834 0.77431 0.3575 0.75447 0.31974 Metetra
0.34038 setgray
0.16596 0.47843 0.1904 0.51114 0.22693 0.49494 0.20263 0.46291 Metetra
0.32887 setgray
0.20263 0.46291 0.22693 0.49494 0.26371 0.48141 0.23954 0.45024 Metetra
0.32975 setgray
0.23954 0.45024 0.26371 0.48141 0.3009 0.46981 0.2769 0.43926 Metetra
0.33823 setgray
0.2769 0.43926 0.3009 0.46981 0.33864 0.45933 0.31486 0.42916 Metetra
0.35098 setgray
0.31486 0.42916 0.33864 0.45933 0.37703 0.44942 0.3535 0.41943 Metetra
0.36596 setgray
0.3535 0.41943 0.37703 0.44942 0.41613 0.43967 0.39288 0.40972 Metetra
0.38176 setgray
0.39288 0.40972 0.41613 0.43967 0.45597 0.42978 0.43304 0.39973 Metetra
0.3972 setgray
0.43304 0.39973 0.45597 0.42978 0.49658 0.41942 0.47399 0.38912 Metetra
0.41103 setgray
0.47399 0.38912 0.49658 0.41942 0.53797 0.4082 0.51575 0.37744 Metetra
0.4215 setgray
0.51575 0.37744 0.53797 0.4082 0.5801 0.39555 0.55828 0.36395 Metetra
0.42588 setgray
0.55828 0.36395 0.5801 0.39555 0.62293 0.38068 0.6015 0.3475 Metetra
0.41986 setgray
0.6015 0.3475 0.62293 0.38068 0.6663 0.36266 0.64521 0.32692 Metetra
0.39896 setgray
0.64521 0.32692 0.6663 0.36266 0.71012 0.34154 0.68933 0.30317 Metetra
0.36698 setgray
0.68933 0.30317 0.71012 0.34154 0.75447 0.31974 0.73408 0.28055 Metetra
0.29655 setgray
0.14108 0.44403 0.16596 0.47843 0.20263 0.46291 0.17779 0.42977 Metetra
0.29185 setgray
0.17779 0.42977 0.20263 0.46291 0.23954 0.45024 0.21477 0.41829 Metetra
0.29918 setgray
0.21477 0.41829 0.23954 0.45024 0.2769 0.43926 0.25226 0.40815 Metetra
0.31272 setgray
0.25226 0.40815 0.2769 0.43926 0.31486 0.42916 0.29041 0.39862 Metetra
0.32944 setgray
0.29041 0.39862 0.31486 0.42916 0.3535 0.41943 0.32928 0.38928 Metetra
0.34765 setgray
0.32928 0.38928 0.3535 0.41943 0.39288 0.40972 0.36894 0.37983 Metetra
0.36617 setgray
0.36894 0.37983 0.39288 0.40972 0.43304 0.39973 0.40942 0.37 Metetra
0.38396 setgray
0.40942 0.37 0.43304 0.39973 0.47399 0.38912 0.45073 0.35944 Metetra
0.39971 setgray
0.45073 0.35944 0.47399 0.38912 0.51575 0.37744 0.49289 0.3476 Metetra
0.41134 setgray
0.49289 0.3476 0.51575 0.37744 0.55828 0.36395 0.53586 0.33343 Metetra
0.41497 setgray
0.53586 0.33343 0.55828 0.36395 0.6015 0.3475 0.5795 0.315 Metetra
0.40325 setgray
0.5795 0.315 0.6015 0.3475 0.64521 0.32692 0.62355 0.29013 Metetra
0.36795 setgray
0.62355 0.29013 0.64521 0.32692 0.68933 0.30317 0.66791 0.26236 Metetra
0.32249 setgray
0.66791 0.26236 0.68933 0.30317 0.73408 0.28055 0.71309 0.23936 Metetra
0.24386 setgray
0.11595 0.40668 0.14108 0.44403 0.17779 0.42977 0.15246 0.3951 Metetra
0.25173 setgray
0.15246 0.3951 0.17779 0.42977 0.21477 0.41829 0.18938 0.38552 Metetra
0.26853 setgray
0.18938 0.38552 0.21477 0.41829 0.25226 0.40815 0.22693 0.37673 Metetra
0.28918 setgray
0.22693 0.37673 0.25226 0.40815 0.29041 0.39862 0.26522 0.36821 Metetra
0.31164 setgray
0.26522 0.36821 0.29041 0.39862 0.32928 0.38928 0.30429 0.35969 Metetra
0.33485 setgray
0.30429 0.35969 0.32928 0.38928 0.36894 0.37983 0.34421 0.351 Metetra
0.35805 setgray
0.34421 0.351 0.36894 0.37983 0.40942 0.37 0.38499 0.34193 Metetra
0.38053 setgray
0.38499 0.34193 0.40942 0.37 0.45073 0.35944 0.42668 0.3322 Metetra
0.40121 setgray
0.42668 0.3322 0.45073 0.35944 0.49289 0.3476 0.46928 0.32125 Metetra
0.41806 setgray
0.46928 0.32125 0.49289 0.3476 0.53586 0.33343 0.51277 0.30775 Metetra
0.42608 setgray
0.51277 0.30775 0.53586 0.33343 0.5795 0.315 0.55698 0.28765 Metetra
0.41005 setgray
0.55698 0.28765 0.5795 0.315 0.62355 0.29013 0.60128 0.25197 Metetra
0.3355 setgray
0.60128 0.25197 0.62355 0.29013 0.66791 0.26236 0.64572 0.21599 Metetra
0.26031 setgray
0.64572 0.21599 0.66791 0.26236 0.71309 0.23936 0.69141 0.19488 Metetra
0.16698 setgray
0.09116 0.36264 0.11595 0.40668 0.15246 0.3951 0.12681 0.35767 Metetra
0.20373 setgray
0.12681 0.35767 0.15246 0.3951 0.18938 0.38552 0.16337 0.35187 Metetra
0.23764 setgray
0.16337 0.35187 0.18938 0.38552 0.22693 0.37673 0.2008 0.34566 Metetra
0.27046 setgray
0.2008 0.34566 0.22693 0.37673 0.26522 0.36821 0.2391 0.33919 Metetra
0.30279 setgray
0.2391 0.33919 0.26522 0.36821 0.30429 0.35969 0.2783 0.33252 Metetra
0.33492 setgray
0.2783 0.33252 0.30429 0.35969 0.34421 0.351 0.31843 0.32569 Metetra
0.36705 setgray
0.31843 0.32569 0.34421 0.351 0.38499 0.34193 0.3595 0.31875 Metetra
0.39937 setgray
0.3595 0.31875 0.38499 0.34193 0.42668 0.3322 0.40155 0.31177 Metetra
0.43218 setgray
0.40155 0.31177 0.42668 0.3322 0.46928 0.32125 0.44463 0.3049 Metetra
0.46606 setgray
0.44463 0.3049 0.46928 0.32125 0.51277 0.30775 0.48878 0.29861 Metetra
0.50272 setgray
0.48878 0.29861 0.51277 0.30775 0.55698 0.28765 0.53412 0.29509 Metetra
0.5502 setgray
0.53412 0.29509 0.55698 0.28765 0.60128 0.25197 0.58205 0.33541 Metetra
0.75487 setgray
0.58205 0.33541 0.60128 0.25197 0.64572 0.21599 0.6221 0.14864 Metetra
0.11905 setgray
0.6221 0.14864 0.64572 0.21599 0.69141 0.19488 0.66882 0.14319 Metetra
0.88095 setgray
0.03332 0.52378 0.09116 0.36264 0.12681 0.35767 0.10158 0.31253 Metetra
0.12768 setgray
0.10158 0.31253 0.12681 0.35767 0.16337 0.35187 0.13671 0.31715 Metetra
0.20594 setgray
0.13671 0.31715 0.16337 0.35187 0.2008 0.34566 0.17344 0.31782 Metetra
0.26795 setgray
0.17344 0.31782 0.2008 0.34566 0.2391 0.33919 0.21149 0.31607 Metetra
0.32046 setgray
0.21149 0.31607 0.2391 0.33919 0.2783 0.33252 0.2507 0.31294 Metetra
0.36782 setgray
0.2507 0.31294 0.2783 0.33252 0.31843 0.32569 0.29103 0.30902 Metetra
0.41251 setgray
0.29103 0.30902 0.31843 0.32569 0.3595 0.31875 0.33245 0.3047 Metetra
0.45605 setgray
0.33245 0.3047 0.3595 0.31875 0.40155 0.31177 0.37498 0.30026 Metetra
0.49959 setgray
0.37498 0.30026 0.40155 0.31177 0.44463 0.3049 0.41866 0.29601 Metetra
0.54428 setgray
0.41866 0.29601 0.44463 0.3049 0.48878 0.29861 0.46355 0.29238 Metetra
0.59164 setgray
0.46355 0.29238 0.48878 0.29861 0.53412 0.29509 0.50974 0.29007 Metetra
0.64415 setgray
0.50974 0.29007 0.53412 0.29509 0.58205 0.33541 0.55738 0.29039 Metetra
0.70616 setgray
0.55738 0.29039 0.58205 0.33541 0.6221 0.14864 0.60677 0.29539 Metetra
0.78442 setgray
0.60677 0.29539 0.6221 0.14864 0.66882 0.14319 0.65831 0.30598 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.2312 0.24947 moveto
0.23935 0.25816 lineto
stroke
0 setgray
[(2)] 0.22713 0.24513 0.937996 1 Mshowa
0.41465 0.17748 moveto
0.42212 0.18675 lineto
stroke
0 setgray
[(4)] 0.41092 0.17284 0.805265 1 Mshowa
0.61324 0.09958 moveto
0.61988 0.10945 lineto
stroke
0 setgray
[(6)] 0.60991 0.09464 0.672535 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.7432 0.2312 moveto
0.73199 0.23521 lineto
stroke
0 setgray
[(2)] 0.74881 0.2292 -1 0.357287 Mshowa
0.82275 0.35296 moveto
0.81144 0.35668 lineto
stroke
0 setgray
[(4)] 0.82841 0.3511 -1 0.328525 Mshowa
0.89242 0.45959 moveto
0.88103 0.46305 lineto
stroke
0 setgray
[(6)] 0.89811 0.45785 -1 0.304048 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.05536 0.35183 moveto
0.06647 0.34754 lineto
stroke
0 setgray
[(-100)] 0.0498 0.35397 1 -0.385381 Mshowa
0.04586 0.41153 moveto
0.05702 0.40737 lineto
stroke
0 setgray
[(0)] 0.04029 0.41361 1 -0.372771 Mshowa
0.03595 0.47386 moveto
0.04715 0.46983 lineto
stroke
0 setgray
[(100)] 0.03035 0.47588 1 -0.359549 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
ZTransData[-10/(-10 + 5/z1 + 8/z2), 
  Rminus[{1/2, (4*Abs[(1 - 1/(2*z1))^(-1)])/5}], 
  Rplus[{DirectedInfinity[1], DirectedInfinity[1]}], 
  ZVariables[{z1, z2}]]
;[o]
                                              1
                                     4 Abs[--------]
                                                1
                                           1 - ----
                -10               1            2 z1
ZTransData[-------------, Rminus[{-, ---------------}], 
                 5    8           2         5
           -10 + -- + --
                 z1   z2
 
  Rplus[{Infinity, Infinity}], ZVariables[{z1, z2}]]
:[font = section; inactive; startGroup; Cclosed; ]
Analog Signal Processing Examples
:[font = subsection; inactive; startGroup; Cclosed; ]
Laplace Transforms
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Forward Laplace Transforms
:[font = input; startGroup; ]

?LaPlace
:[font = info; inactive; endGroup; ]
LaPlace[e, t] or LaPlace[e, t, s] gives the two-sided LaPlace
   transform of the expression e, which is a function of t, by
   returning an object of four slots which is tagged by LTransData:
   <transform>, <rminus>, <rplus>, <laplace_variables>.  The Region
   of Convergence (ROC) is defined as <rminus> < Re{s} < <rplus>.
   Note that the returned ROC is either the actual ROC or a subset
   of the actual ROC. In two dimensions, LaPlace[e, {t1, t2}, {s1,
   s2}] is the same as LaPlace [ LaPlace[e, t1, s1], t2, s2 ]. 
   This notation extends naturally to higher dimensions.  Note that
   the right sided transform is specified by multiplying by
   CStep[t].
:[font = input; startGroup; ]

LaPlace[ A t Exp[- (a + b) t / 2]
		 ( BesselI[0, (a - b) t / 2] -
		   BesselI[1, (a - b) t / 2] ) CStep[t], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(A*b + A*s)/((a + s)^(3/2)*(b + s)^(3/2)), 
  Rminus[Abs[Re[(a - b)/2]] - Re[(a + b)/2]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                 A b + A s
LTransData[---------------------, 
                  3/2        3/2
           (a + s)    (b + s)
 
                a - b        a + b
  Rminus[Abs[Re[-----]] - Re[-----]], Rplus[Infinity], 
                  2            2
 
  LVariables[s]]
:[font = text; inactive; ]

Unfortunately, Mathematica does not quite simplify this one all of the way.  The multiplication by the constant A prevents the simplification somehow.  Without the constant A, the transform is simplified properly:
:[font = input; startGroup; ]

LaPlace[ t Exp[- (a + b) t / 2]
		 ( BesselI[0, (a - b) t / 2] -
		   BesselI[1, (a - b) t / 2] ) CStep[t], t, s ]
:[font = input; ]

:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[1/((a + s)^(3/2)*(b + s)^(1/2)), 
  Rminus[Abs[Re[(a - b)/2]] - Re[(a + b)/2]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                     1
LTransData[----------------------, 
                  3/2
           (a + s)    Sqrt[b + s]
 
                a - b        a + b
  Rminus[Abs[Re[-----]] - Re[-----]], Rplus[Infinity], 
                  2            2
 
  LVariables[s]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Inverse Laplace Transforms
:[font = input; startGroup; ]

?InvLaPlace
:[font = info; inactive; endGroup; ]
InvLaPlace[f, s] and InvLaPlace[f, s, t] gives the multidimensional
   bilateral inverse Laplace transform of f.  A region of
   convergence can be specified by using InvLaPlace[{f, rm, rp}, s,
   t], where rm is Rminus and rp is Rplus in the region (strip) of
   convergence: Rminus < Re(s) < Rplus.
:[font = input; startGroup; ]

InvLaPlace[ LaPlace[ t Exp[- (a + b) t / 2]
					 ( BesselI[0, (a - b) t / 2] -
					   BesselI[1, (a - b) t / 2] ) CStep[t], t, s ] ]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
(t*(BesselI[0, ((a - b)*t)/2] - BesselI[1, ((a - b)*t)/2])*
    CStep[t])/E^(((a + b)*t)/2)
;[o]
              (a - b) t               (a - b) t
t (BesselI[0, ---------] - BesselI[1, ---------]) CStep[t]
                  2                       2
----------------------------------------------------------
                       ((a + b) t)/2
                      E
:[font = subsection; inactive; startGroup; Cclosed; ]
Fourier Transforms
:[font = input; startGroup; ]

?CTFTransform
:[font = info; inactive; endGroup; ]
CTFTransform[f, t] or CTFTransform[f, t, w] computes the
   continuous-time Fourier transform of f.  It has time argument(s)
   t and frequency argument(s) w.
:[font = input; startGroup; ]

?InvCTFTransform
:[font = info; inactive; endGroup; endGroup; ]
InvCTFTransform[f, w, t] computes the inverse continuous time
   Fourier transform of f with frequency arguments w and time
   arguments t.
:[font = subsection; inactive; startGroup; Cclosed; ]
Stability Analysis Example
:[font = input; startGroup; ]

Stable [ LaPlace[ A t Exp[- (a + b) t / 2]
				 ( BesselI[0, (a - b) t / 2] -
				   BesselI[1, (a - b) t / 2] ) CStep[t], t, s ] ]
:[font = output; inactive; output; endGroup; ]
Abs[Re[(a - b)/2]] - Re[(a + b)/2] < 0
;[o]
       a - b        a + b
Abs[Re[-----]] - Re[-----] < 0
         2            2
:[font = text; inactive; endGroup; ]

If a > b, a is real-valued, and b is real-valued, then this stability condition reduces to a > b > 0.
:[font = subsection; inactive; startGroup; Cclosed; ]
Solving a Differential Equation
:[font = input; startGroup; ]

?LSolve
:[font = info; inactive; endGroup; ]
LSolve[ diffequ == drivingfun, y[t] ] solves the difference
   equation diffequ = drivingfun, where diffequ is a linear
   constant coefficient differential equation and drivingfun is the
   driving function (a function of t).  Thus, diffequ has the form
   a0 y[t] + a1 y'[t] + ....  By using options, one can specify
   initial values; e.g., LSolve[ y''[t] + 3/2 y'[t] + 1/2 y[t] ==
   Exp[a t] CStep[t], y[t], y[0] -> 4, y'[0] -> 10 ].
:[font = input; startGroup; ]

LSolve[ y''[t] + 3/2 y'[t] + 1/2 y[t] == Exp[a t] CStep[t],
		y[t], y'[0] -> 1/2, y[0] -> 4 ]
:[font = output; inactive; output; endGroup; ]
((-10 - 36*a)*CStep[t/2])/(2*E^(t/2)*(-1 - 2*a)) + 
  ((3 + 5*a)*CStep[t])/(E^t*(-1 - a)) - 
  (2*E^(a*t)*CStep[t])/(-1 - 3*a - 2*a^2)
;[o]
                   t
(-10 - 36 a) CStep[-]                           a t
                   2    (3 + 5 a) CStep[t]   2 E    CStep[t]
--------------------- + ------------------ - ---------------
     t/2                    t                              2
  2 E    (-1 - 2 a)        E  (-1 - a)       -1 - 3 a - 2 a
:[font = text; inactive; ]

By removing the step functions, we can convert the bilateral result to a unilateral one.  This conversion makes the verification of answer easier.
:[font = input; initialization; startGroup; ]
*)

ysol = LSolve[ y''[t] + 3/2 y'[t] + 1/2 y[t] == Exp[a t] CStep[t],
				y[t], y'[0] -> 1/2, y[0] -> 4 ] /.
		{ CStep[a_] :> 1 }
(*
:[font = print; inactive; startGroup; ]
Solving for y[t] in the differential equation
:[font = print; inactive; ]
  y[t]   3 y'[t]             a t
  ---- + ------- + y''[t] = E    CStep[t]
   2        2
:[font = print; inactive; ]
  subject to the initial conditions
:[font = print; inactive; ]
            1
  {y'[0] -> -, y[0] -> 4}
            2
:[font = print; inactive; ]
After taking the Laplace transform of both sides
:[font = print; inactive; ]
and solving for the transform of y[t]:
:[font = print; inactive; ]
  13           1
  -- + 4 s + -----
  2          s - a
  ----------------
    1   3 s    2
    - + --- + s
    2    2
:[font = print; inactive; ]
Inverse transforming this gives y[t]:
:[font = output; inactive; output; endGroup; endGroup; ]
(-3 + 5*E^(t/2) + 2*E^(t + a*t) - 11*a + 23*E^(t/2)*a - 
    10*a^2 + 18*E^(t/2)*a^2)/(E^t*(1 + a)*(1 + 2*a))
;[o]
         t/2      t + a t              t/2         2
(-3 + 5 E    + 2 E        - 11 a + 23 E    a - 10 a  + 
 
        t/2  2      t
    18 E    a ) / (E  (1 + a) (1 + 2 a))
:[font = input; ]


:[font = input; initialization; startGroup; ]
*)

ysolprime = D[ ysol, t]
(*
:[font = output; inactive; output; endGroup; ]
-((-3 + 5*E^(t/2) + 2*E^(t + a*t) - 11*a + 
       23*E^(t/2)*a - 10*a^2 + 18*E^(t/2)*a^2)/
     (E^t*(1 + a)*(1 + 2*a))) + 
  ((5*E^(t/2))/2 + (23*E^(t/2)*a)/2 + 9*E^(t/2)*a^2 + 
     2*E^(t + a*t)*(1 + a))/(E^t*(1 + a)*(1 + 2*a))
;[o]
           t/2      t + a t              t/2         2
-((-3 + 5 E    + 2 E        - 11 a + 23 E    a - 10 a  + 
 
           t/2  2      t
       18 E    a ) / (E  (1 + a) (1 + 2 a))) + 
 
     t/2       t/2
  5 E      23 E    a      t/2  2      t + a t
  ------ + --------- + 9 E    a  + 2 E        (1 + a)
    2          2
  ---------------------------------------------------
                  t
                 E  (1 + a) (1 + 2 a)
:[font = input; startGroup; ]

ysol2prime = D[ ysolprime, t ];

Simplify[ ysol2prime + 3/2 ysolprime + 1/2 ysol ]
:[font = output; inactive; output; endGroup; ]
E^(a*t)
;[o]
 a t
E
:[font = input; startGroup; ]

Simplify[ ysol /. t -> 0 ]
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = input; startGroup; ]

Simplify[ ysolprime /. t -> 0 ]
:[font = output; inactive; output; endGroup; endGroup; ]
1/2
;[o]
1
-
2
:[font = subsection; inactive; startGroup; Cclosed; ]
Analog Signal Analyzer
:[font = input; startGroup; ]

?ASPAnalyze
:[font = info; inactive; endGroup; ]
ASPAnalyze[f], ASPAnalyze[f, t], and ASPAnalyze[f, t, start, end]
   will plot f(t) as a one-dimensional, continuous-time function.
   It will also print the strip of convergence, indicate stability
   criteria, display the pole-zero diagram, and plot the magnitude
   and phase responses.  For the two-dimensional version, t is a
   list of two variables (like {t1, t2}) and start/end are optional
   two-element lists specifying the range of the time-domain plot.
:[font = input; startGroup; ]

ASPAnalyze[ t Exp[- a t] Cos[3 Pi t / 16] CStep[t], t, 0, 3 Pi ]
:[font = print; inactive; ]
These variables were assigned a value of 1: {a}
               3 Pi t
t CStep[t] Cos[------]
                 16
----------------------
           t
          E
has the following Laplace transform:
-256 (-16 + 3 Pi - 16 s) (16 + 3 Pi + 16 s)
-------------------------------------------
                 2                2 2
      (256 + 9 Pi  + 512 s + 256 s )
The strip of convergence is:
-1 < Re(s) < Infinity
The system is stable.
 
The zeroes are:  {-1.58905, -0.410951}
The poles are:   {-1. + 0.589049 I, -1. - 0.589049 I, 
 
   -1. + 0.589049 I, -1. - 0.589049 I}
               3 Pi t
t CStep[t] Cos[------]
                 16
----------------------
           t
          E
has the following frequency response:
-256 (-16 + 3 Pi + -16 I w) (16 + 3 Pi + 16 I w)
------------------------------------------------
                  2                  2 2
       (256 + 9 Pi  + 512 I w - 256 w )
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.10105 0.09774 1.57756 [
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(2)] 0.22591 0.08524 0 1 Msboxa
[(4)] 0.42801 0.08524 0 1 Msboxa
[(6)] 0.63011 0.08524 0 1 Msboxa
[(8)] 0.83222 0.08524 0 1 Msboxa
[(t)] 1.00625 0.09774 -1 0 Msboxa
[(-0.05)] 0.01131 0.01886 1 0 Msboxa
[(0.05)] 0.01131 0.17662 1 0 Msboxa
[(0.1)] 0.01131 0.2555 1 0 Msboxa
[(0.15)] 0.01131 0.33438 1 0 Msboxa
[(0.2)] 0.01131 0.41325 1 0 Msboxa
[(0.25)] 0.01131 0.49213 1 0 Msboxa
[(0.3)] 0.01131 0.57101 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.09774 moveto
1 0.09774 lineto
stroke
0.22591 0.09149 moveto
0.22591 0.10399 lineto
stroke
0 setgray
[(2)] 0.22591 0.08524 0 1 Mshowa
0.42801 0.09149 moveto
0.42801 0.10399 lineto
stroke
0 setgray
[(4)] 0.42801 0.08524 0 1 Mshowa
0.63011 0.09149 moveto
0.63011 0.10399 lineto
stroke
0 setgray
[(6)] 0.63011 0.08524 0 1 Mshowa
0.83222 0.09149 moveto
0.83222 0.10399 lineto
stroke
0 setgray
[(8)] 0.83222 0.08524 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.09774 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.01886 moveto
0.03006 0.01886 lineto
stroke
0 setgray
[(-0.05)] 0.01131 0.01886 1 0 Mshowa
0.01756 0.17662 moveto
0.03006 0.17662 lineto
stroke
0 setgray
[(0.05)] 0.01131 0.17662 1 0 Mshowa
0.01756 0.2555 moveto
0.03006 0.2555 lineto
stroke
0 setgray
[(0.1)] 0.01131 0.2555 1 0 Mshowa
0.01756 0.33438 moveto
0.03006 0.33438 lineto
stroke
0 setgray
[(0.15)] 0.01131 0.33438 1 0 Mshowa
0.01756 0.41325 moveto
0.03006 0.41325 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.41325 1 0 Mshowa
0.01756 0.49213 moveto
0.03006 0.49213 lineto
stroke
0 setgray
[(0.25)] 0.01131 0.49213 1 0 Mshowa
0.01756 0.57101 moveto
0.03006 0.57101 lineto
stroke
0 setgray
[(0.3)] 0.01131 0.57101 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.09774 moveto
0.03373 0.2379 lineto
0.04365 0.35057 lineto
0.05357 0.43864 lineto
0.06349 0.50491 lineto
0.06845 0.53071 lineto
0.07341 0.55206 lineto
0.07837 0.56926 lineto
0.08333 0.58262 lineto
0.08581 0.58795 lineto
0.08829 0.59243 lineto
0.09077 0.59608 lineto
0.09325 0.59896 lineto
0.09449 0.60011 lineto
0.09573 0.60108 lineto
0.09697 0.60187 lineto
0.09821 0.60249 lineto
0.09945 0.60293 lineto
0.10069 0.60321 lineto
0.10193 0.60332 lineto
0.10317 0.60327 lineto
0.10441 0.60307 lineto
0.10565 0.60271 lineto
0.10689 0.6022 lineto
0.10813 0.60155 lineto
0.11062 0.59982 lineto
0.1131 0.59756 lineto
0.11806 0.59152 lineto
0.12302 0.58364 lineto
0.13294 0.56316 lineto
0.14286 0.53758 lineto
0.18254 0.40765 lineto
0.22222 0.27273 lineto
0.24206 0.21334 lineto
0.2619 0.16181 lineto
0.28175 0.11881 lineto
0.30159 0.08431 lineto
0.32143 0.05783 lineto
0.33135 0.04736 lineto
0.34127 0.03861 lineto
0.35119 0.03143 lineto
0.36111 0.02572 lineto
0.37103 0.02134 lineto
0.37599 0.01961 lineto
0.38095 0.01817 lineto
0.38591 0.017 lineto
0.39087 0.01609 lineto
0.39335 0.01572 lineto
0.39583 0.01542 lineto
0.39831 0.01517 lineto
Mistroke
0.40079 0.01498 lineto
0.40203 0.0149 lineto
0.40327 0.01484 lineto
0.40451 0.01479 lineto
0.40575 0.01475 lineto
0.40699 0.01473 lineto
0.40823 0.01472 lineto
0.40947 0.01472 lineto
0.41071 0.01473 lineto
0.41195 0.01475 lineto
0.41319 0.01478 lineto
0.41443 0.01483 lineto
0.41567 0.01489 lineto
0.41815 0.01503 lineto
0.42063 0.01522 lineto
0.4256 0.01572 lineto
0.43056 0.01637 lineto
0.44048 0.01806 lineto
0.46032 0.02277 lineto
0.5 0.03538 lineto
0.53968 0.04933 lineto
0.57937 0.06239 lineto
0.61905 0.07341 lineto
0.65873 0.08206 lineto
0.67857 0.0855 lineto
0.69841 0.0884 lineto
0.71825 0.09082 lineto
0.7381 0.09279 lineto
0.75794 0.09438 lineto
0.77778 0.09563 lineto
0.79762 0.0966 lineto
0.81746 0.09733 lineto
0.82738 0.09762 lineto
0.8373 0.09786 lineto
0.84722 0.09807 lineto
0.85714 0.09824 lineto
0.86706 0.09837 lineto
0.87698 0.09848 lineto
0.8869 0.09857 lineto
0.89187 0.0986 lineto
0.89683 0.09863 lineto
0.90179 0.09865 lineto
0.90675 0.09867 lineto
0.91171 0.09869 lineto
0.91419 0.0987 lineto
0.91667 0.0987 lineto
0.91915 0.09871 lineto
0.92163 0.09871 lineto
0.92411 0.09871 lineto
0.92659 0.09871 lineto
Mistroke
0.92783 0.09871 lineto
0.92907 0.09872 lineto
0.93031 0.09872 lineto
0.93155 0.09872 lineto
0.93279 0.09872 lineto
0.93403 0.09872 lineto
0.93527 0.09872 lineto
0.93651 0.09872 lineto
0.97619 0.09864 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 173; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
1 0.50345 0.30902 0.41968 [
[(-1.75)] 0.11897 0.29652 0 1 Msboxa
[(-1.5)] 0.24483 0.29652 0 1 Msboxa
[(-1.25)] 0.37069 0.29652 0 1 Msboxa
[(-1)] 0.49655 0.29652 0 1 Msboxa
[(-0.75)] 0.62242 0.29652 0 1 Msboxa
[(-0.5)] 0.74828 0.29652 0 1 Msboxa
[(-0.25)] 0.87414 0.29652 0 1 Msboxa
[(Re s)] 1.00625 0.30902 -1 0 Msboxa
[(-0.6)] 0.9875 0.05721 1 0 Msboxa
[(-0.4)] 0.9875 0.14114 1 0 Msboxa
[(-0.2)] 0.9875 0.22508 1 0 Msboxa
[(0.2)] 0.9875 0.39295 1 0 Msboxa
[(0.4)] 0.9875 0.47689 1 0 Msboxa
[(0.6)] 0.9875 0.56083 1 0 Msboxa
[(Im s)] 1 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.00725 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.11897 0.30277 moveto
0.11897 0.31527 lineto
stroke
0 setgray
[(-1.75)] 0.11897 0.29652 0 1 Mshowa
0.24483 0.30277 moveto
0.24483 0.31527 lineto
stroke
0 setgray
[(-1.5)] 0.24483 0.29652 0 1 Mshowa
0.37069 0.30277 moveto
0.37069 0.31527 lineto
stroke
0 setgray
[(-1.25)] 0.37069 0.29652 0 1 Mshowa
0.49655 0.30277 moveto
0.49655 0.31527 lineto
stroke
0 setgray
[(-1)] 0.49655 0.29652 0 1 Mshowa
0.62242 0.30277 moveto
0.62242 0.31527 lineto
stroke
0 setgray
[(-0.75)] 0.62242 0.29652 0 1 Mshowa
0.74828 0.30277 moveto
0.74828 0.31527 lineto
stroke
0 setgray
[(-0.5)] 0.74828 0.29652 0 1 Mshowa
0.87414 0.30277 moveto
0.87414 0.31527 lineto
stroke
0 setgray
[(-0.25)] 0.87414 0.29652 0 1 Mshowa
0 setgray
[(Re s)] 1.00625 0.30902 -1 0 Mshowa
1 0 moveto
1 0.61803 lineto
stroke
0.99375 0.05721 moveto
1.00625 0.05721 lineto
stroke
0 setgray
[(-0.6)] 0.9875 0.05721 1 0 Mshowa
0.99375 0.14114 moveto
1.00625 0.14114 lineto
stroke
0 setgray
[(-0.4)] 0.9875 0.14114 1 0 Mshowa
0.99375 0.22508 moveto
1.00625 0.22508 lineto
stroke
0 setgray
[(-0.2)] 0.9875 0.22508 1 0 Mshowa
0.99375 0.39295 moveto
1.00625 0.39295 lineto
stroke
0 setgray
[(0.2)] 0.9875 0.39295 1 0 Mshowa
0.99375 0.47689 moveto
1.00625 0.47689 lineto
stroke
0 setgray
[(0.4)] 0.9875 0.47689 1 0 Mshowa
0.99375 0.56083 moveto
1.00625 0.56083 lineto
stroke
0 setgray
[(0.6)] 0.9875 0.56083 1 0 Mshowa
0 setgray
[(Im s)] 1 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
[ 0.05 0.05 ] 0 setdash
0.004 setlinewidth
0.49655 0 moveto
0.49655 0.61803 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
1 0.30902 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.2 0.30902 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.79311 0.30902 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(*X*)] 0.49655 0.0618 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(*X*)] 0.49655 0.55623 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.69927 0.01711 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.60119 0 1 Msboxa
[(-0.7)] 0.16667 0.60119 0 1 Msboxa
[(-0.3)] 0.35714 0.60119 0 1 Msboxa
[(0.3)] 0.64286 0.60119 0 1 Msboxa
[(0.7)] 0.83333 0.60119 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.61369 -1 0 Msboxa
[(-40)] 0.4875 0.01469 1 0 Msboxa
[(-35)] 0.4875 0.10026 1 0 Msboxa
[(-30)] 0.4875 0.18584 1 0 Msboxa
[(-25)] 0.4875 0.27141 1 0 Msboxa
[(-20)] 0.4875 0.35698 1 0 Msboxa
[(-15)] 0.4875 0.44255 1 0 Msboxa
[(-10)] 0.4875 0.52812 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61369 moveto
1 0.61369 lineto
stroke
0.02381 0.60744 moveto
0.02381 0.61994 lineto
stroke
0 setgray
[(-1)] 0.02381 0.60119 0 1 Mshowa
0.16667 0.60744 moveto
0.16667 0.61994 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.60119 0 1 Mshowa
0.35714 0.60744 moveto
0.35714 0.61994 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.60119 0 1 Mshowa
0.64286 0.60744 moveto
0.64286 0.61994 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.60119 0 1 Mshowa
0.83333 0.60744 moveto
0.83333 0.61994 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.60119 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.61369 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.01469 moveto
0.50625 0.01469 lineto
stroke
0 setgray
[(-40)] 0.4875 0.01469 1 0 Mshowa
0.49375 0.10026 moveto
0.50625 0.10026 lineto
stroke
0 setgray
[(-35)] 0.4875 0.10026 1 0 Mshowa
0.49375 0.18584 moveto
0.50625 0.18584 lineto
stroke
0 setgray
[(-30)] 0.4875 0.18584 1 0 Mshowa
0.49375 0.27141 moveto
0.50625 0.27141 lineto
stroke
0 setgray
[(-25)] 0.4875 0.27141 1 0 Mshowa
0.49375 0.35698 moveto
0.50625 0.35698 lineto
stroke
0 setgray
[(-20)] 0.4875 0.35698 1 0 Mshowa
0.49375 0.44255 moveto
0.50625 0.44255 lineto
stroke
0 setgray
[(-15)] 0.4875 0.44255 1 0 Mshowa
0.49375 0.52812 moveto
0.50625 0.52812 lineto
stroke
0 setgray
[(-10)] 0.4875 0.52812 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.55086 moveto
0.36176 0.59402 lineto
0.38158 0.59765 lineto
0.39967 0.6004 lineto
0.40816 0.60143 lineto
0.41631 0.60224 lineto
0.42027 0.60256 lineto
0.42415 0.60282 lineto
0.42796 0.60303 lineto
0.4317 0.60318 lineto
0.43538 0.60328 lineto
0.43899 0.60332 lineto
0.44254 0.60331 lineto
0.44603 0.60324 lineto
0.44946 0.60312 lineto
0.45284 0.60295 lineto
0.45616 0.60273 lineto
0.45943 0.60246 lineto
0.46582 0.60177 lineto
0.47202 0.60088 lineto
0.48388 0.59857 lineto
0.4951 0.59558 lineto
0.50574 0.59199 lineto
0.5255 0.58326 lineto
0.54355 0.57288 lineto
0.56014 0.56132 lineto
0.61573 0.50986 lineto
0.6595 0.45874 lineto
0.69561 0.41215 lineto
0.72634 0.37057 lineto
0.75309 0.33348 lineto
0.77677 0.30019 lineto
0.79801 0.27009 lineto
0.81728 0.24266 lineto
0.8349 0.2175 lineto
0.85114 0.19427 lineto
0.86619 0.17269 lineto
0.88023 0.15257 lineto
0.89337 0.13371 lineto
0.90572 0.11597 lineto
0.91738 0.09922 lineto
0.92842 0.08337 lineto
0.9389 0.06831 lineto
0.94887 0.05398 lineto
0.95838 0.04031 lineto
0.96748 0.02724 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.60241 0.00349 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.58991 0 1 Msboxa
[(-0.7)] 0.16667 0.58991 0 1 Msboxa
[(-0.3)] 0.35714 0.58991 0 1 Msboxa
[(0.3)] 0.64286 0.58991 0 1 Msboxa
[(0.7)] 0.83333 0.58991 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.60241 -1 0 Msboxa
[(-150)] 0.4875 0.07912 1 0 Msboxa
[(-125)] 0.4875 0.16633 1 0 Msboxa
[(-100)] 0.4875 0.25355 1 0 Msboxa
[(-75)] 0.4875 0.34076 1 0 Msboxa
[(-50)] 0.4875 0.42798 1 0 Msboxa
[(-25)] 0.4875 0.51519 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.60241 moveto
1 0.60241 lineto
stroke
0.02381 0.59616 moveto
0.02381 0.60866 lineto
stroke
0 setgray
[(-1)] 0.02381 0.58991 0 1 Mshowa
0.16667 0.59616 moveto
0.16667 0.60866 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.58991 0 1 Mshowa
0.35714 0.59616 moveto
0.35714 0.60866 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.58991 0 1 Mshowa
0.64286 0.59616 moveto
0.64286 0.60866 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.58991 0 1 Mshowa
0.83333 0.59616 moveto
0.83333 0.60866 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.58991 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.60241 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07912 moveto
0.50625 0.07912 lineto
stroke
0 setgray
[(-150)] 0.4875 0.07912 1 0 Mshowa
0.49375 0.16633 moveto
0.50625 0.16633 lineto
stroke
0 setgray
[(-125)] 0.4875 0.16633 1 0 Mshowa
0.49375 0.25355 moveto
0.50625 0.25355 lineto
stroke
0 setgray
[(-100)] 0.4875 0.25355 1 0 Mshowa
0.49375 0.34076 moveto
0.50625 0.34076 lineto
stroke
0 setgray
[(-75)] 0.4875 0.34076 1 0 Mshowa
0.49375 0.42798 moveto
0.50625 0.42798 lineto
stroke
0 setgray
[(-50)] 0.4875 0.42798 1 0 Mshowa
0.49375 0.51519 moveto
0.50625 0.51519 lineto
stroke
0 setgray
[(-25)] 0.4875 0.51519 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.04888 0.60316 lineto
0.07125 0.6029 lineto
0.09142 0.60254 lineto
0.10981 0.60206 lineto
0.12669 0.60148 lineto
0.14229 0.60077 lineto
0.1568 0.59995 lineto
0.17036 0.59899 lineto
0.19508 0.5967 lineto
0.21715 0.59389 lineto
0.23709 0.59057 lineto
0.25527 0.58674 lineto
0.28746 0.57765 lineto
0.3153 0.56682 lineto
0.33983 0.55449 lineto
0.36176 0.54091 lineto
0.39967 0.51101 lineto
0.4317 0.47893 lineto
0.48388 0.41402 lineto
0.56014 0.30325 lineto
0.61573 0.22676 lineto
0.6595 0.17594 lineto
0.69561 0.14117 lineto
0.72634 0.11633 lineto
0.75309 0.09786 lineto
0.77677 0.08363 lineto
0.79801 0.07235 lineto
0.81728 0.06319 lineto
0.8349 0.05562 lineto
0.85114 0.04924 lineto
0.86619 0.04381 lineto
0.88023 0.03911 lineto
0.89337 0.03502 lineto
0.90572 0.03142 lineto
0.91738 0.02822 lineto
0.92842 0.02537 lineto
0.9389 0.02281 lineto
0.94887 0.02049 lineto
0.95838 0.01839 lineto
0.96748 0.01647 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
LTransData[(-256*(-16 + 3*Pi - 16*s)*(16 + 3*Pi + 16*s))/
   (256 + 9*Pi^2 + 512*s + 256*s^2)^2, Rminus[-1], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
           -256 (-16 + 3 Pi - 16 s) (16 + 3 Pi + 16 s)
LTransData[-------------------------------------------, Rminus[-1], 
                            2                2 2
                 (256 + 9 Pi  + 512 s + 256 s )
 
  Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]
ASPAnalyze[ Delta[t - 1/2] + Delta[t - 3/2], t, 0, 2 ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.47619 0.01472 0.5886 [
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(0.5)] 0.2619 0.00222 0 1 Msboxa
[(1)] 0.5 0.00222 0 1 Msboxa
[(1.5)] 0.7381 0.00222 0 1 Msboxa
[(2)] 0.97619 0.00222 0 1 Msboxa
[(t)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.01131 0.13244 1 0 Msboxa
[(0.4)] 0.01131 0.25016 1 0 Msboxa
[(0.6)] 0.01131 0.36788 1 0 Msboxa
[(0.8)] 0.01131 0.4856 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Continuous-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.2619 0.00847 moveto
0.2619 0.02097 lineto
stroke
0 setgray
[(0.5)] 0.2619 0.00222 0 1 Mshowa
0.5 0.00847 moveto
0.5 0.02097 lineto
stroke
0 setgray
[(1)] 0.5 0.00222 0 1 Mshowa
0.7381 0.00847 moveto
0.7381 0.02097 lineto
stroke
0 setgray
[(1.5)] 0.7381 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(2)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.01472 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.13244 moveto
0.03006 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.13244 1 0 Mshowa
0.01756 0.25016 moveto
0.03006 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.25016 1 0 Mshowa
0.01756 0.36788 moveto
0.03006 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.36788 1 0 Mshowa
0.01756 0.4856 moveto
0.03006 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.4856 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
gsave
0.004 setlinewidth
0.7381 0.01472 moveto
0.7381 0.60332 lineto
0.69048 0.42674 lineto
0.78571 0.42674 lineto
0.7381 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.2619 0.01472 moveto
0.2619 0.60332 lineto
0.21429 0.42674 lineto
0.30952 0.42674 lineto
0.2619 0.60332 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
        3                 1
Delta[-(-) + t] + Delta[-(-) + t]
        2                 2
has the following Laplace transform:
      s
 1 + E
--------
 (3 s)/2
E
The strip of convergence is:
-Infinity < Re(s) < Infinity
The system is stable.
        3                 1
Delta[-(-) + t] + Delta[-(-) + t]
        2                 2
has the following frequency response:
 (-3 I)/2 w       I w
E           (1 + E   )
:[font = message; inactive; ]
ASPAnalyze::notinteresting: 
   Could not determine the important section of the frequency
    response.
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.55308 0.00835 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.54058 0 1 Msboxa
[(-0.7)] 0.16667 0.54058 0 1 Msboxa
[(-0.3)] 0.35714 0.54058 0 1 Msboxa
[(0.3)] 0.64286 0.54058 0 1 Msboxa
[(0.7)] 0.83333 0.54058 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.55308 -1 0 Msboxa
[(-60)] 0.4875 0.05237 1 0 Msboxa
[(-50)] 0.4875 0.13582 1 0 Msboxa
[(-40)] 0.4875 0.21927 1 0 Msboxa
[(-30)] 0.4875 0.30272 1 0 Msboxa
[(-20)] 0.4875 0.38617 1 0 Msboxa
[(-10)] 0.4875 0.46962 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.55308 moveto
1 0.55308 lineto
stroke
0.02381 0.54683 moveto
0.02381 0.55933 lineto
stroke
0 setgray
[(-1)] 0.02381 0.54058 0 1 Mshowa
0.16667 0.54683 moveto
0.16667 0.55933 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.54058 0 1 Mshowa
0.35714 0.54683 moveto
0.35714 0.55933 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.54058 0 1 Mshowa
0.64286 0.54683 moveto
0.64286 0.55933 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.54058 0 1 Mshowa
0.83333 0.54683 moveto
0.83333 0.55933 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.54058 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.55308 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.05237 moveto
0.50625 0.05237 lineto
stroke
0 setgray
[(-60)] 0.4875 0.05237 1 0 Mshowa
0.49375 0.13582 moveto
0.50625 0.13582 lineto
stroke
0 setgray
[(-50)] 0.4875 0.13582 1 0 Mshowa
0.49375 0.21927 moveto
0.50625 0.21927 lineto
stroke
0 setgray
[(-40)] 0.4875 0.21927 1 0 Mshowa
0.49375 0.30272 moveto
0.50625 0.30272 lineto
stroke
0 setgray
[(-30)] 0.4875 0.30272 1 0 Mshowa
0.49375 0.38617 moveto
0.50625 0.38617 lineto
stroke
0 setgray
[(-20)] 0.4875 0.38617 1 0 Mshowa
0.49375 0.46962 moveto
0.50625 0.46962 lineto
stroke
0 setgray
[(-10)] 0.4875 0.46962 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60323 moveto
0.04888 0.6032 lineto
0.07125 0.60318 lineto
0.10981 0.60311 lineto
0.14229 0.60303 lineto
0.17036 0.60294 lineto
0.19508 0.60284 lineto
0.21715 0.60273 lineto
0.25527 0.60247 lineto
0.28746 0.60215 lineto
0.3153 0.60179 lineto
0.33983 0.60138 lineto
0.36176 0.60091 lineto
0.39967 0.59983 lineto
0.4317 0.59853 lineto
0.45943 0.59702 lineto
0.48388 0.59527 lineto
0.50574 0.59329 lineto
0.5255 0.59105 lineto
0.54355 0.58854 lineto
0.56014 0.58574 lineto
0.5898 0.57916 lineto
0.61573 0.57108 lineto
0.63877 0.56111 lineto
0.6595 0.54863 lineto
0.66914 0.54114 lineto
0.67834 0.53259 lineto
0.69561 0.51092 lineto
0.70373 0.49668 lineto
0.71154 0.4787 lineto
0.71534 0.46761 lineto
0.71907 0.45445 lineto
0.72274 0.43831 lineto
0.72634 0.41744 lineto
0.72811 0.40419 lineto
0.72988 0.38795 lineto
0.73162 0.36697 lineto
0.73249 0.35365 lineto
0.73336 0.33731 lineto
0.73422 0.31618 lineto
0.73507 0.28622 lineto
0.73593 0.23425 lineto
0.73678 0.01472 lineto
0.73762 0.24094 lineto
0.73847 0.28957 lineto
0.73931 0.31841 lineto
0.74014 0.33898 lineto
0.74181 0.36809 lineto
0.74346 0.38879 lineto
0.74672 0.418 lineto
Mistroke
0.74992 0.43873 lineto
0.75309 0.45479 lineto
0.75926 0.47893 lineto
0.76526 0.49687 lineto
0.77677 0.52278 lineto
0.78766 0.54124 lineto
0.79801 0.5553 lineto
0.81728 0.57538 lineto
0.82628 0.58266 lineto
0.8349 0.58857 lineto
0.84318 0.59331 lineto
0.85114 0.59704 lineto
0.8588 0.59984 lineto
0.86253 0.60092 lineto
0.86619 0.6018 lineto
0.86979 0.60247 lineto
0.87157 0.60274 lineto
0.87333 0.60295 lineto
0.87508 0.60311 lineto
0.87594 0.60318 lineto
0.87681 0.60323 lineto
0.87767 0.60327 lineto
0.8781 0.60329 lineto
0.87852 0.6033 lineto
0.87895 0.60331 lineto
0.87938 0.60331 lineto
0.8798 0.60332 lineto
0.88023 0.60332 lineto
0.88065 0.60332 lineto
0.88107 0.60331 lineto
0.8815 0.6033 lineto
0.88192 0.60329 lineto
0.88276 0.60326 lineto
0.88359 0.60321 lineto
0.88525 0.60309 lineto
0.8869 0.60292 lineto
0.88854 0.60269 lineto
0.89016 0.60242 lineto
0.89337 0.60173 lineto
0.89653 0.60084 lineto
0.89964 0.59974 lineto
0.90572 0.5969 lineto
0.91164 0.59313 lineto
0.91738 0.58834 lineto
0.92298 0.58238 lineto
0.92842 0.57504 lineto
0.93373 0.566 lineto
0.9389 0.55478 lineto
0.94394 0.54057 lineto
0.94642 0.53192 lineto
Mistroke
0.94887 0.52188 lineto
0.95129 0.50999 lineto
0.95368 0.49553 lineto
0.95605 0.4772 lineto
0.95722 0.46585 lineto
0.95838 0.45234 lineto
0.95954 0.43565 lineto
0.96012 0.42558 lineto
0.9607 0.41386 lineto
0.96127 0.39987 lineto
0.96184 0.3825 lineto
0.96213 0.37194 lineto
0.96241 0.35959 lineto
0.9627 0.34468 lineto
0.96298 0.32588 lineto
0.96355 0.26085 lineto
0.96383 0.16691 lineto
0.96411 0.20341 lineto
0.9644 0.27279 lineto
0.96468 0.30758 lineto
0.96496 0.33098 lineto
0.96524 0.34865 lineto
0.9658 0.37469 lineto
0.96636 0.3938 lineto
0.96748 0.42138 lineto
0.96859 0.44128 lineto
0.96969 0.45683 lineto
0.97188 0.48039 lineto
0.97405 0.498 lineto
0.97619 0.51199 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.47619 0.30882 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-1)] 0.02381 0.29632 0 1 Msboxa
[(-0.7)] 0.16667 0.29632 0 1 Msboxa
[(-0.3)] 0.35714 0.29632 0 1 Msboxa
[(0.3)] 0.64286 0.29632 0 1 Msboxa
[(0.7)] 0.83333 0.29632 0 1 Msboxa
[(Log  w)(   10)] 1.00625 0.30882 -1 0 Msboxa
[(-150)] 0.4875 0.06306 1 0 Msboxa
[(-100)] 0.4875 0.14498 1 0 Msboxa
[(-50)] 0.4875 0.2269 1 0 Msboxa
[(50)] 0.4875 0.39074 1 0 Msboxa
[(100)] 0.4875 0.47265 1 0 Msboxa
[(150)] 0.4875 0.55457 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30882 moveto
1 0.30882 lineto
stroke
0.02381 0.30257 moveto
0.02381 0.31507 lineto
stroke
0 setgray
[(-1)] 0.02381 0.29632 0 1 Mshowa
0.16667 0.30257 moveto
0.16667 0.31507 lineto
stroke
0 setgray
[(-0.7)] 0.16667 0.29632 0 1 Mshowa
0.35714 0.30257 moveto
0.35714 0.31507 lineto
stroke
0 setgray
[(-0.3)] 0.35714 0.29632 0 1 Mshowa
0.64286 0.30257 moveto
0.64286 0.31507 lineto
stroke
0 setgray
[(0.3)] 0.64286 0.29632 0 1 Mshowa
0.83333 0.30257 moveto
0.83333 0.31507 lineto
stroke
0 setgray
[(0.7)] 0.83333 0.29632 0 1 Mshowa
0 setgray
[(Log  w)(   10)] 1.00625 0.30882 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06306 moveto
0.50625 0.06306 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06306 1 0 Mshowa
0.49375 0.14498 moveto
0.50625 0.14498 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14498 1 0 Mshowa
0.49375 0.2269 moveto
0.50625 0.2269 lineto
stroke
0 setgray
[(-50)] 0.4875 0.2269 1 0 Mshowa
0.49375 0.39074 moveto
0.50625 0.39074 lineto
stroke
0 setgray
[(50)] 0.4875 0.39074 1 0 Mshowa
0.49375 0.47265 moveto
0.50625 0.47265 lineto
stroke
0 setgray
[(100)] 0.4875 0.47265 1 0 Mshowa
0.49375 0.55457 moveto
0.50625 0.55457 lineto
stroke
0 setgray
[(150)] 0.4875 0.55457 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.29943 moveto
0.10981 0.29459 lineto
0.17036 0.28975 lineto
0.21715 0.28491 lineto
0.25527 0.28007 lineto
0.3153 0.27039 lineto
0.36176 0.26071 lineto
0.4317 0.24135 lineto
0.48388 0.22199 lineto
0.56014 0.18326 lineto
0.61573 0.14454 lineto
0.6595 0.10582 lineto
0.69561 0.0671 lineto
0.71154 0.04774 lineto
0.71907 0.03806 lineto
0.72634 0.02838 lineto
0.72988 0.02353 lineto
0.73162 0.02111 lineto
0.73336 0.01869 lineto
0.73422 0.01748 lineto
0.73507 0.01627 lineto
0.73593 0.01506 lineto
0.73678 0.30876 lineto
0.73762 0.30755 lineto
0.73847 0.30634 lineto
0.74014 0.30392 lineto
0.75309 0.28456 lineto
0.77677 0.24584 lineto
0.79801 0.20712 lineto
0.81728 0.16839 lineto
0.8349 0.12967 lineto
0.85114 0.09095 lineto
0.8588 0.07159 lineto
0.86619 0.05223 lineto
0.86979 0.04255 lineto
0.87333 0.03287 lineto
0.87681 0.02319 lineto
0.87767 0.02077 lineto
0.87852 0.01835 lineto
0.87895 0.01714 lineto
0.87938 0.01593 lineto
0.8798 0.01472 lineto
0.88023 0.60332 lineto
0.88107 0.6009 lineto
0.88192 0.59848 lineto
0.88359 0.59364 lineto
0.8869 0.58396 lineto
0.89337 0.5646 lineto
0.90572 0.52587 lineto
0.91738 0.48715 lineto
Mistroke
0.92842 0.44843 lineto
0.9389 0.40971 lineto
0.94887 0.37099 lineto
0.95838 0.33226 lineto
0.9607 0.32258 lineto
0.96184 0.31774 lineto
0.96241 0.31532 lineto
0.96298 0.3129 lineto
0.96355 0.31048 lineto
0.96383 0.30927 lineto
0.96411 0.60297 lineto
0.96524 0.59813 lineto
0.96748 0.58845 lineto
0.97619 0.54973 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
LTransData[(1 + E^s)/E^((3*s)/2), Rminus[DirectedInfinity[-1]], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
                 s
            1 + E
LTransData[--------, Rminus[-Infinity], Rplus[Infinity], 
            (3 s)/2
           E
 
  LVariables[s]]
:[font = section; inactive; startGroup; Cclosed; ]
Bug Fixes to the Signal Processing Packages
:[font = text; inactive; ]
		The following problems have been reported by various users.  The ones which are starred have been fixed.   If you find any other problems with the signal processing packages, please email  this information to evans@eedsp.gatech.edu.
:[font = subsection; inactive; startGroup; Cclosed; ]
Operators and Signals
:[font = text; inactive; ]
    *1. Shift[-7,n][Sinc[Pi/10] ] these fail to get to the magnitude plot
    without the shift it's OK;
:[font = text; inactive; ]
    *2. Pulse[9,0,n+4] fails, but Pulse[9,-4,n] works w.r.t. stability (discrete
    pulses are Pulse; continuous pulses are CPulse; pulses now take two
    arguments only --  length and t).  Pulses now take only two arguments.
:[font = text; inactive; ]
   *3. Shift works in the opposite direction;
:[font = text; inactive; ]
   *4. Integrating delta functions over a finite interval does not work.
:[font = text; inactive; endGroup; ]
   *5. Continuous and discrete convolution were broken in updating
          the packages to Mathematica 2.0.
:[font = subsection; inactive; startGroup; Cclosed; ]
Transforms
:[font = text; inactive; ]
    *1. The transforms do not justify their answers (now use Dialogue -> All
	 and the rule base will display each step of the transform process), and
:[font = text; inactive; ]
   *2.  The transforms do not handle the convolution operator.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
LaPlace/InvLaPlace
:[font = text; inactive; ]
    *1. The inverse Laplace transform of Log[s] / s is incorrect.
:[font = text; inactive; ]
    *2. The forward Laplace transform of (t -1) CStep[t] was incorrect.
:[font = text; inactive; ]
    *3. The inverse Laplace transform uses MyApart to work around two
           drawbacks to Apart:  (a) it cannot handle repeated complex-valued
           roots that arise from rational polynomials, and (b) it cannot find the
          approximate roots when one or more the polynomial coefficients is
           real-valued.  If the user would like the inverse to use approximate 
           roots, then the option Apart -> All must be specified.  The default
           isApart -> Rational.
:[font = text; inactive; ]
    *4. The inverse Laplace transform was not always correctly inverting
           terms that correspond to integration in the time domain.
:[font = text; inactive; ]
    *5. The inverse Laplace transform works the same under Mathematica
           1.2 and 2.0.  The problem was that under 2.0, Apart does not
           normalize polynomials in the denominator so the resulting
           denominators failed to match any of the transform pairs.
:[font = text; inactive; endGroup; ]
    *6. The inverse Laplace transform was producing left-sided transforms
           when it should have been producing right-sided ones.  The problem
           was Mathematica's Apart function which did not normalize the
           denominator after partial fractions decomposition.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
DTFTransform/InvDTFTransform
:[font = text; inactive; ]
   *1. The DTFT of Sinc squared fails.....  (Sinc[Pi/5 n])^2;
:[font = text; inactive; ]
    *2. The forward DTFT:  certain transform pairs are incorrect
	 like Cos[w0 n + phi] and Sin[w0 n + phi];
:[font = text; inactive; ]
    *3. The multidimensional inverse DTFT does not work at all;
:[font = text; inactive; ]
    *4. The inverse DTFT could not invert pulses or Dirichlet functions;
:[font = text; inactive; ]
    *5. The DTFT of a step function is missing a pi in the second term;
:[font = text; inactive; endGroup; ]
    *6. The interaction between the forward DTFT and the forward
           z-transform does not work for unresolved z-transforms.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
InvZTransform
:[font = text; inactive; ]
   *1. the following example does weird things:
:[font = input; ]
   InvZTransform [ { (1 - b z^-1)/( z^-1 - b ),
                     Abs[1/b], Infinity },
                   z, n, Dialogue -> True ]
:[font = text; inactive; ]
         It gives a phony partial fraction expansion, has trouble with b
         as a constant, and has the impulse at n=0 problem (seems to be
         hung up on "b"--doesn't really think it is a constant);
:[font = text; inactive; ]
  *2. The inverse z-transform could not handle common transform
         functions with a denominator of (1 - 2 r Cos[w0] z^-1 + r^2 z^-2),
         even when r = 1;
:[font = text; inactive; ]
 *3. The inverse z-transform required a ROC of |z| > 1 to invert a
        pulse instead of |z| > 0;
:[font = text; inactive; ]
 *4. The inverse z-transform of the z-transform of a two-sided
        decaying exponential put over a common denominator.  That is,
:[font = input; endGroup; ]
   InvZTransform[
     Together[ZTransform[(1/3)^Abs[n], n, z]],
     z, n ];
:[font = subsubsection; inactive; startGroup; Cclosed; ]
ZTransform
:[font = text; inactive; ]
    1. Transforms of 3-D line impulses;
:[font = text; inactive; ]
   *2. impulses at n=0 are not handled properly in inverse z;
:[font = text; inactive; ]
   *3. ZTransform[ (1/3)^Abs[n], n ] gave
:[font = output; inactive; ]
        1           1
     -------- + -----------
	   1            1
     1 - ---    3 (1 - -) z
         3 z           z
:[font = text; inactive; ]
	instead of
:[font = output; inactive; ]
        1          z
     -------- + ----------
          1             1
     1 - ---     3 (1 - -)
         3 z            z
:[font = text; inactive; ]
   *4. the left-sided case still has a problem; x[n] = (1/2)^n Step[-n] has
         a z-transform of 1/(1 - 2z), BUT the inverse transform of 1/(1 - 2z) is
         wrong !  It gives 1/(1/2)^n Step[-n], i.e., 2^n Step[-n].  I think the
         problem can be solved by removing the n -> -n  substitution in the
         left-sided rule;
:[font = text; inactive; ]
 *5. A ROC check is missing:  3^Abs[n]  has no legitimate z-transform,
        but the ZTransform package gives one with Rminus = 3 and
        Rplus = 1/3 !!!!   SO we need to check that Rminus < Rplus;
:[font = text; inactive; ]
 *6. The ROC is incorrect for the forward transform of a pulse;
:[font = text; inactive; ]
 *7. The forward z-transform of Step[n] / ( n + 1 ) is off by a
        minus sign;
:[font = text; inactive; endGroup; endGroup; ]
 *8. Incorrect inverse transforms downsampled signals;
:[font = subsection; inactive; startGroup; Cclosed; ]
MagPhasePlot
:[font = text; inactive; ]
    *1. Example #1 in the paper is not right. The frequency response of an upsampled
    signal should repeat every 2 Pi / L where L is the upsampling factor;
:[font = text; inactive; ]
   *2. Limit magnitude plots to the range -80 dB to infinity (this is now
   adjustable via PlotRange option to MagPhasePlot);
:[font = text; inactive; ]
   *3. Plotting delta functions on a MacIntosh;
:[font = text; inactive; ]
   *4. Properly labeling logarithmic frequency scale;
:[font = text; inactive; ]
   *5. There is no way to disable the magnitude or phase plot when
	 calling MagPhasePlot.  (Now, set PhaseMagRange -> Null to disable
	 the phase plot or set MagPhaseRange -> Null to disable the
	 magnitude plot);
:[font = text; inactive; ]
   *6. MagPhasePlot can not directly plot the frequency response
	of DTFT, DFT, or CTFT objects.
:[font = text; inactive; ]
   *7. MagPhasePlot generates Set::raw warning messages.
:[font = text; inactive; endGroup; ]
   *8. MagPhasePlot cannot handle discontinuities well.
:[font = subsection; inactive; startGroup; Cclosed; ]
PoleZeroPlot
:[font = text; inactive; ]
	*1. PoleZeroPlot does not shade the region of convergence;
:[font = text; inactive; ]
    *2. PoleZeroPlot prints out the poles and zeroes before they plot
	 them (poles and zeroes are plotted only if the Dialogue option is True or All).
:[font = text; inactive; ]
    *3. PoleZeroPlot does not always correctly report zeroes at z = 0.
:[font = text; inactive; endGroup; ]
	*4. Two-dimensional version of PoleZeroPlot displays two pole-zero
	diagrams (or root maps) for a symmetric transfer function even though
	only one is necessary;
:[font = subsection; inactive; startGroup; Cclosed; ]
DSPAnalyze
:[font = text; inactive; ]
    *1. DSPAnalyze[ Sinc[n] ]  fails to plot at all..... it bombs it also gives
    a message of power::undefined 1/0;
:[font = text; inactive; ]
    *2. For the DSPAnalyze[ n a^n Step[n], n], I get the message
    PoleZeroPlot:: not rational, even though it gives a rational
    function for the answer;
:[font = text; inactive; ]
    *3. DSPAnalyze[ Pulse[10,0,n] ] says it is not stable (which is wrong
    I think it is missing the pole-zero cancellation, except that the list of
    poles and zeros is correct--there are 9 of them);
:[font = text; inactive; ]
   *4. Sinc[Pi/10 (n-7)] through DSPAnalyze;
:[font = text; inactive; ]
   *5.  DSPAnalyze breaks down when the discrete-time function is
           complex-valued, so we only plot the real values of the sequence; and
:[font = text; inactive; ]
   *6. DSPAnalyze of IIR and FIR objects crashes and burns---
         cannot plot their time-domain values and PoleZeroPlot complains
         about poles occurring in the region of convergence.
:[font = text; inactive; endGroup; ]
   *7. DSPAnalyze uses more descriptions and is also immune to
         changes in the Global environment.
:[font = subsection; inactive; startGroup; Cclosed; ]
ASPAnalyze
:[font = text; inactive; endGroup; endGroup; ]
    *1. ASPAnalyze[ Sinc[ Pi t ]]  has a glitch in the plot; without the Pi,
    it works OK;
:[font = section; inactive; startGroup; Cclosed; ]
Signal Processing Packages 2.4, 2.5, and 2.6
:[font = text; inactive; ]
		Version 2.4 of the signal processing packages was the first version to work simultaneously under version 1.2 and 2.0 of Mathematica.  However, porting these extensions for the new version of Mathematica introduced errors.  We also encountered theoretical errors, such as the piecewise convolution routines not being able to handle infinite endpoints.   Version and 2.6  fixes these bugs and introduces many new objects.  The major changes are reported below.
:[font = subsection; inactive; startGroup; Cclosed; ]
New Objects in 2.4
:[font = subsubsection; inactive; startGroup; Cclosed; ]
DTPiecewiseConvolution
:[font = text; inactive; endGroup; ]
		PiecewiseConvolution now supports discrete and continuous linear convolution.  The domain can be specified by the Domain option; otherwise, the value of the global variable $ConvolutionDomain is used (which defaults to Continuous).  Instead of using the Domain option, the user can invoke DTPiecewiseConvolution or CTPiecewiseConvolution directly.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
IIRFunction
:[font = text; inactive; ]
		IIR objects can be converted into a computational form called IIRFunction, and FIR objects can be rewritten as a formula (this conversion is triggered by the TheFunction object).  Their values can now be plotted.  Values are calculated as they are needed, and IIRFunction remembers (caches) previous calculations.
:[font = input; endGroup; ]
	TheFunction[ IIR[n, {1, 1/2, 1/4}] ]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
MyApart
:[font = text; inactive; ]
		In Mathematica 1.2, the Apart function is not robust because it does not handle repeated complex-valued roots in the denominator that arise when factoring rational polynomials.  For example, Apart does not properly decompose F(s) = ( s^2 - 1 ) / (s^2 + 2 s + 2)^2.  A new function MyApart does.
:[font = input; startGroup; ]
Apart[ (s^2 - 1) / ( s^2 + 2 s + 2 )^2, s ]
:[font = output; inactive; output; endGroup; ]
(-3 - 2*s)/(2 + 2*s + s^2)^2 + (2 + 2*s + s^2)^(-1)
;[o]
   -3 - 2 s            1
--------------- + ------------
            2 2              2
(2 + 2 s + s )    2 + 2 s + s
:[font = text; inactive; ]
But this is really not the complete partial fractions decomposition.  Rather, this is:
:[font = input; startGroup; ]
MyApart[ (s^2 - 1) / ( s^2 + 2 s + 2 )^2, s ]
:[font = output; inactive; output; endGroup; ]
(1/4 + I/2)/(1 - I + s)^2 + -I/4/(1 - I + s) + 
  (1/4 - I/2)/(1 + I + s)^2 + I/4/(1 + I + s)
;[o]
   1   I          -I          1   I           I
   - + -          --          - - -           -
   4   2          4           4   2           4
------------ + --------- + ------------ + ---------
           2   1 - I + s              2   1 + I + s
(1 - I + s)                (1 + I + s)
:[font = text; inactive; endGroup; ]
		Apart does not have an option to handle polynomials with real-valued coefficients.  MyApart takes a third argument which is a filter placed on the output of the Solve command which find the roots of the denominator.  If it is N, then the approximate roots will be used.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
RootLocus
:[font = text; inactive; ]
		RootLocus plots root loci for one varying parameter in a function of one variable.
:[font = input; endGroup; ]
	RootLocus[ 1 / ( s^2 + K s + K ), s, {K, 0, 5, 0.1} ]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
SequencePlot
:[font = text; inactive; ]
		SequencePlot now provides a standard way to plot discrete-time expressions. It can plot either functions of one variable or functions of two variables.  The one-variable plotting appears in the conventional lollipop style.  This is the discrete-time version of SignalPlot.
:[font = input; ]
SequencePlot[ IIR[n, {1, 1/2, 1/4}],
              {n, -5, 15} ]
:[font = text; inactive; endGroup; ]
Under 2.41, the lollipops are displayed more boldly and their widths are adapted according to the number of samples to be plotted.  Under 2.5, the labeling of the discrete-time axis contains only integers.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
SignalPlot
:[font = text; inactive; ]
		SignalPlot that plots the real and imaginary components of a continuous function of one variable on the same plot, as well as Dirac delta functions.  It also plots functions of two variables.
:[font = input; endGroup; ]
	SignalPlot[ Cos[t] + I Sin[t], {t, 0, 4 Pi} ]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
SPSimplify
:[font = text; inactive; endGroup; endGroup; ]
		SPSimplify complements the abilities of Simplify.    It contains the rules so that simplification is the same for Mathematica 1.2 and 2.0.  That is, SPSimplify[ x ] iteratively calls Simplify and applies its own rules until the expression no longer changes.  SPSimplify supports a Dialogue option.  Version 2.6 enhanced SPSimplify so that variables of interest could be specified.
:[font = subsection; inactive; startGroup; Cclosed; ]
New Objects in 2.5
:[font = text; inactive; ]
		The two greatest contributions of version 2.5 are in the areas of multirate signal processing and object-oriented representation for signals and systems.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Multirate Signal Processing
:[font = text; inactive; ]
		At the heart of multirate signal processing are the operations of upsampling and downsampling.  In one-dimension, these operations have been well understood for many years.  The general multidimensional case has only recently been generalized.  The symbolic algebra that captures interactions between cascades of upsamplers and downsamplers relies on the following operations (note that a resampling matrix is a non-singular integer matrix):
:[font = special2; inactive; startGroup; Cclosed; ]
Number Theory
:[font = input; ]
BezoutNumbers
:[font = smalltext; inactive; ]
given two integers a and b, the Bezout numbers lambda and mu satisfy the equation lambda a + mu b = gcd(a, b). 
:[font = input; ]
GCRD & GCLD
:[font = smalltext; inactive; ]
finds the greatest common right and left divisors of two resampling matrices
:[font = input; ]
LCLM & LCRM
:[font = smalltext; inactive; ]
finds the least common left and right multiples of two resampling matrices
:[font = input; ]
RelativelyPrime
:[font = smalltext; inactive; ]
determines the conditions for relatively primeness of two integers, two polynomials, or two resampling matrices.  In the case of resampling matrices, the routine needs to know which direction to check for relative primeness (left or right).
:[font = input; ]
ResamplingMatrixMod
:[font = smalltext; inactive; endGroup; ]
implements the integer vector n modulo a sampling matrix N which is defined as the vector operation   n - N . Floor[ N^-1 . n ]. 
:[font = special2; inactive; startGroup; Cclosed; ]
Integer Matrix Algebra
:[font = input; ]
ColumnHermiteForm
:[font = smalltext; inactive; ]
factors an integer matrix into upper triangular integer matrix
:[font = input; ]
RowHermiteForm
:[font = smalltext; inactive; ]
factors an integer matrix into upper triangular integer matrix
:[font = input; ]
SmithFormSameU & SmithFormSameV
:[font = smalltext; inactive; ]
determines if two resampling matrices can be factored in a Smith Form using the same left regular unimodular matrix U or the same right regular unimodular matrix V.
:[font = input; ]
SmithNormalForm & SmithOrderedForm &
SmithReducedForm
:[font = smalltext; inactive; endGroup; ]
implement various versions of the Smith Form Decomposition of a resampling matrix.
:[font = special2; inactive; startGroup; Cclosed; ]
Lattice Theory
:[font = input; ]
CommutableResamplingMatricesQ
:[font = smalltext; inactive; ]
determines whether or not two resampling matrices representing a down/upsampling cascade are commutative.
:[font = input; ]
DistinctCosetVectors
:[font = smalltext; inactive; endGroup; endGroup; ]
generates the distinct coset vectors for a given resampling matrix
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Object-Oriented Representations for Signals and Systems
:[font = text; inactive; ]
		Essentially, this set of extensions allows the capture of properties of signals and systems.  In the case of systems, properties are attached to an operator.  Since these properties do not change, operators are not instantiated.  Signal properties, on the other hand, vary from signal to signal and depend on many factors.
:[font = special2; inactive; startGroup; Cclosed; ]
System Properties
:[font = output; inactive; endGroup; ]
ASSOCIATIVE     can change grouping of inputs
ADDITIVE        distributes over addition
COMMUTATIVE     can change order of inputs
CONTINUOUS      inputs are continuous signals
DISCRETE        inputs are discrete signals
HOMOGENEOUS     scaled input gives scaled output
LINEAR          additive and homogeneous
MEMORYLESS      output does not depend on previous
                inputs/outputs; if a single-input
                system, then SHIFTINVARIANT
SHIFTINVARIANT  shifted input gives shifted output
:[font = special2; inactive; startGroup; Cclosed; ]
Signal Properties
:[font = output; inactive; endGroup; endGroup; endGroup; center; ]
Bandwidth
CenterOfSymmetry
End
EndBandwidth
Period
Start
StartBandwidth
Support
Symmetry
:[font = subsection; inactive; startGroup; Cclosed; ]
New Objects in 2.6
:[font = subsubsection; inactive; startGroup; Cclosed; ]
BezoutNumbers
:[font = text; inactive; ]
BezoutNumbers.  BezoutNumbers finds integers mu and lambda given integers a and b such that
:[font = input; center; ]
a mu + b lambda == gcd(a,b)
:[font = text; inactive; endGroup; ]
BezoutNumbers calls the Mathematica primitive ExtendedGCD.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
EuclidFactors
:[font = text; inactive; ]
EuclidFactors finds the integers mu and lambda given relatively prime integers p and q and any integer k so that
:[font = input; center; ]
p mu + q lambda == k
:[font = text; inactive; endGroup; ]
EuclidFactors also works when p and q are integer matrices (in which case mu, lambda, and k become integer vectors).

:[font = subsubsection; inactive; startGroup; Cclosed; ]
GetShiftFactor
:[font = text; inactive; endGroup; ]
GetShiftFactor computes the shift term for a given variable.  For example, the shift term in (s + b + c) Exp[s + Pi + b] with respect to s is b.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Heuristics
:[font = text; inactive; endGroup; ]
Introduced a heuristic to apply rewrite rules intelligently called SPHeuristicRewrite.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
CircularShift
:[font = text; inactive; endGroup; endGroup; ]
The CircularShift operator is now provided to accompany the DFT rule base.
:[font = subsection; inactive; startGroup; Cclosed; ]
New Transform Capabilities
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Justification
:[font = text; inactive; ]
		As mentioned in the opening paragraphs, all 10 transform rule bases can fully justify their answers.  The value of the option Dialogue indicates the level of justification:  False (none), True (only indicate when strategies are used), and All (show each step of the transformation process).
:[font = input; ]
	LaPlace[ A Exp[a t] Cos[b t] CStep[t], t, s,
			 Dialogue -> All ]
:[font = text; inactive; endGroup; ]
The linear constant coefficient difference and differential equation solvers (ZSolve and LSolve) also support three levels of justification (none, some, and complete) indicated by the value of the dialogue option (False, True, All).
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Assumptions on Free Parameters
:[font = text; inactive; endGroup; ]
	The rule bases now keep track of the assumptions made on free parameters.  These assumptions can be retrieved using Assuming[All].  The assumptions are displayed when full dialogue is enabled (via the option Dialogue -> All).
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Transforms of Abstract Signals
:[font = text; inactive; ]
		The various transform rule bases allows users to specify their own transform pairs.  The transform pairs are put at the beginning of the rule base so they override the built-in knowledge of the rule base.
:[font = text; inactive; ]
		The ability to customize a rule base enable users to transform general functions, like x[n], without ever defining them.  For example,
:[font = input; startGroup; Cclosed; ]
ZTransform[ Shift[L,n][x[n]], n, z,
      TransformLookup -> { x[n] :> X[z] } ]
:[font = output; inactive; output; endGroup; ]
ZTransData[X[z]/z^L, Rminus[0], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
           X[z]
ZTransData[----, Rminus[0], Rplus[Infinity], 
             L
            z
 
  ZVariables[z]]
:[font = text; inactive; ]
In this example, the abstract signal x[n] is shifted by L to produce another abstract signal.  The resulting z-transform is z^(-L) X(z), where x[n] <--> X[z].  Now, the z-transform can be manipulated as an algebraic expression.
:[font = text; inactive; ]
		In N dimensions, the transform rule bases apply a one-dimensional rule base N times.  For example, in the two-dimensional case,
:[font = input; startGroup; Cclosed; ]
ZTransform[ x[n1,n2], {n1,n2}, {z1,z2},
TransformLookup -> { x[n1,n2] :> X[z1, z2] } ]
:[font = message; inactive; startGroup; ]
Transform::incomplete: 
   The rule base could not compute the 
    forward z-transform of 1 with respect to n2.
:[font = output; inactive; output; endGroup; endGroup; ]
MakeZObject[SignalProcessing`Digital`ZTransform`Private\
    `MultiDROC[MakeZObject[ScaleT[ZForm, 
     SignalProcessing`Digital`ZTransform`Private`forwar\
       dz[1, n2, z2, {True, True, True, False, False}, 
      {n1, n2}, {z1, z2}, {Dialogue -> True}], 
     X[z1, z2]], z2], ZTransData[X[z1, z2], Rminus[0], 
    Rplus[DirectedInfinity[1]], ZVariables[z1]]]]
;[o]
-Incomplete z-Transform-
:[font = text; inactive; ]
so a user cannot specify a two-dimensional transform of an abstract function in this way.  Instead, a two-dimensional transform pair would be specified using a partial transform X1[z1, n2] which represents the z-transform of x[n1,n2] w/r to n1:
:[font = input; startGroup; Cclosed; ]
ZTransform[ x[n1,n2], {n1,n2}, {z1,z2},
TransformLookup -> { x[n1,n2] :> X1[z1, n2],
                     X1[z1,n2] :> X[z1, z2] } ]
:[font = output; inactive; output; endGroup; endGroup; ]
ZTransData[X[z1, z2], Rminus[{0, 0}], 
  Rplus[{DirectedInfinity[1], DirectedInfinity[1]}], 
  ZVariables[{z1, z2}]]
;[o]
ZTransData[X[z1, z2], Rminus[{0, 0}], 
 
  Rplus[{Infinity, Infinity}], ZVariables[{z1, z2}]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Error Handling
:[font = text; inactive; endGroup; ]
	The rule bases now check their arguments more closely so as to ``idiot-proof'' them.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
LaPlace transforms
:[font = text; inactive; ]
	Mathematica 1.2 has a problem performing partial fractions decomposition on real-valued polynomials even if you do all the factoring yourself.  So, we have added a new option to the InvLaPlace object called Apart.  If set to All, then we kludge around the Apart deficiency so that a partial fractions decomposition is formed.  Otherwise, we inverse transform the function as an IIR filter whose input is the inverse transform of the numerator.
:[font = input; ]
LaPlace[ 1 / ( s^2 + 2.0 s + 1), t, s,
         Apart -> All ]
:[font = text; inactive; endGroup; ]
Mathematica 2.0 correctly recongizes the denominator as a polynomial.  However, its implementation of Apart is flawed because it will not factor denominators having non-rational roots.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Fourier Transforms
:[font = text; inactive; ]
		We have added many transform pairs to the continuous-time Fourier transform rule bases CTFTransform and InvCTFTransform
:[font = text; inactive; ]
		The Fourier transform rule bases now handle the convolution operator:
:[font = input; endGroup; ]
CTFTransform[ Convolve[t][ CPulse[1, t + 1/2],
                           CStep[t] ],
              t, s ]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
z-Transform
:[font = text; inactive; ]
		The z-transform of IIR structures returns a valid region of convergence.		
:[font = input; endGroup; endGroup; ]
	ZTransform[ IIR[n, {1, 1/2, 1/4}], n, z ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Miscellaneous Improvements
:[font = text; inactive; ]
		The functional form of the Upsample function did not return values when the sample index was not an integer.  This was a problem when the sample index was real-valued integer like 1.0.  This disrupted the plotting of upsampled sequences.  No longer.
:[font = input; startGroup; Cclosed; ]
SequencePlot[Upsample[3,n][Cos[Pi n/8]],
             {n, 0, 48}] 
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01984 0.30902 0.2943 [
[(Sequence Plot)] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.22222 0.29652 0 1 Msboxa
[(20)] 0.42063 0.29652 0 1 Msboxa
[(30)] 0.61905 0.29652 0 1 Msboxa
[(40)] 0.81746 0.29652 0 1 Msboxa
[(n)] 1.00625 0.30902 -1 0 Msboxa
[(-1)] 0.01131 0.01472 1 0 Msboxa
[(-0.5)] 0.01131 0.16187 1 0 Msboxa
[(0.5)] 0.01131 0.45617 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.22222 0.30277 moveto
0.22222 0.31527 lineto
stroke
0 setgray
[(10)] 0.22222 0.29652 0 1 Mshowa
0.42063 0.30277 moveto
0.42063 0.31527 lineto
stroke
0 setgray
[(20)] 0.42063 0.29652 0 1 Mshowa
0.61905 0.30277 moveto
0.61905 0.31527 lineto
stroke
0 setgray
[(30)] 0.61905 0.29652 0 1 Mshowa
0.81746 0.30277 moveto
0.81746 0.31527 lineto
stroke
0 setgray
[(40)] 0.81746 0.29652 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.30902 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.01472 moveto
0.03006 0.01472 lineto
stroke
0 setgray
[(-1)] 0.01131 0.01472 1 0 Mshowa
0.01756 0.16187 moveto
0.03006 0.16187 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.16187 1 0 Mshowa
0.01756 0.45617 moveto
0.03006 0.45617 lineto
stroke
0 setgray
[(0.5)] 0.01131 0.45617 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02381 0.60332 lineto
stroke
0.008 setlinewidth
0.02381 0.60332 Mdot
0.004 setlinewidth
0.04365 0.30902 moveto
0.04365 0.30902 lineto
stroke
0.008 setlinewidth
0.04365 0.30902 Mdot
0.004 setlinewidth
0.06349 0.30902 moveto
0.06349 0.30902 lineto
stroke
0.008 setlinewidth
0.06349 0.30902 Mdot
0.004 setlinewidth
0.08333 0.30902 moveto
0.08333 0.58092 lineto
stroke
0.008 setlinewidth
0.08333 0.58092 Mdot
0.004 setlinewidth
0.10317 0.30902 moveto
0.10317 0.30902 lineto
stroke
0.008 setlinewidth
0.10317 0.30902 Mdot
0.004 setlinewidth
0.12302 0.30902 moveto
0.12302 0.30902 lineto
stroke
0.008 setlinewidth
0.12302 0.30902 Mdot
0.004 setlinewidth
0.14286 0.30902 moveto
0.14286 0.51712 lineto
stroke
0.008 setlinewidth
0.14286 0.51712 Mdot
0.004 setlinewidth
0.1627 0.30902 moveto
0.1627 0.30902 lineto
stroke
0.008 setlinewidth
0.1627 0.30902 Mdot
0.004 setlinewidth
0.18254 0.30902 moveto
0.18254 0.30902 lineto
stroke
0.008 setlinewidth
0.18254 0.30902 Mdot
0.004 setlinewidth
0.20238 0.30902 moveto
0.20238 0.42164 lineto
stroke
0.008 setlinewidth
0.20238 0.42164 Mdot
0.004 setlinewidth
0.22222 0.30902 moveto
0.22222 0.30902 lineto
stroke
0.008 setlinewidth
0.22222 0.30902 Mdot
0.004 setlinewidth
0.24206 0.30902 moveto
0.24206 0.30902 lineto
stroke
0.008 setlinewidth
0.24206 0.30902 Mdot
0.004 setlinewidth
0.2619 0.30902 moveto
0.2619 0.30902 lineto
stroke
0.008 setlinewidth
0.2619 0.30902 Mdot
0.004 setlinewidth
0.28175 0.30902 moveto
0.28175 0.30902 lineto
stroke
0.008 setlinewidth
0.28175 0.30902 Mdot
0.004 setlinewidth
0.30159 0.30902 moveto
0.30159 0.30902 lineto
stroke
0.008 setlinewidth
0.30159 0.30902 Mdot
0.004 setlinewidth
0.32143 0.30902 moveto
0.32143 0.19639 lineto
stroke
0.008 setlinewidth
0.32143 0.19639 Mdot
0.004 setlinewidth
0.34127 0.30902 moveto
0.34127 0.30902 lineto
stroke
0.008 setlinewidth
0.34127 0.30902 Mdot
0.004 setlinewidth
0.36111 0.30902 moveto
0.36111 0.30902 lineto
stroke
0.008 setlinewidth
0.36111 0.30902 Mdot
0.004 setlinewidth
0.38095 0.30902 moveto
0.38095 0.10091 lineto
stroke
0.008 setlinewidth
0.38095 0.10091 Mdot
0.004 setlinewidth
0.40079 0.30902 moveto
0.40079 0.30902 lineto
stroke
0.008 setlinewidth
0.40079 0.30902 Mdot
0.004 setlinewidth
0.42063 0.30902 moveto
0.42063 0.30902 lineto
stroke
0.008 setlinewidth
0.42063 0.30902 Mdot
0.004 setlinewidth
0.44048 0.30902 moveto
0.44048 0.03712 lineto
stroke
0.008 setlinewidth
0.44048 0.03712 Mdot
0.004 setlinewidth
0.46032 0.30902 moveto
0.46032 0.30902 lineto
stroke
0.008 setlinewidth
0.46032 0.30902 Mdot
0.004 setlinewidth
0.48016 0.30902 moveto
0.48016 0.30902 lineto
stroke
0.008 setlinewidth
0.48016 0.30902 Mdot
0.004 setlinewidth
0.5 0.30902 moveto
0.5 0.01472 lineto
stroke
0.008 setlinewidth
0.5 0.01472 Mdot
0.004 setlinewidth
0.51984 0.30902 moveto
0.51984 0.30902 lineto
stroke
0.008 setlinewidth
0.51984 0.30902 Mdot
0.004 setlinewidth
0.53968 0.30902 moveto
0.53968 0.30902 lineto
stroke
0.008 setlinewidth
0.53968 0.30902 Mdot
0.004 setlinewidth
0.55952 0.30902 moveto
0.55952 0.03712 lineto
stroke
0.008 setlinewidth
0.55952 0.03712 Mdot
0.004 setlinewidth
0.57937 0.30902 moveto
0.57937 0.30902 lineto
stroke
0.008 setlinewidth
0.57937 0.30902 Mdot
0.004 setlinewidth
0.59921 0.30902 moveto
0.59921 0.30902 lineto
stroke
0.008 setlinewidth
0.59921 0.30902 Mdot
0.004 setlinewidth
0.61905 0.30902 moveto
0.61905 0.10091 lineto
stroke
0.008 setlinewidth
0.61905 0.10091 Mdot
0.004 setlinewidth
0.63889 0.30902 moveto
0.63889 0.30902 lineto
stroke
0.008 setlinewidth
0.63889 0.30902 Mdot
0.004 setlinewidth
0.65873 0.30902 moveto
0.65873 0.30902 lineto
stroke
0.008 setlinewidth
0.65873 0.30902 Mdot
0.004 setlinewidth
0.67857 0.30902 moveto
0.67857 0.19639 lineto
stroke
0.008 setlinewidth
0.67857 0.19639 Mdot
0.004 setlinewidth
0.69841 0.30902 moveto
0.69841 0.30902 lineto
stroke
0.008 setlinewidth
0.69841 0.30902 Mdot
0.004 setlinewidth
0.71825 0.30902 moveto
0.71825 0.30902 lineto
stroke
0.008 setlinewidth
0.71825 0.30902 Mdot
0.004 setlinewidth
0.7381 0.30902 moveto
0.7381 0.30902 lineto
stroke
0.008 setlinewidth
0.7381 0.30902 Mdot
0.004 setlinewidth
0.75794 0.30902 moveto
0.75794 0.30902 lineto
stroke
0.008 setlinewidth
0.75794 0.30902 Mdot
0.004 setlinewidth
0.77778 0.30902 moveto
0.77778 0.30902 lineto
stroke
0.008 setlinewidth
0.77778 0.30902 Mdot
0.004 setlinewidth
0.79762 0.30902 moveto
0.79762 0.42164 lineto
stroke
0.008 setlinewidth
0.79762 0.42164 Mdot
0.004 setlinewidth
0.81746 0.30902 moveto
0.81746 0.30902 lineto
stroke
0.008 setlinewidth
0.81746 0.30902 Mdot
0.004 setlinewidth
0.8373 0.30902 moveto
0.8373 0.30902 lineto
stroke
0.008 setlinewidth
0.8373 0.30902 Mdot
0.004 setlinewidth
0.85714 0.30902 moveto
0.85714 0.51712 lineto
stroke
0.008 setlinewidth
0.85714 0.51712 Mdot
0.004 setlinewidth
0.87698 0.30902 moveto
0.87698 0.30902 lineto
stroke
0.008 setlinewidth
0.87698 0.30902 Mdot
0.004 setlinewidth
0.89683 0.30902 moveto
0.89683 0.30902 lineto
stroke
0.008 setlinewidth
0.89683 0.30902 Mdot
0.004 setlinewidth
0.91667 0.30902 moveto
0.91667 0.58092 lineto
stroke
0.008 setlinewidth
0.91667 0.58092 Mdot
0.004 setlinewidth
0.93651 0.30902 moveto
0.93651 0.30902 lineto
stroke
0.008 setlinewidth
0.93651 0.30902 Mdot
0.004 setlinewidth
0.95635 0.30902 moveto
0.95635 0.30902 lineto
stroke
0.008 setlinewidth
0.95635 0.30902 Mdot
0.004 setlinewidth
0.97619 0.30902 moveto
0.97619 0.60332 lineto
stroke
0.008 setlinewidth
0.97619 0.60332 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = text; inactive; ]
Another problem with SequencePlot was plotting 2-D signals.  It did not sample the function at integer indices, so the plot below 
:[font = input; startGroup; Cclosed; ]
SequencePlot[ (1/2)^n1 (4/5)^n2
              Multinomial[n1,n2] Step[n1,n2],
              {n1, 0, 10}, {n2, 0, 10} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(0)] 0.05688 0.31214 1 0.933946 Msboxa
[(2)] 0.16235 0.27062 0.987329 1 Msboxa
[(4)] 0.27294 0.22711 0.903932 1 Msboxa
[(6)] 0.38903 0.18145 0.820535 1 Msboxa
[(8)] 0.51104 0.13348 0.737139 1 Msboxa
[(10)] 0.63943 0.08304 0.653742 1 Msboxa
[(0)] 0.65703 0.08867 -1 0.391569 Msboxa
[(2)] 0.71626 0.17936 -1 0.369305 Msboxa
[(4)] 0.77029 0.26211 -1 0.349436 Msboxa
[(6)] 0.81979 0.33791 -1 0.331596 Msboxa
[(8)] 0.8653 0.40761 -1 0.315489 Msboxa
[(10)] 0.90729 0.47191 -1 0.300874 Msboxa
[(0)] 0.05375 0.32922 1 -0.390596 Msboxa
[(5)] 0.04272 0.39834 1 -0.376005 Msboxa
[(10)] 0.03113 0.47102 1 -0.360582 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.16653 0.27486 moveto
0.1749 0.28333 lineto
stroke
0 setgray
[(2)] 0.16235 0.27062 0.987329 1 Mshowa
0.27693 0.23152 moveto
0.28492 0.24035 lineto
stroke
0 setgray
[(4)] 0.27294 0.22711 0.903932 1 Mshowa
0.39281 0.18605 moveto
0.40036 0.19525 lineto
stroke
0 setgray
[(6)] 0.38903 0.18145 0.820535 1 Mshowa
0.51457 0.13827 moveto
0.52164 0.14786 lineto
stroke
0 setgray
[(8)] 0.51104 0.13348 0.737139 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(10)] 0.63943 0.08304 0.653742 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71067 0.18142 moveto
0.69951 0.18555 lineto
stroke
0 setgray
[(2)] 0.71626 0.17936 -1 0.369305 Mshowa
0.76468 0.26407 moveto
0.75344 0.268 lineto
stroke
0 setgray
[(4)] 0.77029 0.26211 -1 0.349436 Mshowa
0.81414 0.33978 moveto
0.80284 0.34353 lineto
stroke
0 setgray
[(6)] 0.81979 0.33791 -1 0.331596 Mshowa
0.85963 0.4094 moveto
0.84827 0.41298 lineto
stroke
0 setgray
[(8)] 0.8653 0.40761 -1 0.315489 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(10)] 0.90729 0.47191 -1 0.300874 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.0483 0.39624 moveto
0.05944 0.39205 lineto
stroke
0 setgray
[(5)] 0.04272 0.39834 1 -0.376005 Mshowa
0.03673 0.469 moveto
0.04792 0.46496 lineto
stroke
0 setgray
[(10)] 0.03113 0.47102 1 -0.360582 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.1265 setgray
0.0015 setlinewidth
0.37366 0.61417 0.39328 0.63207 0.42589 0.62827 0.4065 0.61084 Metetra
0.15629 setgray
0.4065 0.61084 0.42589 0.62827 0.45917 0.61834 0.44009 0.60065 Metetra
0.15629 setgray
0.44009 0.60065 0.45917 0.61834 0.49288 0.6232 0.47401 0.60528 Metetra
0.22148 setgray
0.47401 0.60528 0.49288 0.6232 0.5275 0.63962 0.50879 0.61874 Metetra
0.32391 setgray
0.50879 0.61874 0.5275 0.63962 0.56346 0.66737 0.54473 0.63877 Metetra
0.45194 setgray
0.54473 0.63877 0.56346 0.66737 0.59959 0.65716 0.5811 0.62825 Metetra
0.45194 setgray
0.5811 0.62825 0.59959 0.65716 0.6383 0.69267 0.61929 0.65022 Metetra
0.5851 setgray
0.61929 0.65022 0.6383 0.69267 0.67877 0.7298 0.65867 0.66878 Metetra
0.70161 setgray
0.65867 0.66878 0.67877 0.7298 0.71774 0.71953 0.69751 0.65803 Metetra
0.70161 setgray
0.69751 0.65803 0.71774 0.71953 0.75807 0.71832 0.73861 0.66855 Metetra
0.78484 setgray
0.73861 0.66855 0.75807 0.71832 0.79838 0.70776 0.77994 0.66843 Metetra
0.82645 setgray
0.77994 0.66843 0.79838 0.70776 0.83933 0.69704 0.82109 0.65731 Metetra
0.82645 setgray
0.82109 0.65731 0.83933 0.69704 0.88093 0.68615 0.86289 0.64601 Metetra
0.82645 setgray
0.86289 0.64601 0.88093 0.68615 0.92319 0.67509 0.90413 0.62516 Metetra
0.1265 setgray
0.35355 0.59547 0.37366 0.61417 0.4065 0.61084 0.38663 0.59192 Metetra
0.15629 setgray
0.38663 0.59192 0.4065 0.61084 0.44009 0.60065 0.42052 0.58147 Metetra
0.15629 setgray
0.42052 0.58147 0.44009 0.60065 0.47401 0.60528 0.45465 0.58592 Metetra
0.22148 setgray
0.45465 0.58592 0.47401 0.60528 0.50879 0.61874 0.4896 0.59927 Metetra
0.32391 setgray
0.4896 0.59927 0.50879 0.61874 0.54473 0.63877 0.52569 0.61923 Metetra
0.45194 setgray
0.52569 0.61923 0.54473 0.63877 0.5811 0.62825 0.56243 0.60842 Metetra
0.45194 setgray
0.56243 0.60842 0.5811 0.62825 0.61929 0.65022 0.6008 0.63033 Metetra
0.5851 setgray
0.6008 0.63033 0.61929 0.65022 0.65867 0.66878 0.64042 0.64881 Metetra
0.70161 setgray
0.64042 0.64881 0.65867 0.66878 0.69751 0.65803 0.67968 0.63775 Metetra
0.70161 setgray
0.67968 0.63775 0.69751 0.65803 0.73861 0.66855 0.72111 0.64812 Metetra
0.78484 setgray
0.72111 0.64812 0.73861 0.66855 0.77994 0.66843 0.76285 0.64776 Metetra
0.82645 setgray
0.76285 0.64776 0.77994 0.66843 0.82109 0.65731 0.80447 0.6363 Metetra
0.82645 setgray
0.80447 0.6363 0.82109 0.65731 0.86289 0.64601 0.84677 0.62466 Metetra
0.82645 setgray
0.84677 0.62466 0.86289 0.64601 0.90413 0.62516 0.88854 0.60339 Metetra
0.12836 setgray
0.3329 0.57671 0.35355 0.59547 0.38663 0.59192 0.36619 0.57358 Metetra
0.16095 setgray
0.36619 0.57358 0.38663 0.59192 0.42052 0.58147 0.40039 0.56285 Metetra
0.16095 setgray
0.40039 0.56285 0.42052 0.58147 0.45465 0.58592 0.43476 0.56659 Metetra
0.2238 setgray
0.43476 0.56659 0.45465 0.58592 0.4896 0.59927 0.46992 0.57622 Metetra
0.3111 setgray
0.46992 0.57622 0.4896 0.59927 0.52569 0.61923 0.50611 0.58824 Metetra
0.40713 setgray
0.50611 0.58824 0.52569 0.61923 0.56243 0.60842 0.54307 0.57709 Metetra
0.40713 setgray
0.54307 0.57709 0.56243 0.60842 0.6008 0.63033 0.58117 0.58702 Metetra
0.49355 setgray
0.58117 0.58702 0.6008 0.63033 0.64042 0.64881 0.62017 0.59121 Metetra
0.55597 setgray
0.62017 0.59121 0.64042 0.64881 0.67968 0.63775 0.65935 0.57968 Metetra
0.55597 setgray
0.65935 0.57968 0.67968 0.63775 0.72111 0.64812 0.69968 0.57589 Metetra
0.58718 setgray
0.69968 0.57589 0.72111 0.64812 0.76285 0.64776 0.74023 0.56402 Metetra
0.58718 setgray
0.74023 0.56402 0.76285 0.64776 0.80447 0.6363 0.78079 0.5453 Metetra
0.56117 setgray
0.78079 0.5453 0.80447 0.6363 0.84677 0.62466 0.82255 0.53302 Metetra
0.56117 setgray
0.82255 0.53302 0.84677 0.62466 0.88854 0.60339 0.86358 0.5092 Metetra
0.13069 setgray
0.31168 0.55755 0.3329 0.57671 0.36619 0.57358 0.3452 0.55473 Metetra
0.16561 setgray
0.3452 0.55473 0.36619 0.57358 0.40039 0.56285 0.37971 0.54372 Metetra
0.16561 setgray
0.37971 0.54372 0.40039 0.56285 0.43476 0.56659 0.41434 0.54617 Metetra
0.2238 setgray
0.41434 0.54617 0.43476 0.56659 0.46992 0.57622 0.44976 0.55147 Metetra
0.29364 setgray
0.44976 0.55147 0.46992 0.57622 0.50611 0.58824 0.48612 0.55584 Metetra
0.35912 setgray
0.48612 0.55584 0.50611 0.58824 0.54307 0.57709 0.52331 0.54433 Metetra
0.35912 setgray
0.52331 0.54433 0.54307 0.57709 0.58117 0.58702 0.56131 0.5444 Metetra
0.40713 setgray
0.56131 0.5444 0.58117 0.58702 0.62017 0.59121 0.6 0.53851 Metetra
0.43114 setgray
0.6 0.53851 0.62017 0.59121 0.65935 0.57968 0.63918 0.52652 Metetra
0.43114 setgray
0.63918 0.52652 0.65935 0.57968 0.69968 0.57589 0.67898 0.51434 Metetra
0.43114 setgray
0.67898 0.51434 0.69968 0.57589 0.74023 0.56402 0.71905 0.49708 Metetra
0.41163 setgray
0.71905 0.49708 0.74023 0.56402 0.78079 0.5453 0.75933 0.47636 Metetra
0.37912 setgray
0.75933 0.47636 0.78079 0.5453 0.82255 0.53302 0.80088 0.46354 Metetra
0.37912 setgray
0.80088 0.46354 0.82255 0.53302 0.86358 0.5092 0.84193 0.44075 Metetra
0.1336 setgray
0.28988 0.53801 0.31168 0.55755 0.3452 0.55473 0.32362 0.53529 Metetra
0.16997 setgray
0.32362 0.53529 0.3452 0.55473 0.37971 0.54372 0.35846 0.52398 Metetra
0.16997 setgray
0.35846 0.52398 0.37971 0.54372 0.41434 0.54617 0.39338 0.52451 Metetra
0.22089 setgray
0.39338 0.52451 0.41434 0.54617 0.44976 0.55147 0.42911 0.52505 Metetra
0.27182 setgray
0.42911 0.52505 0.44976 0.55147 0.48612 0.55584 0.46573 0.52252 Metetra
0.31001 setgray
0.46573 0.52252 0.48612 0.55584 0.52331 0.54433 0.50314 0.51063 Metetra
0.31001 setgray
0.50314 0.51063 0.52331 0.54433 0.56131 0.5444 0.54119 0.50322 Metetra
0.32911 setgray
0.54119 0.50322 0.56131 0.5444 0.6 0.53851 0.57983 0.49098 Metetra
0.32911 setgray
0.57983 0.49098 0.6 0.53851 0.63918 0.52652 0.61908 0.47854 Metetra
0.32911 setgray
0.61908 0.47854 0.63918 0.52652 0.67898 0.51434 0.65875 0.46221 Metetra
0.3141 setgray
0.65875 0.46221 0.67898 0.51434 0.71905 0.49708 0.6988 0.44334 Metetra
0.28972 setgray
0.6988 0.44334 0.71905 0.49708 0.75933 0.47636 0.73923 0.42325 Metetra
0.26128 setgray
0.73923 0.42325 0.75933 0.47636 0.80088 0.46354 0.78081 0.40994 Metetra
0.26128 setgray
0.78081 0.40994 0.80088 0.46354 0.84193 0.44075 0.82226 0.38938 Metetra
0.1336 setgray
0.26754 0.51725 0.28988 0.53801 0.32362 0.53529 0.3015 0.51428 Metetra
0.16997 setgray
0.3015 0.51428 0.32362 0.53529 0.35846 0.52398 0.33666 0.50266 Metetra
0.16997 setgray
0.33666 0.50266 0.35846 0.52398 0.39338 0.52451 0.37181 0.50294 Metetra
0.22089 setgray
0.37181 0.50294 0.39338 0.52451 0.42911 0.52505 0.4078 0.50323 Metetra
0.27182 setgray
0.4078 0.50323 0.42911 0.52505 0.46573 0.52252 0.44471 0.50043 Metetra
0.31001 setgray
0.44471 0.50043 0.46573 0.52252 0.50314 0.51063 0.48249 0.4882 Metetra
0.31001 setgray
0.48249 0.4882 0.50314 0.51063 0.54119 0.50322 0.52089 0.48047 Metetra
0.32911 setgray
0.52089 0.48047 0.54119 0.50322 0.57983 0.49098 0.55994 0.46786 Metetra
0.32911 setgray
0.55994 0.46786 0.57983 0.49098 0.61908 0.47854 0.59961 0.45506 Metetra
0.32911 setgray
0.59961 0.45506 0.61908 0.47854 0.65875 0.46221 0.63974 0.43832 Metetra
0.3141 setgray
0.63974 0.43832 0.65875 0.46221 0.6988 0.44334 0.68027 0.41903 Metetra
0.28972 setgray
0.68027 0.41903 0.6988 0.44334 0.73923 0.42325 0.72121 0.3985 Metetra
0.26128 setgray
0.72121 0.3985 0.73923 0.42325 0.78081 0.40994 0.76327 0.38478 Metetra
0.26128 setgray
0.76327 0.38478 0.78081 0.40994 0.82226 0.38938 0.80525 0.36377 Metetra
0.13723 setgray
0.2445 0.49677 0.26754 0.51725 0.3015 0.51428 0.27871 0.49355 Metetra
0.17361 setgray
0.27871 0.49355 0.3015 0.51428 0.33666 0.50266 0.31419 0.4816 Metetra
0.17361 setgray
0.31419 0.4816 0.33666 0.50266 0.37181 0.50294 0.34971 0.47924 Metetra
0.21453 setgray
0.34971 0.47924 0.37181 0.50294 0.4078 0.50323 0.38611 0.47463 Metetra
0.24636 setgray
0.38611 0.47463 0.4078 0.50323 0.44471 0.50043 0.42338 0.46605 Metetra
0.26227 setgray
0.42338 0.46605 0.44471 0.50043 0.48249 0.4882 0.46139 0.45342 Metetra
0.26227 setgray
0.46139 0.45342 0.48249 0.4882 0.52089 0.48047 0.5 0.44058 Metetra
0.26227 setgray
0.5 0.44058 0.52089 0.48047 0.55994 0.46786 0.53919 0.42462 Metetra
0.25033 setgray
0.53919 0.42462 0.55994 0.46786 0.59961 0.45506 0.57902 0.41136 Metetra
0.25033 setgray
0.57902 0.41136 0.59961 0.45506 0.63974 0.43832 0.61929 0.39327 Metetra
0.23158 setgray
0.61929 0.39327 0.63974 0.43832 0.68027 0.41903 0.66006 0.37436 Metetra
0.21048 setgray
0.66006 0.37436 0.68027 0.41903 0.72121 0.3985 0.70136 0.35541 Metetra
0.19016 setgray
0.70136 0.35541 0.72121 0.3985 0.76327 0.38478 0.74363 0.34121 Metetra
0.19016 setgray
0.74363 0.34121 0.76327 0.38478 0.80525 0.36377 0.78615 0.32238 Metetra
0.14178 setgray
0.22079 0.47592 0.2445 0.49677 0.27871 0.49355 0.25528 0.47189 Metetra
0.17588 setgray
0.25528 0.47189 0.27871 0.49355 0.31419 0.4816 0.2911 0.4596 Metetra
0.17588 setgray
0.2911 0.4596 0.31419 0.4816 0.34971 0.47924 0.32706 0.45395 Metetra
0.2043 setgray
0.32706 0.45395 0.34971 0.47924 0.38611 0.47463 0.36392 0.44474 Metetra
0.21851 setgray
0.36392 0.44474 0.38611 0.47463 0.42338 0.46605 0.40157 0.4319 Metetra
0.21851 setgray
0.40157 0.4319 0.42338 0.46605 0.46139 0.45342 0.43982 0.41886 Metetra
0.21851 setgray
0.43982 0.41886 0.46139 0.45342 0.5 0.44058 0.4787 0.40318 Metetra
0.20856 setgray
0.4787 0.40318 0.5 0.44058 0.53919 0.42462 0.51814 0.38606 Metetra
0.19364 setgray
0.51814 0.38606 0.53919 0.42462 0.57902 0.41136 0.5582 0.37236 Metetra
0.19364 setgray
0.5582 0.37236 0.57902 0.41136 0.61929 0.39327 0.59877 0.3545 Metetra
0.17766 setgray
0.59877 0.3545 0.61929 0.39327 0.66006 0.37436 0.63991 0.33673 Metetra
0.16301 setgray
0.63991 0.33673 0.66006 0.37436 0.70136 0.35541 0.68167 0.31931 Metetra
0.15079 setgray
0.68167 0.31931 0.70136 0.35541 0.74363 0.34121 0.72428 0.30464 Metetra
0.15079 setgray
0.72428 0.30464 0.74363 0.34121 0.78615 0.32238 0.76738 0.28737 Metetra
0.14178 setgray
0.1965 0.45339 0.22079 0.47592 0.25528 0.47189 0.23123 0.44906 Metetra
0.17588 setgray
0.23123 0.44906 0.25528 0.47189 0.2911 0.4596 0.26737 0.43642 Metetra
0.17588 setgray
0.26737 0.43642 0.2911 0.4596 0.32706 0.45395 0.30361 0.43045 Metetra
0.2043 setgray
0.30361 0.43045 0.32706 0.45395 0.36392 0.44474 0.3408 0.42088 Metetra
0.21851 setgray
0.3408 0.42088 0.36392 0.44474 0.40157 0.4319 0.37882 0.40766 Metetra
0.21851 setgray
0.37882 0.40766 0.40157 0.4319 0.43982 0.41886 0.41746 0.39423 Metetra
0.21851 setgray
0.41746 0.39423 0.43982 0.41886 0.4787 0.40318 0.45677 0.37814 Metetra
0.20856 setgray
0.45677 0.37814 0.4787 0.40318 0.51814 0.38606 0.49665 0.36059 Metetra
0.19364 setgray
0.49665 0.36059 0.51814 0.38606 0.5582 0.37236 0.53714 0.34646 Metetra
0.19364 setgray
0.53714 0.34646 0.5582 0.37236 0.59877 0.3545 0.57819 0.32816 Metetra
0.17766 setgray
0.57819 0.32816 0.59877 0.3545 0.63991 0.33673 0.61982 0.30992 Metetra
0.16301 setgray
0.61982 0.30992 0.63991 0.33673 0.68167 0.31931 0.66208 0.29204 Metetra
0.15079 setgray
0.66208 0.29204 0.68167 0.31931 0.72428 0.30464 0.7052 0.2769 Metetra
0.15079 setgray
0.7052 0.2769 0.72428 0.30464 0.76738 0.28737 0.74884 0.25915 Metetra
0.14746 setgray
0.17136 0.43157 0.1965 0.45339 0.23123 0.44906 0.20648 0.42557 Metetra
0.17588 setgray
0.20648 0.42557 0.23123 0.44906 0.26737 0.43642 0.24295 0.41256 Metetra
0.17588 setgray
0.24295 0.41256 0.26737 0.43642 0.30361 0.43045 0.27974 0.40279 Metetra
0.19009 setgray
0.27974 0.40279 0.30361 0.43045 0.3408 0.42088 0.31744 0.38937 Metetra
0.19009 setgray
0.31744 0.38937 0.3408 0.42088 0.37882 0.40766 0.35586 0.37356 Metetra
0.18121 setgray
0.35586 0.37356 0.37882 0.40766 0.41746 0.39423 0.39477 0.35969 Metetra
0.18121 setgray
0.39477 0.35969 0.41746 0.39423 0.45677 0.37814 0.43439 0.34254 Metetra
0.16878 setgray
0.43439 0.34254 0.45677 0.37814 0.49665 0.36059 0.47459 0.32514 Metetra
0.15635 setgray
0.47459 0.32514 0.49665 0.36059 0.53714 0.34646 0.51538 0.31055 Metetra
0.15635 setgray
0.51538 0.31055 0.53714 0.34646 0.57819 0.32816 0.5568 0.29308 Metetra
0.14569 setgray
0.5568 0.29308 0.57819 0.32816 0.61982 0.30992 0.59887 0.27593 Metetra
0.13736 setgray
0.59887 0.27593 0.61982 0.30992 0.66208 0.29204 0.64163 0.25905 Metetra
0.13126 setgray
0.64163 0.25905 0.66208 0.29204 0.7052 0.2769 0.68517 0.24342 Metetra
0.13126 setgray
0.68517 0.24342 0.7052 0.2769 0.74884 0.25915 0.72939 0.22646 Metetra
0.15457 setgray
0.14542 0.40943 0.17136 0.43157 0.20648 0.42557 0.1811 0.40052 Metetra
0.17233 setgray
0.1811 0.40052 0.20648 0.42557 0.24295 0.41256 0.2179 0.38712 Metetra
0.17233 setgray
0.2179 0.38712 0.24295 0.41256 0.27974 0.40279 0.2553 0.3735 Metetra
0.17233 setgray
0.2553 0.3735 0.27974 0.40279 0.31744 0.38937 0.29346 0.35749 Metetra
0.16345 setgray
0.29346 0.35749 0.31744 0.38937 0.35586 0.37356 0.33223 0.3407 Metetra
0.15235 setgray
0.33223 0.3407 0.35586 0.37356 0.39477 0.35969 0.37144 0.32638 Metetra
0.15235 setgray
0.37144 0.32638 0.39477 0.35969 0.43439 0.34254 0.41138 0.30937 Metetra
0.14236 setgray
0.41138 0.30937 0.43439 0.34254 0.47459 0.32514 0.45192 0.29265 Metetra
0.13459 setgray
0.45192 0.29265 0.47459 0.32514 0.51538 0.31055 0.49307 0.27758 Metetra
0.13459 setgray
0.49307 0.27758 0.51538 0.31055 0.5568 0.29308 0.53492 0.26089 Metetra
0.12904 setgray
0.53492 0.26089 0.5568 0.29308 0.59887 0.27593 0.57745 0.24437 Metetra
0.12529 setgray
0.57745 0.24437 0.59887 0.27593 0.64163 0.25905 0.62071 0.2279 Metetra
0.12286 setgray
0.62071 0.2279 0.64163 0.25905 0.68517 0.24342 0.66475 0.21175 Metetra
0.12286 setgray
0.66475 0.21175 0.68517 0.24342 0.72939 0.22646 0.70953 0.19494 Metetra
0.16345 setgray
0.11862 0.38704 0.14542 0.40943 0.1811 0.40052 0.15513 0.37345 Metetra
0.16345 setgray
0.15513 0.37345 0.1811 0.40052 0.2179 0.38712 0.19225 0.35964 Metetra
0.16345 setgray
0.19225 0.35964 0.2179 0.38712 0.2553 0.3735 0.23024 0.34288 Metetra
0.15235 setgray
0.23024 0.34288 0.2553 0.3735 0.29346 0.35749 0.26878 0.32588 Metetra
0.14125 setgray
0.26878 0.32588 0.29346 0.35749 0.33223 0.3407 0.30784 0.30931 Metetra
0.13292 setgray
0.30784 0.30931 0.33223 0.3407 0.37144 0.32638 0.34738 0.29454 Metetra
0.13292 setgray
0.34738 0.29454 0.37144 0.32638 0.41138 0.30937 0.38765 0.27814 Metetra
0.12737 setgray
0.38765 0.27814 0.41138 0.30937 0.45192 0.29265 0.42855 0.262 Metetra
0.1239 setgray
0.42855 0.262 0.45192 0.29265 0.49307 0.27758 0.47012 0.24644 Metetra
0.1239 setgray
0.47012 0.24644 0.49307 0.27758 0.53492 0.26089 0.51241 0.2301 Metetra
0.12182 setgray
0.51241 0.2301 0.53492 0.26089 0.57745 0.24437 0.55543 0.21369 Metetra
0.12061 setgray
0.55543 0.21369 0.57745 0.24437 0.62071 0.2279 0.5992 0.19713 Metetra
0.11991 setgray
0.5992 0.19713 0.62071 0.2279 0.66475 0.21175 0.64376 0.18045 Metetra
0.11991 setgray
0.64376 0.18045 0.66475 0.21175 0.70953 0.19494 0.68911 0.16337 Metetra
0.16345 setgray
0.09129 0.36178 0.11862 0.38704 0.15513 0.37345 0.12813 0.34777 Metetra
0.16345 setgray
0.12813 0.34777 0.15513 0.37345 0.19225 0.35964 0.16559 0.33354 Metetra
0.16345 setgray
0.16559 0.33354 0.19225 0.35964 0.23024 0.34288 0.20397 0.31633 Metetra
0.15235 setgray
0.20397 0.31633 0.23024 0.34288 0.26878 0.32588 0.24291 0.29887 Metetra
0.14125 setgray
0.24291 0.29887 0.26878 0.32588 0.30784 0.30931 0.28238 0.28184 Metetra
0.13292 setgray
0.28238 0.28184 0.30784 0.30931 0.34738 0.29454 0.32233 0.26659 Metetra
0.13292 setgray
0.32233 0.26659 0.34738 0.29454 0.38765 0.27814 0.36304 0.24971 Metetra
0.12737 setgray
0.36304 0.24971 0.38765 0.27814 0.42855 0.262 0.40439 0.23307 Metetra
0.1239 setgray
0.40439 0.23307 0.42855 0.262 0.47012 0.24644 0.44642 0.21701 Metetra
0.1239 setgray
0.44642 0.21701 0.47012 0.24644 0.51241 0.2301 0.48919 0.20015 Metetra
0.12182 setgray
0.48919 0.20015 0.51241 0.2301 0.55543 0.21369 0.53271 0.18321 Metetra
0.12061 setgray
0.53271 0.18321 0.55543 0.21369 0.5992 0.19713 0.57701 0.1661 Metetra
0.11991 setgray
0.57701 0.1661 0.5992 0.19713 0.64376 0.18045 0.62211 0.14886 Metetra
0.11991 setgray
0.62211 0.14886 0.64376 0.18045 0.68911 0.16337 0.66803 0.1312 Metetra
0.17455 setgray
0.06269 0.33847 0.09129 0.36178 0.12813 0.34777 0.1009 0.31721 Metetra
0.1468 setgray
0.1009 0.31721 0.12813 0.34777 0.16559 0.33354 0.13865 0.30252 Metetra
0.1468 setgray
0.13865 0.30252 0.16559 0.33354 0.20397 0.31633 0.17745 0.28416 Metetra
0.13292 setgray
0.17745 0.28416 0.20397 0.31633 0.24291 0.29887 0.21663 0.26724 Metetra
0.12599 setgray
0.21663 0.26724 0.24291 0.29887 0.28238 0.28184 0.25636 0.25091 Metetra
0.12252 setgray
0.25636 0.25091 0.28238 0.28184 0.32233 0.26659 0.29668 0.23517 Metetra
0.12252 setgray
0.29668 0.23517 0.32233 0.26659 0.36304 0.24971 0.33773 0.21872 Metetra
0.12078 setgray
0.33773 0.21872 0.36304 0.24971 0.40439 0.23307 0.37948 0.2022 Metetra
0.11991 setgray
0.37948 0.2022 0.40439 0.23307 0.44642 0.21701 0.42197 0.18561 Metetra
0.11991 setgray
0.42197 0.18561 0.44642 0.21701 0.48919 0.20015 0.46521 0.16862 Metetra
0.11948 setgray
0.46521 0.16862 0.48919 0.20015 0.53271 0.18321 0.50924 0.15137 Metetra
0.11926 setgray
0.50924 0.15137 0.53271 0.18321 0.57701 0.1661 0.55407 0.13383 Metetra
0.11916 setgray
0.55407 0.13383 0.57701 0.1661 0.62211 0.14886 0.59972 0.116 Metetra
0.11916 setgray
0.59972 0.116 0.62211 0.14886 0.66803 0.1312 0.64622 0.09782 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06123 0.3162 moveto
0.06993 0.32433 lineto
stroke
0 setgray
[(0)] 0.05688 0.31214 1 0.933946 Mshowa
0.16653 0.27486 moveto
0.1749 0.28333 lineto
stroke
0 setgray
[(2)] 0.16235 0.27062 0.987329 1 Mshowa
0.27693 0.23152 moveto
0.28492 0.24035 lineto
stroke
0 setgray
[(4)] 0.27294 0.22711 0.903932 1 Mshowa
0.39281 0.18605 moveto
0.40036 0.19525 lineto
stroke
0 setgray
[(6)] 0.38903 0.18145 0.820535 1 Mshowa
0.51457 0.13827 moveto
0.52164 0.14786 lineto
stroke
0 setgray
[(8)] 0.51104 0.13348 0.737139 1 Mshowa
0.64269 0.08803 moveto
0.6492 0.09799 lineto
stroke
0 setgray
[(10)] 0.63943 0.08304 0.653742 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.65149 0.09084 moveto
0.6404 0.09518 lineto
stroke
0 setgray
[(0)] 0.65703 0.08867 -1 0.391569 Mshowa
0.71067 0.18142 moveto
0.69951 0.18555 lineto
stroke
0 setgray
[(2)] 0.71626 0.17936 -1 0.369305 Mshowa
0.76468 0.26407 moveto
0.75344 0.268 lineto
stroke
0 setgray
[(4)] 0.77029 0.26211 -1 0.349436 Mshowa
0.81414 0.33978 moveto
0.80284 0.34353 lineto
stroke
0 setgray
[(6)] 0.81979 0.33791 -1 0.331596 Mshowa
0.85963 0.4094 moveto
0.84827 0.41298 lineto
stroke
0 setgray
[(8)] 0.8653 0.40761 -1 0.315489 Mshowa
0.90159 0.47362 moveto
0.89019 0.47705 lineto
stroke
0 setgray
[(10)] 0.90729 0.47191 -1 0.300874 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.0483 0.39624 moveto
0.05944 0.39205 lineto
stroke
0 setgray
[(5)] 0.04272 0.39834 1 -0.376005 Mshowa
0.03673 0.469 moveto
0.04792 0.46496 lineto
stroke
0 setgray
[(10)] 0.03113 0.47102 1 -0.360582 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-SurfaceGraphics-
:[font = text; inactive; ]
These functions also do a better job plotting periodic functions.
:[font = text; inactive; ]
		The Piecewise Convolution package for convolving piecewise-continuous functions is now more consistent in that either argument to the PiecewiseConvolution function can be in list or expression form.  See the PiecewiseConvolution notebook for examples.
:[font = text; inactive; ]
		CFIR and CIIR structures have an optional third argument: Roots->roots.  See the AnalogFilters notebook for examples.
:[font = text; inactive; endGroup; ]
		The CirclePS routine now uses Mathematica's built in Circle command.
:[font = subsection; inactive; startGroup; Cclosed; ]
Initialization with Stubs
:[font = text; inactive; endGroup; ]
		Mathematica 2.0 allows the association of a package with a set of symbols without having to load the package.  This means that initialization now occurs very rapidly even for a large set of extensions and that only packages will be automatically loaded as needed.  Stubs are now defined for all  of the objects in the signal processing packages.  This is what the initialization files "Analog.m", "Digital.m", and "Support.m" do under Mathematica 2.0.
:[font = subsection; inactive; startGroup; Cclosed; ]
Impact
:[font = text; inactive; ]
		Because of the changes, we can recreate (for the most part) the pictorial dictionary of Fourier transforms in chapter 19 of Bracewell's book entitled "The Fourier Transform and Its Applications".
:[font = text; inactive; ]
		Because of the changes and because of subtle modifications to the ExtractVariables object, DSPAnalyze now works correctly for IIR and FIR structures.
:[font = text; inactive; endGroup; endGroup; ]
		We have updated all eight of the notebooks accompanying the signal processing packages to reflect the above enhancements.
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)