(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
Analog Filter Design in Mathematica
:[font = subtitle; inactive; ]

by
:[font = subtitle; inactive; ]

Brian L. Evans and James H. McClellan
:[font = subsubtitle; inactive; ]

Digital Signal Processing Laboratory
School of Electrical Engineering
Georgia Institute of Technology
Atlanta, GA  30332-0250

EMAIL:  evans@eedsp.gatech.edu

:[font = text; inactive; ]
WARNING:  Under Mathematica 1.2, this notebook may take up to 5 minutes to load the analog signal processing packages and initialize the examples.  If it is taking longer than this, then open the Initialization section and check for error messages.  The command to abort the kernel is invoked by hitting the COMMAND and period keys simultaneously.
:[font = text; inactive; ]
WARNING:  Designing elliptic filters depends on the Mathematica elliptic functions EllipticK, JacobiSN, etc.   Versions of Mathematica on some computers (like Mathematica 1.2 on the MacIntosh) may not load these automatically.
:[font = text; inactive; ]
	A Notebook is completely defined by a portable ASCII file but  machine-dependent binary information (bitmaps, etc.) is generated as side information to speed up the display of parts of the Notebook.   Mathematica 1.2 generates missing side information as needed whereas Mathematica 2.0 and higher generates all missing side information when a Notebook is opened.    Mathematica 2.0 and higher will display the message "Rendering ..." in the header of the Notebook when it is generating bitmaps for PostScript graphics contained in the Notebook.  This particular Notebook contains some  60 or so graphics cells whose bitmaps will require an 1.2 Mb of memory (60 cells x 20 kb/cell) to store.  The ASCII version of this Notebook occupies 600 kb.
:[font = text; inactive; ]
	As a reminder, in order to open a section below, just move the mouse to the downward-pointing arrow and double click. To get help information for any command, place the cursor in an input cell and type ?Command (like ?ZTransform).
:[font = special1; inactive; ]

Table of Contents

:[font = section; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; ]
		In general, linear filters are designed to alter the frequency characteristics of input signals.  The four common kinds of alterations are:
:[font = special3; inactive; ]
(1)  Lowpass --  pass all frequencies below a threshold;
(2)  Highpass --  pass all frequencies above a threshold;
(3)  Bandpass --  pass all frequencies in a given range; and
(4)  Bandstop -- reject all frequencies in a given range.
:[font = text; inactive; ]
The part of the input signal corresponding to frequencies outside a passband will be attenuated (reduced in magnitude).  In the ideal case,  these filters would outright reject these frequency components.   In practice, filters approximately reject unwanted frequency components and approximately pass desired frequencies; frequencies in a transition region between a stopband and a passband are partially rejected and partially passed.
:[font = subsection; inactive; startGroup; Cclosed; ]
Characterizing Filters
:[font = text; inactive; endGroup; ]
		Filters are characterized by their impulse response, which is the output of the filter when the input is an impulsive function (a Dirac delta in continuous time and a Kronecker delta in discrete time).  If the impulse response is zero beyond a certain point in time, then the filter is called a finite impulse response (FIR) filter.  Otherwise, the filter is an infinite impulse response (IIR) filter.  This impulse response represents a solution to a linear constant coefficient differential equation (whose coefficients correspond to those of the filter).   When the filter is a linear operator, the transfer function of the filter H(s) is a ratio of two rational polynomials.  Its FIR section corresponds to the numerator polynomial, and its IIR section corresponds to the denominator polynomial.
:[font = subsection; inactive; startGroup; Cclosed; ]
Filter Design
:[font = text; inactive; ]
		Designing linear filters is carried out in the s-domain (a.k.a. the Laplace transform domain).  The goal is to fit the magnitude of a complex-valued function as constrained by the specifications.  For a lowpass filter that passes all frequencies up to wp and rejects all frequencies above ws, the magnitude response is constrained to the shaded regions:
:[font = postscript; inactive; PostScript; locked; output; height = 174; pictureLeft = 71; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.29762 0.01472 0.5886 [
[(w)( p)] 0.32143 0.00222 0 1 Msboxa
[(w)( s)] 0.61905 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(d)( 2)] 0.01131 0.13244 1 0 Msboxa
[(1 - d)(     1)] 0.01131 0.4856 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[(|H\(jw\)|)] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.32143 0.00847 moveto
0.32143 0.02097 lineto
stroke
0 setgray
[(w)( p)] 0.32143 0.00222 0 1 Mshowa
0.61905 0.00847 moveto
0.61905 0.02097 lineto
stroke
0 setgray
[(w)( s)] 0.61905 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.13244 moveto
0.03006 0.13244 lineto
stroke
0 setgray
[(d)( 2)] 0.01131 0.13244 1 0 Mshowa
0.01756 0.4856 moveto
0.03006 0.4856 lineto
stroke
0 setgray
[(1 - d)(     1)] 0.01131 0.4856 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[(|H\(jw\)|)] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.05357 0.60332 moveto
0.05357 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.08333 0.60332 moveto
0.08333 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.1131 0.60332 moveto
0.1131 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.14286 0.60332 moveto
0.14286 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.17262 0.60332 moveto
0.17262 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.20238 0.60332 moveto
0.20238 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.23214 0.60332 moveto
0.23214 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.2619 0.60332 moveto
0.2619 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.29167 0.60332 moveto
0.29167 0.4856 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.61905 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.02381 0.4856 moveto
0.32143 0.4856 lineto
stroke
grestore
gsave
[ 0.05 0.05 ] 0 setdash
0.004 setlinewidth
0.32143 0.60332 moveto
0.32143 0.01472 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.35119 0.01472 moveto
0.35119 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.38095 0.01472 moveto
0.38095 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.41071 0.01472 moveto
0.41071 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.44048 0.01472 moveto
0.44048 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.47024 0.01472 moveto
0.47024 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.52976 0.01472 moveto
0.52976 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.55952 0.01472 moveto
0.55952 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.58929 0.01472 moveto
0.58929 0.60332 lineto
stroke
grestore
gsave
[ 0.05 0.05 ] 0 setdash
0.004 setlinewidth
0.61905 0.60332 moveto
0.61905 0.01472 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.64881 0.01472 moveto
0.64881 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.67857 0.01472 moveto
0.67857 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.70833 0.01472 moveto
0.70833 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.7381 0.01472 moveto
0.7381 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.76786 0.01472 moveto
0.76786 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.79762 0.01472 moveto
0.79762 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.82738 0.01472 moveto
0.82738 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.85714 0.01472 moveto
0.85714 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.8869 0.01472 moveto
0.8869 0.13244 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.61905 0.13244 moveto
0.97619 0.13244 lineto
stroke
grestore
gsave
0 setgray
[(...)] 0.91667 0.07358 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; endGroup; ]
The stopband attenuation is d2 (or delta2) and the maximum passband ripple is d1 (or delta1).  The function H(s) has a magnitude frequency response of  | H(j w) |, which is the absolute value of the complex variable s evaluated at s = j w (w is the frequency variable).  For linear filters, H(s) is a ratio of two rational polynomials (a rational polynomial is a function of s consisting of a sum of products of rational numbers and integer powers of s).  The polynomial coefficients are called filter coefficients.  In this notebook, the filters that we design only have positive coefficients.
:[font = subsection; inactive; startGroup; Cclosed; ]
About this Notebook
:[font = text; inactive; endGroup; endGroup; ]
 		In this notebook,  we design passive analog filters so they can be implemented with resistors, capacitors, and inductors.  The focus of this notebook, however, is how to design the filter coefficients in the analog domain, and not on choosing the actual resistor, capacitor, and inductor values.  Once we generate a filter object, we can then use it in other expressions (e.g., modulation), specify an alternate input function to it (in place of the Dirac delta function), transform it, or plot its frequency response.  We can also quantize the filter coefficients (or its poles and zeroes) to get a better feeling of how the implemented filter might behave (for example, it is difficult to get more than three digits of accuracy in the filter coefficients when using resistors, capacitors, and inductors).
:[font = section; inactive; startGroup; Cclosed; ]
References
:[font = subsection; inactive; ]
[Daniels] Richard Daniels.  "Approximation Methods for Electronic Filter Design".  McGraw-Hill Book Company:  New York.  1976.
:[font = subsection; inactive; ]
[Evans & McClellan] Brian Evans and James McClellan.  "Symbolic Transforms with Applications to Signal Processing."  Mathematica Journal.  vol. 1, issue 2.  Fall, 1990.
:[font = subsection; inactive; ]
[Ludeman] Lonnie Ludeman.  "Fundamentals of Digital Signal Processing".  Harper & Row: New York.  1986.
:[font = subsection; inactive; ]
[Parks & Burrus] Thomas Parks and Cidney Burrus.  "Digital Filter Design."  John Wiley & Sons: New York.  1987.
:[font = subsection; inactive; endGroup; ]
[Rabiner & Gold]  Lawrence Rabiner and Bernard Gold.
"Theory and Application of Digital Signal Processing".
Prentice Hall, Inc.: Englewood Cliffs, NJ.  1975.
:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = input; initialization; ]
*)
define::usage =
  "define[variable, expression] is used to save \
  memory because expression is evaluated and set \
  to variable only if variable is referenced \
  during the evaluation of a piece of code.";
(*
:[font = input; initialization; ]
*)
define[variable_, expression_] :=
  variable := variable = expression
(*
:[font = input; initialization; ]
*)
SetAttributes[define, {HoldAll, Protected}]
(*
:[font = input; initialization; startGroup; Cclosed; ]
*)
Needs[ "SignalProcessing`Analog`" ]
(*
:[font = print; inactive; startGroup; ]
Loading version 2.7 of the signal processing\
 
  support packages ...
:[font = print; inactive; ]
Support module has been loaded.
:[font = print; inactive; ]
The knowledge base of signal processing\
 
  operators has been loaded.
:[font = print; inactive; ]
Supporting routines for filter design are\
 
  loaded.
:[font = print; inactive; ]
Region of convergence routines for the transform\
 
  rule bases are loaded.
:[font = print; inactive; ]
Piecewise convolution rules have been loaded.
:[font = print; inactive; ]
Supporting routines for transform rule bases are\
 
  loaded.
:[font = message; inactive; ]
support::loaded: 
   Supporting routines, objects, and rules for
    the signal processing package have been
    loaded successfully.
:[font = message; inactive; ]
support::change: 
   The loading process has changed such that the
    files Tree.m and DataType.m are no longer
    automatically loaded (the signal processing
    packages no longer rely on the definitions in
    these files).
:[font = print; inactive; ]
Loading version 2.7 of the analog signal\
 
  processing packages ...
:[font = print; inactive; ]
The one-dimensional analog filter design objects\
 
  are loaded.
:[font = print; inactive; ]
Supporting routines and objects for the Laplace\
 
  transform are loaded.
:[font = print; inactive; ]
The forward Laplace transform rule base LaPlace\
 
  has been loaded.
:[font = print; inactive; ]
The inverse Laplace transform rule base\
 
  InvLaPlace has been loaded.
:[font = print; inactive; ]
The supporting functions are loaded for symbolic\
 
  Fourier transforms.
:[font = print; inactive; ]
The continuous Fourier transform (CTFT)\
 
  functions are loaded.
:[font = print; inactive; ]
LSolve, a differential equation solver, is\
 
  loaded.
:[font = print; inactive; ]
The analog signal analyzer is now loaded.
:[font = message; inactive; ]
analog::loaded: 
   Routines, objects, and rules for the analog
    signal processing packages have been loaded
    successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
Analog signal processing extensions have been\
 
  defined.
:[font = print; inactive; ]
Good starting points are the objects ASPAnalyze\
 
  and LaPlace.
:[font = print; inactive; ]
Active packages are maintained in $ContextPath.
:[font = print; inactive; ]
  Evaluate SPsignals for a list of all new\
 
  signals (functions).
:[font = print; inactive; ]
  Evaluate SPoperators for a list of all new\
 
  operators (systems).
:[font = print; inactive; ]
  Evaluate SPfunctions for a list of all new\
 
  routines.
:[font = print; inactive; ]
Use SPSimplify to simplify signal processing\
 
  expressions.
:[font = print; inactive; endGroup; endGroup; endGroup; ]

:[font = section; inactive; startGroup; Cclosed; ]
Filter Classes
:[font = text; inactive; ]
		The four most common classes of analog filters are Butterworth, Chebyshev type I, Chebyshev type II, and Elliptic.  Each filter has a characteristic frequency response and each filter is optimal but in a different sense.  When choosing a filter type, then, it is important to know in what sense each is optimal.  Parks and Burrus write:
:[font = smalltext; inactive; ]
	"The classical Butterworth filter is optimal in the sense that it is the best Taylor series approximation to the ideal lowpass filter magnitude response at both w=0 and w=infinity.
	The Chebyshev [type I] filter gives the smallest maximum magnitude error over the entire passband of any filter that is also a Taylor series approximation at w=infinity to the ideal magnitude characteristic.
	The inverse Chebyshev filter [type II]  is a Taylor series approximation to the ideal magnitude response at w=0 and minimizes the maximum error in the approximation to zero over the stopband.  Or we can say it maximizes the minimum rejection of the filter over the stopband.
	The elliptic function filter (Cauer filter) considers the four parameters of the filter:  the passband ripple, the transition bandwidth, the stopband ripple, and the order of the filter.  For given values of any three of the four, the fourth is minimized.
	Remember that all four of these filter designs are magnitude approximations and do not address the phase frequency response or the time-domain characteristics.  For most designs the Butterworth filter has the smoothest phase curve, followed by the inverse Chebyshev filer, Chebyshev filter, and elliptic function filter....
	In some cases, especially where the time-domain characteristics are important, ripples in the frequency response cause irregularities, such as echoes in the time response.  For that reason the Butterworth and Chebyshev II filters are more desirable than their frequency response alone might indicate."
:[font = text; inactive; right; ]
[Parks & Burrus, 199-201]
:[font = subsection; inactive; startGroup; Cclosed; ]
Butterworth Filters
:[font = text; inactive; ]
		The magnitude squared frequency response of a Butterworth filter is of the form
:[font = input; center; ]
1 / ( 1 + (w/wc)^(2 n) )
:[font = text; inactive; ]
where w is the frequency variable, wc is the cutoff frequency, and n is the filter order. The magnitude response of a lowpass Butterworth filter is smooth (no ripples) and monotonically decreases with respect to frequency since  it is the best Taylor series approximation to the ideal lowpass filter magnitude response at both w=0 and w=infinity.  Below is the magnitude and phase response of a fourth-order Butterworth filter with a cutoff frequency of 22 rad/sec:
:[font = postscript; inactive; PostScript; locked; output; height = 174; pictureLeft = 86; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.60332 0.01119 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.59082 0 1 Msboxa
[(40)] 0.40476 0.59082 0 1 Msboxa
[(60)] 0.59524 0.59082 0 1 Msboxa
[(80)] 0.78571 0.59082 0 1 Msboxa
[(100)] 0.97619 0.59082 0 1 Msboxa
[(w)] 1.00625 0.60332 -1 0 Msboxa
[(-50)] 0.01131 0.04388 1 0 Msboxa
[(-40)] 0.01131 0.15576 1 0 Msboxa
[(-30)] 0.01131 0.26765 1 0 Msboxa
[(-20)] 0.01131 0.37954 1 0 Msboxa
[(-10)] 0.01131 0.49143 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.60332 moveto
1 0.60332 lineto
stroke
0.21429 0.59707 moveto
0.21429 0.60957 lineto
stroke
0 setgray
[(20)] 0.21429 0.59082 0 1 Mshowa
0.40476 0.59707 moveto
0.40476 0.60957 lineto
stroke
0 setgray
[(40)] 0.40476 0.59082 0 1 Mshowa
0.59524 0.59707 moveto
0.59524 0.60957 lineto
stroke
0 setgray
[(60)] 0.59524 0.59082 0 1 Mshowa
0.78571 0.59707 moveto
0.78571 0.60957 lineto
stroke
0 setgray
[(80)] 0.78571 0.59082 0 1 Mshowa
0.97619 0.59707 moveto
0.97619 0.60957 lineto
stroke
0 setgray
[(100)] 0.97619 0.59082 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.60332 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.04388 moveto
0.03006 0.04388 lineto
stroke
0 setgray
[(-50)] 0.01131 0.04388 1 0 Mshowa
0.01756 0.15576 moveto
0.03006 0.15576 lineto
stroke
0 setgray
[(-40)] 0.01131 0.15576 1 0 Mshowa
0.01756 0.26765 moveto
0.03006 0.26765 lineto
stroke
0 setgray
[(-30)] 0.01131 0.26765 1 0 Mshowa
0.01756 0.37954 moveto
0.03006 0.37954 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37954 1 0 Mshowa
0.01756 0.49143 moveto
0.03006 0.49143 lineto
stroke
0 setgray
[(-10)] 0.01131 0.49143 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.02505 0.60332 lineto
0.02629 0.60332 lineto
0.02753 0.60332 lineto
0.02877 0.60332 lineto
0.03001 0.60332 lineto
0.03125 0.60332 lineto
0.03249 0.60332 lineto
0.03373 0.60332 lineto
0.03497 0.60332 lineto
0.03621 0.60332 lineto
0.03745 0.60332 lineto
0.03869 0.60332 lineto
0.03993 0.60332 lineto
0.04117 0.60332 lineto
0.04241 0.60332 lineto
0.04365 0.60332 lineto
0.04489 0.60332 lineto
0.04613 0.60332 lineto
0.04737 0.60332 lineto
0.04861 0.60332 lineto
0.04985 0.60332 lineto
0.05109 0.60332 lineto
0.05233 0.60332 lineto
0.05357 0.60332 lineto
0.05481 0.60332 lineto
0.05605 0.60332 lineto
0.05729 0.60332 lineto
0.05853 0.60332 lineto
0.06101 0.60332 lineto
0.06225 0.60332 lineto
0.06349 0.60332 lineto
0.06473 0.60332 lineto
0.06597 0.60332 lineto
0.06845 0.60332 lineto
0.06969 0.60332 lineto
0.07093 0.60332 lineto
0.07341 0.60332 lineto
0.07589 0.60332 lineto
0.07837 0.60332 lineto
0.08085 0.60332 lineto
0.08333 0.60332 lineto
0.08581 0.60332 lineto
0.08829 0.60331 lineto
0.09077 0.60331 lineto
0.09325 0.60331 lineto
0.09573 0.60331 lineto
0.09821 0.60331 lineto
0.10069 0.6033 lineto
0.10317 0.6033 lineto
Mistroke
0.10565 0.60329 lineto
0.10813 0.60329 lineto
0.1131 0.60327 lineto
0.11558 0.60325 lineto
0.11806 0.60324 lineto
0.12302 0.6032 lineto
0.12798 0.60314 lineto
0.13294 0.60306 lineto
0.1379 0.60294 lineto
0.14286 0.60279 lineto
0.14782 0.60259 lineto
0.15278 0.60233 lineto
0.15774 0.60198 lineto
0.1627 0.60154 lineto
0.16766 0.60098 lineto
0.17262 0.60027 lineto
0.17758 0.59939 lineto
0.18254 0.59831 lineto
0.19246 0.59543 lineto
0.20238 0.59139 lineto
0.2123 0.58597 lineto
0.22222 0.57908 lineto
0.24206 0.56106 lineto
0.2619 0.5387 lineto
0.30159 0.48886 lineto
0.34127 0.44007 lineto
0.38095 0.39533 lineto
0.42063 0.35475 lineto
0.46032 0.31786 lineto
0.5 0.2841 lineto
0.53968 0.25302 lineto
0.57937 0.22423 lineto
0.61905 0.19741 lineto
0.65873 0.17233 lineto
0.69841 0.14876 lineto
0.7381 0.12655 lineto
0.77778 0.10553 lineto
0.81746 0.08559 lineto
0.85714 0.06662 lineto
0.89683 0.04854 lineto
0.93651 0.03126 lineto
0.97619 0.01472 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; locked; output; endGroup; height = 174; pictureLeft = 78; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.30807 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.29557 0 1 Msboxa
[(40)] 0.40476 0.29557 0 1 Msboxa
[(60)] 0.59524 0.29557 0 1 Msboxa
[(80)] 0.78571 0.29557 0 1 Msboxa
[(100)] 0.97619 0.29557 0 1 Msboxa
[(w)] 1.00625 0.30807 -1 0 Msboxa
[(-150)] 0.01131 0.06196 1 0 Msboxa
[(-100)] 0.01131 0.14399 1 0 Msboxa
[(-50)] 0.01131 0.22603 1 0 Msboxa
[(50)] 0.01131 0.39011 1 0 Msboxa
[(100)] 0.01131 0.47214 1 0 Msboxa
[(150)] 0.01131 0.55418 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30807 moveto
1 0.30807 lineto
stroke
0.21429 0.30182 moveto
0.21429 0.31432 lineto
stroke
0 setgray
[(20)] 0.21429 0.29557 0 1 Mshowa
0.40476 0.30182 moveto
0.40476 0.31432 lineto
stroke
0 setgray
[(40)] 0.40476 0.29557 0 1 Mshowa
0.59524 0.30182 moveto
0.59524 0.31432 lineto
stroke
0 setgray
[(60)] 0.59524 0.29557 0 1 Mshowa
0.78571 0.30182 moveto
0.78571 0.31432 lineto
stroke
0 setgray
[(80)] 0.78571 0.29557 0 1 Mshowa
0.97619 0.30182 moveto
0.97619 0.31432 lineto
stroke
0 setgray
[(100)] 0.97619 0.29557 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30807 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06196 moveto
0.03006 0.06196 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06196 1 0 Mshowa
0.01756 0.14399 moveto
0.03006 0.14399 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14399 1 0 Mshowa
0.01756 0.22603 moveto
0.03006 0.22603 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22603 1 0 Mshowa
0.01756 0.39011 moveto
0.03006 0.39011 lineto
stroke
0 setgray
[(50)] 0.01131 0.39011 1 0 Mshowa
0.01756 0.47214 moveto
0.03006 0.47214 lineto
stroke
0 setgray
[(100)] 0.01131 0.47214 1 0 Mshowa
0.01756 0.55418 moveto
0.03006 0.55418 lineto
stroke
0 setgray
[(150)] 0.01131 0.55418 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30807 moveto
0.06349 0.26131 lineto
0.10317 0.21298 lineto
0.14286 0.16059 lineto
0.18254 0.10009 lineto
0.20238 0.06625 lineto
0.2123 0.04887 lineto
0.22222 0.03158 lineto
0.22718 0.02307 lineto
0.22966 0.01887 lineto
0.2309 0.01679 lineto
0.23214 0.01472 lineto
0.23338 0.60332 lineto
0.23462 0.60127 lineto
0.2371 0.59721 lineto
0.24206 0.58926 lineto
0.2619 0.56006 lineto
0.28175 0.53539 lineto
0.30159 0.51491 lineto
0.34127 0.48362 lineto
0.38095 0.46102 lineto
0.42063 0.4439 lineto
0.46032 0.43042 lineto
0.5 0.41947 lineto
0.53968 0.41039 lineto
0.57937 0.40272 lineto
0.61905 0.39615 lineto
0.65873 0.39045 lineto
0.69841 0.38545 lineto
0.7381 0.38103 lineto
0.77778 0.3771 lineto
0.81746 0.37357 lineto
0.85714 0.37039 lineto
0.89683 0.36751 lineto
0.93651 0.36489 lineto
0.97619 0.36248 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; startGroup; Cclosed; ]
Chebyshev type I Filters
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; ]
		The Chebyshev type I filter gives the smallest maximum magnitude error over the entire passband of any filter that is also a Taylor series approximation at w=infinity to the ideal magnitude characteristic [Parks & Burrus].  This means that the magnitude response of the stopband monotonically decreases with respect to frequency and that the passband features ripples.
:[font = postscript; inactive; PostScript; locked; output; pictureLeft = 83; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.02381 0.01414 0.58918 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.2619 0.00164 0 1 Msboxa
[(20)] 0.5 0.00164 0 1 Msboxa
[(30)] 0.7381 0.00164 0 1 Msboxa
[(40)] 0.97619 0.00164 0 1 Msboxa
[(w)] 1.00625 0.01414 -1 0 Msboxa
[(0.2)] 0.01131 0.13198 1 0 Msboxa
[(0.4)] 0.01131 0.24982 1 0 Msboxa
[(0.6)] 0.01131 0.36765 1 0 Msboxa
[(0.8)] 0.01131 0.48549 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01414 moveto
1 0.01414 lineto
stroke
0.2619 0.00789 moveto
0.2619 0.02039 lineto
stroke
0 setgray
[(10)] 0.2619 0.00164 0 1 Mshowa
0.5 0.00789 moveto
0.5 0.02039 lineto
stroke
0 setgray
[(20)] 0.5 0.00164 0 1 Mshowa
0.7381 0.00789 moveto
0.7381 0.02039 lineto
stroke
0 setgray
[(30)] 0.7381 0.00164 0 1 Mshowa
0.97619 0.00789 moveto
0.97619 0.02039 lineto
stroke
0 setgray
[(40)] 0.97619 0.00164 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01414 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.13198 moveto
0.03006 0.13198 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.13198 1 0 Mshowa
0.01756 0.24982 moveto
0.03006 0.24982 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.24982 1 0 Mshowa
0.01756 0.36765 moveto
0.03006 0.36765 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.36765 1 0 Mshowa
0.01756 0.48549 moveto
0.03006 0.48549 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.48549 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.48215 moveto
0.02505 0.48217 lineto
0.02629 0.48223 lineto
0.02753 0.48234 lineto
0.02877 0.48248 lineto
0.03125 0.4829 lineto
0.03373 0.48349 lineto
0.03621 0.48425 lineto
0.03869 0.48518 lineto
0.04365 0.48753 lineto
0.05357 0.4942 lineto
0.06349 0.5034 lineto
0.08333 0.52852 lineto
0.10317 0.55925 lineto
0.1131 0.57445 lineto
0.12302 0.58777 lineto
0.12798 0.59324 lineto
0.13294 0.59767 lineto
0.13542 0.59945 lineto
0.1379 0.6009 lineto
0.13914 0.60151 lineto
0.14038 0.60203 lineto
0.14162 0.60246 lineto
0.14286 0.60281 lineto
0.1441 0.60307 lineto
0.14534 0.60324 lineto
0.14658 0.60332 lineto
0.14782 0.60331 lineto
0.14906 0.60321 lineto
0.1503 0.60302 lineto
0.15154 0.60273 lineto
0.15278 0.60236 lineto
0.15526 0.60136 lineto
0.15774 0.60001 lineto
0.16022 0.59832 lineto
0.1627 0.59631 lineto
0.17262 0.58543 lineto
0.18254 0.57108 lineto
0.20238 0.53833 lineto
0.2123 0.52268 lineto
0.22222 0.50887 lineto
0.23214 0.49753 lineto
0.2371 0.49294 lineto
0.24206 0.48912 lineto
0.24702 0.4861 lineto
0.2495 0.4849 lineto
0.25198 0.48392 lineto
0.25446 0.48315 lineto
0.2557 0.48284 lineto
0.25694 0.48259 lineto
Mistroke
0.25818 0.4824 lineto
0.25942 0.48226 lineto
0.26066 0.48217 lineto
0.2619 0.48215 lineto
0.26314 0.48217 lineto
0.26438 0.48226 lineto
0.26563 0.4824 lineto
0.26687 0.4826 lineto
0.26935 0.48317 lineto
0.27183 0.48397 lineto
0.27431 0.485 lineto
0.27679 0.48627 lineto
0.28175 0.48952 lineto
0.28671 0.49371 lineto
0.29167 0.49886 lineto
0.30159 0.51192 lineto
0.32143 0.54739 lineto
0.33135 0.56735 lineto
0.34127 0.58563 lineto
0.34623 0.59308 lineto
0.35119 0.59878 lineto
0.35367 0.60083 lineto
0.35491 0.60164 lineto
0.35615 0.60229 lineto
0.35739 0.60279 lineto
0.35863 0.60313 lineto
0.35987 0.6033 lineto
0.36111 0.6033 lineto
0.36235 0.60314 lineto
0.36359 0.60281 lineto
0.36483 0.6023 lineto
0.36607 0.60163 lineto
0.36731 0.60078 lineto
0.36855 0.59977 lineto
0.37103 0.59726 lineto
0.37599 0.59039 lineto
0.38095 0.58138 lineto
0.39087 0.55895 lineto
0.40079 0.53435 lineto
0.41071 0.51166 lineto
0.41567 0.50205 lineto
0.42063 0.49402 lineto
0.4256 0.48786 lineto
0.42808 0.48556 lineto
0.42932 0.48462 lineto
0.43056 0.48382 lineto
0.4318 0.48318 lineto
0.43304 0.48268 lineto
0.43428 0.48235 lineto
0.43552 0.48217 lineto
Mistroke
0.43676 0.48216 lineto
0.438 0.48232 lineto
0.43924 0.48266 lineto
0.44048 0.48318 lineto
0.44172 0.48388 lineto
0.44296 0.48477 lineto
0.44544 0.48715 lineto
0.44792 0.49035 lineto
0.4504 0.49441 lineto
0.45536 0.50528 lineto
0.46032 0.51999 lineto
0.47024 0.55979 lineto
0.4752 0.58157 lineto
0.47768 0.59114 lineto
0.47892 0.5952 lineto
0.48016 0.5986 lineto
0.4814 0.60119 lineto
0.48264 0.60282 lineto
0.48388 0.60332 lineto
0.48512 0.60256 lineto
0.48636 0.6004 lineto
0.4876 0.59674 lineto
0.48884 0.5915 lineto
0.49008 0.58466 lineto
0.49256 0.56626 lineto
0.49504 0.54217 lineto
0.5 0.48215 lineto
0.50992 0.35478 lineto
0.51488 0.30115 lineto
0.51984 0.25643 lineto
0.52976 0.1898 lineto
0.53472 0.16525 lineto
0.53968 0.14502 lineto
0.5496 0.11419 lineto
0.55952 0.09232 lineto
0.56944 0.07636 lineto
0.57937 0.06442 lineto
0.58929 0.05532 lineto
0.59921 0.04824 lineto
0.61905 0.03819 lineto
0.62897 0.03458 lineto
0.63889 0.03163 lineto
0.64881 0.0292 lineto
0.65873 0.02718 lineto
0.67857 0.02406 lineto
0.69841 0.02181 lineto
0.71825 0.02016 lineto
0.7381 0.01893 lineto
0.75794 0.01799 lineto
0.77778 0.01727 lineto
Mistroke
0.79762 0.0167 lineto
0.81746 0.01626 lineto
0.85714 0.01562 lineto
0.87698 0.01539 lineto
0.89683 0.0152 lineto
0.91667 0.01504 lineto
0.93651 0.01491 lineto
0.97619 0.01472 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; locked; output; endGroup; pictureLeft = 78; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.02381 0.30966 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.2619 0.29716 0 1 Msboxa
[(20)] 0.5 0.29716 0 1 Msboxa
[(30)] 0.7381 0.29716 0 1 Msboxa
[(40)] 0.97619 0.29716 0 1 Msboxa
[(w)] 1.00625 0.30966 -1 0 Msboxa
[(-150)] 0.01131 0.06385 1 0 Msboxa
[(-100)] 0.01131 0.14579 1 0 Msboxa
[(-50)] 0.01131 0.22772 1 0 Msboxa
[(50)] 0.01131 0.3916 1 0 Msboxa
[(100)] 0.01131 0.47353 1 0 Msboxa
[(150)] 0.01131 0.55547 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30966 moveto
1 0.30966 lineto
stroke
0.2619 0.30341 moveto
0.2619 0.31591 lineto
stroke
0 setgray
[(10)] 0.2619 0.29716 0 1 Mshowa
0.5 0.30341 moveto
0.5 0.31591 lineto
stroke
0 setgray
[(20)] 0.5 0.29716 0 1 Mshowa
0.7381 0.30341 moveto
0.7381 0.31591 lineto
stroke
0 setgray
[(30)] 0.7381 0.29716 0 1 Mshowa
0.97619 0.30341 moveto
0.97619 0.31591 lineto
stroke
0 setgray
[(40)] 0.97619 0.29716 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30966 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06385 moveto
0.03006 0.06385 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06385 1 0 Mshowa
0.01756 0.14579 moveto
0.03006 0.14579 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14579 1 0 Mshowa
0.01756 0.22772 moveto
0.03006 0.22772 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22772 1 0 Mshowa
0.01756 0.3916 moveto
0.03006 0.3916 lineto
stroke
0 setgray
[(50)] 0.01131 0.3916 1 0 Mshowa
0.01756 0.47353 moveto
0.03006 0.47353 lineto
stroke
0 setgray
[(100)] 0.01131 0.47353 1 0 Mshowa
0.01756 0.55547 moveto
0.03006 0.55547 lineto
stroke
0 setgray
[(150)] 0.01131 0.55547 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30966 moveto
0.06349 0.27649 lineto
0.10317 0.23624 lineto
0.14286 0.18489 lineto
0.18254 0.13099 lineto
0.22222 0.08652 lineto
0.2619 0.04956 lineto
0.27183 0.04047 lineto
0.28175 0.03109 lineto
0.29167 0.02122 lineto
0.29415 0.01866 lineto
0.29539 0.01736 lineto
0.29663 0.01604 lineto
0.29787 0.01472 lineto
0.29911 0.60332 lineto
0.30035 0.60197 lineto
0.30159 0.6006 lineto
0.34127 0.54671 lineto
0.38095 0.47514 lineto
0.42063 0.41295 lineto
0.44048 0.38572 lineto
0.4504 0.37079 lineto
0.46032 0.35305 lineto
0.47024 0.32991 lineto
0.48016 0.2977 lineto
0.5 0.21158 lineto
0.50496 0.19322 lineto
0.50992 0.17787 lineto
0.51488 0.16528 lineto
0.51984 0.15494 lineto
0.52976 0.1392 lineto
0.53968 0.12785 lineto
0.5496 0.11923 lineto
0.55952 0.11241 lineto
0.57937 0.10211 lineto
0.59921 0.09455 lineto
0.61905 0.08864 lineto
0.65873 0.07976 lineto
0.69841 0.07326 lineto
0.7381 0.06818 lineto
0.77778 0.06407 lineto
0.81746 0.06063 lineto
0.85714 0.05771 lineto
0.89683 0.05518 lineto
0.93651 0.05296 lineto
0.97619 0.051 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Magnitude Squared Response
:[font = text; inactive; ]
		The magnitude squared response of a Chebyshev type I filter is of the form
:[font = input; center; ]
1 / ( 1 + e^2 ChebyshevT[n, w/wc]^2 )
:[font = text; inactive; endGroup; ]
where e controls passband ripple, w is the frequency variable, and wc is the cutoff frequency.  The term ChebyshevT[n, s] is the nth-order Chebyshev polynomial.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example Magnitude Squared Response
:[font = text; inactive; ]
		The cImsr function below defines the magnitude squared response of a Chebyshev type I filter using the parameters mentioned above:
:[font = input; initialization; ]
*)
cImsr[wc_, n_, e_, w_] :=
	1 / ( 1 + e^2 ChebyshevT[n, w/wc]^2 )
(*
:[font = text; inactive; ]
Now, we can plot the passband response, which ripples:
:[font = input; startGroup; ]
Plot[ cImsr[3, 4, 0.1, w], {w, 0, 2} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.47619 -58.84568 59.449 [
[(0.5)] 0.2619 0.59082 0 1 Msboxa
[(1)] 0.5 0.59082 0 1 Msboxa
[(1.5)] 0.7381 0.59082 0 1 Msboxa
[(2)] 0.97619 0.59082 0 1 Msboxa
[(0.99)] 0.01131 0.00883 1 0 Msboxa
[(0.992)] 0.01131 0.12773 1 0 Msboxa
[(0.994)] 0.01131 0.24663 1 0 Msboxa
[(0.996)] 0.01131 0.36552 1 0 Msboxa
[(0.998)] 0.01131 0.48442 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.60332 moveto
1 0.60332 lineto
stroke
0.2619 0.59707 moveto
0.2619 0.60957 lineto
stroke
0 setgray
[(0.5)] 0.2619 0.59082 0 1 Mshowa
0.5 0.59707 moveto
0.5 0.60957 lineto
stroke
0 setgray
[(1)] 0.5 0.59082 0 1 Mshowa
0.7381 0.59707 moveto
0.7381 0.60957 lineto
stroke
0 setgray
[(1.5)] 0.7381 0.59082 0 1 Mshowa
0.97619 0.59707 moveto
0.97619 0.60957 lineto
stroke
0 setgray
[(2)] 0.97619 0.59082 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.00883 moveto
0.03006 0.00883 lineto
stroke
0 setgray
[(0.99)] 0.01131 0.00883 1 0 Mshowa
0.01756 0.12773 moveto
0.03006 0.12773 lineto
stroke
0 setgray
[(0.992)] 0.01131 0.12773 1 0 Mshowa
0.01756 0.24663 moveto
0.03006 0.24663 lineto
stroke
0 setgray
[(0.994)] 0.01131 0.24663 1 0 Mshowa
0.01756 0.36552 moveto
0.03006 0.36552 lineto
stroke
0 setgray
[(0.996)] 0.01131 0.36552 1 0 Mshowa
0.01756 0.48442 moveto
0.03006 0.48442 lineto
stroke
0 setgray
[(0.998)] 0.01131 0.48442 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02505 0.01472 lineto
0.02629 0.01474 lineto
0.02753 0.01478 lineto
0.02877 0.01483 lineto
0.03001 0.01489 lineto
0.03125 0.01497 lineto
0.03373 0.01516 lineto
0.03621 0.01542 lineto
0.03869 0.01573 lineto
0.04365 0.01651 lineto
0.04861 0.01752 lineto
0.05357 0.01875 lineto
0.06349 0.02188 lineto
0.08333 0.03077 lineto
0.10317 0.04307 lineto
0.14286 0.07731 lineto
0.18254 0.12306 lineto
0.22222 0.17822 lineto
0.2619 0.24019 lineto
0.30159 0.306 lineto
0.34127 0.37241 lineto
0.38095 0.43601 lineto
0.42063 0.49342 lineto
0.46032 0.54143 lineto
0.48016 0.56099 lineto
0.5 0.57714 lineto
0.51984 0.58963 lineto
0.52976 0.59441 lineto
0.53968 0.5982 lineto
0.5496 0.60095 lineto
0.55456 0.60194 lineto
0.55704 0.60233 lineto
0.55952 0.60266 lineto
0.562 0.60293 lineto
0.56448 0.60312 lineto
0.56572 0.60319 lineto
0.56696 0.60325 lineto
0.5682 0.60329 lineto
0.56944 0.60331 lineto
0.57068 0.60332 lineto
0.57192 0.60331 lineto
0.57316 0.60328 lineto
0.5744 0.60324 lineto
0.57564 0.60317 lineto
0.57688 0.6031 lineto
0.57937 0.60289 lineto
0.58185 0.60261 lineto
0.58433 0.60227 lineto
0.58929 0.60138 lineto
Mistroke
0.59425 0.60022 lineto
0.59921 0.59879 lineto
0.60913 0.59511 lineto
0.61905 0.59034 lineto
0.63889 0.57758 lineto
0.65873 0.56062 lineto
0.69841 0.51481 lineto
0.7381 0.45507 lineto
0.77778 0.3846 lineto
0.81746 0.30759 lineto
0.85714 0.2291 lineto
0.89683 0.1548 lineto
0.93651 0.09078 lineto
0.97619 0.04315 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = text; inactive; ]
We can also plot the overall response:
:[font = input; startGroup; ]
Plot[ cImsr[3, 4, 0.1, w], {w, 0, 10} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.09524 0.01472 0.5886 [
[(2)] 0.21429 0.00222 0 1 Msboxa
[(4)] 0.40476 0.00222 0 1 Msboxa
[(6)] 0.59524 0.00222 0 1 Msboxa
[(8)] 0.78571 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(0.2)] 0.01131 0.13244 1 0 Msboxa
[(0.4)] 0.01131 0.25016 1 0 Msboxa
[(0.6)] 0.01131 0.36788 1 0 Msboxa
[(0.8)] 0.01131 0.4856 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.21429 0.00847 moveto
0.21429 0.02097 lineto
stroke
0 setgray
[(2)] 0.21429 0.00222 0 1 Mshowa
0.40476 0.00847 moveto
0.40476 0.02097 lineto
stroke
0 setgray
[(4)] 0.40476 0.00222 0 1 Mshowa
0.59524 0.00847 moveto
0.59524 0.02097 lineto
stroke
0 setgray
[(6)] 0.59524 0.00222 0 1 Mshowa
0.78571 0.00847 moveto
0.78571 0.02097 lineto
stroke
0 setgray
[(8)] 0.78571 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.13244 moveto
0.03006 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.13244 1 0 Mshowa
0.01756 0.25016 moveto
0.03006 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.25016 1 0 Mshowa
0.01756 0.36788 moveto
0.03006 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.36788 1 0 Mshowa
0.01756 0.4856 moveto
0.03006 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.4856 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.59749 moveto
0.02505 0.59749 lineto
0.02629 0.5975 lineto
0.02753 0.59751 lineto
0.02877 0.59752 lineto
0.03125 0.59755 lineto
0.03373 0.5976 lineto
0.03869 0.59774 lineto
0.04365 0.59793 lineto
0.05357 0.59844 lineto
0.06349 0.59911 lineto
0.08333 0.60071 lineto
0.09325 0.60151 lineto
0.10317 0.60223 lineto
0.1131 0.60281 lineto
0.11806 0.60302 lineto
0.12054 0.60311 lineto
0.12302 0.60318 lineto
0.1255 0.60324 lineto
0.12798 0.60328 lineto
0.12922 0.6033 lineto
0.13046 0.60331 lineto
0.1317 0.60332 lineto
0.13294 0.60332 lineto
0.13418 0.60332 lineto
0.13542 0.60331 lineto
0.13666 0.6033 lineto
0.1379 0.60329 lineto
0.14038 0.60325 lineto
0.14286 0.60319 lineto
0.14534 0.60312 lineto
0.14782 0.60303 lineto
0.15278 0.6028 lineto
0.1627 0.60216 lineto
0.18254 0.60039 lineto
0.20238 0.59854 lineto
0.20734 0.59818 lineto
0.2123 0.59787 lineto
0.21478 0.59775 lineto
0.21726 0.59765 lineto
0.2185 0.59761 lineto
0.21974 0.59757 lineto
0.22098 0.59754 lineto
0.22222 0.59752 lineto
0.22346 0.5975 lineto
0.2247 0.59749 lineto
0.22594 0.59749 lineto
0.22718 0.5975 lineto
0.22842 0.59751 lineto
0.22966 0.59752 lineto
Mistroke
0.23214 0.59758 lineto
0.23338 0.59762 lineto
0.23462 0.59767 lineto
0.2371 0.59779 lineto
0.24206 0.59812 lineto
0.24702 0.59856 lineto
0.25198 0.59912 lineto
0.2619 0.60047 lineto
0.27183 0.60193 lineto
0.27679 0.60258 lineto
0.27927 0.60285 lineto
0.28175 0.60307 lineto
0.28299 0.60316 lineto
0.28423 0.60323 lineto
0.28547 0.60328 lineto
0.28671 0.60331 lineto
0.28795 0.60332 lineto
0.28919 0.6033 lineto
0.29043 0.60326 lineto
0.29167 0.60319 lineto
0.29291 0.60309 lineto
0.29415 0.60295 lineto
0.29539 0.60278 lineto
0.29663 0.60257 lineto
0.29911 0.60203 lineto
0.30159 0.60131 lineto
0.30407 0.60038 lineto
0.30655 0.59922 lineto
0.31151 0.59612 lineto
0.31647 0.5918 lineto
0.32143 0.58605 lineto
0.32639 0.57867 lineto
0.33135 0.56947 lineto
0.34127 0.54499 lineto
0.35119 0.51194 lineto
0.36111 0.47082 lineto
0.38095 0.37253 lineto
0.40079 0.27273 lineto
0.42063 0.19031 lineto
0.44048 0.13085 lineto
0.4504 0.10883 lineto
0.46032 0.09102 lineto
0.47024 0.07668 lineto
0.48016 0.06518 lineto
0.5 0.04853 lineto
0.50992 0.04256 lineto
0.51984 0.03774 lineto
0.52976 0.03383 lineto
0.53968 0.03065 lineto
0.55952 0.02593 lineto
Mistroke
0.56944 0.02418 lineto
0.57937 0.02273 lineto
0.58929 0.02153 lineto
0.59921 0.02053 lineto
0.61905 0.01899 lineto
0.63889 0.01789 lineto
0.65873 0.01711 lineto
0.67857 0.01653 lineto
0.69841 0.01611 lineto
0.71825 0.0158 lineto
0.7381 0.01556 lineto
0.75794 0.01538 lineto
0.77778 0.01524 lineto
0.79762 0.01514 lineto
0.81746 0.01506 lineto
0.8373 0.01499 lineto
0.85714 0.01494 lineto
0.87698 0.0149 lineto
0.89683 0.01487 lineto
0.91667 0.01484 lineto
0.93651 0.01482 lineto
0.97619 0.01479 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsection; inactive; startGroup; Cclosed; ]
Chebyshev type II Filters
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; ]
		This filter class is a Taylor series approximation to the ideal magnitude response at w=0 and minimizes the maximum error in the approximation to zero over the stopband.  This hints at the shape of its magnitude response, which is characterized by a monotonically decreasing function in the passband region and by a rippling function in the stopband region:
:[font = postscript; inactive; PostScript; locked; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.0147 0.58862 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.0022 0 1 Msboxa
[(40)] 0.40476 0.0022 0 1 Msboxa
[(60)] 0.59524 0.0022 0 1 Msboxa
[(80)] 0.78571 0.0022 0 1 Msboxa
[(100)] 0.97619 0.0022 0 1 Msboxa
[(w)] 1.00625 0.0147 -1 0 Msboxa
[(0.2)] 0.01131 0.13242 1 0 Msboxa
[(0.4)] 0.01131 0.25015 1 0 Msboxa
[(0.6)] 0.01131 0.36787 1 0 Msboxa
[(0.8)] 0.01131 0.48559 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.0147 moveto
1 0.0147 lineto
stroke
0.21429 0.00845 moveto
0.21429 0.02095 lineto
stroke
0 setgray
[(20)] 0.21429 0.0022 0 1 Mshowa
0.40476 0.00845 moveto
0.40476 0.02095 lineto
stroke
0 setgray
[(40)] 0.40476 0.0022 0 1 Mshowa
0.59524 0.00845 moveto
0.59524 0.02095 lineto
stroke
0 setgray
[(60)] 0.59524 0.0022 0 1 Mshowa
0.78571 0.00845 moveto
0.78571 0.02095 lineto
stroke
0 setgray
[(80)] 0.78571 0.0022 0 1 Mshowa
0.97619 0.00845 moveto
0.97619 0.02095 lineto
stroke
0 setgray
[(100)] 0.97619 0.0022 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.0147 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.13242 moveto
0.03006 0.13242 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.13242 1 0 Mshowa
0.01756 0.25015 moveto
0.03006 0.25015 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.25015 1 0 Mshowa
0.01756 0.36787 moveto
0.03006 0.36787 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.36787 1 0 Mshowa
0.01756 0.48559 moveto
0.03006 0.48559 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.48559 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.02629 0.60332 lineto
0.02753 0.60332 lineto
0.02877 0.60332 lineto
0.03001 0.60332 lineto
0.03125 0.60332 lineto
0.03249 0.60332 lineto
0.03373 0.60332 lineto
0.03497 0.60332 lineto
0.03621 0.60332 lineto
0.03745 0.60332 lineto
0.03869 0.60332 lineto
0.03993 0.60332 lineto
0.04117 0.60332 lineto
0.04241 0.60332 lineto
0.04365 0.60332 lineto
0.04489 0.60332 lineto
0.04613 0.60332 lineto
0.04737 0.60332 lineto
0.04861 0.60332 lineto
0.04985 0.60332 lineto
0.05109 0.60332 lineto
0.05233 0.60332 lineto
0.05357 0.60332 lineto
0.05481 0.60332 lineto
0.05605 0.60332 lineto
0.05729 0.60332 lineto
0.05853 0.60332 lineto
0.05977 0.60332 lineto
0.06101 0.60332 lineto
0.06225 0.60332 lineto
0.06349 0.60332 lineto
0.06473 0.60332 lineto
0.06597 0.60332 lineto
0.06721 0.60332 lineto
0.06845 0.60332 lineto
0.06969 0.60332 lineto
0.07093 0.60332 lineto
0.07217 0.60332 lineto
0.07341 0.60332 lineto
0.07465 0.60332 lineto
0.07589 0.60332 lineto
0.07713 0.60332 lineto
0.07837 0.60332 lineto
0.07961 0.60332 lineto
0.08085 0.60332 lineto
0.08333 0.60332 lineto
0.08457 0.60332 lineto
0.08581 0.60332 lineto
0.08705 0.60332 lineto
Mistroke
0.08829 0.60332 lineto
0.09077 0.60332 lineto
0.09201 0.60332 lineto
0.09325 0.60332 lineto
0.09449 0.60332 lineto
0.09573 0.60332 lineto
0.09821 0.60332 lineto
0.09945 0.60332 lineto
0.10069 0.60332 lineto
0.10193 0.60332 lineto
0.10317 0.60332 lineto
0.10565 0.60332 lineto
0.10689 0.60332 lineto
0.10813 0.60332 lineto
0.11062 0.60332 lineto
0.1131 0.60332 lineto
0.11558 0.60331 lineto
0.11806 0.60331 lineto
0.12054 0.60331 lineto
0.12302 0.60331 lineto
0.1255 0.6033 lineto
0.12798 0.60329 lineto
0.13046 0.60329 lineto
0.13294 0.60327 lineto
0.13542 0.60326 lineto
0.1379 0.60324 lineto
0.14038 0.60321 lineto
0.14286 0.60318 lineto
0.14534 0.60314 lineto
0.14782 0.60308 lineto
0.1503 0.60301 lineto
0.15278 0.60292 lineto
0.15526 0.6028 lineto
0.15774 0.60265 lineto
0.16022 0.60247 lineto
0.1627 0.60223 lineto
0.16518 0.60193 lineto
0.16766 0.60155 lineto
0.17262 0.60049 lineto
0.1751 0.59975 lineto
0.17758 0.59884 lineto
0.18006 0.5977 lineto
0.18254 0.5963 lineto
0.1875 0.59245 lineto
0.18998 0.58986 lineto
0.19246 0.5867 lineto
0.19494 0.58286 lineto
0.19742 0.57822 lineto
0.20238 0.56602 lineto
0.20734 0.54894 lineto
Mistroke
0.2123 0.52584 lineto
0.21726 0.49596 lineto
0.22222 0.4593 lineto
0.24206 0.27766 lineto
0.25198 0.19698 lineto
0.2619 0.13534 lineto
0.26687 0.11139 lineto
0.27183 0.09141 lineto
0.27679 0.07486 lineto
0.28175 0.06125 lineto
0.29167 0.04101 lineto
0.29663 0.03365 lineto
0.30159 0.02771 lineto
0.30655 0.02295 lineto
0.31151 0.01918 lineto
0.31399 0.01761 lineto
0.31647 0.01622 lineto
0.31771 0.01559 lineto
0.31895 0.01499 lineto
0.32143 0.01547 lineto
0.32639 0.01721 lineto
0.33135 0.0185 lineto
0.33631 0.01942 lineto
0.33879 0.01976 lineto
0.34127 0.02003 lineto
0.34375 0.02024 lineto
0.34499 0.02033 lineto
0.34623 0.0204 lineto
0.34747 0.02046 lineto
0.34871 0.0205 lineto
0.34995 0.02054 lineto
0.35119 0.02056 lineto
0.35243 0.02058 lineto
0.35367 0.02058 lineto
0.35491 0.02058 lineto
0.35615 0.02057 lineto
0.35739 0.02055 lineto
0.35863 0.02052 lineto
0.35987 0.02048 lineto
0.36111 0.02044 lineto
0.38095 0.01912 lineto
0.39087 0.01821 lineto
0.40079 0.01725 lineto
0.41071 0.01628 lineto
0.41567 0.01581 lineto
0.42063 0.01535 lineto
0.4256 0.0149 lineto
0.42684 0.01479 lineto
0.42808 0.01472 lineto
0.43056 0.01493 lineto
Mistroke
0.44048 0.01574 lineto
0.46032 0.01716 lineto
0.48016 0.01827 lineto
0.5 0.01912 lineto
0.50992 0.01946 lineto
0.51984 0.01974 lineto
0.52976 0.01997 lineto
0.53968 0.02016 lineto
0.5496 0.02031 lineto
0.55952 0.02042 lineto
0.56448 0.02047 lineto
0.56944 0.0205 lineto
0.5744 0.02053 lineto
0.57937 0.02055 lineto
0.58185 0.02056 lineto
0.58433 0.02057 lineto
0.58681 0.02058 lineto
0.58929 0.02058 lineto
0.59053 0.02058 lineto
0.59177 0.02058 lineto
0.59301 0.02058 lineto
0.59425 0.02058 lineto
0.59549 0.02058 lineto
0.59673 0.02058 lineto
0.59797 0.02058 lineto
0.59921 0.02058 lineto
0.60045 0.02058 lineto
0.60169 0.02058 lineto
0.60417 0.02058 lineto
0.60665 0.02057 lineto
0.60913 0.02056 lineto
0.61409 0.02055 lineto
0.61905 0.02053 lineto
0.62897 0.02048 lineto
0.63889 0.02041 lineto
0.65873 0.02024 lineto
0.69841 0.01981 lineto
0.7381 0.0193 lineto
0.77778 0.01876 lineto
0.81746 0.01821 lineto
0.85714 0.01767 lineto
0.89683 0.01715 lineto
0.93651 0.01666 lineto
0.97619 0.0162 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; locked; output; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.30749 0.00165 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.29499 0 1 Msboxa
[(40)] 0.40476 0.29499 0 1 Msboxa
[(60)] 0.59524 0.29499 0 1 Msboxa
[(80)] 0.78571 0.29499 0 1 Msboxa
[(100)] 0.97619 0.29499 0 1 Msboxa
[(w)] 1.00625 0.30749 -1 0 Msboxa
[(-150)] 0.01131 0.06066 1 0 Msboxa
[(-100)] 0.01131 0.14294 1 0 Msboxa
[(-50)] 0.01131 0.22521 1 0 Msboxa
[(50)] 0.01131 0.38976 1 0 Msboxa
[(100)] 0.01131 0.47203 1 0 Msboxa
[(150)] 0.01131 0.55431 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30749 moveto
1 0.30749 lineto
stroke
0.21429 0.30124 moveto
0.21429 0.31374 lineto
stroke
0 setgray
[(20)] 0.21429 0.29499 0 1 Mshowa
0.40476 0.30124 moveto
0.40476 0.31374 lineto
stroke
0 setgray
[(40)] 0.40476 0.29499 0 1 Mshowa
0.59524 0.30124 moveto
0.59524 0.31374 lineto
stroke
0 setgray
[(60)] 0.59524 0.29499 0 1 Mshowa
0.78571 0.30124 moveto
0.78571 0.31374 lineto
stroke
0 setgray
[(80)] 0.78571 0.29499 0 1 Mshowa
0.97619 0.30124 moveto
0.97619 0.31374 lineto
stroke
0 setgray
[(100)] 0.97619 0.29499 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30749 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06066 moveto
0.03006 0.06066 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06066 1 0 Mshowa
0.01756 0.14294 moveto
0.03006 0.14294 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14294 1 0 Mshowa
0.01756 0.22521 moveto
0.03006 0.22521 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22521 1 0 Mshowa
0.01756 0.38976 moveto
0.03006 0.38976 lineto
stroke
0 setgray
[(50)] 0.01131 0.38976 1 0 Mshowa
0.01756 0.47203 moveto
0.03006 0.47203 lineto
stroke
0 setgray
[(100)] 0.01131 0.47203 1 0 Mshowa
0.01756 0.55431 moveto
0.03006 0.55431 lineto
stroke
0 setgray
[(150)] 0.01131 0.55431 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30749 moveto
0.06349 0.25631 lineto
0.10317 0.20215 lineto
0.14286 0.14057 lineto
0.1627 0.10436 lineto
0.17262 0.08397 lineto
0.18254 0.06141 lineto
0.1875 0.04912 lineto
0.19246 0.03604 lineto
0.19494 0.02917 lineto
0.19742 0.02206 lineto
0.19866 0.01842 lineto
0.1999 0.01472 lineto
0.20114 0.60332 lineto
0.20238 0.59949 lineto
0.20362 0.5956 lineto
0.20486 0.59165 lineto
0.20734 0.58355 lineto
0.2123 0.56666 lineto
0.22222 0.53068 lineto
0.24206 0.4595 lineto
0.2619 0.40323 lineto
0.28175 0.3619 lineto
0.29167 0.34511 lineto
0.30159 0.33021 lineto
0.30655 0.32334 lineto
0.31151 0.31682 lineto
0.31399 0.31368 lineto
0.31647 0.31061 lineto
0.31771 0.30911 lineto
0.31895 0.30762 lineto
0.32019 0.60233 lineto
0.32143 0.60087 lineto
0.32267 0.59943 lineto
0.32391 0.59801 lineto
0.32639 0.59521 lineto
0.33135 0.58979 lineto
0.34127 0.57962 lineto
0.38095 0.54581 lineto
0.40079 0.53206 lineto
0.41071 0.52579 lineto
0.41567 0.52279 lineto
0.42063 0.51988 lineto
0.42312 0.51845 lineto
0.4256 0.51705 lineto
0.42684 0.51635 lineto
0.42808 0.21948 lineto
0.43056 0.21811 lineto
0.44048 0.21283 lineto
0.46032 0.20306 lineto
Mistroke
0.5 0.18619 lineto
0.53968 0.17212 lineto
0.57937 0.16018 lineto
0.61905 0.14993 lineto
0.65873 0.14102 lineto
0.69841 0.1332 lineto
0.7381 0.12627 lineto
0.77778 0.1201 lineto
0.81746 0.11457 lineto
0.85714 0.10957 lineto
0.89683 0.10504 lineto
0.93651 0.10091 lineto
0.97619 0.09713 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Magnitude Squared Response
:[font = text; inactive; ]
		The magnitude squared response of a Chebyshev type II filter is of the form 
:[font = graphlabel; inactive; center; ]
1 / ( 1 + e^2 Xn(w/wc)^2 ) 
:[font = text; inactive; ]
where e controls stopband ripple, w is the frequency variable, and wc is the cutoff frequency.  Here, Xn(v) = Tn(wr) / Tn(wr / v), where Tn(v) is the nth-order Chebyshev polynomial and wr is the ratio of wc over the transition ratio.  That is, as a formula, the magnitude squared response is
:[font = output; inactive; output; endGroup; ]
(1 + (e^2*ChebyshevT[n, wr]^2)/
     ChebyshevT[n, (wc*wr)/w]^2)^(-1)
;[o]
      2                  2
     e  ChebyshevT[n, wr]  -1
(1 + ---------------------)
                   wc wr 2
     ChebyshevT[n, -----]
                     w
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example Magnitude Squared Response
:[font = text; inactive; ]
		Here is the general definition of the magnitude squared response of a Chebyshev type II filter following the previous variable conventions (wc is the cutoff frequency and so forth):
:[font = input; initialization; ]
*)
cIImsr[wc_, wr_, n_, e_, w_] :=
  1 / ( 1 + e^2 (ChebyshevT[n, wr] / ChebyshevT[n, wr wc / w])^2 )
(*
:[font = text; inactive; ]
Our example is a fourth-order filter with a cutoff frequency of 3 rad/sec, a transition ratio of 2/3, and ripple control parameter of 1.  The frequency variable is w.  Now, we can plot the magnitude squared response over the passband region (we start at 0.1 because w = 0 causes a division-by-zero error):
:[font = input; startGroup; ]
Plot[ cIImsr[3, 3 / (2/3), 4, 1, w], {w, 0.1, 2} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.47619 -482.98216 483.58548 [
[(0.5)] 0.2619 0.59082 0 1 Msboxa
[(1)] 0.5 0.59082 0 1 Msboxa
[(1.5)] 0.7381 0.59082 0 1 Msboxa
[(2)] 0.97619 0.59082 0 1 Msboxa
[(0.9988)] 0.01131 0.02302 1 0 Msboxa
[(0.999)] 0.01131 0.11973 1 0 Msboxa
[(0.9992)] 0.01131 0.21645 1 0 Msboxa
[(0.9994)] 0.01131 0.31317 1 0 Msboxa
[(0.9996)] 0.01131 0.40988 1 0 Msboxa
[(0.9998)] 0.01131 0.5066 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.60332 moveto
1 0.60332 lineto
stroke
0.2619 0.59707 moveto
0.2619 0.60957 lineto
stroke
0 setgray
[(0.5)] 0.2619 0.59082 0 1 Mshowa
0.5 0.59707 moveto
0.5 0.60957 lineto
stroke
0 setgray
[(1)] 0.5 0.59082 0 1 Mshowa
0.7381 0.59707 moveto
0.7381 0.60957 lineto
stroke
0 setgray
[(1.5)] 0.7381 0.59082 0 1 Mshowa
0.97619 0.59707 moveto
0.97619 0.60957 lineto
stroke
0 setgray
[(2)] 0.97619 0.59082 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.02302 moveto
0.03006 0.02302 lineto
stroke
0 setgray
[(0.9988)] 0.01131 0.02302 1 0 Mshowa
0.01756 0.11973 moveto
0.03006 0.11973 lineto
stroke
0 setgray
[(0.999)] 0.01131 0.11973 1 0 Mshowa
0.01756 0.21645 moveto
0.03006 0.21645 lineto
stroke
0 setgray
[(0.9992)] 0.01131 0.21645 1 0 Mshowa
0.01756 0.31317 moveto
0.03006 0.31317 lineto
stroke
0 setgray
[(0.9994)] 0.01131 0.31317 1 0 Mshowa
0.01756 0.40988 moveto
0.03006 0.40988 lineto
stroke
0 setgray
[(0.9996)] 0.01131 0.40988 1 0 Mshowa
0.01756 0.5066 moveto
0.03006 0.5066 lineto
stroke
0 setgray
[(0.9998)] 0.01131 0.5066 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.07143 0.60332 moveto
0.07378 0.60332 lineto
0.07614 0.60332 lineto
0.0785 0.60332 lineto
0.08085 0.60332 lineto
0.08321 0.60332 lineto
0.08557 0.60332 lineto
0.08792 0.60332 lineto
0.09028 0.60332 lineto
0.09263 0.60332 lineto
0.09499 0.60332 lineto
0.09735 0.60332 lineto
0.0997 0.60332 lineto
0.10441 0.60332 lineto
0.10677 0.60332 lineto
0.10913 0.60332 lineto
0.11148 0.60332 lineto
0.11384 0.60332 lineto
0.11855 0.60332 lineto
0.12326 0.60332 lineto
0.12798 0.60332 lineto
0.13269 0.60332 lineto
0.1374 0.60332 lineto
0.14211 0.60332 lineto
0.14683 0.60332 lineto
0.15154 0.60332 lineto
0.15625 0.60332 lineto
0.16096 0.60332 lineto
0.16567 0.60331 lineto
0.17039 0.60331 lineto
0.1751 0.60331 lineto
0.17981 0.60331 lineto
0.18452 0.60331 lineto
0.18924 0.6033 lineto
0.19395 0.6033 lineto
0.19866 0.6033 lineto
0.20337 0.60329 lineto
0.2128 0.60328 lineto
0.22222 0.60326 lineto
0.23165 0.60323 lineto
0.24107 0.60319 lineto
0.2505 0.60314 lineto
0.25992 0.60307 lineto
0.26935 0.60298 lineto
0.27877 0.60287 lineto
0.28819 0.60272 lineto
0.29762 0.60252 lineto
0.30704 0.60227 lineto
0.31647 0.60196 lineto
0.32589 0.60156 lineto
Mistroke
0.33532 0.60107 lineto
0.34474 0.60047 lineto
0.35417 0.59972 lineto
0.37302 0.59771 lineto
0.38244 0.59638 lineto
0.39187 0.59477 lineto
0.41071 0.59057 lineto
0.42956 0.58465 lineto
0.44841 0.57645 lineto
0.46726 0.56526 lineto
0.48611 0.55018 lineto
0.50496 0.5301 lineto
0.52381 0.50367 lineto
0.54266 0.46922 lineto
0.56151 0.42476 lineto
0.58036 0.36788 lineto
0.59921 0.29572 lineto
0.6369 0.09136 lineto
0.65575 -0.04954 lineto
0.6746 -0.22327 lineto
0.69345 -0.43618 lineto
0.7123 -0.69558 lineto
0.73115 -1.0099 lineto
0.75 -1.38871 lineto
0.7877 -2.385 lineto
0.8254 -3.78982 lineto
0.8631 -5.73532 lineto
0.90079 -8.38365 lineto
0.93849 -11.92886 lineto
0.97619 -16.59664 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = text; inactive; ]
Note that the magnitude response of the passband region monotonically decreases with respect to frequency.  We can also plot the stopband region:
:[font = input; startGroup; ]
Plot[ cIImsr[3, 3 / (2/3), 4, 1, w], {w, 10, 100} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01313 0.01472 2.297411e+06 [
[(10)] 0.15514 0.00222 0 1 Msboxa
[(20)] 0.28646 0.00222 0 1 Msboxa
[(30)] 0.41779 0.00222 0 1 Msboxa
[(40)] 0.54912 0.00222 0 1 Msboxa
[(50)] 0.68045 0.00222 0 1 Msboxa
[(60)] 0.81177 0.00222 0 1 Msboxa
[(70)] 0.9431 0.00222 0 1 Msboxa
[(     -8)(5. 10)] 0.01131 0.12959 1 0 Msboxa
[(     -7)(1. 10)] 0.01131 0.24446 1 0 Msboxa
[(      -7)(1.5 10)] 0.01131 0.35933 1 0 Msboxa
[(     -7)(2. 10)] 0.01131 0.4742 1 0 Msboxa
[(      -7)(2.5 10)] 0.01131 0.58907 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.15514 0.00847 moveto
0.15514 0.02097 lineto
stroke
0 setgray
[(10)] 0.15514 0.00222 0 1 Mshowa
0.28646 0.00847 moveto
0.28646 0.02097 lineto
stroke
0 setgray
[(20)] 0.28646 0.00222 0 1 Mshowa
0.41779 0.00847 moveto
0.41779 0.02097 lineto
stroke
0 setgray
[(30)] 0.41779 0.00222 0 1 Mshowa
0.54912 0.00847 moveto
0.54912 0.02097 lineto
stroke
0 setgray
[(40)] 0.54912 0.00222 0 1 Mshowa
0.68045 0.00847 moveto
0.68045 0.02097 lineto
stroke
0 setgray
[(50)] 0.68045 0.00222 0 1 Mshowa
0.81177 0.00847 moveto
0.81177 0.02097 lineto
stroke
0 setgray
[(60)] 0.81177 0.00222 0 1 Mshowa
0.9431 0.00847 moveto
0.9431 0.02097 lineto
stroke
0 setgray
[(70)] 0.9431 0.00222 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.12959 moveto
0.03006 0.12959 lineto
stroke
0 setgray
[(     -8)(5. 10)] 0.01131 0.12959 1 0 Mshowa
0.01756 0.24446 moveto
0.03006 0.24446 lineto
stroke
0 setgray
[(     -7)(1. 10)] 0.01131 0.24446 1 0 Mshowa
0.01756 0.35933 moveto
0.03006 0.35933 lineto
stroke
0 setgray
[(      -7)(1.5 10)] 0.01131 0.35933 1 0 Mshowa
0.01756 0.4742 moveto
0.03006 0.4742 lineto
stroke
0 setgray
[(     -7)(2. 10)] 0.01131 0.4742 1 0 Mshowa
0.01756 0.58907 moveto
0.03006 0.58907 lineto
stroke
0 setgray
[(      -7)(2.5 10)] 0.01131 0.58907 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.15514 39.86363 moveto
0.15822 30.16245 lineto
0.16129 22.77856 lineto
0.16437 17.15502 lineto
0.16745 12.87212 lineto
0.17053 9.61243 lineto
0.1736 7.13496 lineto
0.17668 5.25625 lineto
0.17976 3.83622 lineto
0.18284 2.76765 lineto
0.18592 1.9683 lineto
0.18899 1.37498 lineto
0.19207 0.93906 lineto
0.19515 0.6231 lineto
0.19669 0.5008 lineto
0.19823 0.39821 lineto
0.19977 0.31276 lineto
0.20131 0.24217 lineto
0.20285 0.18444 lineto
0.20438 0.13782 lineto
0.20592 0.10078 lineto
0.20746 0.07197 lineto
0.209 0.05022 lineto
0.21054 0.03448 lineto
0.21208 0.02386 lineto
0.21362 0.01756 lineto
0.21516 0.0149 lineto
0.2167 0.01528 lineto
0.21824 0.01816 lineto
0.21977 0.0231 lineto
0.22285 0.03761 lineto
0.22901 0.07707 lineto
0.23516 0.12014 lineto
0.24132 0.15977 lineto
0.24748 0.19271 lineto
0.25055 0.20627 lineto
0.25363 0.21787 lineto
0.25671 0.22754 lineto
0.25979 0.23537 lineto
0.26287 0.24145 lineto
0.26441 0.24387 lineto
0.26594 0.2459 lineto
0.26748 0.24755 lineto
0.26902 0.24885 lineto
0.27056 0.2498 lineto
0.2721 0.25043 lineto
0.27364 0.25075 lineto
0.27518 0.25078 lineto
0.27672 0.25052 lineto
0.27826 0.25001 lineto
Mistroke
0.2798 0.24924 lineto
0.28133 0.24825 lineto
0.28441 0.24561 lineto
0.29057 0.23814 lineto
0.30288 0.217 lineto
0.3275 0.16477 lineto
0.35213 0.11525 lineto
0.37675 0.07595 lineto
0.38906 0.06058 lineto
0.40138 0.04791 lineto
0.41369 0.03773 lineto
0.426 0.02976 lineto
0.43831 0.02377 lineto
0.44447 0.02143 lineto
0.45062 0.01949 lineto
0.45678 0.01792 lineto
0.46294 0.01669 lineto
0.46601 0.0162 lineto
0.46909 0.01578 lineto
0.47217 0.01544 lineto
0.47525 0.01516 lineto
0.47679 0.01505 lineto
0.47833 0.01496 lineto
0.47986 0.01488 lineto
0.4814 0.01482 lineto
0.48294 0.01477 lineto
0.48448 0.01474 lineto
0.48602 0.01472 lineto
0.48756 0.01472 lineto
0.4891 0.01473 lineto
0.49064 0.01475 lineto
0.49218 0.01479 lineto
0.49372 0.01484 lineto
0.49679 0.01499 lineto
0.49987 0.01518 lineto
0.50603 0.01571 lineto
0.51218 0.01641 lineto
0.5245 0.01827 lineto
0.54912 0.02347 lineto
0.59837 0.03752 lineto
0.64762 0.05363 lineto
0.69686 0.06989 lineto
0.74611 0.08537 lineto
0.79536 0.09967 lineto
0.84461 0.11268 lineto
0.89385 0.1244 lineto
0.9431 0.13491 lineto
0.99235 0.14432 lineto
1.0416 0.15274 lineto
1.09085 0.16029 lineto
Mistroke
1.14009 0.16706 lineto
1.18934 0.17314 lineto
1.23859 0.17862 lineto
1.28784 0.18357 lineto
1.33708 0.18805 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = text; inactive; ]
Note that the stopband response riples.  Here is the overall frequency response:
:[font = input; startGroup; ]
Plot[ cIImsr[3, 3 / (2/3), 4, 1, w], {w, 0.1, 10} ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.09524 0.01472 0.5886 [
[(2)] 0.21429 0.00222 0 1 Msboxa
[(4)] 0.40476 0.00222 0 1 Msboxa
[(6)] 0.59524 0.00222 0 1 Msboxa
[(8)] 0.78571 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(0.2)] 0.01131 0.13244 1 0 Msboxa
[(0.4)] 0.01131 0.25016 1 0 Msboxa
[(0.6)] 0.01131 0.36788 1 0 Msboxa
[(0.8)] 0.01131 0.4856 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.21429 0.00847 moveto
0.21429 0.02097 lineto
stroke
0 setgray
[(2)] 0.21429 0.00222 0 1 Mshowa
0.40476 0.00847 moveto
0.40476 0.02097 lineto
stroke
0 setgray
[(4)] 0.40476 0.00222 0 1 Mshowa
0.59524 0.00847 moveto
0.59524 0.02097 lineto
stroke
0 setgray
[(6)] 0.59524 0.00222 0 1 Mshowa
0.78571 0.00847 moveto
0.78571 0.02097 lineto
stroke
0 setgray
[(8)] 0.78571 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.13244 moveto
0.03006 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.13244 1 0 Mshowa
0.01756 0.25016 moveto
0.03006 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.25016 1 0 Mshowa
0.01756 0.36788 moveto
0.03006 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.36788 1 0 Mshowa
0.01756 0.4856 moveto
0.03006 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.4856 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.03333 0.60332 moveto
0.03456 0.60332 lineto
0.03579 0.60332 lineto
0.03702 0.60332 lineto
0.03824 0.60332 lineto
0.03947 0.60332 lineto
0.0407 0.60332 lineto
0.04193 0.60332 lineto
0.04315 0.60332 lineto
0.04438 0.60332 lineto
0.04561 0.60332 lineto
0.04684 0.60332 lineto
0.04807 0.60332 lineto
0.04929 0.60332 lineto
0.05052 0.60332 lineto
0.05175 0.60332 lineto
0.05298 0.60332 lineto
0.0542 0.60332 lineto
0.05543 0.60332 lineto
0.05666 0.60332 lineto
0.05789 0.60332 lineto
0.05911 0.60332 lineto
0.06034 0.60332 lineto
0.06157 0.60332 lineto
0.0628 0.60332 lineto
0.06525 0.60332 lineto
0.06648 0.60332 lineto
0.06771 0.60332 lineto
0.06894 0.60332 lineto
0.07016 0.60332 lineto
0.07139 0.60332 lineto
0.07262 0.60332 lineto
0.07507 0.60332 lineto
0.07753 0.60332 lineto
0.07999 0.60332 lineto
0.08244 0.60332 lineto
0.0849 0.60332 lineto
0.08735 0.60332 lineto
0.08981 0.60331 lineto
0.09226 0.60331 lineto
0.09472 0.60331 lineto
0.09717 0.60331 lineto
0.09963 0.60331 lineto
0.10208 0.6033 lineto
0.10699 0.60329 lineto
0.10945 0.60328 lineto
0.1119 0.60328 lineto
0.11436 0.60326 lineto
0.11682 0.60325 lineto
0.11927 0.60324 lineto
Mistroke
0.12173 0.60322 lineto
0.12664 0.60317 lineto
0.13155 0.6031 lineto
0.13646 0.603 lineto
0.14137 0.60287 lineto
0.14628 0.6027 lineto
0.15119 0.60247 lineto
0.1561 0.60217 lineto
0.16101 0.60178 lineto
0.16592 0.60128 lineto
0.17083 0.60064 lineto
0.17574 0.59984 lineto
0.18065 0.59883 lineto
0.18557 0.59758 lineto
0.19048 0.59603 lineto
0.2003 0.59183 lineto
0.20521 0.58905 lineto
0.21012 0.58571 lineto
0.21994 0.57704 lineto
0.22976 0.56511 lineto
0.23958 0.54918 lineto
0.2494 0.52861 lineto
0.26905 0.47213 lineto
0.30833 0.31406 lineto
0.32798 0.23495 lineto
0.34762 0.16949 lineto
0.35744 0.14298 lineto
0.36726 0.12048 lineto
0.37708 0.10165 lineto
0.3869 0.08605 lineto
0.39673 0.07321 lineto
0.40655 0.06271 lineto
0.42619 0.04714 lineto
0.43601 0.04144 lineto
0.44583 0.0368 lineto
0.45565 0.03301 lineto
0.46548 0.0299 lineto
0.4753 0.02736 lineto
0.48512 0.02527 lineto
0.49494 0.02355 lineto
0.50476 0.02213 lineto
0.51458 0.02096 lineto
0.5244 0.01998 lineto
0.53423 0.01917 lineto
0.54405 0.01849 lineto
0.56369 0.01745 lineto
0.58333 0.01671 lineto
0.60298 0.01618 lineto
0.62262 0.0158 lineto
0.64226 0.01553 lineto
Mistroke
0.6619 0.01532 lineto
0.68155 0.01518 lineto
0.70119 0.01506 lineto
0.72083 0.01498 lineto
0.74048 0.01492 lineto
0.76012 0.01487 lineto
0.77976 0.01484 lineto
0.7994 0.01481 lineto
0.81905 0.01479 lineto
0.83869 0.01477 lineto
0.85833 0.01476 lineto
0.87798 0.01475 lineto
0.89762 0.01474 lineto
0.91726 0.01474 lineto
0.9369 0.01473 lineto
0.95655 0.01473 lineto
0.97619 0.01473 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsection; inactive; startGroup; Cclosed; ]
Elliptic Filters
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; ]
		The elliptic or Cauer filter considers the four parameters of the filter:  the passband ripple, the transition bandwidth, the stopband ripple, and the order of the filter.  For given values of any three of the four, the fourth is minimized [Parks & Burrus, 199-201].  Elliptic filters exhibit equiripple in the passbands and stopbands, as seen here for a fourth-order elliptic filter:
:[font = postscript; inactive; PostScript; locked; output; height = 174; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.48193 0 1 Msboxa
[(40)] 0.40476 0.48193 0 1 Msboxa
[(60)] 0.59524 0.48193 0 1 Msboxa
[(80)] 0.78571 0.48193 0 1 Msboxa
[(100)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(20)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(40)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(60)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(80)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(100)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.48207 moveto
0.02505 0.48207 lineto
0.02629 0.48209 lineto
0.02753 0.48211 lineto
0.02877 0.48215 lineto
0.03125 0.48225 lineto
0.03373 0.48239 lineto
0.03869 0.48279 lineto
0.04365 0.48334 lineto
0.05357 0.48488 lineto
0.06349 0.48689 lineto
0.08333 0.49151 lineto
0.08829 0.49254 lineto
0.09325 0.4934 lineto
0.09573 0.49374 lineto
0.09821 0.49403 lineto
0.09945 0.49414 lineto
0.10069 0.49424 lineto
0.10193 0.49432 lineto
0.10317 0.49437 lineto
0.10441 0.49441 lineto
0.10565 0.49443 lineto
0.10689 0.49442 lineto
0.10813 0.49439 lineto
0.10937 0.49434 lineto
0.11062 0.49427 lineto
0.1131 0.49407 lineto
0.11558 0.49377 lineto
0.11806 0.49339 lineto
0.12302 0.49241 lineto
0.13294 0.48977 lineto
0.14286 0.48675 lineto
0.14782 0.48531 lineto
0.15278 0.48404 lineto
0.15774 0.48302 lineto
0.16022 0.48263 lineto
0.16146 0.48247 lineto
0.1627 0.48234 lineto
0.16394 0.48223 lineto
0.16518 0.48215 lineto
0.16642 0.48209 lineto
0.16766 0.48207 lineto
0.1689 0.48208 lineto
0.17014 0.48212 lineto
0.17138 0.48219 lineto
0.17262 0.4823 lineto
0.17386 0.48245 lineto
0.1751 0.48263 lineto
0.17758 0.48312 lineto
0.18006 0.48378 lineto
Mistroke
0.18254 0.48462 lineto
0.1875 0.48681 lineto
0.19246 0.4896 lineto
0.19494 0.49111 lineto
0.19742 0.49254 lineto
0.19866 0.49317 lineto
0.1999 0.49371 lineto
0.20114 0.49412 lineto
0.20238 0.49437 lineto
0.20362 0.49442 lineto
0.20486 0.49421 lineto
0.2061 0.49372 lineto
0.20734 0.49291 lineto
0.20982 0.49025 lineto
0.21106 0.48839 lineto
0.2123 0.4862 lineto
0.22222 0.46078 lineto
0.2619 0.35704 lineto
0.28175 0.31044 lineto
0.29167 0.28531 lineto
0.30159 0.25664 lineto
0.30655 0.23979 lineto
0.31151 0.21987 lineto
0.31399 0.20809 lineto
0.31647 0.19439 lineto
0.31895 0.17772 lineto
0.32143 0.15589 lineto
0.32267 0.14149 lineto
0.32391 0.12275 lineto
0.32515 0.0953 lineto
0.32639 0.04056 lineto
0.32887 0.08584 lineto
0.33011 0.11337 lineto
0.33135 0.13083 lineto
0.33259 0.14348 lineto
0.33383 0.15331 lineto
0.33631 0.16796 lineto
0.33879 0.17857 lineto
0.34127 0.18673 lineto
0.34375 0.19324 lineto
0.34623 0.19857 lineto
0.35119 0.20675 lineto
0.35615 0.21268 lineto
0.36111 0.21709 lineto
0.36607 0.22042 lineto
0.37103 0.22293 lineto
0.37599 0.22482 lineto
0.38095 0.2262 lineto
0.38343 0.22674 lineto
0.38591 0.22718 lineto
Mistroke
0.38839 0.22754 lineto
0.39087 0.22783 lineto
0.39211 0.22794 lineto
0.39335 0.22804 lineto
0.39459 0.22813 lineto
0.39583 0.22819 lineto
0.39707 0.22825 lineto
0.39831 0.22828 lineto
0.39955 0.22831 lineto
0.40079 0.22832 lineto
0.40203 0.22832 lineto
0.40327 0.2283 lineto
0.40451 0.22828 lineto
0.40575 0.22824 lineto
0.40823 0.22813 lineto
0.41071 0.22799 lineto
0.41319 0.2278 lineto
0.41567 0.22758 lineto
0.42063 0.22703 lineto
0.43056 0.22557 lineto
0.44048 0.22372 lineto
0.46032 0.21904 lineto
0.5 0.20667 lineto
0.53968 0.19069 lineto
0.57937 0.17015 lineto
0.59921 0.15726 lineto
0.61905 0.14149 lineto
0.62897 0.13198 lineto
0.63889 0.12084 lineto
0.65873 0.08989 lineto
0.66369 0.0788 lineto
0.66865 0.06507 lineto
0.67113 0.05674 lineto
0.67361 0.04696 lineto
0.67857 0.02005 lineto
0.67981 0.01063 lineto
0.68105 -0.00075 lineto
0.68229 -0.01514 lineto
0.68353 -0.03476 lineto
0.68477 -0.06581 lineto
0.68601 -0.14704 lineto
0.68725 -0.0973 lineto
0.68849 -0.05053 lineto
0.68973 -0.02601 lineto
0.69097 -0.0093 lineto
0.69345 0.01358 lineto
0.69469 0.02212 lineto
0.69593 0.02945 lineto
0.69841 0.04159 lineto
0.70337 0.05964 lineto
Mistroke
0.70833 0.07292 lineto
0.71825 0.092 lineto
0.72817 0.10564 lineto
0.7381 0.11617 lineto
0.75794 0.13181 lineto
0.77778 0.1432 lineto
0.79762 0.15203 lineto
0.81746 0.15916 lineto
0.85714 0.17008 lineto
0.89683 0.17815 lineto
0.93651 0.18441 lineto
0.97619 0.18941 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; locked; output; endGroup; height = 174; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.30947 0.00165 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.29697 0 1 Msboxa
[(40)] 0.40476 0.29697 0 1 Msboxa
[(60)] 0.59524 0.29697 0 1 Msboxa
[(80)] 0.78571 0.29697 0 1 Msboxa
[(100)] 0.97619 0.29697 0 1 Msboxa
[(w)] 1.00625 0.30947 -1 0 Msboxa
[(-150)] 0.01131 0.06224 1 0 Msboxa
[(-100)] 0.01131 0.14465 1 0 Msboxa
[(-50)] 0.01131 0.22706 1 0 Msboxa
[(50)] 0.01131 0.39188 1 0 Msboxa
[(100)] 0.01131 0.47429 1 0 Msboxa
[(150)] 0.01131 0.55669 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30947 moveto
1 0.30947 lineto
stroke
0.21429 0.30322 moveto
0.21429 0.31572 lineto
stroke
0 setgray
[(20)] 0.21429 0.29697 0 1 Mshowa
0.40476 0.30322 moveto
0.40476 0.31572 lineto
stroke
0 setgray
[(40)] 0.40476 0.29697 0 1 Mshowa
0.59524 0.30322 moveto
0.59524 0.31572 lineto
stroke
0 setgray
[(60)] 0.59524 0.29697 0 1 Mshowa
0.78571 0.30322 moveto
0.78571 0.31572 lineto
stroke
0 setgray
[(80)] 0.78571 0.29697 0 1 Mshowa
0.97619 0.30322 moveto
0.97619 0.31572 lineto
stroke
0 setgray
[(100)] 0.97619 0.29697 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30947 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06224 moveto
0.03006 0.06224 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06224 1 0 Mshowa
0.01756 0.14465 moveto
0.03006 0.14465 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14465 1 0 Mshowa
0.01756 0.22706 moveto
0.03006 0.22706 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22706 1 0 Mshowa
0.01756 0.39188 moveto
0.03006 0.39188 lineto
stroke
0 setgray
[(50)] 0.01131 0.39188 1 0 Mshowa
0.01756 0.47429 moveto
0.03006 0.47429 lineto
stroke
0 setgray
[(100)] 0.01131 0.47429 1 0 Mshowa
0.01756 0.55669 moveto
0.03006 0.55669 lineto
stroke
0 setgray
[(150)] 0.01131 0.55669 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30947 moveto
0.04365 0.28846 lineto
0.06349 0.26443 lineto
0.10317 0.19613 lineto
0.14286 0.11629 lineto
0.1627 0.08328 lineto
0.17262 0.06653 lineto
0.18254 0.0468 lineto
0.1875 0.03444 lineto
0.18998 0.02725 lineto
0.19122 0.02332 lineto
0.19246 0.01916 lineto
0.1937 0.01472 lineto
0.19494 0.60332 lineto
0.19618 0.59826 lineto
0.19742 0.59285 lineto
0.20238 0.56744 lineto
0.2123 0.50385 lineto
0.21726 0.47502 lineto
0.22222 0.4525 lineto
0.22718 0.43568 lineto
0.23214 0.42305 lineto
0.2371 0.41332 lineto
0.24206 0.40562 lineto
0.25198 0.39412 lineto
0.2619 0.38585 lineto
0.27183 0.37951 lineto
0.28175 0.37443 lineto
0.30159 0.36665 lineto
0.31151 0.36357 lineto
0.32143 0.36087 lineto
0.32391 0.36025 lineto
0.32515 0.35994 lineto
0.32639 0.35964 lineto
0.32763 0.06267 lineto
0.32887 0.06238 lineto
0.33011 0.06209 lineto
0.33135 0.06181 lineto
0.34127 0.05966 lineto
0.38095 0.05288 lineto
0.42063 0.04797 lineto
0.46032 0.04422 lineto
0.5 0.04123 lineto
0.53968 0.03879 lineto
0.57937 0.03675 lineto
0.61905 0.03502 lineto
0.65873 0.03353 lineto
0.66865 0.03319 lineto
0.67857 0.03286 lineto
0.68105 0.03278 lineto
Mistroke
0.68353 0.0327 lineto
0.68477 0.03266 lineto
0.68601 0.03262 lineto
0.68725 0.32925 lineto
0.68849 0.32921 lineto
0.69841 0.32891 lineto
0.7381 0.32777 lineto
0.77778 0.32676 lineto
0.81746 0.32585 lineto
0.85714 0.32504 lineto
0.89683 0.32431 lineto
0.93651 0.32364 lineto
0.97619 0.32303 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Magnitude Squared Response
:[font = text; inactive; ]
		The magnitude squared response of an elliptic filter is of the form
:[font = graphlabel; inactive; center; ]
1 / (1 + e^2 Rn(w/wc,L)^2 )  
:[font = text; inactive; ]
where e controls ripple, w is the frequency variable, and wc is the cutoff frequency.  Here, Rn(w, L) is called a Chebyshev rational function such that L is a parameter describing ripple properties.  As a formula, the magnitude squared response is
:[font = input; center; ]
1 / ( 1 + e^2 RationalChebyshev[n, w, xL, L]^2 )
:[font = text; inactive; endGroup; ]
where xLand L are free parameters (although xL can be expressed in terms of L).  
:[font = subsubsection; inactive; startGroup; Cclosed; ]
The Rational Chebyshev Function
:[font = text; inactive; ]
		The design of elliptic filters is based on the rational Chebyshev function Rn(x, L).  This function is implemented as RationalChebyshev [Daniels, chapter 5]:
:[font = input; startGroup; ]
?RationalChebyshev
:[font = info; inactive; endGroup; ]
RationalChebyshev[n, x, xL, L] returns a rational
   polynomial which is the nth order rational Chebyshev
   function evaluated at x for parameters xL and L.
:[font = text; inactive; ]
In filter design terms, the rational Chebyshev parameters n, xL, and L are dependent upon the filter parameters:  xL = 1 / (transition-ratio) and L = 1 / nu = Sqrt[A^2 - 1] / epsilon.  The order n is a function of the transition ration and nu.  In the plot below, the fifth order rational Chebyshev function is plotted for xL = 1.3 and L = 207.1:
:[font = input; startGroup; ]
Plot[ Release[RationalChebyshev[5, x, 1.3, 207.1]^2],
      {x, -5, 5}, PlotPoints -> 100 ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.09524 0.01472 0 [
[(-4)] 0.11905 0.00222 0 1 Msboxa
[(-2)] 0.30952 0.00222 0 1 Msboxa
[(2)] 0.69048 0.00222 0 1 Msboxa
[(4)] 0.88095 0.00222 0 1 Msboxa
[(200000)] 0.4875 0.14712 1 0 Msboxa
[(400000)] 0.4875 0.27952 1 0 Msboxa
[(600000)] 0.4875 0.41192 1 0 Msboxa
[(800000)] 0.4875 0.54432 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.11905 0.00847 moveto
0.11905 0.02097 lineto
stroke
0 setgray
[(-4)] 0.11905 0.00222 0 1 Mshowa
0.30952 0.00847 moveto
0.30952 0.02097 lineto
stroke
0 setgray
[(-2)] 0.30952 0.00222 0 1 Mshowa
0.69048 0.00847 moveto
0.69048 0.02097 lineto
stroke
0 setgray
[(2)] 0.69048 0.00222 0 1 Mshowa
0.88095 0.00847 moveto
0.88095 0.02097 lineto
stroke
0 setgray
[(4)] 0.88095 0.00222 0 1 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.14712 moveto
0.50625 0.14712 lineto
stroke
0 setgray
[(200000)] 0.4875 0.14712 1 0 Mshowa
0.49375 0.27952 moveto
0.50625 0.27952 lineto
stroke
0 setgray
[(400000)] 0.4875 0.27952 1 0 Mshowa
0.49375 0.41192 moveto
0.50625 0.41192 lineto
stroke
0 setgray
[(600000)] 0.4875 0.41192 1 0 Mshowa
0.49375 0.54432 moveto
0.50625 0.54432 lineto
stroke
0 setgray
[(800000)] 0.4875 0.54432 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.03592 moveto
0.03343 0.03541 lineto
0.04305 0.03492 lineto
0.05267 0.03445 lineto
0.06229 0.034 lineto
0.07191 0.03357 lineto
0.08153 0.03317 lineto
0.09115 0.03279 lineto
0.10077 0.03244 lineto
0.11039 0.03212 lineto
0.12001 0.03183 lineto
0.12963 0.03158 lineto
0.13925 0.03137 lineto
0.14406 0.03128 lineto
0.14887 0.03121 lineto
0.15368 0.03115 lineto
0.15608 0.03112 lineto
0.15849 0.0311 lineto
0.16089 0.03109 lineto
0.1621 0.03108 lineto
0.1633 0.03107 lineto
0.1645 0.03107 lineto
0.1657 0.03107 lineto
0.16631 0.03107 lineto
0.16661 0.03107 lineto
0.16691 0.03107 lineto
0.16721 0.03106 lineto
0.16751 0.03106 lineto
0.16781 0.03106 lineto
0.16811 0.03106 lineto
0.16841 0.03106 lineto
0.16871 0.03106 lineto
0.16901 0.03106 lineto
0.16931 0.03106 lineto
0.16961 0.03107 lineto
0.16991 0.03107 lineto
0.17051 0.03107 lineto
0.17112 0.03107 lineto
0.17172 0.03107 lineto
0.17292 0.03107 lineto
0.17412 0.03108 lineto
0.17532 0.03109 lineto
0.17773 0.0311 lineto
0.18013 0.03113 lineto
0.18254 0.03116 lineto
0.18735 0.03124 lineto
0.19216 0.03136 lineto
0.19697 0.0315 lineto
0.20659 0.03192 lineto
0.2114 0.03221 lineto
Mistroke
0.21621 0.03256 lineto
0.22583 0.03348 lineto
0.23064 0.03409 lineto
0.23545 0.03482 lineto
0.24507 0.03679 lineto
0.24988 0.03812 lineto
0.25469 0.03977 lineto
0.2595 0.04184 lineto
0.26431 0.04449 lineto
0.26912 0.04795 lineto
0.27393 0.05259 lineto
0.27874 0.05902 lineto
0.28114 0.06321 lineto
0.28355 0.06832 lineto
0.28595 0.07463 lineto
0.28836 0.08257 lineto
0.29076 0.09278 lineto
0.29317 0.10624 lineto
0.29557 0.12455 lineto
0.29678 0.13631 lineto
0.29798 0.15045 lineto
0.29918 0.16767 lineto
0.30038 0.18896 lineto
0.30159 0.21575 lineto
0.30279 0.25016 lineto
0.30399 0.29545 lineto
0.30519 0.35688 lineto
0.3058 0.39619 lineto
0.3064 0.4433 lineto
0.307 0.50043 lineto
0.3076 0.57069 lineto
0.3082 0.65852 lineto
0.3088 0.77037 lineto
0.3094 0.91599 lineto
0.31 1.11071 lineto
0.31061 1.37963 lineto
0.31091 1.55442 lineto
0.31121 1.76637 lineto
0.31241 3.30309 lineto
0.31271 4.01919 lineto
0.31301 5.00376 lineto
0.31331 6.4108 lineto
0.31361 8.52328 lineto
0.31391 11.90858 lineto
0.31421 17.84624 lineto
0.31481 59.48829 lineto
0.31512 174.64395 lineto
0.31542 2184.91694 lineto
0.31572 908.96392 lineto
0.31602 129.10568 lineto
Mistroke
0.31632 48.81996 lineto
0.31662 25.38067 lineto
0.31692 15.48498 lineto
0.31722 10.40592 lineto
0.31752 7.46059 lineto
0.31782 5.60329 lineto
0.31812 4.35816 lineto
0.31842 3.48352 lineto
0.31872 2.84608 lineto
0.31902 2.36746 lineto
0.31932 1.99913 lineto
0.31962 1.70976 lineto
0.31993 1.47839 lineto
0.32023 1.29056 lineto
0.32083 1.00744 lineto
0.32143 0.80756 lineto
0.32203 0.66136 lineto
0.32263 0.55134 lineto
0.32323 0.46654 lineto
0.32383 0.39987 lineto
0.32443 0.34655 lineto
0.32504 0.30327 lineto
0.32564 0.2677 lineto
0.32684 0.21327 lineto
0.32804 0.17423 lineto
0.32924 0.14536 lineto
0.33045 0.12345 lineto
0.33165 0.10648 lineto
0.33285 0.09309 lineto
0.33405 0.08237 lineto
0.33526 0.07368 lineto
0.33646 0.06654 lineto
0.33886 0.05569 lineto
0.34127 0.04801 lineto
0.34367 0.04247 lineto
0.34608 0.03841 lineto
0.34848 0.03544 lineto
0.34969 0.03429 lineto
0.35089 0.03332 lineto
0.35209 0.03254 lineto
0.35329 0.03191 lineto
0.3539 0.03167 lineto
0.3545 0.03146 lineto
0.3551 0.03129 lineto
0.3554 0.03123 lineto
0.3557 0.03117 lineto
0.356 0.03113 lineto
0.3563 0.03109 lineto
0.3566 0.03107 lineto
0.3569 0.03106 lineto
Mistroke
0.3572 0.03107 lineto
0.3575 0.03109 lineto
0.3578 0.03112 lineto
0.3581 0.03116 lineto
0.35841 0.03122 lineto
0.35871 0.0313 lineto
0.35931 0.0315 lineto
0.35991 0.03177 lineto
0.36051 0.03214 lineto
0.36111 0.0326 lineto
0.36171 0.03318 lineto
0.36231 0.03391 lineto
0.36291 0.03481 lineto
0.36352 0.03592 lineto
0.36412 0.03731 lineto
0.36472 0.03905 lineto
0.36532 0.04127 lineto
0.36592 0.04413 lineto
0.36652 0.0479 lineto
0.36712 0.05301 lineto
0.36742 0.05627 lineto
0.36772 0.06017 lineto
0.36833 0.07069 lineto
0.36863 0.07792 lineto
0.36893 0.08712 lineto
0.36923 0.0991 lineto
0.36953 0.11514 lineto
0.36983 0.1374 lineto
0.37013 0.16967 lineto
0.37043 0.21924 lineto
0.37073 0.30166 lineto
0.37103 0.45518 lineto
0.37133 0.79729 lineto
0.37163 1.85506 lineto
0.37193 9.40622 lineto
0.37223 94.75016 lineto
0.37253 3.31195 lineto
0.37284 0.97904 lineto
0.37314 0.45543 lineto
0.37344 0.26088 lineto
0.37374 0.1689 lineto
0.37404 0.11872 lineto
0.37434 0.08861 lineto
0.37464 0.06928 lineto
0.37494 0.05621 lineto
0.37524 0.04702 lineto
0.37554 0.04034 lineto
0.37584 0.03537 lineto
0.37614 0.03158 lineto
0.37644 0.02865 lineto
Mistroke
0.37674 0.02633 lineto
0.37704 0.02449 lineto
0.37734 0.023 lineto
0.37765 0.02178 lineto
0.37795 0.02077 lineto
0.37855 0.01924 lineto
0.37915 0.01815 lineto
0.37975 0.01736 lineto
0.38035 0.01678 lineto
0.38095 0.01634 lineto
0.38155 0.016 lineto
0.38215 0.01574 lineto
0.38276 0.01554 lineto
0.38336 0.01538 lineto
0.38396 0.01526 lineto
0.38456 0.01516 lineto
0.38576 0.01501 lineto
0.38636 0.01496 lineto
0.38696 0.01491 lineto
0.38757 0.01488 lineto
0.38817 0.01485 lineto
0.38877 0.01483 lineto
0.38937 0.01481 lineto
0.39057 0.01478 lineto
0.39117 0.01477 lineto
0.39177 0.01476 lineto
0.39238 0.01475 lineto
0.39298 0.01474 lineto
0.39358 0.01474 lineto
0.39418 0.01473 lineto
0.39478 0.01473 lineto
0.39538 0.01473 lineto
0.39598 0.01473 lineto
0.39658 0.01472 lineto
0.39779 0.01472 lineto
0.39839 0.01472 lineto
0.39899 0.01472 lineto
0.39959 0.01472 lineto
0.40019 0.01472 lineto
0.40079 0.01472 lineto
0.40139 0.01472 lineto
0.402 0.01472 lineto
0.4026 0.01472 lineto
0.4032 0.01472 lineto
0.4038 0.01472 lineto
0.4044 0.01472 lineto
0.4047 0.01472 lineto
0.405 0.01472 lineto
0.4053 0.01472 lineto
0.4056 0.01472 lineto
Mistroke
0.4059 0.01472 lineto
0.4062 0.01472 lineto
0.40651 0.01472 lineto
0.40681 0.01472 lineto
0.40711 0.01472 lineto
0.40741 0.01472 lineto
0.40771 0.01472 lineto
0.40801 0.01472 lineto
0.40831 0.01472 lineto
0.40861 0.01472 lineto
0.41101 0.01472 lineto
0.41222 0.01472 lineto
0.41342 0.01472 lineto
0.41402 0.01472 lineto
0.41462 0.01472 lineto
0.41522 0.01472 lineto
0.41552 0.01472 lineto
0.41582 0.01472 lineto
0.41613 0.01472 lineto
0.41643 0.01472 lineto
0.41673 0.01472 lineto
0.41703 0.01472 lineto
0.41733 0.01472 lineto
0.41763 0.01472 lineto
0.41793 0.01472 lineto
0.41823 0.01472 lineto
0.41853 0.01472 lineto
0.41883 0.01472 lineto
0.41943 0.01472 lineto
0.42003 0.01472 lineto
0.42063 0.01472 lineto
0.42184 0.01472 lineto
0.42304 0.01472 lineto
0.42544 0.01472 lineto
0.42785 0.01472 lineto
0.43025 0.01472 lineto
0.43146 0.01472 lineto
0.43206 0.01472 lineto
0.43266 0.01472 lineto
0.43326 0.01472 lineto
0.43386 0.01472 lineto
0.43416 0.01472 lineto
0.43446 0.01472 lineto
0.43476 0.01472 lineto
0.43506 0.01472 lineto
0.43537 0.01472 lineto
0.43567 0.01472 lineto
0.43597 0.01472 lineto
0.43627 0.01472 lineto
0.43657 0.01472 lineto
Mistroke
0.43687 0.01472 lineto
0.43717 0.01472 lineto
0.43747 0.01472 lineto
0.44709 0.01472 lineto
0.4519 0.01472 lineto
0.4543 0.01472 lineto
0.45671 0.01472 lineto
0.45911 0.01472 lineto
0.46032 0.01472 lineto
0.46092 0.01472 lineto
0.46152 0.01472 lineto
0.46212 0.01472 lineto
0.46242 0.01472 lineto
0.46272 0.01472 lineto
0.46302 0.01472 lineto
0.46332 0.01472 lineto
0.46362 0.01472 lineto
0.46392 0.01472 lineto
0.46423 0.01472 lineto
0.46453 0.01472 lineto
0.46483 0.01472 lineto
0.46513 0.01472 lineto
0.46543 0.01472 lineto
0.46573 0.01472 lineto
0.46633 0.01472 lineto
0.46693 0.01472 lineto
0.46753 0.01472 lineto
0.46873 0.01472 lineto
0.46994 0.01472 lineto
0.47114 0.01472 lineto
0.47595 0.01472 lineto
0.48557 0.01472 lineto
0.49038 0.01472 lineto
0.49278 0.01472 lineto
0.49399 0.01472 lineto
0.49519 0.01472 lineto
0.49639 0.01472 lineto
0.49699 0.01472 lineto
0.49759 0.01472 lineto
0.4982 0.01472 lineto
0.4985 0.01472 lineto
0.4988 0.01472 lineto
0.4991 0.01472 lineto
0.4994 0.01472 lineto
0.4997 0.01472 lineto
0.5 0.01472 lineto
0.5003 0.01472 lineto
0.5006 0.01472 lineto
0.5009 0.01472 lineto
0.5012 0.01472 lineto
Mistroke
0.5015 0.01472 lineto
0.5018 0.01472 lineto
0.50241 0.01472 lineto
0.50361 0.01472 lineto
0.50481 0.01472 lineto
0.50722 0.01472 lineto
0.50962 0.01472 lineto
0.51443 0.01472 lineto
0.51924 0.01472 lineto
0.52405 0.01472 lineto
0.52646 0.01472 lineto
0.52886 0.01472 lineto
0.53006 0.01472 lineto
0.53127 0.01472 lineto
0.53187 0.01472 lineto
0.53247 0.01472 lineto
0.53307 0.01472 lineto
0.53367 0.01472 lineto
0.53397 0.01472 lineto
0.53427 0.01472 lineto
0.53457 0.01472 lineto
0.53487 0.01472 lineto
0.53517 0.01472 lineto
0.53547 0.01472 lineto
0.53577 0.01472 lineto
0.53608 0.01472 lineto
0.53638 0.01472 lineto
0.53668 0.01472 lineto
0.53698 0.01472 lineto
0.53728 0.01472 lineto
0.53788 0.01472 lineto
0.53848 0.01472 lineto
0.53968 0.01472 lineto
0.54089 0.01472 lineto
0.54329 0.01472 lineto
0.5457 0.01472 lineto
0.5481 0.01472 lineto
0.55291 0.01472 lineto
0.55532 0.01472 lineto
0.55772 0.01472 lineto
0.55892 0.01472 lineto
0.56013 0.01472 lineto
0.56133 0.01472 lineto
0.56193 0.01472 lineto
0.56223 0.01472 lineto
0.56253 0.01472 lineto
0.56283 0.01472 lineto
0.56313 0.01472 lineto
0.56343 0.01472 lineto
0.56373 0.01472 lineto
Mistroke
0.56403 0.01472 lineto
0.56433 0.01472 lineto
0.56463 0.01472 lineto
0.56494 0.01472 lineto
0.56554 0.01472 lineto
0.56584 0.01472 lineto
0.56614 0.01472 lineto
0.56674 0.01472 lineto
0.56734 0.01472 lineto
0.56854 0.01472 lineto
0.56975 0.01472 lineto
0.57215 0.01472 lineto
0.57456 0.01472 lineto
0.57696 0.01472 lineto
0.57816 0.01472 lineto
0.57937 0.01472 lineto
0.57997 0.01472 lineto
0.58057 0.01472 lineto
0.58117 0.01472 lineto
0.58147 0.01472 lineto
0.58177 0.01472 lineto
0.58207 0.01472 lineto
0.58237 0.01472 lineto
0.58267 0.01472 lineto
0.58297 0.01472 lineto
0.58327 0.01472 lineto
0.58357 0.01472 lineto
0.58387 0.01472 lineto
0.58418 0.01472 lineto
0.58478 0.01472 lineto
0.58538 0.01472 lineto
0.58658 0.01472 lineto
0.58899 0.01472 lineto
0.59019 0.01472 lineto
0.59079 0.01472 lineto
0.59109 0.01472 lineto
0.59139 0.01472 lineto
0.59169 0.01472 lineto
0.59199 0.01472 lineto
0.59229 0.01472 lineto
0.59259 0.01472 lineto
0.59289 0.01472 lineto
0.59319 0.01472 lineto
0.59349 0.01472 lineto
0.5938 0.01472 lineto
0.5944 0.01472 lineto
0.5947 0.01472 lineto
0.595 0.01472 lineto
0.5956 0.01472 lineto
0.5962 0.01472 lineto
Mistroke
0.5968 0.01472 lineto
0.5974 0.01472 lineto
0.598 0.01472 lineto
0.59861 0.01472 lineto
0.59921 0.01472 lineto
0.59981 0.01472 lineto
0.60041 0.01472 lineto
0.60101 0.01472 lineto
0.60221 0.01472 lineto
0.60281 0.01472 lineto
0.60342 0.01472 lineto
0.60402 0.01473 lineto
0.60462 0.01473 lineto
0.60522 0.01473 lineto
0.60582 0.01473 lineto
0.60642 0.01474 lineto
0.60702 0.01474 lineto
0.60762 0.01475 lineto
0.60823 0.01476 lineto
0.60943 0.01478 lineto
0.61003 0.01479 lineto
0.61063 0.01481 lineto
0.61123 0.01483 lineto
0.61183 0.01485 lineto
0.61243 0.01488 lineto
0.61304 0.01491 lineto
0.61364 0.01496 lineto
0.61424 0.01501 lineto
0.61484 0.01508 lineto
0.61544 0.01516 lineto
0.61664 0.01538 lineto
0.61724 0.01554 lineto
0.61785 0.01574 lineto
0.61845 0.016 lineto
0.61905 0.01634 lineto
0.61965 0.01678 lineto
0.62025 0.01736 lineto
0.62085 0.01815 lineto
0.62145 0.01924 lineto
0.62175 0.01994 lineto
0.62205 0.02077 lineto
0.62235 0.02178 lineto
0.62266 0.023 lineto
0.62326 0.02633 lineto
0.62356 0.02865 lineto
0.62386 0.03158 lineto
0.62506 0.05621 lineto
0.62536 0.06928 lineto
0.62566 0.08861 lineto
0.62596 0.11872 lineto
Mistroke
0.62626 0.1689 lineto
0.62656 0.26088 lineto
0.62686 0.45543 lineto
0.62716 0.97904 lineto
0.62747 3.31195 lineto
0.62777 94.75016 lineto
0.62807 9.40622 lineto
0.62837 1.85506 lineto
0.62867 0.79729 lineto
0.62897 0.45518 lineto
0.62927 0.30166 lineto
0.62957 0.21924 lineto
0.62987 0.16967 lineto
0.63017 0.1374 lineto
0.63047 0.11514 lineto
0.63077 0.0991 lineto
0.63107 0.08712 lineto
0.63137 0.07792 lineto
0.63167 0.07069 lineto
0.63197 0.06489 lineto
0.63228 0.06017 lineto
0.63288 0.05301 lineto
0.63348 0.0479 lineto
0.63408 0.04413 lineto
0.63468 0.04127 lineto
0.63528 0.03905 lineto
0.63588 0.03731 lineto
0.63648 0.03592 lineto
0.63709 0.03481 lineto
0.63769 0.03391 lineto
0.63829 0.03318 lineto
0.63889 0.0326 lineto
0.63949 0.03214 lineto
0.64009 0.03177 lineto
0.64069 0.0315 lineto
0.64099 0.03139 lineto
0.64129 0.0313 lineto
0.64159 0.03122 lineto
0.6419 0.03116 lineto
0.6422 0.03112 lineto
0.6425 0.03109 lineto
0.6428 0.03107 lineto
0.6431 0.03106 lineto
0.6434 0.03107 lineto
0.6437 0.03109 lineto
0.644 0.03113 lineto
0.6443 0.03117 lineto
0.6449 0.03129 lineto
0.6455 0.03146 lineto
0.64671 0.03191 lineto
Mistroke
0.64791 0.03254 lineto
0.64911 0.03332 lineto
0.65152 0.03544 lineto
0.65392 0.03841 lineto
0.65633 0.04247 lineto
0.65873 0.04801 lineto
0.66114 0.05569 lineto
0.66234 0.06063 lineto
0.66354 0.06654 lineto
0.66595 0.08237 lineto
0.66715 0.09309 lineto
0.66835 0.10648 lineto
0.66955 0.12345 lineto
0.67076 0.14536 lineto
0.67196 0.17423 lineto
0.67316 0.21327 lineto
0.67436 0.2677 lineto
0.67496 0.30327 lineto
0.67557 0.34655 lineto
0.67617 0.39987 lineto
0.67677 0.46654 lineto
0.67737 0.55134 lineto
0.67797 0.66136 lineto
0.67857 0.80756 lineto
0.67917 1.00744 lineto
0.67947 1.13604 lineto
0.67977 1.29056 lineto
0.68007 1.47839 lineto
0.68038 1.70976 lineto
0.68068 1.99913 lineto
0.68098 2.36746 lineto
0.68128 2.84608 lineto
0.68158 3.48352 lineto
0.68188 4.35816 lineto
0.68218 5.60329 lineto
0.68248 7.46059 lineto
0.68278 10.40592 lineto
0.68308 15.48498 lineto
0.68338 25.38067 lineto
0.68368 48.81996 lineto
0.68398 129.10568 lineto
0.68428 908.96392 lineto
0.68458 2184.91694 lineto
0.68488 174.64395 lineto
0.68519 59.48829 lineto
0.68549 29.7507 lineto
0.68579 17.84624 lineto
0.68609 11.90858 lineto
0.68639 8.52328 lineto
0.68669 6.4108 lineto
Mistroke
0.68699 5.00376 lineto
0.68729 4.01919 lineto
0.68759 3.30309 lineto
0.68789 2.76578 lineto
0.68819 2.35217 lineto
0.68849 2.02689 lineto
0.68879 1.76637 lineto
0.68909 1.55442 lineto
0.68939 1.37963 lineto
0.69 1.11071 lineto
0.6906 0.91599 lineto
0.6912 0.77037 lineto
0.6918 0.65852 lineto
0.6924 0.57069 lineto
0.693 0.50043 lineto
0.6936 0.4433 lineto
0.69481 0.35688 lineto
0.69601 0.29545 lineto
0.69721 0.25016 lineto
0.69841 0.21575 lineto
0.69962 0.18896 lineto
0.70082 0.16767 lineto
0.70202 0.15045 lineto
0.70443 0.12455 lineto
0.70683 0.10624 lineto
0.70924 0.09278 lineto
0.71164 0.08257 lineto
0.71405 0.07463 lineto
0.71645 0.06832 lineto
0.71886 0.06321 lineto
0.72126 0.05902 lineto
0.72607 0.05259 lineto
0.73088 0.04795 lineto
0.73569 0.04449 lineto
0.7405 0.04184 lineto
0.74531 0.03977 lineto
0.75493 0.03679 lineto
0.75974 0.03571 lineto
0.76455 0.03482 lineto
0.77417 0.03348 lineto
0.77898 0.03298 lineto
0.78379 0.03256 lineto
0.79341 0.03192 lineto
0.79822 0.03169 lineto
0.80303 0.0315 lineto
0.80784 0.03136 lineto
0.81265 0.03124 lineto
0.81746 0.03116 lineto
0.81987 0.03113 lineto
0.82227 0.0311 lineto
Mistroke
0.82347 0.03109 lineto
0.82468 0.03109 lineto
0.82588 0.03108 lineto
0.82708 0.03107 lineto
0.82768 0.03107 lineto
0.82828 0.03107 lineto
0.82888 0.03107 lineto
0.82949 0.03107 lineto
0.82979 0.03107 lineto
0.83009 0.03107 lineto
0.83039 0.03107 lineto
0.83069 0.03106 lineto
0.83099 0.03106 lineto
0.83129 0.03106 lineto
0.83159 0.03106 lineto
0.83189 0.03106 lineto
0.83219 0.03106 lineto
0.83249 0.03106 lineto
0.83279 0.03106 lineto
0.83309 0.03107 lineto
0.83369 0.03107 lineto
0.8343 0.03107 lineto
0.8355 0.03107 lineto
0.8367 0.03107 lineto
0.83911 0.03109 lineto
0.84151 0.0311 lineto
0.84632 0.03115 lineto
0.85113 0.03121 lineto
0.86075 0.03137 lineto
0.87037 0.03158 lineto
0.87999 0.03183 lineto
0.88961 0.03212 lineto
0.89923 0.03244 lineto
0.90885 0.03279 lineto
0.91847 0.03317 lineto
0.92809 0.03357 lineto
0.93771 0.034 lineto
0.94733 0.03445 lineto
0.95695 0.03492 lineto
0.96657 0.03541 lineto
0.97619 0.03592 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Elliptic Functions in Mathematica
:[font = text; inactive; ]
		In filter design, elliptic functions (like the complete elliptic integral) are defined slightly differently than Mathematica defines it.  The modulus squared in filter design literature is really the same as the modulus in Mathematica:
:[font = print; inactive; center; ]
K(k) = EllipticK[k^2]      
sn(u, k) = JacobiSN[u, k^2]
:[font = text; inactive; endGroup; endGroup; ]
Please keep this is mind when using elliptic functions.  The routines provided for filter design already take this into account.
:[font = subsection; inactive; startGroup; Cclosed; ]
Bessel Filters
:[font = text; inactive; startGroup; ]
		The Bessel filter is an all-pole filter whose transfer function is of the form d0 / Bn(s) where Bn(s) is the nth order Bessel polynomial.  Bessel lowpass filters are useful for two reasons:  
:[font = special3; inactive; wordwrap; ]
(1) their group delay is maximally flat at the origin of the complex s (Laplace) plane, and
:[font = special3; inactive; wordwrap; ]
(2) their step response exhibits low overshoot, typically less than 1%.
:[font = text; inactive; endGroup; ]
(Group delay of a filter is defined as the derivative of the phase with respect to frequency.)  Bessel filter differ from the previous four classes because the cutoff frequency varies with filter order [Rabiner & Gold, 228-230].
:[font = text; inactive; startGroup; ]
		The magnitude squared response of a Bessel  filter is smooth (no ripples) and monotonically decreases with respect to frequency.   Therefore, the magnitude response also monotonically decreases with respect to frequency:
:[font = postscript; inactive; PostScript; locked; output; height = 174; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.2381 0.52974 0.00441 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(1)] 0.2619 0.51724 0 1 Msboxa
[(2)] 0.5 0.51724 0 1 Msboxa
[(3)] 0.7381 0.51724 0 1 Msboxa
[(4)] 0.97619 0.51724 0 1 Msboxa
[(w)] 1.00625 0.52974 -1 0 Msboxa
[(-120)] 0.01131 0 1 0 Msboxa
[(-100)] 0.01131 0.08829 1 0 Msboxa
[(-80)] 0.01131 0.17658 1 0 Msboxa
[(-60)] 0.01131 0.26487 1 0 Msboxa
[(-40)] 0.01131 0.35316 1 0 Msboxa
[(-20)] 0.01131 0.44145 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.52974 moveto
1 0.52974 lineto
stroke
0.2619 0.52349 moveto
0.2619 0.53599 lineto
stroke
0 setgray
[(1)] 0.2619 0.51724 0 1 Mshowa
0.5 0.52349 moveto
0.5 0.53599 lineto
stroke
0 setgray
[(2)] 0.5 0.51724 0 1 Mshowa
0.7381 0.52349 moveto
0.7381 0.53599 lineto
stroke
0 setgray
[(3)] 0.7381 0.51724 0 1 Mshowa
0.97619 0.52349 moveto
0.97619 0.53599 lineto
stroke
0 setgray
[(4)] 0.97619 0.51724 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.52974 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-120)] 0.01131 0 1 0 Mshowa
0.01756 0.08829 moveto
0.03006 0.08829 lineto
stroke
0 setgray
[(-100)] 0.01131 0.08829 1 0 Mshowa
0.01756 0.17658 moveto
0.03006 0.17658 lineto
stroke
0 setgray
[(-80)] 0.01131 0.17658 1 0 Mshowa
0.01756 0.26487 moveto
0.03006 0.26487 lineto
stroke
0 setgray
[(-60)] 0.01131 0.26487 1 0 Mshowa
0.01756 0.35316 moveto
0.03006 0.35316 lineto
stroke
0 setgray
[(-40)] 0.01131 0.35316 1 0 Mshowa
0.01756 0.44145 moveto
0.03006 0.44145 lineto
stroke
0 setgray
[(-20)] 0.01131 0.44145 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.52974 moveto
0.02505 0.52974 lineto
0.02629 0.52974 lineto
0.02753 0.52973 lineto
0.02877 0.52972 lineto
0.03001 0.5297 lineto
0.03125 0.52969 lineto
0.03373 0.52964 lineto
0.03621 0.52958 lineto
0.03869 0.52951 lineto
0.04365 0.52934 lineto
0.04861 0.52911 lineto
0.05357 0.52883 lineto
0.06349 0.52811 lineto
0.07341 0.52719 lineto
0.08333 0.52607 lineto
0.10317 0.52318 lineto
0.12302 0.51942 lineto
0.14286 0.51477 lineto
0.18254 0.50255 lineto
0.22222 0.48585 lineto
0.2619 0.46325 lineto
0.30159 0.43319 lineto
0.34127 0.39735 lineto
0.38095 0.35994 lineto
0.42063 0.32373 lineto
0.46032 0.28969 lineto
0.5 0.25795 lineto
0.53968 0.22839 lineto
0.57937 0.2008 lineto
0.61905 0.17496 lineto
0.65873 0.1507 lineto
0.69841 0.12784 lineto
0.7381 0.10623 lineto
0.77778 0.08576 lineto
0.81746 0.0663 lineto
0.85714 0.04777 lineto
0.89683 0.03009 lineto
0.93651 0.01318 lineto
0.97619 -0.00303 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; locked; output; endGroup; endGroup; endGroup; height = 174; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.2381 0.3091 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(1)] 0.2619 0.2966 0 1 Msboxa
[(2)] 0.5 0.2966 0 1 Msboxa
[(3)] 0.7381 0.2966 0 1 Msboxa
[(4)] 0.97619 0.2966 0 1 Msboxa
[(w)] 1.00625 0.3091 -1 0 Msboxa
[(-150)] 0.01131 0.06309 1 0 Msboxa
[(-100)] 0.01131 0.14509 1 0 Msboxa
[(-50)] 0.01131 0.2271 1 0 Msboxa
[(50)] 0.01131 0.3911 1 0 Msboxa
[(100)] 0.01131 0.47311 1 0 Msboxa
[(150)] 0.01131 0.55511 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.3091 moveto
1 0.3091 lineto
stroke
0.2619 0.30285 moveto
0.2619 0.31535 lineto
stroke
0 setgray
[(1)] 0.2619 0.2966 0 1 Mshowa
0.5 0.30285 moveto
0.5 0.31535 lineto
stroke
0 setgray
[(2)] 0.5 0.2966 0 1 Mshowa
0.7381 0.30285 moveto
0.7381 0.31535 lineto
stroke
0 setgray
[(3)] 0.7381 0.2966 0 1 Mshowa
0.97619 0.30285 moveto
0.97619 0.31535 lineto
stroke
0 setgray
[(4)] 0.97619 0.2966 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.3091 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06309 moveto
0.03006 0.06309 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06309 1 0 Mshowa
0.01756 0.14509 moveto
0.03006 0.14509 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14509 1 0 Mshowa
0.01756 0.2271 moveto
0.03006 0.2271 lineto
stroke
0 setgray
[(-50)] 0.01131 0.2271 1 0 Mshowa
0.01756 0.3911 moveto
0.03006 0.3911 lineto
stroke
0 setgray
[(50)] 0.01131 0.3911 1 0 Mshowa
0.01756 0.47311 moveto
0.03006 0.47311 lineto
stroke
0 setgray
[(100)] 0.01131 0.47311 1 0 Mshowa
0.01756 0.55511 moveto
0.03006 0.55511 lineto
stroke
0 setgray
[(150)] 0.01131 0.55511 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.3091 moveto
0.06349 0.18986 lineto
0.08333 0.13023 lineto
0.09325 0.10042 lineto
0.10317 0.07061 lineto
0.10813 0.05571 lineto
0.1131 0.0408 lineto
0.11558 0.03335 lineto
0.11806 0.02589 lineto
0.1193 0.02217 lineto
0.12054 0.01844 lineto
0.12178 0.01472 lineto
0.12302 0.60141 lineto
0.12426 0.59769 lineto
0.1255 0.59396 lineto
0.12798 0.58651 lineto
0.13294 0.5716 lineto
0.14286 0.54179 lineto
0.18254 0.42255 lineto
0.22222 0.3034 lineto
0.2619 0.18564 lineto
0.30159 0.07573 lineto
0.31151 0.05075 lineto
0.31647 0.03873 lineto
0.32143 0.02704 lineto
0.32391 0.02132 lineto
0.32515 0.01849 lineto
0.32639 0.01568 lineto
0.32763 0.60332 lineto
0.32887 0.60055 lineto
0.33135 0.59508 lineto
0.34127 0.57403 lineto
0.38095 0.50226 lineto
0.42063 0.44676 lineto
0.46032 0.40295 lineto
0.5 0.3675 lineto
0.53968 0.33818 lineto
0.57937 0.31349 lineto
0.61905 0.2924 lineto
0.65873 0.27415 lineto
0.69841 0.25819 lineto
0.7381 0.24411 lineto
0.77778 0.23159 lineto
0.81746 0.22038 lineto
0.85714 0.21029 lineto
0.89683 0.20114 lineto
0.93651 0.19282 lineto
0.97619 0.18522 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = section; inactive; startGroup; Cclosed; ]
Design of Lowpass Analog Filters
:[font = text; inactive; ]
		In this section, we discuss how to use the signal processing packages to design analog Butterworth, Chebyshev, Elliptic, and Bessel filters.  These filters can be designed using the Mathematica object DesignFilter and analyzed by transform objects like LaPlace and CTFTransform.
:[font = subsection; inactive; startGroup; Cclosed; ]
General Design Algorithm for Analog Lowpass Filters
:[font = text; inactive; ]
		Here is the general design algorithm for the design of IIR analog lowpass filters:
:[font = subsubsection; inactive; startGroup; Cclosed; ]
1.  Determine filter parameters
:[font = text; inactive; ]
Interpret the problem so that you can determine
:[font = special3; inactive; ]
(a)  the passband error tolerance (delta1) or epsilon, and 
:[font = special3; inactive; ]
(b)  the stopband error tolerance (delta2) or A.
:[font = text; inactive; ]
This information, completely determines the values of the filter parameters delta1, delta2, epsilon, A, Eripple, ATT, and nu.  In Mathematica, this is done by calling FilterParameters.
:[font = input; startGroup; ]
?FilterParameters
:[font = info; inactive; endGroup; endGroup; ]
FilterParameters[delta1, delta2, epsilon, A,
   Eripple, ATT, nu] fills in the values of
   the missing parameters. It assumes that
   either the passband ripple (delta1) and the
   stopband ripple (delta2) or epsilon
   (controls ripple) and A (1 / delta2) are
   given. The values of Eripple, ATT, and nu
   will be computed and assigned to the
   symbols passed into those slots. Note that
   the passband takes on values between 1 and
   (1 - delta1) and that the stopband takes on
   values between 0 and delta2. The function
   returns a list of all seven parameters.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
2.  Determine filter order
:[font = text; inactive; ]
Next, determine the ratio of transition from the passband to the stopband.  The transition ratio and nu will determine the necessary filter order.  In Mathematica, this is done by calling FilterOrder.
:[font = input; startGroup; ]
?FilterOrder
:[font = info; inactive; endGroup; endGroup; ]
FilterOrder[filter-type, transition-ratio, nu]
   returns the filter order for the lowpass
   filter that meets the transition ratio (for
   digital filters, see
   BilinearTransformation) and the filter
   parameter nu (which is a function of the
   passband and stopband ripple parameters--
   c.f. FilterParameters).
:[font = subsubsection; inactive; startGroup; Cclosed; ]
3. Determine prototype filter
:[font = text; inactive; ]
Now that all of  the necessary filter parameters are known, the filter coefficients for a lowpass filter with a cutoff frequency of 1 rad/sec can be computed.  We can then transform this filter to have the proper cutoff frequency.  In Mathematica, this is done by calling AnalogFilter.
:[font = input; startGroup; ]
?AnalogFilter
:[font = info; inactive; endGroup; endGroup; ]
AnalogFilter[class, time-variable, order,
   epsilon, A, transition-ratio,
   cutoff-frequency] will return a filter
   expression containing one or more of a gain
   term, a CFIR section, and a CIIR section.
   Here, class is one of Bessel, Butterworth,
   ChebyshevI, ChebyshevII, Elliptic. The last
   four arguments are filter parameters. The
   value of the cutoff-frequency defaults to
   1. The Bessel filter design procedure,
   however, only uses the order and the
   cutoff-frequency and ignores the other
   arguments. See also FilterParameters and
   FilterOrder.
:[font = text; inactive; ]
This general design algorithm does not apply to Bessel filters because the cutoff frequency varies with the filter order but does apply to the other classes of filters [Rabiner & Gold, 228-230].
:[font = text; inactive; ]
		In Mathematica, this whole process is grouped together in a routine called DesignFilter (which does handle Bessel filters as a special case).
:[font = input; startGroup; Cclosed; ]
?DesignFilter
:[font = info; inactive; endGroup; ]
DesignFilter[domain, class, type, time-variable,
   deltap, deltas, w1, w2, w3, w4] returns a
   filter expression (involving IIR/FIR or
   CIIR/CFIR filter sections). Domain is either
   Analog or Digital. Possibilities for class
   include Butterworth, ChebyshevI, ChebyshevII,
   and Elliptic. Possible filter types are
   Lowpass, Highpass, Bandpass, and Bandstop.
   For lowpass filters, the magnitude response
   of the passband resides on [1, 1 - deltap]
   and the magnitude response of the stopband
   occupies [0, deltas]. The last two arguments,
   w3 and w4, are only necessary for bandpass
   and bandstop filters. Frequencies w1, w2, w3,
   and w4 are measured in rad/sec and should be
   given in ascending order.
:[font = text; inactive; endGroup; ]
The remaining sections give one design example per filter class which requires using either the general design procedure or the high-level functionality of DesignFilter.
:[font = subsection; inactive; startGroup; Cclosed; ]
Butterworth Example (Using Object AnalogFilter)
:[font = text; inactive; ]
Problem:  Design a lowpass Butterworth analog filter that has a -2 dB or better cutoff at 20 rad/sec and at least 10 db of attenuation at 30 rad/sec [Ludeman, 131].
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 1:  Determine the order of the filter
:[font = text; inactive; ]
First, we need to determine the order of the Butterworth filter necessary.  At the cutoff frequency, we want a magnitude response of -2 dB or better:
:[font = input; initialization; startGroup; ]
*)
bdelta1 = 1 - N[ 10^(-2/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.2056717652757185
;[o]
0.205672
:[font = text; inactive; ]
In the stopband, we want an attenuation of at least 10 dB:
:[font = input; initialization; startGroup; ]
*)
bdelta2 = N[ 10^(-10/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.3162277660168379
;[o]
0.316228
:[font = text; inactive; ]
From the values of delta1 and delta2, we can determine the other filter parameters:
:[font = input; initialization; startGroup; ]
*)
FilterParameters[
  bdelta1, bdelta2,
  bepsilon, bA, bEripple, bATT, bnu ]
(*
:[font = output; inactive; output; endGroup; ]
{0.2056717652757185, 0.3162277660168379, 
  0.7647831015792084, 3.162277660168379, 
  2.466913365931468, 10., 0.2549277005264028}
;[o]
{0.205672, 0.316228, 0.764783, 3.16228, 
 
  2.46691, 10., 0.254928}
:[font = text; inactive; ]
The parameters Eripple and ATT are useful when using filter design charts and are calculated here for completeness (note that the attenuation ATT should be 10 dB in this case).  The values of delta1 and delta2 determine the values of the other parameters.  The value of nu and the transition width (2/3 = 20 rad/sec divided by 30 rad/sec) determine the filter order:
:[font = input; startGroup; ]
FilterOrder[ Butterworth, 2/3, bnu ]
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = text; inactive; endGroup; ]
Now, we know that we need a Butterworth filter of order 4.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 2:  Find the coefficients of the filter
:[font = text; inactive; ]
We now know that we need a fourth order Butterworth filter to meet specifications.  So, now we can ask Mathematica to create a fourth-order Butterworth filter with a transition band from 20 rad/sec to 30 rad/sec.  The actual cutoff frequency needs to be between 21.39 rad/sec and 22.79 rad/sec (this comes as a consequence of the monotonically decreasing nature of the magnitude response of Butterworth filters).  We have chosen 22 rad/sec as the cutoff frequency:
:[font = input; initialization; ]
*)
define[ bfilter, 
        AnalogFilter[Butterworth, t, 4,
                     bepsilon, bA, 2/3, 22] ]
(*
:[font = input; startGroup; ]
bfilter
:[font = output; inactive; output; endGroup; ]
234256*CIIR[t, {234256., 27824.56490000732, 
    1652.479364188578, 57.48877045456058, 1}, 
   Roots -> 
    {22*E^((5*I)/8*Pi), 22*E^((7*I)/8*Pi), 
     22*E^((9*I)/8*Pi), 22*E^((11*I)/8*Pi)}]
;[o]
234256 CIIR[t, {234256., 27824.6, 1652.48, 
 
    57.4888, 1}]
:[font = text; inactive; ]
(Note that define is used instead of  =  to save memory; define is not a standard Mathematica command but instead created by this Notebook in the Initialization section.)  This expression represents a fourth-order filter (because there are four roots yielding five feedback coefficients).  The gain is 234526  and the feedback coefficients are {234256, 27824.6, 1652.48, 57.48888, 1}.   
:[font = special3; inactive; startGroup; Cclosed; center; ]
Examining the Poles of a Butterworth Filter
:[font = text; inactive; ]
Whenever a CIIR object has three instead of two data slots, the CIIR object contains a list of the exact pole locations.  Here is the third argument of the CIIR object embedded in the fourth-order Butterworth filter that we just designed:
:[font = input; startGroup; ]
bfilter[[2]][[3]]
:[font = output; inactive; output; endGroup; ]
Roots -> {22*E^((5*I)/8*Pi), 
   22*E^((7*I)/8*Pi), 22*E^((9*I)/8*Pi), 
   22*E^((11*I)/8*Pi)}
;[o]
              (5 I)/8 Pi      (7 I)/8 Pi
Roots -> {22 E          , 22 E          , 
 
       (9 I)/8 Pi      (11 I)/8 Pi
   22 E          , 22 E           }
:[font = text; inactive; endGroup; ]
The location of the roots of this all-pole filter characterizes it as Butterworth; that is, the poles are equally spaced along a semicircle located in the left-hand side of the s-plane.
:[font = special3; inactive; startGroup; Cclosed; center; ]
Extracting Poles for Analog IIR Filters
:[font = text; inactive; ]
		There are many ways to extract the poles (roots) from CIIR objects.  In the above example, we took the easy way out.  By viewing the expression contained in bfilter as a tree, the first level is simply a product of 234256 and the filter object.  So, the code
:[font = input; startGroup; ]
bfilter[[2]]
:[font = output; inactive; output; endGroup; ]
CIIR[t, {234256., 27824.56490000732, 
   1652.479364188578, 57.48877045456058, 1}, 
  Roots -> 
   {22*E^((5*I)/8*Pi), 22*E^((7*I)/8*Pi), 
    22*E^((9*I)/8*Pi), 22*E^((11*I)/8*Pi)}]
;[o]
CIIR[t, {234256., 27824.6, 1652.48, 57.4888, 
 
   1}]
:[font = text; inactive; ]
extracts the second argument in the product.  Now, if the roots are contained in the CIIR object, then they are contained in the third data slot:
:[font = input; startGroup; ]
bfilter[[2]][[3]]
:[font = output; inactive; output; endGroup; endGroup; ]
Roots -> {22*E^((5*I)/8*Pi), 
   22*E^((7*I)/8*Pi), 22*E^((9*I)/8*Pi), 
   22*E^((11*I)/8*Pi)}
;[o]
              (5 I)/8 Pi      (7 I)/8 Pi
Roots -> {22 E          , 22 E          , 
 
       (9 I)/8 Pi      (11 I)/8 Pi
   22 E          , 22 E           }
:[font = special3; inactive; startGroup; Cclosed; center; ]
Getting Help About CIIR
:[font = text; inactive; ]
	Of course, Mathematica can give us help about the object CIIR:
:[font = input; startGroup; ]
?CIIR
:[font = info; inactive; endGroup; endGroup; endGroup; ]
CIIR[t, {a0, a1, a2, ...}] represents an
   all-pole analog filter with gain 1 and DC
   gain 1/a0. The terms a1, a2, ... are the
   feedback coefficients. The Laplace
   transform of such an expression is 1 / (
   a0 + a1 s + a2 s^2 + ... ). Such filters
   can alternatively be specified by their
   poles via CIIR[t, Roots -> {-1, -2, -3}]
   which yields the object CIIR[t, {6., 11.,
   6., 1}, Roots -> {-1, -2, -3}]. CIIR is
   also an operator whose default input is a
   Dirac delta. An alternate input h can be
   specified by CIIR[t, {a0, a1, a2,
   ...}][h]. For the generalized
   N-dimensional IIR structure, the argument
   t becomes a list of indices (like {t1, t2}
   for N=2) and the feedback coefficients are
   specified by an N x N matrix.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 3:  Verify that the filter meets the specifications
:[font = text; inactive; ]
In order to verify that the filter meets specifications, we need to examine the frequency response of the filter.  This can be done by simply taking the continuous-time Fourier transform of the filter:
:[font = input; initialization; ]
*)
define[ bfiltertransobject,
        CTFTransform[ bfilter, t, w ] ]
(*
:[font = input; initialization; ]
*)
define[ bfiltertrans,
        TheFunction[bfiltertransobject] ]
(*
:[font = input; startGroup; Cclosed; ]
bfiltertrans
:[font = output; inactive; output; endGroup; ]
234256/((-22*E^((5*I)/8*Pi) + I*w)*
    (-22*E^((7*I)/8*Pi) + I*w)*
    (-22*E^((9*I)/8*Pi) + I*w)*
    (-22*E^((11*I)/8*Pi) + I*w))
;[o]
                (5 I)/8 Pi
234256 / ((-22 E           + I w) 
 
          (7 I)/8 Pi
    (-22 E           + I w) 
 
          (9 I)/8 Pi
    (-22 E           + I w) 
 
          (11 I)/8 Pi
    (-22 E            + I w))
:[font = text; inactive; ]
Now, we can plot the magnitude and phase response:
:[font = input; startGroup; Cclosed; ]

MagPhasePlot[ bfiltertrans,
              {w, 0, 100},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.46353 0.00773 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.45103 0 1 Msboxa
[(40)] 0.40476 0.45103 0 1 Msboxa
[(60)] 0.59524 0.45103 0 1 Msboxa
[(80)] 0.78571 0.45103 0 1 Msboxa
[(100)] 0.97619 0.45103 0 1 Msboxa
[(w)] 1.00625 0.46353 -1 0 Msboxa
[(-60)] 0.01131 0 1 0 Msboxa
[(-50)] 0.01131 0.07725 1 0 Msboxa
[(-40)] 0.01131 0.15451 1 0 Msboxa
[(-30)] 0.01131 0.23176 1 0 Msboxa
[(-20)] 0.01131 0.30902 1 0 Msboxa
[(-10)] 0.01131 0.38627 1 0 Msboxa
[(10)] 0.01131 0.54078 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.46353 moveto
1 0.46353 lineto
stroke
0.21429 0.45728 moveto
0.21429 0.46978 lineto
stroke
0 setgray
[(20)] 0.21429 0.45103 0 1 Mshowa
0.40476 0.45728 moveto
0.40476 0.46978 lineto
stroke
0 setgray
[(40)] 0.40476 0.45103 0 1 Mshowa
0.59524 0.45728 moveto
0.59524 0.46978 lineto
stroke
0 setgray
[(60)] 0.59524 0.45103 0 1 Mshowa
0.78571 0.45728 moveto
0.78571 0.46978 lineto
stroke
0 setgray
[(80)] 0.78571 0.45103 0 1 Mshowa
0.97619 0.45728 moveto
0.97619 0.46978 lineto
stroke
0 setgray
[(100)] 0.97619 0.45103 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.46353 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-60)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-50)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-40)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-30)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-20)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-10)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(10)] 0.01131 0.54078 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.46353 moveto
0.02505 0.46353 lineto
0.02629 0.46353 lineto
0.02753 0.46353 lineto
0.02877 0.46353 lineto
0.03001 0.46353 lineto
0.03125 0.46353 lineto
0.03249 0.46353 lineto
0.03373 0.46353 lineto
0.03497 0.46353 lineto
0.03621 0.46353 lineto
0.03745 0.46353 lineto
0.03869 0.46353 lineto
0.03993 0.46353 lineto
0.04117 0.46353 lineto
0.04241 0.46353 lineto
0.04365 0.46353 lineto
0.04489 0.46353 lineto
0.04613 0.46353 lineto
0.04737 0.46353 lineto
0.04861 0.46353 lineto
0.04985 0.46353 lineto
0.05109 0.46353 lineto
0.05233 0.46353 lineto
0.05357 0.46353 lineto
0.05481 0.46353 lineto
0.05605 0.46353 lineto
0.05729 0.46353 lineto
0.05853 0.46353 lineto
0.06101 0.46353 lineto
0.06225 0.46353 lineto
0.06349 0.46353 lineto
0.06473 0.46353 lineto
0.06597 0.46353 lineto
0.06845 0.46353 lineto
0.06969 0.46353 lineto
0.07093 0.46353 lineto
0.07341 0.46353 lineto
0.07589 0.46353 lineto
0.07837 0.46352 lineto
0.08085 0.46352 lineto
0.08333 0.46352 lineto
0.08581 0.46352 lineto
0.08829 0.46352 lineto
0.09077 0.46352 lineto
0.09325 0.46352 lineto
0.09573 0.46352 lineto
0.09821 0.46352 lineto
0.10069 0.46351 lineto
0.10317 0.46351 lineto
Mistroke
0.10565 0.46351 lineto
0.10813 0.4635 lineto
0.1131 0.46349 lineto
0.11558 0.46348 lineto
0.11806 0.46347 lineto
0.12302 0.46344 lineto
0.12798 0.4634 lineto
0.13294 0.46334 lineto
0.1379 0.46327 lineto
0.14286 0.46316 lineto
0.14782 0.46302 lineto
0.15278 0.46284 lineto
0.15774 0.4626 lineto
0.1627 0.4623 lineto
0.16766 0.46191 lineto
0.17262 0.46142 lineto
0.17758 0.46081 lineto
0.18254 0.46007 lineto
0.19246 0.45808 lineto
0.20238 0.45529 lineto
0.2123 0.45155 lineto
0.22222 0.44679 lineto
0.24206 0.43435 lineto
0.2619 0.41891 lineto
0.30159 0.3845 lineto
0.34127 0.35081 lineto
0.38095 0.31992 lineto
0.42063 0.2919 lineto
0.46032 0.26643 lineto
0.5 0.24312 lineto
0.53968 0.22166 lineto
0.57937 0.20178 lineto
0.61905 0.18327 lineto
0.65873 0.16595 lineto
0.69841 0.14968 lineto
0.7381 0.13433 lineto
0.77778 0.11982 lineto
0.81746 0.10606 lineto
0.85714 0.09296 lineto
0.89683 0.08047 lineto
0.93651 0.06854 lineto
0.97619 0.05712 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.30807 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.29557 0 1 Msboxa
[(40)] 0.40476 0.29557 0 1 Msboxa
[(60)] 0.59524 0.29557 0 1 Msboxa
[(80)] 0.78571 0.29557 0 1 Msboxa
[(100)] 0.97619 0.29557 0 1 Msboxa
[(w)] 1.00625 0.30807 -1 0 Msboxa
[(-150)] 0.01131 0.06196 1 0 Msboxa
[(-100)] 0.01131 0.14399 1 0 Msboxa
[(-50)] 0.01131 0.22603 1 0 Msboxa
[(50)] 0.01131 0.39011 1 0 Msboxa
[(100)] 0.01131 0.47214 1 0 Msboxa
[(150)] 0.01131 0.55418 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30807 moveto
1 0.30807 lineto
stroke
0.21429 0.30182 moveto
0.21429 0.31432 lineto
stroke
0 setgray
[(20)] 0.21429 0.29557 0 1 Mshowa
0.40476 0.30182 moveto
0.40476 0.31432 lineto
stroke
0 setgray
[(40)] 0.40476 0.29557 0 1 Mshowa
0.59524 0.30182 moveto
0.59524 0.31432 lineto
stroke
0 setgray
[(60)] 0.59524 0.29557 0 1 Mshowa
0.78571 0.30182 moveto
0.78571 0.31432 lineto
stroke
0 setgray
[(80)] 0.78571 0.29557 0 1 Mshowa
0.97619 0.30182 moveto
0.97619 0.31432 lineto
stroke
0 setgray
[(100)] 0.97619 0.29557 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30807 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06196 moveto
0.03006 0.06196 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06196 1 0 Mshowa
0.01756 0.14399 moveto
0.03006 0.14399 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14399 1 0 Mshowa
0.01756 0.22603 moveto
0.03006 0.22603 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22603 1 0 Mshowa
0.01756 0.39011 moveto
0.03006 0.39011 lineto
stroke
0 setgray
[(50)] 0.01131 0.39011 1 0 Mshowa
0.01756 0.47214 moveto
0.03006 0.47214 lineto
stroke
0 setgray
[(100)] 0.01131 0.47214 1 0 Mshowa
0.01756 0.55418 moveto
0.03006 0.55418 lineto
stroke
0 setgray
[(150)] 0.01131 0.55418 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30807 moveto
0.06349 0.26131 lineto
0.10317 0.21298 lineto
0.14286 0.16059 lineto
0.18254 0.10009 lineto
0.20238 0.06625 lineto
0.2123 0.04887 lineto
0.22222 0.03158 lineto
0.22718 0.02307 lineto
0.22966 0.01887 lineto
0.2309 0.01679 lineto
0.23214 0.01472 lineto
0.23338 0.60332 lineto
0.23462 0.60127 lineto
0.2371 0.59721 lineto
0.24206 0.58926 lineto
0.2619 0.56006 lineto
0.28175 0.53539 lineto
0.30159 0.51491 lineto
0.34127 0.48362 lineto
0.38095 0.46102 lineto
0.42063 0.4439 lineto
0.46032 0.43042 lineto
0.5 0.41947 lineto
0.53968 0.41039 lineto
0.57937 0.40272 lineto
0.61905 0.39615 lineto
0.65873 0.39045 lineto
0.69841 0.38545 lineto
0.7381 0.38103 lineto
0.77778 0.3771 lineto
0.81746 0.37357 lineto
0.85714 0.37039 lineto
0.89683 0.36751 lineto
0.93651 0.36489 lineto
0.97619 0.36248 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{Graphics[{{Line[{{0., -(9.64327466553287*10^-16)}, 
       {0.1302083333333333, 0.}, 
       {0.2604166666666667, 
        -(9.64327466553287*10^-16)}, 
       {0.390625, -(4.243040852834473*10^-14)}, 
       {0.5208333333333334, 
        -(4.300900500827766*10^-13)}, 
       {0.6510416666666667, 
        -(2.554503458900033*10^-12)}, 
       {0.78125, -(1.098272551658233*10^-11)}, 
       {0.911458333333333, 
        -(3.769652499511635*10^-11)}, 
       {1.041666666666667, 
        -(1.097067142331275*10^-10)}, 
       {1.171875, -(2.814842945090659*10^-10)}, 
       {1.302083333333333, 
        -(6.539046691295987*10^-10)}, 
       {1.432291666666667, -(1.401699153449097*10^-9)}, 
       {1.5625, -(2.811661629187963*10^-9)}, 
       {1.692708333333333, -(5.33408577176804*10^-9)}, 
       {1.822916666666667, -(9.6502255432726*10^-9)}, 
       {1.953125, -(1.675881079716774*10^-8)}, 
       {2.083333333333333, -(2.808490442399607*10^-8)}, 
       {2.213541666666667, -(4.561466423039656*10^-8)}, 
       {2.34375, -(7.205981672072245*10^-8)}, 
       {2.473958333333333, -(1.110559691464714*10^-7)}, 
       {2.604166666666667, -(1.673990771314735*10^-7)}, 
       {2.734375, -(2.473246754528456*10^-7)}, 
       {2.864583333333333, -(3.588347823714419*10^-7)}, 
       {2.994791666666667, -(5.120775865798201*10^-7)}, 
       {3.125, -(7.197853498840106*10^-7)}, 
       {3.255208333333333, -(9.97776162258849*10^-7)}, 
       {3.385416666666667, -0.000001365525515789447}, 
       {3.515625, -0.000001846813859873442}, 
       {3.645833333333333, -0.000002470456616503237}, 
       {3.90625, -0.000004290253236625378}, 
       {4.036458333333334, -0.00000557707360561725}, 
       {4.166666666666667, -0.000007189729837865325}, 
       {4.296875, -0.00000919653363740319}, 
       {4.427083333333334, -0.0000116773381586722}, 
       {4.6875, -0.00001844727356587346}, 
       {4.817708333333334, -0.00002296813586934091}, 
       {4.947916666666667, -0.0000284302354160196}, 
       {5.208333333333334, -0.00004285395333946428}, 
       {5.46875, -0.00006331465750163}, 
       {5.729166666666667, -0.0000918607365493948}, 
       {5.989583333333334, -0.000131089891320037}, 
       {6.25, -0.0001842611555394739}, 
       {6.510416666666667, -0.0002554232155275542}, 
       {6.770833333333334, -0.0003495605189402058}, 
       {7.03125, -0.0004727587164994111}, 
       {7.291666666666667, -0.0006323910291687686}, 
       {7.552083333333334, -0.000837327174447657}, 
       {7.8125, -0.001098166517207317}, 
       {8.07291666666667, -0.001427497129607831}, 
       {8.33333333333333, -0.001840182447855589}, 
       {8.59375, -0.002353677196032369}, 
       {8.85416666666667, -0.002988374203798711}, 
       {9.375, -0.004719946296157031}, 
       {9.63541666666667, -0.005875881586674517}, 
       {9.89583333333333, -0.007272072305208329}, 
       {10.41666666666667, -0.0109568330310808}, 
       {10.9375, -0.01617849864633785}, 
       {11.45833333333333, -0.02345315620707671}, 
       {11.97916666666667, -0.03343051946750253}, 
       {12.5, -0.04691751280979623}, 
       {13.02083333333333, -0.06490287265224987}, 
       {13.54166666666667, -0.0885815374598569}, 
       {14.0625, -0.1193769906057637}, 
       {14.58333333333333, -0.1589589898506859}, 
       {15.10416666666667, -0.2092533135228149}, 
       {15.625, -0.2724393875308502}, 
       {16.14583333333334, -0.3509311198492313}, 
       {16.66666666666667, -0.4473362363082883}, 
       {17.70833333333334, -0.7048629196643788}, 
       {18.75, -1.066579422977551}, 
       {19.79166666666667, -1.55038294494502}, 
       {20.83333333333334, -2.166089062996311}, 
       {22.91666666666667, -3.777093051719796}, 
       {25., -5.775608067636306}, 
       {29.16666666666667, -10.22989565302369}, 
       {33.33333333333334, -14.59009973298618}, 
       {37.5, -18.58920517873301}, 
       {41.66666666666667, -22.2154407506314}, 
       {45.83333333333334, -25.51292190522114}, 
       {50., -28.52988266565831}, 
       {54.16666666666667, -31.30796913865475}, 
       {58.33333333333334, -33.88130627707812}, 
       {62.50000000000001, -36.27761039016486}, 
       {66.66666666666667, -38.51949556232383}, 
       {70.83333333333334, -40.62557595749191}, 
       {75., -42.61132465312718}, 
       {79.16666666666667, -44.48972873463467}, 
       {83.3333333333333, -46.27178832368528}, 
       {87.5, -47.96689913421687}, 
       {91.6666666666667, -49.58314846790995}, 
       {95.8333333333333, -51.12754657766277}, 
       {100., -52.60620936644717}}]}}, 
   {PlotRange -> Automatic, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]
   , Graphics[{{Line[{{0., 0.}, 
       {4.166666666666667, -28.49990856556255}, 
       {8.33333333333333, -57.95386685185316}, 
       {12.5, -89.8856243159781}, 
       {16.66666666666667, -126.7606711103178}, 
       {18.75, -147.3855233529654}, 
       {19.79166666666667, -157.9768308480074}, 
       {20.83333333333334, -168.5155581201708}, 
       {21.35416666666667, -173.6998499390056}, 
       {21.61458333333334, -176.259523126013}, 
       {21.74479166666667, -177.5299294639054}, 
       {21.875, -178.793575720311}, 
       {22.00520833333334, 179.9498786662376}, 
       {22.13541666666667, 178.700761883017}, 
       {22.39583333333334, 176.2260619035217}, 
       {22.91666666666667, 171.3787401758882}, 
       {25., 153.5824947896394}, 
       {27.08333333333334, 138.5466329868608}, 
       {29.16666666666667, 126.0669225218068}, 
       {33.33333333333334, 106.9938559080811}, 
       {37.5, 93.2242937238403}, 
       {41.66666666666667, 82.7895665524799}, 
       {45.83333333333334, 74.56917683905063}, 
       {50., 67.89995181150334}, 
       {54.16666666666667, 62.36556833986922}, 
       {58.33333333333334, 57.69030790178747}, 
       {62.50000000000001, 53.68332580594596}, 
       {66.66666666666667, 50.20770706112258}, 
       {70.83333333333334, 47.16231274999164}, 
       {75., 44.47060253298343}, 
       {79.16666666666667, 42.07346274224197}, 
       {83.3333333333333, 39.92444088124741}, 
       {87.5, 37.98648348448841}, 
       {91.6666666666667, 36.22964537830778}, 
       {95.8333333333333, 34.62944517370985}, 
       {100., 33.16566170062674}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; ]
Graphically, the magnitude response seems to meet the passband and stopband specifications, and the phase response clearly shows that the cutoff frequency is about 22 rad/sec. We will now check the magnitude response at the end of the passband and the beginning of the stopband just to make sure:
:[font = input; startGroup; ]
20 Log[10, Abs[bfiltertrans /. w -> 20]]
:[font = output; inactive; output; endGroup; ]
-1.662842529124097
;[o]
-1.66284
:[font = input; startGroup; ]
20 Log[10, Abs[bfiltertrans /. w -> 30]]
:[font = output; inactive; output; endGroup; ]
-11.12473416925727
;[o]
-11.1247
:[font = text; inactive; ]
Here, the error in the passband is no greater than 1.67 dB (which is less than the specification of 2 dB) and the attenuation of the stopband is greater than 11 dB (which is better than the specification of 10 dB).  Therefore, the following filter meets the specifications:
:[font = text; inactive; endGroup; endGroup; ]
234256 CIIR[t, {234526, 27824.6, 1652.48, 57.4888, 1}]
:[font = subsection; inactive; startGroup; Cclosed; ]
Chebyshev Type I Example (Using Object AnalogFilter)
:[font = text; inactive; ]
Problem:  Design a lowpass Chebyshev type I analog filter that has a -2 dB or better cutoff at 20 rad/sec and at least 40 db of attenuation at 30 rad/sec.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 1:  Determine the order of the filter
:[font = text; inactive; ]
First, we need to determine the order of the Chebyshev filter necessary.  At the cutoff frequency, we want a magnitude response of -2 dB or better:
:[font = input; initialization; startGroup; ]
*)
c1delta1 = 1 - N[ 10^(-2/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.2056717652757185
;[o]
0.205672
:[font = text; inactive; ]
In the stopband, we want an attenuation of at least 40 db:
:[font = input; initialization; startGroup; ]
*)
c1delta2 = N[ 10^(-40/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.01
;[o]
0.01
:[font = text; inactive; ]
From the values of delta1 and delta2, we can determine the other filter parameters:
:[font = input; initialization; startGroup; ]
*)
FilterParameters[ c1delta1, c1delta2,
   c1epsilon, c1A, Eripple, ATT, c1nu ]
(*
:[font = output; inactive; output; endGroup; ]
{0.2056717652757185, 0.01, 0.7647831015792084, 
  100., 2.466913365931468, 4.99999999999999, 
  0.00764821343602463}
;[o]
{0.205672, 0.01, 0.764783, 100., 2.46691, 40., 
 
  0.00764821}
:[font = text; inactive; ]
The parameters Eripple and ATT are useful when using filter design charts and are calculated here for completeness (note that the attenuation ATT should be 40 dB in this case).  The values of delta1 and delta2 determine the values of the other parameters.  The value of nu and the transition width (2/3 = 20 rad/sec divided by 30 rad/sec) determine the filter order:
:[font = input; startGroup; ]
FilterOrder[ ChebyshevI, 2/3, c1nu ]
:[font = output; inactive; output; endGroup; ]
6
;[o]
6
:[font = text; inactive; endGroup; ]
Now, we know that we need a Chebyshev type I filter of order 6.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 2:  Find the coefficients of the filter
:[font = text; inactive; ]
We now know that we need a fourth order Butterworth filter to meet specifications.  So, now we can ask Mathematica to create a fourth-order Butterworth filter with a cutoff frequency between 20 rad/sec and 30 rad/sec (we have chosen a cutoff of 22 rad/sec):
:[font = input; initialization; ]
*)
define[ c1filter,
        AnalogFilter[ChebyshevI, t, 6,
                     c1epsilon, c1A, 2/3, 20] ]
(*
:[font = input; startGroup; ]
c1filter
:[font = output; inactive; output; endGroup; ]
2615120.54315816*CIIR[t, 
   {3292241.706686772, 672865.7798417783, 
    123433.8833675754, 6936.119375271063, 
    698.3434983669848, 14.02451413539769, 1}, 
   Roots -> 
    {20*(1.016335980968083*I*Cos[Pi/12] - 
        0.1814905678275217*Sin[Pi/12]), 
     (-1.814905678275217 + 
        10.16335980968083*I)*2^(1/2), 
     20*(1.016335980968083*I*Cos[(5*Pi)/12] - 
        0.1814905678275217*Sin[(5*Pi)/12]), 
     20*(1.016335980968083*I*Cos[(7*Pi)/12] - 
        0.1814905678275217*Sin[(7*Pi)/12]), 
     (-1.814905678275217 - 
        10.16335980968083*I)*2^(1/2), 
     20*(1.016335980968083*I*Cos[(11*Pi)/12] - 
        0.1814905678275217*Sin[(11*Pi)/12])}]
;[o]
          6
2.61512 10  CIIR[t, 
 
              6
   {3.29224 10 , 672866., 123434., 6936.12, 
 
    698.343, 14.0245, 1}]
:[font = text; inactive; ]
Like Butterworth filters, Chebyshev type I filters contain only poles.  Here, the DC gain is about 4/5, which is less than one.  This is true for Chebyshev type I filters with even order.  The DC gain is scaled to compensate for the location of the ripples in the passband (the maximum value in the passband is still one, but it occurs at locations other than DC).  Note that odd-ordered Chebyshev type I and Chebyshev type II filters have a DC gain of unity.  The ripple characteristics in the passband of this Chebyshev type I filter is shown in the magnitude frequency response plot in Step 3 (the next sub-section).
:[font = text; inactive; startGroup; Cclosed; ]
		In order to learn more about the CIIR object, see Step 2 of the Butterworth Example. Like the Butterworth example, the poles of this filter are also embedded in the CIIR object:
:[font = input; startGroup; ]
c1filter[[2]][[3]]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
Roots -> {20*(1.016335980968083*I*
       Cos[Pi/12] - 
      0.1814905678275217*Sin[Pi/12]), 
   (-1.814905678275217 + 
      10.16335980968083*I)*2^(1/2), 
   20*(1.016335980968083*I*Cos[(5*Pi)/12] - 
      0.1814905678275217*Sin[(5*Pi)/12]), 
   20*(1.016335980968083*I*Cos[(7*Pi)/12] - 
      0.1814905678275217*Sin[(7*Pi)/12]), 
   (-1.814905678275217 - 
      10.16335980968083*I)*2^(1/2), 
   20*(1.016335980968083*I*Cos[(11*Pi)/12] - 
      0.1814905678275217*Sin[(11*Pi)/12])}
;[o]
                            Pi
Roots -> {20 (1.01634 I Cos[--] - 
                            12
 
                   Pi
      0.181491 Sin[--]), 
                   12
 
   (-1.81491 + 10.1634 I) Sqrt[2], 
 
                     5 Pi
   20 (1.01634 I Cos[----] - 
                      12
 
                   5 Pi
      0.181491 Sin[----]), 
                    12
 
                     7 Pi
   20 (1.01634 I Cos[----] - 
                      12
 
                   7 Pi
      0.181491 Sin[----]), 
                    12
 
   (-1.81491 - 10.1634 I) Sqrt[2], 
 
                     11 Pi
   20 (1.01634 I Cos[-----] - 
                      12
 
                   11 Pi
      0.181491 Sin[-----])}
                    12
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 3:  Verify that the filter meets the specifications
:[font = text; inactive; ]
In order to verify that the filter meets specifications, we need to examine the frequency response of the filter.  This can be done by simply taking the continuous-time Fourier transform of the filter.  In previous examples, the CTFT of a filter object returns a Fourier transform in terms of its unevaluated roots.  For large analog filters, this can really bog Mathematica down.   We will therefore transform a numeric approximation of the filter to save time.
:[font = input; initialization; ]
*)
define[ c1filtertransobject,
        CTFTransform[ N[c1filter], t, w ] ]
(*
:[font = input; initialization; ]
*)
define[ c1filtertrans,
        TheFunction[c1filtertransobject] ]
(*
:[font = input; startGroup; Cclosed; ]
c1filtertrans
:[font = output; inactive; output; endGroup; ]
2615120.54315816/
  (3292241.706686773 + 
     9.31322574615479*10^-10*I + 
    (-(2.91038304567337*10^-10) + 
       672865.7798417782*I)*w + 
    -123433.8833675754*w^2 + 
    (2.728484105318785*10^-12 - 
       6936.119375271063*I)*w^3 + 
    698.3434983669849*w^4 + 
    (3.552713678800501*10^-15 + 
       14.02451413539769*I)*w^5 - w^6)
;[o]
           6
(2.61512 10 ) / 
 
             6             -10
  (3.29224 10  + 9.31323 10    I + 
 
                -10
    (-2.91038 10    + 672866. I) w + 
 
              2              -12
    -123434. w  + (2.72848 10    - 6936.12 I) 
 
      3            4
     w  + 698.343 w  + 
 
               -15               5    6
    (3.55271 10    + 14.0245 I) w  - w )
:[font = text; inactive; ]
Now, we can plot the magnitude and frequency response:
:[font = input; startGroup; Cclosed; ]
MagPhasePlot[ c1filtertrans,
              {w, 0, 40},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.02381 0.60332 0.00976 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.2619 0.59082 0 1 Msboxa
[(20)] 0.5 0.59082 0 1 Msboxa
[(30)] 0.7381 0.59082 0 1 Msboxa
[(40)] 0.97619 0.59082 0 1 Msboxa
[(w)] 1.00625 0.60332 -1 0 Msboxa
[(-60)] 0.01131 0.01749 1 0 Msboxa
[(-50)] 0.01131 0.11513 1 0 Msboxa
[(-40)] 0.01131 0.21276 1 0 Msboxa
[(-30)] 0.01131 0.3104 1 0 Msboxa
[(-20)] 0.01131 0.40804 1 0 Msboxa
[(-10)] 0.01131 0.50568 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.60332 moveto
1 0.60332 lineto
stroke
0.2619 0.59707 moveto
0.2619 0.60957 lineto
stroke
0 setgray
[(10)] 0.2619 0.59082 0 1 Mshowa
0.5 0.59707 moveto
0.5 0.60957 lineto
stroke
0 setgray
[(20)] 0.5 0.59082 0 1 Mshowa
0.7381 0.59707 moveto
0.7381 0.60957 lineto
stroke
0 setgray
[(30)] 0.7381 0.59082 0 1 Mshowa
0.97619 0.59707 moveto
0.97619 0.60957 lineto
stroke
0 setgray
[(40)] 0.97619 0.59082 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.60332 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.01749 moveto
0.03006 0.01749 lineto
stroke
0 setgray
[(-60)] 0.01131 0.01749 1 0 Mshowa
0.01756 0.11513 moveto
0.03006 0.11513 lineto
stroke
0 setgray
[(-50)] 0.01131 0.11513 1 0 Mshowa
0.01756 0.21276 moveto
0.03006 0.21276 lineto
stroke
0 setgray
[(-40)] 0.01131 0.21276 1 0 Mshowa
0.01756 0.3104 moveto
0.03006 0.3104 lineto
stroke
0 setgray
[(-30)] 0.01131 0.3104 1 0 Mshowa
0.01756 0.40804 moveto
0.03006 0.40804 lineto
stroke
0 setgray
[(-20)] 0.01131 0.40804 1 0 Mshowa
0.01756 0.50568 moveto
0.03006 0.50568 lineto
stroke
0 setgray
[(-10)] 0.01131 0.50568 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.58379 moveto
0.02505 0.5838 lineto
0.02629 0.58381 lineto
0.02753 0.58383 lineto
0.02877 0.58385 lineto
0.03125 0.58393 lineto
0.03373 0.58404 lineto
0.03621 0.58417 lineto
0.03869 0.58434 lineto
0.04365 0.58476 lineto
0.05357 0.58595 lineto
0.06349 0.58756 lineto
0.10317 0.59673 lineto
0.1131 0.59906 lineto
0.12302 0.60105 lineto
0.12798 0.60186 lineto
0.13294 0.6025 lineto
0.13542 0.60276 lineto
0.1379 0.60297 lineto
0.13914 0.60306 lineto
0.14038 0.60313 lineto
0.14162 0.6032 lineto
0.14286 0.60325 lineto
0.1441 0.60328 lineto
0.14534 0.60331 lineto
0.14658 0.60332 lineto
0.14782 0.60332 lineto
0.14906 0.6033 lineto
0.1503 0.60328 lineto
0.15154 0.60323 lineto
0.15278 0.60318 lineto
0.15526 0.60304 lineto
0.15774 0.60284 lineto
0.16022 0.6026 lineto
0.1627 0.6023 lineto
0.17262 0.6007 lineto
0.18254 0.59855 lineto
0.20238 0.59341 lineto
0.22222 0.5885 lineto
0.23214 0.58654 lineto
0.2371 0.58573 lineto
0.24206 0.58505 lineto
0.24702 0.58451 lineto
0.2495 0.58429 lineto
0.25198 0.58411 lineto
0.25446 0.58397 lineto
0.2557 0.58392 lineto
0.25694 0.58387 lineto
0.25818 0.58384 lineto
0.25942 0.58381 lineto
Mistroke
0.26066 0.5838 lineto
0.2619 0.58379 lineto
0.26314 0.5838 lineto
0.26438 0.58381 lineto
0.26563 0.58384 lineto
0.26687 0.58387 lineto
0.26935 0.58398 lineto
0.27183 0.58412 lineto
0.27431 0.58431 lineto
0.27679 0.58454 lineto
0.28175 0.58512 lineto
0.29167 0.58677 lineto
0.30159 0.58902 lineto
0.32143 0.59486 lineto
0.33135 0.59798 lineto
0.33631 0.59943 lineto
0.34127 0.60073 lineto
0.34623 0.60183 lineto
0.35119 0.60266 lineto
0.35367 0.60296 lineto
0.35491 0.60308 lineto
0.35615 0.60317 lineto
0.35739 0.60324 lineto
0.35863 0.60329 lineto
0.35987 0.60332 lineto
0.36111 0.60332 lineto
0.36235 0.60329 lineto
0.36359 0.60325 lineto
0.36483 0.60317 lineto
0.36607 0.60307 lineto
0.36731 0.60295 lineto
0.36855 0.60281 lineto
0.37103 0.60244 lineto
0.37599 0.60144 lineto
0.38095 0.6001 lineto
0.39087 0.59668 lineto
0.40079 0.59276 lineto
0.41071 0.58898 lineto
0.41567 0.58732 lineto
0.42063 0.58592 lineto
0.4256 0.58482 lineto
0.42808 0.58441 lineto
0.42932 0.58424 lineto
0.43056 0.5841 lineto
0.4318 0.58398 lineto
0.43304 0.58389 lineto
0.43428 0.58383 lineto
0.43552 0.5838 lineto
0.43676 0.58379 lineto
0.438 0.58382 lineto
Mistroke
0.43924 0.58389 lineto
0.44048 0.58398 lineto
0.44172 0.58411 lineto
0.44296 0.58427 lineto
0.44544 0.58469 lineto
0.44792 0.58527 lineto
0.4504 0.58599 lineto
0.45536 0.58788 lineto
0.46032 0.59039 lineto
0.47024 0.59681 lineto
0.4752 0.60013 lineto
0.47768 0.60155 lineto
0.47892 0.60214 lineto
0.48016 0.60264 lineto
0.4814 0.60301 lineto
0.48264 0.60325 lineto
0.48388 0.60332 lineto
0.48512 0.60321 lineto
0.48636 0.6029 lineto
0.4876 0.60237 lineto
0.48884 0.6016 lineto
0.49008 0.60059 lineto
0.49256 0.59781 lineto
0.49504 0.59403 lineto
0.5 0.58379 lineto
0.53968 0.47573 lineto
0.57937 0.3946 lineto
0.61905 0.33205 lineto
0.65873 0.2801 lineto
0.69841 0.23511 lineto
0.7381 0.19512 lineto
0.77778 0.15895 lineto
0.81746 0.12582 lineto
0.85714 0.09519 lineto
0.89683 0.06665 lineto
0.93651 0.03991 lineto
0.97619 0.01472 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.02381 0.30966 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.2619 0.29716 0 1 Msboxa
[(20)] 0.5 0.29716 0 1 Msboxa
[(30)] 0.7381 0.29716 0 1 Msboxa
[(40)] 0.97619 0.29716 0 1 Msboxa
[(w)] 1.00625 0.30966 -1 0 Msboxa
[(-150)] 0.01131 0.06385 1 0 Msboxa
[(-100)] 0.01131 0.14579 1 0 Msboxa
[(-50)] 0.01131 0.22772 1 0 Msboxa
[(50)] 0.01131 0.3916 1 0 Msboxa
[(100)] 0.01131 0.47353 1 0 Msboxa
[(150)] 0.01131 0.55547 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30966 moveto
1 0.30966 lineto
stroke
0.2619 0.30341 moveto
0.2619 0.31591 lineto
stroke
0 setgray
[(10)] 0.2619 0.29716 0 1 Mshowa
0.5 0.30341 moveto
0.5 0.31591 lineto
stroke
0 setgray
[(20)] 0.5 0.29716 0 1 Mshowa
0.7381 0.30341 moveto
0.7381 0.31591 lineto
stroke
0 setgray
[(30)] 0.7381 0.29716 0 1 Mshowa
0.97619 0.30341 moveto
0.97619 0.31591 lineto
stroke
0 setgray
[(40)] 0.97619 0.29716 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30966 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06385 moveto
0.03006 0.06385 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06385 1 0 Mshowa
0.01756 0.14579 moveto
0.03006 0.14579 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14579 1 0 Mshowa
0.01756 0.22772 moveto
0.03006 0.22772 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22772 1 0 Mshowa
0.01756 0.3916 moveto
0.03006 0.3916 lineto
stroke
0 setgray
[(50)] 0.01131 0.3916 1 0 Mshowa
0.01756 0.47353 moveto
0.03006 0.47353 lineto
stroke
0 setgray
[(100)] 0.01131 0.47353 1 0 Mshowa
0.01756 0.55547 moveto
0.03006 0.55547 lineto
stroke
0 setgray
[(150)] 0.01131 0.55547 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30966 moveto
0.06349 0.27649 lineto
0.10317 0.23624 lineto
0.14286 0.18489 lineto
0.18254 0.13099 lineto
0.22222 0.08652 lineto
0.2619 0.04956 lineto
0.27183 0.04047 lineto
0.28175 0.03109 lineto
0.29167 0.02122 lineto
0.29415 0.01866 lineto
0.29539 0.01736 lineto
0.29663 0.01604 lineto
0.29787 0.01472 lineto
0.29911 0.60332 lineto
0.30035 0.60197 lineto
0.30159 0.6006 lineto
0.34127 0.54671 lineto
0.38095 0.47514 lineto
0.42063 0.41295 lineto
0.44048 0.38572 lineto
0.4504 0.37079 lineto
0.46032 0.35305 lineto
0.47024 0.32991 lineto
0.48016 0.2977 lineto
0.5 0.21158 lineto
0.50496 0.19322 lineto
0.50992 0.17787 lineto
0.51488 0.16528 lineto
0.51984 0.15494 lineto
0.52976 0.1392 lineto
0.53968 0.12785 lineto
0.5496 0.11923 lineto
0.55952 0.11241 lineto
0.57937 0.10211 lineto
0.59921 0.09455 lineto
0.61905 0.08864 lineto
0.65873 0.07976 lineto
0.69841 0.07326 lineto
0.7381 0.06818 lineto
0.77778 0.06407 lineto
0.81746 0.06063 lineto
0.85714 0.05771 lineto
0.89683 0.05518 lineto
0.93651 0.05296 lineto
0.97619 0.051 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{Graphics[{{Line[{{0., -2.000000000000004}, 
       {0.05208333333333334, 
        -1.999608721367311}, 
       {0.1041666666666667, 
        -1.998435045497451}, 
       {0.15625, -1.996479452775577}, 
       {0.2083333333333333, 
        -1.993742744845318}, 
       {0.3125, -1.985930805843106}, 
       {0.4166666666666667, 
        -1.975012138933879}, 
       {0.5208333333333334, 
        -1.961004953368554}, 
       {0.625, -1.943932891817085}, 
       {0.833333333333333, 
        -1.900716954812301}, 
       {1.25, -1.779198323330883}, 
       {1.666666666666667, 
        -1.614190199567361}, 
       {3.333333333333333, 
        -0.675386632055639}, 
       {3.75, -0.436402943414256}, 
       {4.166666666666667, 
        -0.2323858061291877}, 
       {4.375, -0.1499474082170808}, 
       {4.583333333333334, 
        -0.08373502268969}, 
       {4.6875, -0.0573580317056479}, 
       {4.791666666666667, 
        -0.03575977399463781}, 
       {4.84375, -0.02681062549280745}, 
       {4.895833333333334, 
        -0.01912152587878078}, 
       {4.947916666666667, 
        -0.01270975269489211}, 
       {5., -0.007590273930551074}, 
       {5.052083333333334, 
        -0.003775679510069897}, 
       {5.104166666666667, 
        -0.001276122177532928}, 
       {5.15625, -0.0000992683039587905}, 
       {5.208333333333334, 
        -0.0002502590582714333}, 
       {5.260416666666667, 
        -0.001731682293186312}, 
       {5.3125, -0.004543555400999975}, 
       {5.364583333333334, 
        -0.00868331929451682}, 
       {5.416666666666667, 
        -0.01414584356576958}, 
       {5.520833333333334, 
        -0.02900590369683193}, 
       {5.625, -0.04903215722847583}, 
       {5.729166666666667, 
        -0.07409404197564073}, 
       {5.833333333333334, 
        -0.1040240189247996}, 
       {6.25, -0.2679360845319231}, 
       {6.666666666666667, 
        -0.4887970371676392}, 
       {7.5, -1.015267762326715}, 
       {8.33333333333333, 
        -1.517712923903269}, 
       {8.75, -1.718993323772498}, 
       {8.95833333333333, 
        -1.801920934517968}, 
       {9.16666666666667, 
        -1.871528471062649}, 
       {9.375, -1.926875224183171}, 
       {9.47916666666667, 
        -1.948945404464977}, 
       {9.58333333333333, 
        -1.967160613715554}, 
       {9.6875, -1.9814413129233}, 
       {9.73958333333333, 
        -1.987083537559587}, 
       {9.79166666666667, 
        -1.991715902941025}, 
       {9.84375, -1.99533069593157}, 
       {9.89583333333333, 
        -1.997920701149086}, 
       {9.94791666666667, 
        -1.999479204809946}, 
       {10., -2.000000000000004}, 
       {10.05208333333333, 
        -1.999477393424023}, 
       {10.10416666666667, 
        -1.997906213686893}, 
       {10.15625, -1.995281821162166}, 
       {10.20833333333333, 
        -1.991600119504764}, 
       {10.3125, -1.981051200877537}, 
       {10.41666666666667, 
        -1.966238099475301}, 
       {10.52083333333333, 
        -1.94714918431363}, 
       {10.625, -1.923783246166383}, 
       {10.83333333333333, 
        -1.864272686230305}, 
       {11.25, -1.695255381269559}, 
       {11.66666666666667, 
        -1.464189243611546}, 
       {12.5, -0.866357438394314}, 
       {12.91666666666667, 
        -0.5472450147619314}, 
       {13.125, -0.3985118509244518}, 
       {13.33333333333333, 
        -0.2647860239603805}, 
       {13.54166666666667, 
        -0.152334845432388}, 
       {13.75, -0.06730378016892942}, 
       {13.85416666666667, 
        -0.03683064824768138}, 
       {13.90625, -0.02487421921925044}, 
       {13.95833333333333, 
        -0.01519286912852844}, 
       {14.01041666666667, 
        -0.007844856197496173}, 
       {14.0625, -0.002881436126322297}, 
       {14.11458333333333, 
        -0.0003463916430957452}, 
       {14.16666666666667, 
        -0.0002756072696265638}, 
       {14.21875, -0.002696695843353158}, 
       {14.27083333333333, 
        -0.00762868266227159}, 
       {14.32291666666667, 
        -0.01508175228571149}, 
       {14.375, -0.0250570620499128}, 
       {14.42708333333333, 
        -0.0375466252664058}, 
       {14.47916666666667, 
        -0.05253326589490306}, 
       {14.58333333333333, 
        -0.089883360072025}, 
       {14.79166666666667, 
        -0.192793451822802}, 
       {15., -0.3296476764292001}, 
       {15.41666666666667, 
        -0.6800994701973938}, 
       {15.83333333333333, 
        -1.081395180404025}, 
       {16.25, -1.468809735409067}, 
       {16.45833333333334, 
        -1.638270432496955}, 
       {16.66666666666667, 
        -1.782320775426833}, 
       {16.875, -1.894555558838547}, 
       {16.97916666666667, 
        -1.936832422252293}, 
       {17.03125, -1.954186777468768}, 
       {17.08333333333334, 
        -1.968897434145862}, 
       {17.13541666666667, 
        -1.980874715251353}, 
       {17.1875, -1.990029790021883}, 
       {17.23958333333334, 
        -1.996274705584609}, 
       {17.29166666666667, 
        -1.999522452214634}, 
       {17.34375, -1.999687068473844}, 
       {17.39583333333334, 
        -1.996683793478394}, 
       {17.44791666666667, 
        -1.990429274729788}, 
       {17.5, -1.980841841351082}, 
       {17.55208333333334, 
        -1.967841854226496}, 
       {17.60416666666667, 
        -1.951352146492891}, 
       {17.70833333333334, 
        -1.907610666925218}, 
       {17.8125, -1.849073570021595}, 
       {17.91666666666667, 
        -1.77528654922809}, 
       {18.125, -1.580865077085475}, 
       {18.33333333333334, 
        -1.324608368155396}, 
       {18.75, -0.6667797301644595}, 
       {18.95833333333334, 
        -0.3267843185441142}, 
       {19.0625, -0.1815677394221228}, 
       {19.11458333333334, 
        -0.1205996122329026}, 
       {19.16666666666667, 
        -0.06989235155744233}, 
       {19.21875, -0.03148240440676363}, 
       {19.27083333333334, 
        -0.007490165405068949}, 
       {19.32291666666667, 
        -0.00006628544097142481}, 
       {19.375, -0.01132427929220636}, 
       {19.42708333333334, 
        -0.04326172640206628}, 
       {19.47916666666667, 
        -0.0976744355604354}, 
       {19.53125, -0.1760699304513349}, 
       {19.58333333333334, 
        -0.2795880445822658}, 
       {19.6875, -0.5643510141025379}, 
       {19.79166666666667, 
        -0.951893816427158}, 
       {20., -2.000000000000039}, 
       {21.66666666666667, 
        -13.06757559803225}, 
       {23.33333333333334, 
        -21.37708199944991}, 
       {25., -27.78312713763923}, 
       {26.66666666666667, 
        -33.10365318221579}, 
       {28.33333333333334, 
        -37.71182197573322}, 
       {30., -41.80756963255438}, 
       {31.66666666666667, 
        -45.51195617115651}, 
       {33.33333333333334, 
        -48.90478855040801}, 
       {35., -52.04199424133348}, 
       {36.66666666666667, 
        -54.96459761720124}, 
       {38.33333333333334, 
        -57.70377170407104}, 
       {40., -60.28387671522704}}]}}, 
   DisplayFunction :> $DisplayFunction, 
   PlotRange -> All, 
   PlotLabel -> "Magnitude Response (dB)", 
   PlotRange -> {-80, 20}, 
   Ticks -> Automatic, 
   AxesLabel -> {"w", " "}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, 
    AxesLabel -> None, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[{{Line[{{0., 0.}, 
       {1.666666666666667, 
        -20.24064085380655}, 
       {3.333333333333333, 
        -44.80171841600196}, 
       {5., -76.13472995887646}, 
       {6.666666666666667, 
        -109.0300125245268}, 
       {8.33333333333333, 
        -136.1682527536589}, 
       {10., -158.7172028287569}, 
       {10.41666666666667, 
        -164.2665385231566}, 
       {10.83333333333333, 
        -169.9902306789802}, 
       {11.25, -176.0104122299133}, 
       {11.35416666666667, 
        -177.5772952795224}, 
       {11.40625, -178.3715147461399}, 
       {11.45833333333333, 
        -179.1732948834513}, 
       {11.51041666666667, 
        -179.9829202263719}, 
       {11.5625, 179.1993225551543}, 
       {11.61458333333333, 
        178.3731449214399}, 
       {11.66666666666667, 
        177.5382567683941}, 
       {13.33333333333333, 
        144.6540187872928}, 
       {15., 100.9801736970715}, 
       {16.66666666666667, 
        63.03091183689556}, 
       {17.5, 46.41674795726676}, 
       {17.91666666666667, 
        37.30236330660985}, 
       {18.33333333333334, 
        26.48062375639121}, 
       {18.75, 12.36014701924501}, 
       {19.16666666666667, 
        -7.298005264678974}, 
       {20., -59.84862010098066}, 
       {20.20833333333334, 
        -71.05720648332722}, 
       {20.41666666666667, 
        -80.4189345759436}, 
       {20.625, -88.1062033289052}, 
       {20.83333333333334, 
        -94.4162055583195}, 
       {21.25, -104.0201019172537}, 
       {21.66666666666667, 
        -110.9471975183529}, 
       {22.08333333333334, 
        -116.2051613958437}, 
       {22.5, -120.3694872806944}, 
       {23.33333333333334, 
        -126.6493910022396}, 
       {24.16666666666667, 
        -131.2647990315955}, 
       {25., -134.8742920722431}, 
       {26.66666666666667, 
        -140.288116121682}, 
       {28.33333333333334, 
        -144.2581970199732}, 
       {30., -147.35425586235}, 
       {31.66666666666667, 
        -149.8663107949136}, 
       {33.33333333333334, 
        -151.9618568484332}, 
       {35., -153.7463146037281}, 
       {36.66666666666667, 
        -155.2902867709819}, 
       {38.33333333333334, 
        -156.6433278368289}, 
       {40., -157.8415175131979}}]}}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> 
     (Display[$Display, #1] & ), 
    PlotColor -> Automatic, 
    Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, 
    Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; ]
Graphically, the magnitude response seems to meet the passband and stopband specifications, and the phase response shows that the cutoff frequency is about 20 rad/sec. We will now check the magnitude response at the end of the passband and the beginning of the stopband just to make sure:
:[font = input; startGroup; ]
20 Log[10, Abs[c1filtertrans /. w -> 20]]
:[font = output; inactive; output; endGroup; ]
-1.999999999999999
;[o]
-2.
:[font = input; startGroup; ]
20 Log[10, Abs[c1filtertrans /. w -> 30]]
:[font = output; inactive; output; endGroup; ]
-41.80756963255439
;[o]
-41.8076
:[font = text; inactive; ]
Here, the error in the passband is no greater than 2 dB (which is the specification) and the attenuation of the stopband is greater than 41 dB (which is better than the specification of 40 dB).  Therefore, the following filter meets the specifications:
:[font = text; inactive; endGroup; endGroup; ]
2615120.5  CIIR[t, {3292241.7,  672865.78,  123433.88,  6936.1194,  698.3535,  14.024514,  1}]

:[font = subsection; inactive; startGroup; Cclosed; ]
Chebyshev Type II Example (Using Object DesignFilter)
:[font = text; inactive; ]
Problem:  Design a lowpass Chebyshev type II analog filter that has a -2 dB or better cutoff at 20 rad/sec and at least 40 db of attenuation at 30 rad/sec.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 1:  Determine the filter coefficients
:[font = text; inactive; ]
First, we need to determine the order of the Chebyshev filter necessary.  At the cutoff frequency, we want a magnitude response of -2 dB or better:
:[font = input; initialization; startGroup; ]
*)
c2delta1 = 1 - N[ 10^(-2/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.2056717652757185
;[o]
0.205672
:[font = text; inactive; ]
In the stopband, we want an attenuation of at least 40 db:
:[font = input; initialization; startGroup; ]
*)
c2delta2 = N[ 10^(-40/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.01
;[o]
0.01
:[font = text; inactive; ]
From the values of delta1 and delta2, we can determine the entire filter using the DesignFilter command (this abstracts the general design algorithm discussed in the Butterworth and Chebyshev type I examples):
:[font = input; initialization; ]
*)
define[ c2filter,
        DesignFilter[Analog, ChebyshevII,
                     Lowpass, t, c2delta1,
                     c2delta2, 20, 30] ]
(*
:[font = input; startGroup; ]
c2filter
:[font = output; inactive; output; endGroup; ]
0.01*CIIR[t, {233280000., 30115373.8914797, 
     2332678.053462828, 118311.5674218439, 
     4096.698036875321, 90.4994810689577, 1}, 
    Roots -> 
     {(42.47672063846061*I*Cos[Pi/12])/
        (2.004746440219806*Cos[Pi/12]^2 + 
          1.004746440219806*Sin[Pi/12]^2) - 
       (30.07111232059474*Sin[Pi/12])/
        (2.004746440219806*Cos[Pi/12]^2 + 
          1.004746440219806*Sin[Pi/12]^2), 
      (-9.99208621360889 + 
         14.11424526522084*I)*2^(1/2), 
      (42.47672063846061*I*Cos[(5*Pi)/12])/
        (2.004746440219806*Cos[(5*Pi)/12]^2 + 
          1.004746440219806*Sin[(5*Pi)/12]^2) \
        - (30.07111232059474*Sin[(5*Pi)/12])/
        (2.004746440219806*Cos[(5*Pi)/12]^2 + 
          1.004746440219806*Sin[(5*Pi)/12]^2), 
      (42.47672063846061*I*Cos[(7*Pi)/12])/
        (2.004746440219806*Cos[(7*Pi)/12]^2 + 
          1.004746440219806*Sin[(7*Pi)/12]^2) \
        - (30.07111232059474*Sin[(7*Pi)/12])/
        (2.004746440219806*Cos[(7*Pi)/12]^2 + 
          1.004746440219806*Sin[(7*Pi)/12]^2), 
      (-9.99208621360889 - 
         14.11424526522084*I)*2^(1/2), 
      (42.47672063846061*I*Cos[(11*Pi)/12])/
        (2.004746440219806*Cos[(11*Pi)/12]^2 + 
          1.004746440219806*Sin[(11*Pi)/12]^2)\
         - (30.07111232059474*Sin[(11*Pi)/12])/
        (2.004746440219806*Cos[(11*Pi)/12]^2 + 
          1.004746440219806*Sin[(11*Pi)/12]^2)}
     ][CFIR[t, {23328000000., 0, 
     38879999.99999999, 0., 16200., 0., 1}, 
    Roots -> 
     {(30*I)/Cos[Pi/12], (60*I)/2^(1/2), 
      (30*I)/Cos[(5*Pi)/12], 
      (30*I)/Cos[(7*Pi)/12], (-60*I)/2^(1/2), 
      (30*I)/Cos[(11*Pi)/12]}]]
;[o]
                       8            7
0.01 CIIR[t, {2.3328 10 , 3.01154 10 , 
 
               6
     2.33268 10 , 118312., 4096.7, 90.4995, 1}]
 
                       10             7
    [CFIR[t, {2.3328 10  , 0, 3.888 10 , 0., 
 
     16200., 0., 1}]]
:[font = text; inactive; endGroup; ]
We have a Chebyshev type II filter of order 6.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 2:  Verify that the filter meets the specifications
:[font = text; inactive; ]
In order to verify that the filter meets specifications, we need to examine the frequency response of the filter.  This can be done by simply taking the continuous-time Fourier transform of the filter object.  As was done in the last example, we wil take the CTFT of a numerical approximation of the Chebyshev II filter:
:[font = input; initialization; ]
*)
define[ c2filtertransobject,
        CTFTransform[ N[c2filter], t, w ] ]
(*
:[font = input; initialization; ]
*)
define[ c2filtertrans,
        TheFunction[c2filtertransobject] ]
(*
:[font = input; startGroup; Cclosed; ]
c2filtertrans
:[font = output; inactive; output; endGroup; ]
(0.01*(-115.9110991546882*I + I*w)*
    (-42.42640687119285*I + I*w)*
    (-31.05828541230249*I + I*w)*
    (31.0582854123025*I + I*w)*
    (42.42640687119285*I + I*w)*
    (115.9110991546882*I + I*w))/
  ((4.016482960572728 - 21.17361264828599*I + 
      I*w)*(4.016482960572733 + 
       21.17361264828599*I + I*w)*
    (14.13094383968692 - 19.96055707673555*I + 
      I*w)*(14.13094383968692 + 
       19.96055707673555*I + I*w)*
    (27.10231373421923 - 10.25794363055924*I + 
      I*w)*(27.10231373421923 + 
       10.25794363055925*I + I*w))
;[o]
(0.01 (-115.911 I + I w) (-42.4264 I + I w) 
 
    (-31.0583 I + I w) (31.0583 I + I w) 
 
    (42.4264 I + I w) (115.911 I + I w)) / 
 
  ((4.01648 - 21.1736 I + I w) 
 
    (4.01648 + 21.1736 I + I w) 
 
    (14.1309 - 19.9606 I + I w) 
 
    (14.1309 + 19.9606 I + I w) 
 
    (27.1023 - 10.2579 I + I w) 
 
    (27.1023 + 10.2579 I + I w))
:[font = text; inactive; ]
Now, we can plot the magnitude and phase response:
:[font = input; startGroup; Cclosed; ]
MagPhasePlot[ c2filtertrans,
              {w, 0, 100},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.60332 0.00652 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.59082 0 1 Msboxa
[(40)] 0.40476 0.59082 0 1 Msboxa
[(60)] 0.59524 0.59082 0 1 Msboxa
[(80)] 0.78571 0.59082 0 1 Msboxa
[(100)] 0.97619 0.59082 0 1 Msboxa
[(w)] 1.00625 0.60332 -1 0 Msboxa
[(-80)] 0.01131 0.0821 1 0 Msboxa
[(-60)] 0.01131 0.21241 1 0 Msboxa
[(-40)] 0.01131 0.34271 1 0 Msboxa
[(-20)] 0.01131 0.47301 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.60332 moveto
1 0.60332 lineto
stroke
0.21429 0.59707 moveto
0.21429 0.60957 lineto
stroke
0 setgray
[(20)] 0.21429 0.59082 0 1 Mshowa
0.40476 0.59707 moveto
0.40476 0.60957 lineto
stroke
0 setgray
[(40)] 0.40476 0.59082 0 1 Mshowa
0.59524 0.59707 moveto
0.59524 0.60957 lineto
stroke
0 setgray
[(60)] 0.59524 0.59082 0 1 Mshowa
0.78571 0.59707 moveto
0.78571 0.60957 lineto
stroke
0 setgray
[(80)] 0.78571 0.59082 0 1 Mshowa
0.97619 0.59707 moveto
0.97619 0.60957 lineto
stroke
0 setgray
[(100)] 0.97619 0.59082 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.60332 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.0821 moveto
0.03006 0.0821 lineto
stroke
0 setgray
[(-80)] 0.01131 0.0821 1 0 Mshowa
0.01756 0.21241 moveto
0.03006 0.21241 lineto
stroke
0 setgray
[(-60)] 0.01131 0.21241 1 0 Mshowa
0.01756 0.34271 moveto
0.03006 0.34271 lineto
stroke
0 setgray
[(-40)] 0.01131 0.34271 1 0 Mshowa
0.01756 0.47301 moveto
0.03006 0.47301 lineto
stroke
0 setgray
[(-20)] 0.01131 0.47301 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.02505 0.60332 lineto
0.02629 0.60332 lineto
0.02753 0.60332 lineto
0.02877 0.60332 lineto
0.03001 0.60332 lineto
0.03125 0.60332 lineto
0.03249 0.60332 lineto
0.03373 0.60332 lineto
0.03497 0.60332 lineto
0.03621 0.60332 lineto
0.03745 0.60332 lineto
0.03869 0.60332 lineto
0.03993 0.60332 lineto
0.04117 0.60332 lineto
0.04241 0.60332 lineto
0.04365 0.60332 lineto
0.04489 0.60332 lineto
0.04613 0.60332 lineto
0.04737 0.60332 lineto
0.04861 0.60332 lineto
0.04985 0.60332 lineto
0.05109 0.60332 lineto
0.05233 0.60332 lineto
0.05357 0.60332 lineto
0.05481 0.60332 lineto
0.05605 0.60332 lineto
0.05729 0.60332 lineto
0.05853 0.60332 lineto
0.05977 0.60332 lineto
0.06101 0.60332 lineto
0.06225 0.60332 lineto
0.06349 0.60332 lineto
0.06473 0.60332 lineto
0.06597 0.60332 lineto
0.06721 0.60332 lineto
0.06845 0.60332 lineto
0.06969 0.60332 lineto
0.07093 0.60332 lineto
0.07217 0.60332 lineto
0.07341 0.60332 lineto
0.07465 0.60332 lineto
0.07589 0.60332 lineto
0.07713 0.60332 lineto
0.07837 0.60332 lineto
0.07961 0.60332 lineto
0.08085 0.60332 lineto
0.08333 0.60332 lineto
0.08457 0.60332 lineto
0.08581 0.60332 lineto
Mistroke
0.08705 0.60332 lineto
0.08829 0.60332 lineto
0.09077 0.60332 lineto
0.09201 0.60332 lineto
0.09325 0.60332 lineto
0.09449 0.60332 lineto
0.09573 0.60332 lineto
0.09821 0.60332 lineto
0.09945 0.60332 lineto
0.10069 0.60332 lineto
0.10193 0.60332 lineto
0.10317 0.60332 lineto
0.10565 0.60332 lineto
0.10689 0.60332 lineto
0.10813 0.60332 lineto
0.11062 0.60332 lineto
0.1131 0.60332 lineto
0.11558 0.60332 lineto
0.11806 0.60332 lineto
0.12054 0.60332 lineto
0.12302 0.60332 lineto
0.1255 0.60332 lineto
0.12798 0.60332 lineto
0.13046 0.60332 lineto
0.13294 0.60331 lineto
0.13542 0.60331 lineto
0.1379 0.60331 lineto
0.14038 0.60331 lineto
0.14286 0.60331 lineto
0.14534 0.6033 lineto
0.14782 0.6033 lineto
0.1503 0.60329 lineto
0.15278 0.60328 lineto
0.15526 0.60327 lineto
0.15774 0.60326 lineto
0.16022 0.60324 lineto
0.1627 0.60321 lineto
0.16518 0.60319 lineto
0.16766 0.60315 lineto
0.17262 0.60305 lineto
0.1751 0.60298 lineto
0.17758 0.60289 lineto
0.18006 0.60278 lineto
0.18254 0.60264 lineto
0.1875 0.60226 lineto
0.18998 0.60201 lineto
0.19246 0.6017 lineto
0.19494 0.60132 lineto
0.19742 0.60085 lineto
0.20238 0.59961 lineto
Mistroke
0.20486 0.5988 lineto
0.20734 0.59783 lineto
0.2123 0.59533 lineto
0.21726 0.59192 lineto
0.22222 0.58744 lineto
0.23214 0.57487 lineto
0.24206 0.55772 lineto
0.2619 0.51362 lineto
0.28175 0.45974 lineto
0.29167 0.42746 lineto
0.29663 0.40887 lineto
0.30159 0.38759 lineto
0.30655 0.36186 lineto
0.30903 0.34618 lineto
0.31151 0.3273 lineto
0.31399 0.30283 lineto
0.31523 0.28683 lineto
0.31647 0.26608 lineto
0.31771 0.2357 lineto
0.31895 0.17365 lineto
0.32143 0.22794 lineto
0.32267 0.25538 lineto
0.32391 0.2727 lineto
0.32515 0.28513 lineto
0.32639 0.29464 lineto
0.32887 0.30846 lineto
0.33011 0.31365 lineto
0.33135 0.31805 lineto
0.33383 0.32504 lineto
0.33631 0.33026 lineto
0.33879 0.3342 lineto
0.34127 0.33717 lineto
0.34375 0.33936 lineto
0.34499 0.34021 lineto
0.34623 0.34091 lineto
0.34747 0.34149 lineto
0.34871 0.34194 lineto
0.34995 0.34229 lineto
0.35119 0.34252 lineto
0.35243 0.34266 lineto
0.35367 0.34271 lineto
0.35491 0.34267 lineto
0.35615 0.34255 lineto
0.35739 0.34235 lineto
0.35863 0.34208 lineto
0.35987 0.34174 lineto
0.36111 0.34132 lineto
0.36607 0.33903 lineto
0.37103 0.33579 lineto
0.38095 0.3266 lineto
Mistroke
0.39087 0.31355 lineto
0.39583 0.30524 lineto
0.40079 0.29538 lineto
0.40575 0.28342 lineto
0.41071 0.2684 lineto
0.41319 0.2592 lineto
0.41567 0.24832 lineto
0.42063 0.21791 lineto
0.42188 0.20703 lineto
0.42312 0.19368 lineto
0.42436 0.17634 lineto
0.4256 0.15147 lineto
0.42684 0.10665 lineto
0.42808 0.01472 lineto
0.42932 0.125 lineto
0.43056 0.1598 lineto
0.4318 0.18101 lineto
0.43304 0.19627 lineto
0.43428 0.20817 lineto
0.43552 0.2179 lineto
0.44048 0.24502 lineto
0.44296 0.25457 lineto
0.44544 0.26256 lineto
0.4504 0.27535 lineto
0.45536 0.28529 lineto
0.46032 0.29331 lineto
0.47024 0.30557 lineto
0.48016 0.31453 lineto
0.49008 0.32133 lineto
0.5 0.3266 lineto
0.50992 0.33073 lineto
0.51984 0.33398 lineto
0.52976 0.33653 lineto
0.53968 0.33852 lineto
0.5496 0.34003 lineto
0.55952 0.34115 lineto
0.56448 0.34158 lineto
0.56944 0.34194 lineto
0.5744 0.34222 lineto
0.57937 0.34243 lineto
0.58185 0.34251 lineto
0.58433 0.34258 lineto
0.58681 0.34263 lineto
0.58929 0.34267 lineto
0.59053 0.34269 lineto
0.59177 0.3427 lineto
0.59301 0.34271 lineto
0.59425 0.34271 lineto
0.59549 0.34271 lineto
0.59673 0.34271 lineto
Mistroke
0.59797 0.3427 lineto
0.59921 0.34269 lineto
0.60045 0.34268 lineto
0.60169 0.34267 lineto
0.60417 0.34263 lineto
0.60665 0.34258 lineto
0.60913 0.34252 lineto
0.61409 0.34237 lineto
0.61905 0.34217 lineto
0.62897 0.34167 lineto
0.63889 0.34102 lineto
0.65873 0.33936 lineto
0.69841 0.33477 lineto
0.7381 0.32882 lineto
0.77778 0.32169 lineto
0.81746 0.31345 lineto
0.85714 0.30401 lineto
0.89683 0.29316 lineto
0.93651 0.2805 lineto
0.97619 0.26528 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.30749 0.00165 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.29499 0 1 Msboxa
[(40)] 0.40476 0.29499 0 1 Msboxa
[(60)] 0.59524 0.29499 0 1 Msboxa
[(80)] 0.78571 0.29499 0 1 Msboxa
[(100)] 0.97619 0.29499 0 1 Msboxa
[(w)] 1.00625 0.30749 -1 0 Msboxa
[(-150)] 0.01131 0.06066 1 0 Msboxa
[(-100)] 0.01131 0.14294 1 0 Msboxa
[(-50)] 0.01131 0.22521 1 0 Msboxa
[(50)] 0.01131 0.38976 1 0 Msboxa
[(100)] 0.01131 0.47203 1 0 Msboxa
[(150)] 0.01131 0.55431 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30749 moveto
1 0.30749 lineto
stroke
0.21429 0.30124 moveto
0.21429 0.31374 lineto
stroke
0 setgray
[(20)] 0.21429 0.29499 0 1 Mshowa
0.40476 0.30124 moveto
0.40476 0.31374 lineto
stroke
0 setgray
[(40)] 0.40476 0.29499 0 1 Mshowa
0.59524 0.30124 moveto
0.59524 0.31374 lineto
stroke
0 setgray
[(60)] 0.59524 0.29499 0 1 Mshowa
0.78571 0.30124 moveto
0.78571 0.31374 lineto
stroke
0 setgray
[(80)] 0.78571 0.29499 0 1 Mshowa
0.97619 0.30124 moveto
0.97619 0.31374 lineto
stroke
0 setgray
[(100)] 0.97619 0.29499 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30749 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06066 moveto
0.03006 0.06066 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06066 1 0 Mshowa
0.01756 0.14294 moveto
0.03006 0.14294 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14294 1 0 Mshowa
0.01756 0.22521 moveto
0.03006 0.22521 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22521 1 0 Mshowa
0.01756 0.38976 moveto
0.03006 0.38976 lineto
stroke
0 setgray
[(50)] 0.01131 0.38976 1 0 Mshowa
0.01756 0.47203 moveto
0.03006 0.47203 lineto
stroke
0 setgray
[(100)] 0.01131 0.47203 1 0 Mshowa
0.01756 0.55431 moveto
0.03006 0.55431 lineto
stroke
0 setgray
[(150)] 0.01131 0.55431 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30749 moveto
0.06349 0.25631 lineto
0.10317 0.20215 lineto
0.14286 0.14057 lineto
0.1627 0.10436 lineto
0.17262 0.08397 lineto
0.18254 0.06141 lineto
0.1875 0.04912 lineto
0.19246 0.03604 lineto
0.19494 0.02917 lineto
0.19742 0.02206 lineto
0.19866 0.01842 lineto
0.1999 0.01472 lineto
0.20114 0.60332 lineto
0.20238 0.59949 lineto
0.20362 0.5956 lineto
0.20486 0.59165 lineto
0.20734 0.58355 lineto
0.2123 0.56666 lineto
0.22222 0.53068 lineto
0.24206 0.4595 lineto
0.2619 0.40323 lineto
0.28175 0.3619 lineto
0.29167 0.34511 lineto
0.30159 0.33021 lineto
0.30655 0.32334 lineto
0.31151 0.31682 lineto
0.31399 0.31368 lineto
0.31647 0.31061 lineto
0.31771 0.30911 lineto
0.31895 0.30762 lineto
0.32019 0.60233 lineto
0.32143 0.60087 lineto
0.32267 0.59943 lineto
0.32391 0.59801 lineto
0.32639 0.59521 lineto
0.33135 0.58979 lineto
0.34127 0.57962 lineto
0.38095 0.54581 lineto
0.40079 0.53206 lineto
0.41071 0.52579 lineto
0.41567 0.52279 lineto
0.42063 0.51988 lineto
0.42312 0.51845 lineto
0.4256 0.51705 lineto
0.42684 0.51635 lineto
0.42808 0.21948 lineto
0.43056 0.21811 lineto
0.44048 0.21283 lineto
0.46032 0.20306 lineto
Mistroke
0.5 0.18619 lineto
0.53968 0.17212 lineto
0.57937 0.16018 lineto
0.61905 0.14993 lineto
0.65873 0.14102 lineto
0.69841 0.1332 lineto
0.7381 0.12627 lineto
0.77778 0.1201 lineto
0.81746 0.11457 lineto
0.85714 0.10957 lineto
0.89683 0.10504 lineto
0.93651 0.10091 lineto
0.97619 0.09713 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{Graphics[{{Line[{{0., 
        -(3.857309866213149*10^-15)}, 
       {0.1302083333333333, 
        -(1.928654933106574*10^-15)}, 
       {0.2604166666666667, 0.}, 
       {0.390625, -(3.857309866213149*10^
           -15)}, {0.5208333333333334, 
        -(1.928654933106574*10^-15)}, 
       {0.6510416666666667, 
        -(5.785964799319723*10^-15)}, 
       {0.78125, -(2.892982399659862*10^
           -15)}, {0.911458333333333, 0.}, 
       {1.041666666666667, 
        -(9.64327466553287*10^-16)}, 
       {1.171875, -(1.928654933106574*10^
           -15)}, {1.302083333333333, 
        -(3.857309866213149*10^-15)}, 
       {1.432291666666667, 
        -(1.060760213208616*10^-14)}, 
       {1.5625, -(1.928654933106576*10^-14)}, 
       {1.692708333333333, 
        -(5.014502826077107*10^-14)}, 
       {1.822916666666667, 
        -(1.137906410532886*10^-13)}, 
       {1.953125, -(2.507251413038582*10^
           -13)}, {2.083333333333333, 
        -(5.458093460691774*10^-13)}, 
       {2.213541666666667, 
        -(1.126334480934312*10^-12)}, 
       {2.34375, -(2.235311067470807*10^
           -12)}, {2.473958333333333, 
        -(4.288364243763526*10^-12)}, 
       {2.604166666666667, 
        -(7.942201014536502*10^-12)}, 
       {2.734375, 
        -(1.42971190191308*10^-11)}, 
       {2.864583333333333, 
        -(2.50406913240253*10^-11)}, 
       {2.994791666666667, 
        -(4.280456758547277*10^-11)}, 
       {3.125, -(7.150873895508679*10^-11)}, 
       {3.255208333333333, 
        -(1.170442819262273*10^-10)}, 
       {3.385416666666667, 
        -(1.87933922648737*10^-10)}, 
       {3.515625, -(2.964863369067345*10^
           -10)}, {3.645833333333333, 
        -(4.601500658823537*10^-10)}, 
       {3.776041666666667, 
        -(7.033900974071136*10^-10)}, 
       {3.90625, -(1.060082291064318*10^-9)}, 
       {4.036458333333334, 
        -(1.576672514975324*10^-9)}, 
       {4.166666666666667, 
        -(2.316161246902625*10^-9)}, 
       {4.296875, 
        -(3.363220295808768*10^-9)}, 
       {4.427083333333334, 
        -(4.830654760249458*10^-9)}, 
       {4.557291666666667, 
        -(6.867486021270647*10^-9)}, 
       {4.6875, -(9.66908007391962*10^-9)}, 
       {4.817708333333334, 
        -(1.348969439214137*10^-8)}, 
       {4.947916666666667, 
        -(1.865790138267649*10^-8)}, 
       {5.078125, 
        -(2.559559238712559*10^-8)}, 
       {5.208333333333334, 
        -(3.484115818674059*10^-8)}, 
       {5.338541666666667, 
        -(4.707759336402724*10^-8)}, 
       {5.46875, -(6.31666103543597*10^-8)}, 
       {5.598958333333334, 
        -(8.41896224041209*10^-8)}, 
       {5.729166666666667, 
        -(1.114970428920489*10^-7)}, 
       {5.859375, 
        -(1.467671604272326*10^-7)}, 
       {5.989583333333334, 
        -(1.920762724778845*10^-7)}, 
       {6.25, -(3.236220154246866*10^-7)}, 
       {6.380208333333334, 
        -(4.168301080427595*10^-7)}, 
       {6.510416666666667, 
        -(5.342733280635152*10^-7)}, 
       {6.640625, 
        -(6.816124585059678*10^-7)}, 
       {6.770833333333334, 
        -(8.65689988364077*10^-7)}, 
       {7.03125, -0.000001378690455689865}, 
       {7.161458333333334, 
        -0.000001729366161125878}, 
       {7.291666666666667, 
        -0.000002160926294892158}, 
       {7.421875, -0.000002690215244016872}, 
       {7.552083333333334, 
        -0.00000333723106705517}, 
       {7.8125, -0.000005083456163384389}, 
       {7.942708333333334, 
        -0.000006243596328274758}, 
       {8.07291666666667, 
        -0.000007644822924213726}, 
       {8.203125, -0.00000933258735998759}, 
       {8.33333333333333, 
        -0.00001136008928990739}, 
       {8.59375, -0.00001669316107339194}, 
       {8.72395833333333, 
        -0.00002015544432105007}, 
       {8.85416666666667, 
        -0.00002427418743450484}, 
       {9.11458333333333, 
        -0.00003495268286855273}, 
       {9.375, -0.00004986583550926729}, 
       {9.63541666666667, 
        -0.00007052591742110905}, 
       {9.89583333333333, 
        -0.0000989316366082281}, 
       {10.15625, -0.0001377093989798928}, 
       {10.41666666666667, 
        -0.0001902918238701057}, 
       {10.67708333333333, 
        -0.0002611425313573487}, 
       {10.9375, -0.0003560382557932838}, 
       {11.19791666666667, 
        -0.0004824218127512765}, 
       {11.45833333333333, 
        -0.0006498424450273277}, 
       {11.71875, -0.000870503704639921}, 
       {11.97916666666667, 
        -0.001159943417462518}, 
       {12.23958333333333, 
        -0.001537875573512314}, 
       {12.5, -0.002029230361736641}, 
       {12.76041666666667, 
        -0.0026654362201884}, 
       {13.02083333333333, 
        -0.003485996924134967}, 
       {13.28125, -0.004540427628766896}, 
       {13.54166666666667, 
        -0.005890626675849471}, 
       {13.80208333333333, 
        -0.007613775114651525}, 
       {14.0625, -0.00980587349081121}, 
       {14.32291666666667, 
        -0.01258604564917454}, 
       {14.58333333333333, 
        -0.01610176203441812}, 
       {14.84375, -0.0205351599188475}, 
       {15.10416666666667, 
        -0.02611066431603842}, 
       {15.625, -0.04185382391855308}, 
       {15.88541666666667, 
        -0.05277331807951622}, 
       {16.14583333333334, 
        -0.0663668943045799}, 
       {16.40625, -0.083247376639022}, 
       {16.66666666666667, 
        -0.1041567745269881}, 
       {17.1875, -0.1618196509068568}, 
       {17.44791666666667, 
        -0.2009270005231122}, 
       {17.70833333333334, 
        -0.2488288823044504}, 
       {17.96875, -0.3073082006718759}, 
       {18.22916666666667, 
        -0.3784399527039126}, 
       {18.75, -0.5685290505195445}, 
       {19.01041666666667, 
        -0.6932136484845873}, 
       {19.27083333333334, 
        -0.84196498492279}, 
       {19.79166666666667, 
        -1.225865911358984}, 
       {20.3125, -1.749031109821375}, 
       {20.83333333333334, 
        -2.437341390876186}, 
       {21.875, -4.366122362445013}, 
       {22.91666666666667, 
        -6.998816362456407}, 
       {25., -13.76694588529614}, 
       {27.08333333333334, 
        -22.0381688169961}, 
       {28.125, -26.99265935871237}, 
       {28.64583333333334, 
        -29.84523131423726}, 
       {29.16666666666667, 
        -33.11093245973633}, 
       {29.6875, -37.06085234056306}, 
       {29.94791666666667, 
        -39.46737974960663}, 
       {30.20833333333334, 
        -42.36566356865023}, 
       {30.46875, -46.12072577310266}, 
       {30.59895833333334, 
        -48.57743822061487}, 
       {30.72916666666667, 
        -51.76199935574947}, 
       {30.859375, -56.42532003976928}, 
       {30.98958333333334, 
        -65.94876762835254}, 
       {31.25, -57.61540526025519}, 
       {31.38020833333334, 
        -53.40418393813152}, 
       {31.51041666666667, 
        -50.74505113615459}, 
       {31.640625, -48.83837668482655}, 
       {31.77083333333334, 
        -47.37766038907484}, 
       {32.03125, -45.25766301581836}, 
       {32.16145833333334, 
        -44.46043300886618}, 
       {32.29166666666667, 
        -43.78569372566317}, 
       {32.55208333333334, 
        -42.71254983678879}, 
       {32.8125, -41.91054485717704}, 
       {33.07291666666667, 
        -41.30554798478449}, 
       {33.33333333333334, 
        -40.85076537323725}, 
       {33.59375, -40.5148392007579}, 
       {33.72395833333334, 
        -40.38431795541069}, 
       {33.85416666666667, 
        -40.27580065740564}, 
       {33.984375, -40.18746299505105}, 
       {34.11458333333334, 
        -40.11773032044859}, 
       {34.24479166666667, 
        -40.06523658661291}, 
       {34.375, -40.02879156285178}, 
       {34.50520833333334, 
        -40.00735441877837}, 
       {34.63541666666667, 
        -40.00001226396372}, 
       {34.765625, -40.00596258474432}, 
       {34.89583333333334, 
        -40.02449877629175}, 
       {35.02604166666667, 
        -40.05499815617228}, 
       {35.15625, -40.09691198520617}, 
       {35.28645833333334, 
        -40.14975712616821}, 
       {35.41666666666667, 
        -40.21310905029296}, 
       {35.9375, -40.56484139318412}, 
       {36.45833333333334, 
        -41.06267640838374}, 
       {37.5, -42.47323721939317}, 
       {38.54166666666667, 
        -44.47642554493405}, 
       {39.0625, -45.75085286237447}, 
       {39.58333333333334, 
        -47.26496294422537}, 
       {40.10416666666667, 
        -49.10036251752126}, 
       {40.625, -51.40542537673946}, 
       {40.88541666666667, 
        -52.81835134572784}, 
       {41.14583333333334, 
        -54.48726180240607}, 
       {41.66666666666667, 
        -59.15588737292868}, 
       {41.796875, -60.82457345450347}, 
       {41.92708333333334, 
        -62.87387835164995}, 
       {42.05729166666667, 
        -65.5356972058627}, 
       {42.1875, -69.35257908042546}, 
       {42.31770833333334, 
        -76.23166772677831}, 
       {42.44791666666667, -90.343155547748}, 
       {42.578125, -73.41559704931893}, 
       {42.70833333333334, 
        -68.07479865291265}, 
       {42.83854166666667, 
        -64.81858037014453}, 
       {42.96875, -62.47639437582891}, 
       {43.09895833333334, 
        -60.6505184245806}, 
       {43.22916666666667, 
        -59.15708910805141}, 
       {43.75, -54.9946435442518}, 
       {44.01041666666667, 
        -53.52830826981182}, 
       {44.27083333333334, 
        -52.30197894366672}, 
       {44.79166666666667, 
        -50.33867734347759}, 
       {45.3125, -48.81382951399442}, 
       {45.83333333333334, 
        -47.58255678932989}, 
       {46.875, -45.70036004270411}, 
       {47.91666666666667, 
        -44.32504072733777}, 
       {48.95833333333334, 
        -43.28180420700807}, 
       {50., -42.47323721939316}, 
       {51.04166666666667, 
        -41.83928639698397}, 
       {52.08333333333334, 
        -41.34022731473432}, 
       {53.125, -40.94838256980711}, 
       {54.16666666666667, 
        -40.64368688074899}, 
       {55.20833333333334, 
        -40.41113169321743}, 
       {56.25, -40.23920526903265}, 
       {56.77083333333334, 
        -40.17308354237046}, 
       {57.29166666666667, 
        -40.11889494374006}, 
       {57.8125, -40.07579484430359}, 
       {58.33333333333334, 
        -40.04302387941983}, 
       {58.59375, -40.03029516830634}, 
       {58.85416666666667, 
        -40.01989725330409}, 
       {59.11458333333334, 
        -40.01175470173323}, 
       {59.375, -40.00579568531359}, 
       {59.50520833333334, 
        -40.00361348923349}, 
       {59.63541666666667, 
        -40.00195176697846}, 
       {59.765625, -40.00080246139972}, 
       {59.89583333333334, 
        -40.00015770341079}, 
       {60.02604166666667, 
        -40.00000980658147}, 
       {60.15625, -40.00035126192729}, 
       {60.28645833333334, 
        -40.00117473288632}, 
       {60.41666666666667, 
        -40.00247305047505}, 
       {60.54687500000001, 
        -40.00423920861583}, 
       {60.67708333333334, 
        -40.00646635962858}, 
       {60.93750000000001, 
        -40.0122770155837}, 
       {61.19791666666667, 
        -40.01985324324299}, 
       {61.45833333333334, 
        -40.02914553857275}, 
       {61.97916666666667, 
        -40.05269096460161}, 
       {62.50000000000001, 
        -40.08255834791888}, 
       {63.54166666666667, 
        -40.15998376696571}, 
       {64.58333333333334, 
        -40.25912317071062}, 
       {66.66666666666667, 
        -40.51505693595742}, 
       {70.83333333333334, 
        -41.21923469700144}, 
       {75., -42.13267575363048}, 
       {79.16666666666667, 
        -43.22583464559916}, 
       {83.3333333333333, 
        -44.49127818967363}, 
       {87.5, -45.94035466956708}, 
       {91.6666666666667, 
        -47.60531189755486}, 
       {95.8333333333333, 
        -49.54837745128448}, 
       {100., -51.88488252267931}}]}}, 
   DisplayFunction :> $DisplayFunction, 
   PlotRange -> All, 
   PlotLabel -> "Magnitude Response (dB)", 
   PlotRange -> {-80, 20}, 
   Ticks -> Automatic, 
   AxesLabel -> {"w", " "}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, 
    AxesLabel -> None, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[{{Line[{{0., 0.}, 
       {4.166666666666667, 
        -31.10013961908818}, 
       {8.33333333333333, 
        -64.01794909443842}, 
       {12.5, -101.4378962743578}, 
       {14.58333333333333, 
        -123.4453023703025}, 
       {15.625, -135.8390520024228}, 
       {16.66666666666667, 
        -149.5453153737451}, 
       {17.1875, -157.0136352726814}, 
       {17.70833333333334, 
        -164.9668891561482}, 
       {17.96875, -169.1429839224151}, 
       {18.22916666666667, 
        -173.4605886792625}, 
       {18.359375, -175.6741439432352}, 
       {18.48958333333334, 
        -177.9249327291625}, 
       {18.61979166666667, 179.786630428355}, 
       {18.75, 177.4602603340718}, 
       {18.88020833333334, 
        175.0958206575407}, 
       {19.01041666666667, 
        172.6933441654525}, 
       {19.27083333333334, 
        167.7753805869766}, 
       {19.79166666666667, 
        157.5079403584372}, 
       {20.83333333333334, 
        135.6388664860104}, 
       {22.91666666666667, 92.3819324779931}, 
       {25., 58.18560026469519}, 
       {27.08333333333334, 33.0676371000457}, 
       {28.125, 22.86673523201974}, 
       {29.16666666666667, 
        13.80857943687155}, 
       {29.6875, 9.63699511483768}, 
       {30.20833333333334, 
        5.673788408840873}, 
       {30.46875, 3.76441321197195}, 
       {30.72916666666667, 
        1.900363236407875}, 
       {30.859375, 0.984723634998861}, 
       {30.98958333333334, 
        0.07969798902329407}, 
       {31.11979166666667, 
        179.1850637708499}, 
       {31.25, 178.3006058036185}, 
       {31.38020833333334, 
        177.4261159400447}, 
       {31.51041666666667, 
        176.5613927568264}, 
       {31.77083333333334, 
        174.8604726282344}, 
       {32.29166666666667, 
        171.5676511148404}, 
       {33.33333333333334, 
        165.3817287020797}, 
       {37.5, 144.8377975037915}, 
       {39.58333333333334, 
        136.4788883622151}, 
       {40.625, 132.6700893546752}, 
       {41.14583333333334, 
        130.8483476577311}, 
       {41.66666666666667, 
        129.0783937076949}, 
       {41.92708333333334, 
        128.2121151316796}, 
       {42.1875, 127.3579351524874}, 
       {42.31770833333334, 
        126.9352991237141}, 
       {42.44791666666667, 
        -53.48441084783852}, 
       {42.70833333333334, 
        -54.31517939888383}, 
       {43.75, -57.52734446881868}, 
       {45.83333333333334, 
        -63.46500165007905}, 
       {50., -73.71671247580997}, 
       {54.16666666666667, 
        -82.2682806568687}, 
       {58.33333333333334, 
        -89.5193458915979}, 
       {62.50000000000001, 
        -95.7510328125238}, 
       {66.66666666666667, -101.16754411703}, 
       {70.83333333333334, 
        -105.9211620301364}, 
       {75., -110.1279785160226}, 
       {79.16666666666667, 
        -113.878169644673}, 
       {83.3333333333333, 
        -117.2429212677713}, 
       {87.5, -120.2792250067543}, 
       {91.6666666666667, 
        -123.0332778311077}, 
       {95.8333333333333, 
        -125.5429414174159}, 
       {100., -127.8395535576933}}]}}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> 
     (Display[$Display, #1] & ), 
    PlotColor -> Automatic, 
    Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, 
    Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; ]
Graphically, the magnitude response seems to meet the passband and stopband specifications, and the phase response shows that the cutoff frequency is about 20 rad/sec. We will now check the magnitude response at the end of the passband and the beginning of the stopband just to make sure:
:[font = input; startGroup; ]
20 Log[10, Abs[c2filtertrans /. w -> 20]]
:[font = output; inactive; output; endGroup; ]
-1.416845759315674
;[o]
-1.41685
:[font = input; startGroup; ]
20 Log[10, Abs[c2filtertrans /. w -> 30]]
:[font = output; inactive; output; endGroup; ]
-39.99999999999995
;[o]
-40.
:[font = text; inactive; ]
Here, the error in the passband is no greater than 1.42 dB (which is the specification) and the attenuation of the stopband is greater than 40 dB (which is the specification).  Therefore, the following filter meets the specifications:
:[font = special3; inactive; endGroup; endGroup; ]
0.01
  CIIR[t, {233280000, 30115374, 2332678.1,
          118311.57, 4096.698, 90.499481, 1}] [
    CFIR[ t, {23328000000, 0, 38880000, 0,
              16200, 0, 1} ] ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Elliptic Example (Using Object AnalogFilter)
:[font = text; inactive; ]
Problem:  Design a lowpass elliptic analog filter that has a -2 dB or better cutoff at 20 rad/sec and at least 40 db of attenuation at 30 rad/sec.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 1:  Determine the order of the filter
:[font = text; inactive; ]
First, we need to determine the order of the elliptic filter necessary.  At the cutoff frequency, we want a magnitude response of -2 dB or better:
:[font = input; initialization; startGroup; ]
*)
edelta1 = 1 - N[ 10^(-2/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.2056717652757185
;[o]
0.205672
:[font = text; inactive; ]
In the stopband, we want an attenuation of at least 40 db:
:[font = input; initialization; startGroup; ]
*)
edelta2 = N[ 10^(-40/20) ]
(*
:[font = output; inactive; output; endGroup; ]
0.01
;[o]
0.01
:[font = text; inactive; ]
From the values of delta1 and delta2, we can determine the other filter parameters:
:[font = input; initialization; startGroup; ]
*)
FilterParameters[ edelta1, edelta2,
   eepsilon, eA, Eripple, ATT, enu ]
(*
:[font = output; inactive; output; endGroup; ]
{0.2056717652757185, 0.01, 0.7647831015792084, 
  100., 2.466913365931468, 4.99999999999999, 
  0.00764821343602463}
;[o]
{0.205672, 0.01, 0.764783, 100., 2.46691, 40., 
 
  0.00764821}
:[font = text; inactive; ]
The parameters Eripple and ATT are useful when using filter design charts and are calculated here for completeness (note that the attenuation ATT should be 40 dB in this case).  The values of delta1 and delta2 determine the values of the other parameters.  The value of nu and the transition width (2/3 = 20 rad/sec divided by 30 rad/sec) determine the filter order:
:[font = input; startGroup; ]
FilterOrder[ Elliptic, 2/3, enu ]
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = text; inactive; endGroup; ]
Now, we know that we need an elliptic filter of order 4 (for the same specifications, we needed a Chebyshev filter of order of 6).
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 2:  Find the coefficients of the filter
:[font = text; inactive; ]
We now know that we need a fourth order elliptic filter to meet specifications.  So, now we can ask Mathematica to create a fourth-order elliptic filter with a transition region of 20 rad/sec to 30 rad/sec (a cutoff frequency of 20 rad/sec and a transition ration of 2/3):
:[font = input; initialization; ]
*)
define[ efilter,
        AnalogFilter[Elliptic, t, 4,
                     eepsilon, eA, 2/3, 20] ]
(*
:[font = input; startGroup; ]
efilter
:[font = output; inactive; output; endGroup; endGroup; ]
0.007033143007862013*
  CIIR[t, {43461.29998099303, 
     4532.068401061019, 529.812583270024, 
     14.1568140287867, 1}, 
    Roots -> 
     {-5.474525743379237 + 9.1795634894521*I, 
      -5.474525743379237 - 9.1795634894521*I, 
      -1.603881271014111 + 
       19.43922253941108*I, 
      -1.603881271014111 - 19.43922253941108*I}
     ][CFIR[t, {4908550.509229452, 0., 
     5853.94501025495, 0, 1}, 
    Roots -> 
     {-69.56812348597884*I, 
      69.56812348597884*I, 
      -31.84683979446859*I, 
      31.84683979446859*I}]]
;[o]
0.00703314 CIIR[t, 
 
    {43461.3, 4532.07, 529.813, 14.1568, 1}]
 
                        6
    [CFIR[t, {4.90855 10 , 0., 5853.95, 0, 1}]]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 3:  Verify that the filter meets the specifications
:[font = text; inactive; ]
In order to verify that the filter meets specifications, we need to examine the frequency response of the filter.  This can be done by simply taking the continuous-time Fourier transform of the filter object:
:[font = input; initialization; ]
*)
define[ efiltertransobject,
        CTFTransform[ efilter, t, w ] ]
(*
:[font = input; initialization; ]
*)
define[ efiltertrans,
        TheFunction[efiltertransobject] ]
(*
:[font = input; startGroup; Cclosed; ]
efiltertrans
:[font = output; inactive; output; endGroup; ]
(0.007033143007862013*
    (-69.56812348597884*I + I*w)*
    (-31.84683979446859*I + I*w)*
    (31.84683979446859*I + I*w)*
    (69.56812348597884*I + I*w))/
  ((1.603881271014111 - 19.43922253941108*I + 
      I*w)*(1.603881271014111 + 
       19.43922253941108*I + I*w)*
    (5.474525743379237 - 9.1795634894521*I + 
      I*w)*(5.474525743379237 + 
       9.1795634894521*I + I*w))
;[o]
(0.00703314 (-69.5681 I + I w) 
 
    (-31.8468 I + I w) (31.8468 I + I w) 
 
    (69.5681 I + I w)) / 
 
  ((1.60388 - 19.4392 I + I w) 
 
    (1.60388 + 19.4392 I + I w) 
 
    (5.47453 - 9.17956 I + I w) 
 
    (5.47453 + 9.17956 I + I w))
:[font = text; inactive; ]
Now, we can plot the magnitude and phase response:
:[font = input; startGroup; Cclosed; ]
MagPhasePlot[ efiltertrans,
              {w, 0, 100},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.60332 0.00567 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.59082 0 1 Msboxa
[(40)] 0.40476 0.59082 0 1 Msboxa
[(60)] 0.59524 0.59082 0 1 Msboxa
[(80)] 0.78571 0.59082 0 1 Msboxa
[(100)] 0.97619 0.59082 0 1 Msboxa
[(w)] 1.00625 0.60332 -1 0 Msboxa
[(-100)] 0.01131 0.03622 1 0 Msboxa
[(-80)] 0.01131 0.14964 1 0 Msboxa
[(-60)] 0.01131 0.26306 1 0 Msboxa
[(-40)] 0.01131 0.37648 1 0 Msboxa
[(-20)] 0.01131 0.4899 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.60332 moveto
1 0.60332 lineto
stroke
0.21429 0.59707 moveto
0.21429 0.60957 lineto
stroke
0 setgray
[(20)] 0.21429 0.59082 0 1 Mshowa
0.40476 0.59707 moveto
0.40476 0.60957 lineto
stroke
0 setgray
[(40)] 0.40476 0.59082 0 1 Mshowa
0.59524 0.59707 moveto
0.59524 0.60957 lineto
stroke
0 setgray
[(60)] 0.59524 0.59082 0 1 Mshowa
0.78571 0.59707 moveto
0.78571 0.60957 lineto
stroke
0 setgray
[(80)] 0.78571 0.59082 0 1 Mshowa
0.97619 0.59707 moveto
0.97619 0.60957 lineto
stroke
0 setgray
[(100)] 0.97619 0.59082 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.60332 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.03622 moveto
0.03006 0.03622 lineto
stroke
0 setgray
[(-100)] 0.01131 0.03622 1 0 Mshowa
0.01756 0.14964 moveto
0.03006 0.14964 lineto
stroke
0 setgray
[(-80)] 0.01131 0.14964 1 0 Mshowa
0.01756 0.26306 moveto
0.03006 0.26306 lineto
stroke
0 setgray
[(-60)] 0.01131 0.26306 1 0 Mshowa
0.01756 0.37648 moveto
0.03006 0.37648 lineto
stroke
0 setgray
[(-40)] 0.01131 0.37648 1 0 Mshowa
0.01756 0.4899 moveto
0.03006 0.4899 lineto
stroke
0 setgray
[(-20)] 0.01131 0.4899 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.59198 moveto
0.02505 0.59198 lineto
0.02629 0.592 lineto
0.02753 0.59202 lineto
0.02877 0.59205 lineto
0.03125 0.59214 lineto
0.03373 0.59227 lineto
0.03869 0.59264 lineto
0.04365 0.59315 lineto
0.05357 0.59456 lineto
0.06349 0.5964 lineto
0.08333 0.60064 lineto
0.08829 0.60158 lineto
0.09325 0.60237 lineto
0.09573 0.60269 lineto
0.09821 0.60295 lineto
0.09945 0.60306 lineto
0.10069 0.60315 lineto
0.10193 0.60322 lineto
0.10317 0.60327 lineto
0.10441 0.6033 lineto
0.10565 0.60332 lineto
0.10689 0.60331 lineto
0.10813 0.60329 lineto
0.10937 0.60324 lineto
0.11062 0.60318 lineto
0.1131 0.60299 lineto
0.11558 0.60272 lineto
0.11806 0.60237 lineto
0.12302 0.60147 lineto
0.13294 0.59905 lineto
0.14286 0.59627 lineto
0.14782 0.59496 lineto
0.15278 0.59379 lineto
0.15774 0.59286 lineto
0.16022 0.5925 lineto
0.16146 0.59235 lineto
0.1627 0.59223 lineto
0.16394 0.59213 lineto
0.16518 0.59205 lineto
0.16642 0.592 lineto
0.16766 0.59198 lineto
0.1689 0.59199 lineto
0.17014 0.59202 lineto
0.17138 0.59209 lineto
0.17262 0.59219 lineto
0.17386 0.59233 lineto
0.1751 0.5925 lineto
0.17758 0.59295 lineto
0.18006 0.59355 lineto
Mistroke
0.18254 0.59432 lineto
0.1875 0.59633 lineto
0.19246 0.59889 lineto
0.19494 0.60027 lineto
0.19742 0.60158 lineto
0.19866 0.60216 lineto
0.1999 0.60266 lineto
0.20114 0.60304 lineto
0.20238 0.60327 lineto
0.20362 0.60331 lineto
0.20486 0.60312 lineto
0.2061 0.60267 lineto
0.20734 0.60193 lineto
0.20982 0.59949 lineto
0.21106 0.59778 lineto
0.2123 0.59577 lineto
0.22222 0.57245 lineto
0.2619 0.47726 lineto
0.28175 0.4345 lineto
0.29167 0.41144 lineto
0.30159 0.38513 lineto
0.30655 0.36967 lineto
0.31151 0.35139 lineto
0.31399 0.34058 lineto
0.31647 0.328 lineto
0.31895 0.31271 lineto
0.32143 0.29268 lineto
0.32267 0.27947 lineto
0.32391 0.26227 lineto
0.32515 0.23709 lineto
0.32639 0.18686 lineto
0.32887 0.2284 lineto
0.33011 0.25366 lineto
0.33135 0.26968 lineto
0.33259 0.28129 lineto
0.33383 0.29032 lineto
0.33631 0.30375 lineto
0.33879 0.31349 lineto
0.34127 0.32098 lineto
0.34375 0.32696 lineto
0.34623 0.33184 lineto
0.35119 0.33935 lineto
0.35615 0.34479 lineto
0.36111 0.34884 lineto
0.36607 0.35189 lineto
0.37103 0.3542 lineto
0.37599 0.35593 lineto
0.38095 0.3572 lineto
0.38343 0.35769 lineto
0.38591 0.3581 lineto
Mistroke
0.38839 0.35843 lineto
0.39087 0.35869 lineto
0.39211 0.3588 lineto
0.39335 0.35889 lineto
0.39459 0.35896 lineto
0.39583 0.35902 lineto
0.39707 0.35907 lineto
0.39831 0.35911 lineto
0.39955 0.35913 lineto
0.40079 0.35914 lineto
0.40203 0.35914 lineto
0.40327 0.35913 lineto
0.40451 0.3591 lineto
0.40575 0.35907 lineto
0.40823 0.35897 lineto
0.41071 0.35884 lineto
0.41319 0.35866 lineto
0.41567 0.35846 lineto
0.42063 0.35795 lineto
0.43056 0.35662 lineto
0.44048 0.35492 lineto
0.46032 0.35063 lineto
0.5 0.33928 lineto
0.53968 0.32461 lineto
0.57937 0.30576 lineto
0.59921 0.29393 lineto
0.61905 0.27947 lineto
0.62897 0.27074 lineto
0.63889 0.26052 lineto
0.65873 0.23212 lineto
0.66369 0.22194 lineto
0.66865 0.20935 lineto
0.67113 0.2017 lineto
0.67361 0.19273 lineto
0.67857 0.16803 lineto
0.67981 0.15939 lineto
0.68105 0.14894 lineto
0.68229 0.13574 lineto
0.68353 0.11774 lineto
0.68477 0.08925 lineto
0.68601 0.01472 lineto
0.68725 0.06035 lineto
0.68849 0.10327 lineto
0.68973 0.12577 lineto
0.69097 0.1411 lineto
0.69345 0.1621 lineto
0.69469 0.16993 lineto
0.69593 0.17666 lineto
0.69841 0.1878 lineto
0.70337 0.20436 lineto
Mistroke
0.70833 0.21654 lineto
0.71825 0.23406 lineto
0.72817 0.24657 lineto
0.7381 0.25623 lineto
0.75794 0.27059 lineto
0.77778 0.28104 lineto
0.79762 0.28914 lineto
0.81746 0.29568 lineto
0.85714 0.3057 lineto
0.89683 0.31311 lineto
0.93651 0.31885 lineto
0.97619 0.32343 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 58; pictureWidth = 322; pictureHeight = 199; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.30947 0.00165 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.29697 0 1 Msboxa
[(40)] 0.40476 0.29697 0 1 Msboxa
[(60)] 0.59524 0.29697 0 1 Msboxa
[(80)] 0.78571 0.29697 0 1 Msboxa
[(100)] 0.97619 0.29697 0 1 Msboxa
[(w)] 1.00625 0.30947 -1 0 Msboxa
[(-150)] 0.01131 0.06224 1 0 Msboxa
[(-100)] 0.01131 0.14465 1 0 Msboxa
[(-50)] 0.01131 0.22706 1 0 Msboxa
[(50)] 0.01131 0.39188 1 0 Msboxa
[(100)] 0.01131 0.47429 1 0 Msboxa
[(150)] 0.01131 0.55669 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30947 moveto
1 0.30947 lineto
stroke
0.21429 0.30322 moveto
0.21429 0.31572 lineto
stroke
0 setgray
[(20)] 0.21429 0.29697 0 1 Mshowa
0.40476 0.30322 moveto
0.40476 0.31572 lineto
stroke
0 setgray
[(40)] 0.40476 0.29697 0 1 Mshowa
0.59524 0.30322 moveto
0.59524 0.31572 lineto
stroke
0 setgray
[(60)] 0.59524 0.29697 0 1 Mshowa
0.78571 0.30322 moveto
0.78571 0.31572 lineto
stroke
0 setgray
[(80)] 0.78571 0.29697 0 1 Mshowa
0.97619 0.30322 moveto
0.97619 0.31572 lineto
stroke
0 setgray
[(100)] 0.97619 0.29697 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30947 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06224 moveto
0.03006 0.06224 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06224 1 0 Mshowa
0.01756 0.14465 moveto
0.03006 0.14465 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14465 1 0 Mshowa
0.01756 0.22706 moveto
0.03006 0.22706 lineto
stroke
0 setgray
[(-50)] 0.01131 0.22706 1 0 Mshowa
0.01756 0.39188 moveto
0.03006 0.39188 lineto
stroke
0 setgray
[(50)] 0.01131 0.39188 1 0 Mshowa
0.01756 0.47429 moveto
0.03006 0.47429 lineto
stroke
0 setgray
[(100)] 0.01131 0.47429 1 0 Mshowa
0.01756 0.55669 moveto
0.03006 0.55669 lineto
stroke
0 setgray
[(150)] 0.01131 0.55669 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30947 moveto
0.04365 0.28846 lineto
0.06349 0.26443 lineto
0.10317 0.19613 lineto
0.14286 0.11629 lineto
0.1627 0.08328 lineto
0.17262 0.06653 lineto
0.18254 0.0468 lineto
0.1875 0.03444 lineto
0.18998 0.02725 lineto
0.19122 0.02332 lineto
0.19246 0.01916 lineto
0.1937 0.01472 lineto
0.19494 0.60332 lineto
0.19618 0.59826 lineto
0.19742 0.59285 lineto
0.20238 0.56744 lineto
0.2123 0.50385 lineto
0.21726 0.47502 lineto
0.22222 0.4525 lineto
0.22718 0.43568 lineto
0.23214 0.42305 lineto
0.2371 0.41332 lineto
0.24206 0.40562 lineto
0.25198 0.39412 lineto
0.2619 0.38585 lineto
0.27183 0.37951 lineto
0.28175 0.37443 lineto
0.30159 0.36665 lineto
0.31151 0.36357 lineto
0.32143 0.36087 lineto
0.32391 0.36025 lineto
0.32515 0.35994 lineto
0.32639 0.35964 lineto
0.32763 0.06267 lineto
0.32887 0.06238 lineto
0.33011 0.06209 lineto
0.33135 0.06181 lineto
0.34127 0.05966 lineto
0.38095 0.05288 lineto
0.42063 0.04797 lineto
0.46032 0.04422 lineto
0.5 0.04123 lineto
0.53968 0.03879 lineto
0.57937 0.03675 lineto
0.61905 0.03502 lineto
0.65873 0.03353 lineto
0.66865 0.03319 lineto
0.67857 0.03286 lineto
0.68105 0.03278 lineto
Mistroke
0.68353 0.0327 lineto
0.68477 0.03266 lineto
0.68601 0.03262 lineto
0.68725 0.32925 lineto
0.68849 0.32921 lineto
0.69841 0.32891 lineto
0.7381 0.32777 lineto
0.77778 0.32676 lineto
0.81746 0.32585 lineto
0.85714 0.32504 lineto
0.89683 0.32431 lineto
0.93651 0.32364 lineto
0.97619 0.32303 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{Graphics[{{Line[{{0., -2.}, 
       {0.1302083333333333, 
        -1.999181139038646}, 
       {0.2604166666666667, 
        -1.996725103297035}, 
       {0.390625, -1.992633537523434}, 
       {0.5208333333333334, 
        -1.98690919404319}, 
       {0.78125, -1.970578827742227}, 
       {1.041666666666667, 
        -1.947778975448649}, 
       {1.5625, -1.883049668442111}, 
       {2.083333333333333, 
        -1.793501395618865}, 
       {3.125, -1.545223810269009}, 
       {4.166666666666667, 
        -1.219450029005986}, 
       {6.25, -0.4721180715978562}, 
       {6.770833333333334, 
        -0.3060168000038118}, 
       {7.291666666666667, 
        -0.1668299673043862}, 
       {7.552083333333334, 
        -0.110510576235548}, 
       {7.8125, -0.06465730694186828}, 
       {7.942708333333334, 
        -0.04600301064535032}, 
       {8.07291666666667, 
        -0.03036599026335631}, 
       {8.203125, -0.01786056809620088}, 
       {8.33333333333333, 
        -0.008589578946108}, 
       {8.46354166666667, 
        -0.002643173430532137}, 
       {8.59375, -0.0000977037449513586}, 
       {8.72395833333333, 
        -0.001014713945612857}, 
       {8.85416666666667, 
        -0.005440055444031343}, 
       {8.984375, -0.0134031462946838}, 
       {9.11458333333333, 
        -0.02491639006064498}, 
       {9.375, -0.05855560354965913}, 
       {9.63541666666667, 
        -0.1061056270738562}, 
       {9.89583333333333, 
        -0.1670349346591159}, 
       {10.41666666666667, 
        -0.3255949615784722}, 
       {11.45833333333333, 
        -0.7536465272960903}, 
       {12.5, -1.242720760981101}, 
       {13.02083333333333, 
        -1.474826878040066}, 
       {13.54166666666667, 
        -1.680070550692043}, 
       {14.0625, -1.844949291625429}, 
       {14.32291666666667, 
        -1.908070711378589}, 
       {14.453125, -1.934066375166716}, 
       {14.58333333333333, 
        -1.956068599112297}, 
       {14.71354166666667, 
        -1.973862693210633}, 
       {14.84375, -1.987232034571436}, 
       {14.97395833333333, 
        -1.995957986871163}, 
       {15.10416666666667, 
        -1.999819948470831}, 
       {15.234375, -1.998595569531226}, 
       {15.36458333333333, 
        -1.992061188723028}, 
       {15.49479166666667, 
        -1.979992553223891}, 
       {15.625, -1.962165902358113}, 
       {15.75520833333333, 
        -1.938359516395175}, 
       {15.88541666666667, 
        -1.90835585883069}, 
       {16.14583333333334, 
        -1.828925847186513}, 
       {16.40625, -1.722355505566533}, 
       {16.66666666666667, 
        -1.587502356814622}, 
       {17.1875, -1.232406145899788}, 
       {17.70833333333334, 
        -0.7802952064638292}, 
       {17.96875, -0.5373381501280654}, 
       {18.22916666666667, 
        -0.3060798016131165}, 
       {18.359375, -0.2036076615080875}, 
       {18.48958333333334, 
        -0.1160728826172613}, 
       {18.61979166666667, 
        -0.04904772476820891}, 
       {18.75, -0.00875261252282709}, 
       {18.88020833333334, 
        -0.001831505155976613}, 
       {19.01041666666667, 
        -0.03499200390131388}, 
       {19.140625, -0.1145190601441678}, 
       {19.27083333333334, 
        -0.2457093977164299}, 
       {19.53125, -0.676098897218721}, 
       {19.66145833333334, 
        -0.976629086426461}, 
       {19.79166666666667, 
        -1.331325299074723}, 
       {20.83333333333334, 
        -5.443497399196314}, 
       {25., -22.22933914999257}, 
       {27.08333333333334, 
        -29.76914966491557}, 
       {28.125, -33.83507060639335}, 
       {29.16666666666667, 
        -38.47411545012954}, 
       {29.6875, -41.20133217987708}, 
       {30.20833333333334, 
        -44.42366018087985}, 
       {30.46875, -46.33060967512849}, 
       {30.72916666666667, 
        -48.54779218742632}, 
       {30.98958333333334, 
        -51.24441914720482}, 
       {31.25, -54.77685642748935}, 
       {31.38020833333334, 
        -57.1063454991578}, 
       {31.51041666666667, 
        -60.13870559605498}, 
       {31.640625, -64.57942902259278}, 
       {31.77083333333334, 
        -73.43704735126178}, 
       {32.03125, -66.11139956141135}, 
       {32.16145833333334, 
        -61.65626426902571}, 
       {32.29166666666667, 
        -58.83189739770688}, 
       {32.421875, -56.78453182854912}, 
       {32.55208333333334, 
        -55.19329629319028}, 
       {32.8125, -52.82385043256103}, 
       {33.07291666666667, 
        -51.10628767636719}, 
       {33.33333333333334, 
        -49.78587335864737}, 
       {33.59375, -48.73253727486438}, 
       {33.85416666666667, 
        -47.87085408005779}, 
       {34.375, -46.54750434453777}, 
       {34.89583333333334, 
        -45.58807320926255}, 
       {35.41666666666667, -44.873950323639}, 
       {35.9375, -44.33559018689579}, 
       {36.45833333333334, 
        -43.92880109833521}, 
       {36.97916666666667, 
        -43.62381718650419}, 
       {37.5, -43.39968408779275}, 
       {37.76041666666667, 
        -43.31299902833878}, 
       {38.02083333333334, 
        -43.24113164740822}, 
       {38.28125, -43.18275824256961}, 
       {38.54166666666667, 
        -43.1367191423613}, 
       {38.671875, -43.11800110216689}, 
       {38.80208333333334, 
        -43.1019934759431}, 
       {38.93229166666667, -43.088586969331}, 
       {39.0625, -43.07767859747797}, 
       {39.19270833333334, 
        -43.06917122956357}, 
       {39.32291666666667, 
        -43.06297317353496}, 
       {39.453125, -43.0589977968808}, 
       {39.58333333333334, 
        -43.05716317976851}, 
       {39.71354166666667, 
        -43.05739179729894}, 
       {39.84375, -43.05961022800658}, 
       {39.97395833333334, 
        -43.06374888605772}, 
       {40.10416666666667, 
        -43.06974177488301}, 
       {40.36458333333334, 
        -43.08704286083056}, 
       {40.625, -43.11104910237748}, 
       {40.88541666666667, 
        -43.14134071746584}, 
       {41.14583333333334, 
        -43.1775374073727}, 
       {41.66666666666667, 
        -43.26629640993256}, 
       {42.70833333333334, 
        -43.50140773423011}, 
       {43.75, -43.8015516369712}, 
       {45.83333333333334, 
        -44.55835437890705}, 
       {50., -46.55969629893078}, 
       {54.16666666666667, 
        -49.14614604650251}, 
       {58.33333333333334, 
        -52.4697963186717}, 
       {60.41666666666667, 
        -54.55553499547933}, 
       {62.50000000000001, 
        -57.10665699673945}, 
       {63.54166666666667, 
        -58.6455727761853}, 
       {64.58333333333334, 
        -60.4478635595277}, 
       {66.66666666666667, 
        -65.45540291292031}, 
       {67.1875, -67.25030297934724}, 
       {67.70833333333334, 
        -69.47106007873177}, 
       {67.96875, -70.81938330956578}, 
       {68.22916666666667, 
        -72.40104376973591}, 
       {68.75, -76.75583493612227}, 
       {68.88020833333334, 
        -78.28044120453775}, 
       {69.01041666666667, 
        -80.1219327558599}, 
       {69.140625, -82.4502597358426}, 
       {69.27083333333334, 
        -85.6242265675463}, 
       {69.40104166666667, 
        -90.6481248408066}, 
       {69.53125, -103.7912823494098}, 
       {69.66145833333334, 
        -95.7435330766132}, 
       {69.79166666666667, 
        -88.1760097035353}, 
       {69.921875, -84.2080861356473}, 
       {70.05208333333334, 
        -81.5046648994903}, 
       {70.3125, -77.80255168629223}, 
       {70.44270833333334, 
        -76.42111982333562}, 
       {70.57291666666667, 
        -75.23436366651893}, 
       {70.83333333333334, 
        -73.27007604752919}, 
       {71.35416666666667, 
        -70.35015727350411}, 
       {71.875, -68.20191686679939}, 
       {72.91666666666667, 
        -65.1132863919682}, 
       {73.95833333333334, 
        -62.90757107476704}, 
       {75., -61.20397929842797}, 
       {77.08333333333334, 
        -58.67190581513395}, 
       {79.16666666666667, 
        -56.82934635902946}, 
       {81.25, -55.40077941151325}, 
       {83.3333333333333, 
        -54.24775222236875}, 
       {87.5, -52.48005269378954}, 
       {91.6666666666667, 
        -51.17398501836477}, 
       {95.8333333333333, 
        -50.16253068482843}, 
       {100., -49.35350995597634}}]}}, 
   DisplayFunction :> $DisplayFunction, 
   PlotRange -> All, 
   PlotLabel -> "Magnitude Response (dB)", 
   PlotRange -> {-80, 20}, 
   Ticks -> Automatic, 
   AxesLabel -> {"w", " "}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, 
    AxesLabel -> None, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[{{Line[{{0., 0.}, 
       {2.083333333333333, 
        -12.74415024510595}, 
       {4.166666666666667, 
        -27.32543584159589}, 
       {8.33333333333333, -68.7662522689718}, 
       {12.5, -117.2053959580421}, 
       {14.58333333333333, 
        -137.232991579234}, 
       {15.625, -147.3983945446929}, 
       {16.66666666666667, 
        -159.3720332753725}, 
       {17.1875, -166.8670488008216}, 
       {17.44791666666667, 
        -171.2330110145981}, 
       {17.578125, -173.6127079577342}, 
       {17.70833333333334, 
        -176.1422224033096}, 
       {17.83854166666667, 
        -178.8365560111001}, 
       {17.96875, 178.2888449840322}, 
       {18.09895833333334, 
        175.2185976468963}, 
       {18.22916666666667, 
        171.9381374206284}, 
       {18.75, 156.5198264837592}, 
       {19.79166666666667, 
        117.9364562552658}, 
       {20.3125, 100.4443933141034}, 
       {20.83333333333334, 86.783015767893}, 
       {21.35416666666667, 
        76.57647299806138}, 
       {21.875, 68.91128060252669}, 
       {22.39583333333334, 
        63.01092509749524}, 
       {22.91666666666667, 
        58.33675135132194}, 
       {23.95833333333334, 51.3639050860664}, 
       {25., 46.34350159605067}, 
       {26.04166666666667, 
        42.49534846734813}, 
       {27.08333333333334, 
        39.41167358897987}, 
       {29.16666666666667, 
        34.69551228994088}, 
       {30.20833333333334, 
        32.82635562973513}, 
       {31.25, 31.18805845291246}, 
       {31.51041666666667, 
        30.80891967637261}, 
       {31.640625, 30.62349048237248}, 
       {31.77083333333334, 
        30.44072966699655}, 
       {31.90104166666667, 
        -149.7394284845347}, 
       {32.03125, -149.9170473477492}, 
       {32.16145833333334, 
        -150.0921880673931}, 
       {32.29166666666667, 
        -150.2649096597683}, 
       {33.33333333333334, 
        -151.5660452179066}, 
       {37.5, -155.6819486176671}, 
       {41.66666666666667, 
        -158.6587623780706}, 
       {45.83333333333334, 
        -160.9372434027283}, 
       {50., -162.7488998752809}, 
       {54.16666666666667, 
        -164.2297729314456}, 
       {58.33333333333334, 
        -165.4661516977571}, 
       {62.50000000000001, 
        -166.5159011184652}, 
       {66.66666666666667, 
        -167.419512199455}, 
       {67.70833333333334, 
        -167.6262013173735}, 
       {68.75, -167.8259988877582}, 
       {69.01041666666667, 
        -167.8749128778964}, 
       {69.27083333333334, 
        -167.9234232654027}, 
       {69.40104166666667, 
        -167.9475287112374}, 
       {69.53125, -167.9715351689652}, 
       {69.66145833333334, 
        12.00455673538415}, 
       {69.79166666666667, 
        11.98074638118743}, 
       {70.83333333333334, 
        11.79370950287203}, 
       {75., 11.1019631578562}, 
       {79.16666666666667, 
        10.48865568778765}, 
       {83.3333333333333, 9.94091078041973}, 
       {87.5, 9.44856870972318}, 
       {91.6666666666667, 9.00349638646716}, 
       {95.8333333333333, 8.59909982134994}, 
       {100., 8.22997232018063}}]}}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> 
     (Display[$Display, #1] & ), 
    PlotColor -> Automatic, 
    Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, 
    Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; ]
Graphically, the magnitude response seems to meet the passband and stopband specifications, and the phase response shows that the cutoff frequency is about 20 rad/sec. We will now check the magnitude response at the end of the passband and the beginning of the stopband just to make sure:
:[font = input; startGroup; ]
20 Log[10, Abs[efiltertrans /. w -> 20]]
:[font = output; inactive; output; endGroup; ]
-1.999999999999988
;[o]
-2.
:[font = input; startGroup; ]
20 Log[10, Abs[efiltertrans /. w -> 30]]
:[font = output; inactive; output; endGroup; ]
-43.05701103608025
;[o]
-43.057
:[font = text; inactive; ]
Here, the error in the passband is no greater than 2 dB (which is the specification) and the attenuation of the stopband is greater than 43 dB (which is better than the specification of 40 dB).  Therefore, the following filter meets the specifications:
:[font = text; inactive; endGroup; endGroup; ]
0.00703314 
	CIIR[t, {43461.3, 4532.0684, 529.81258, 14.156814, 1}] [
		CFIR[t, {4908550.5, 0, 5853.945,  0, 1}] ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Bessel Example (Using Object AnalogFilter)
:[font = text; inactive; ]
		Design a 10th order Bessel filter with a cutoff of 1 rad/sec. [Rabiner & Gold, 230]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 1:  Design the filter
:[font = input; initialization; ]
*)
define[ besfilter,
        AnalogFilter[Bessel, t, 10, ignored,
                     ignored, ignored, 1] ]
(*
:[font = input; startGroup; ]
besfilter
:[font = output; inactive; output; endGroup; ]
CIIR[t, {1, 7.613882366493523, 
   27.46004432722153, 61.9489028996037, 
   97.1088710551878, 110.9063281435781, 
   93.8253040205482, 58.3163124745262, 
   25.61616595550315, 7.223647195028783, 
   1.000000000000001}, 
  Roots -> 
   {-0.909134732089576 - 0.1139583137364039*I, 
    -0.909134732089576 + 0.1139583137364039*I, 
    -0.868845964129487 - 0.3430008233748756*I, 
    -0.868845964129487 + 0.3430008233748756*I, 
    -0.783769441309402 - 0.5759147538505069*I, 
    -0.783769441309402 + 0.5759147538505069*I, 
    -0.6417513866990496 - 0.817583616719106*I, 
    -0.6417513866990496 + 0.817583616719106*I, 
    -0.408322073286874 - 1.081274842819102*I, 
    -0.408322073286874 + 1.081274842819102*I}]
;[o]
CIIR[t, {1, 7.61388, 27.46, 61.9489, 97.1089, 
 
   110.906, 93.8253, 58.3163, 25.6162, 
 
   7.22365, 1.}]
:[font = text; inactive; startGroup; Cclosed; ]
		Like the other lowpass prototypes, the filter poles are embedded in the CIIR object but not displayed when printed:
:[font = input; startGroup; ]
besfilter[[3]]
:[font = output; inactive; output; endGroup; endGroup; ]
Roots -> {-0.909134732089576 - 
    0.1139583137364039*I, 
   -0.909134732089576 + 
    0.1139583137364039*I, 
   -0.868845964129487 - 
    0.3430008233748756*I, 
   -0.868845964129487 + 
    0.3430008233748756*I, 
   -0.783769441309402 - 
    0.5759147538505069*I, 
   -0.783769441309402 + 
    0.5759147538505069*I, 
   -0.6417513866990496 - 
    0.817583616719106*I, 
   -0.6417513866990496 + 
    0.817583616719106*I, 
   -0.408322073286874 - 1.081274842819102*I, 
   -0.408322073286874 + 1.081274842819102*I}
;[o]
Roots -> {-0.909135 - 0.113958 I, 
 
   -0.909135 + 0.113958 I, 
 
   -0.868846 - 0.343001 I, 
 
   -0.868846 + 0.343001 I, 
 
   -0.783769 - 0.575915 I, 
 
   -0.783769 + 0.575915 I, 
 
   -0.641751 - 0.817584 I, 
 
   -0.641751 + 0.817584 I, 
 
   -0.408322 - 1.08127 I, 
 
   -0.408322 + 1.08127 I}
:[font = text; inactive; endGroup; ]
Unfortunately, Bessel polynomials are generated iteratively by the Mathematica object BesselPolynomial and the closed form of the roots are not available.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step 2:  Verify that the filter meets the specifications
:[font = text; inactive; ]
In order to verify that the filter meets specifications, we need to examine the frequency response of the filter.  This can be done by simply taking the continuous-time Fourier transform of the filter object:
:[font = input; initialization; ]
*)
define[ besfiltertransobject,
        CTFTransform[ besfilter, t, w ] ]
(*
:[font = input; initialization; ]
*)
define[ besfiltertrans,
        TheFunction[besfiltertransobject] ]
(*
:[font = input; startGroup; Cclosed; ]
besfiltertrans
:[font = output; inactive; output; endGroup; ]
(0.999999999999996 + 7.6138823664935*I*w + 
    -27.46004432722154*w^2 + 
    -61.9489028996034*I*w^3 + 
    97.1088710551877*w^4 + 
    110.9063281435779*I*w^5 + 
    -93.825304020548*w^6 + 
    -58.31631247452614*I*w^7 + 
    25.61616595550313*w^8 + 
    7.223647195028778*I*w^9 - w^10)^(-1)
;[o]
                                2
1 / (1. + 7.61388 I w + -27.46 w  + 
 
                3            4
    -61.9489 I w  + 97.1089 w  + 
 
               5             6
    110.906 I w  + -93.8253 w  + 
 
                7            8
    -58.3163 I w  + 25.6162 w  + 
 
               9    10
    7.22365 I w  - w  )
:[font = text; inactive; ]
Now, we can plot the magnitude and phase response:
:[font = input; startGroup; Cclosed; ]
MagPhasePlot[ besfiltertrans,
              {w, 0, 4},
              MagRangeScale -> Log,
              PlotRange -> { -120, 20 } ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.2381 0.52974 0.00441 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(1)] 0.2619 0.51724 0 1 Msboxa
[(2)] 0.5 0.51724 0 1 Msboxa
[(3)] 0.7381 0.51724 0 1 Msboxa
[(4)] 0.97619 0.51724 0 1 Msboxa
[(w)] 1.00625 0.52974 -1 0 Msboxa
[(-120)] 0.01131 0 1 0 Msboxa
[(-100)] 0.01131 0.08829 1 0 Msboxa
[(-80)] 0.01131 0.17658 1 0 Msboxa
[(-60)] 0.01131 0.26487 1 0 Msboxa
[(-40)] 0.01131 0.35316 1 0 Msboxa
[(-20)] 0.01131 0.44145 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.52974 moveto
1 0.52974 lineto
stroke
0.2619 0.52349 moveto
0.2619 0.53599 lineto
stroke
0 setgray
[(1)] 0.2619 0.51724 0 1 Mshowa
0.5 0.52349 moveto
0.5 0.53599 lineto
stroke
0 setgray
[(2)] 0.5 0.51724 0 1 Mshowa
0.7381 0.52349 moveto
0.7381 0.53599 lineto
stroke
0 setgray
[(3)] 0.7381 0.51724 0 1 Mshowa
0.97619 0.52349 moveto
0.97619 0.53599 lineto
stroke
0 setgray
[(4)] 0.97619 0.51724 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.52974 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-120)] 0.01131 0 1 0 Mshowa
0.01756 0.08829 moveto
0.03006 0.08829 lineto
stroke
0 setgray
[(-100)] 0.01131 0.08829 1 0 Mshowa
0.01756 0.17658 moveto
0.03006 0.17658 lineto
stroke
0 setgray
[(-80)] 0.01131 0.17658 1 0 Mshowa
0.01756 0.26487 moveto
0.03006 0.26487 lineto
stroke
0 setgray
[(-60)] 0.01131 0.26487 1 0 Mshowa
0.01756 0.35316 moveto
0.03006 0.35316 lineto
stroke
0 setgray
[(-40)] 0.01131 0.35316 1 0 Mshowa
0.01756 0.44145 moveto
0.03006 0.44145 lineto
stroke
0 setgray
[(-20)] 0.01131 0.44145 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.52974 moveto
0.02505 0.52974 lineto
0.02629 0.52974 lineto
0.02753 0.52973 lineto
0.02877 0.52972 lineto
0.03001 0.5297 lineto
0.03125 0.52969 lineto
0.03373 0.52964 lineto
0.03621 0.52958 lineto
0.03869 0.52951 lineto
0.04365 0.52934 lineto
0.04861 0.52911 lineto
0.05357 0.52883 lineto
0.06349 0.52811 lineto
0.07341 0.52719 lineto
0.08333 0.52607 lineto
0.10317 0.52318 lineto
0.12302 0.51942 lineto
0.14286 0.51477 lineto
0.18254 0.50255 lineto
0.22222 0.48585 lineto
0.2619 0.46325 lineto
0.30159 0.43319 lineto
0.34127 0.39735 lineto
0.38095 0.35994 lineto
0.42063 0.32373 lineto
0.46032 0.28969 lineto
0.5 0.25795 lineto
0.53968 0.22839 lineto
0.57937 0.2008 lineto
0.61905 0.17496 lineto
0.65873 0.1507 lineto
0.69841 0.12784 lineto
0.7381 0.10623 lineto
0.77778 0.08576 lineto
0.81746 0.0663 lineto
0.85714 0.04777 lineto
0.89683 0.03009 lineto
0.93651 0.01318 lineto
0.97619 -0.00303 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.2381 0.3091 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(1)] 0.2619 0.2966 0 1 Msboxa
[(2)] 0.5 0.2966 0 1 Msboxa
[(3)] 0.7381 0.2966 0 1 Msboxa
[(4)] 0.97619 0.2966 0 1 Msboxa
[(w)] 1.00625 0.3091 -1 0 Msboxa
[(-150)] 0.01131 0.06309 1 0 Msboxa
[(-100)] 0.01131 0.14509 1 0 Msboxa
[(-50)] 0.01131 0.2271 1 0 Msboxa
[(50)] 0.01131 0.3911 1 0 Msboxa
[(100)] 0.01131 0.47311 1 0 Msboxa
[(150)] 0.01131 0.55511 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.3091 moveto
1 0.3091 lineto
stroke
0.2619 0.30285 moveto
0.2619 0.31535 lineto
stroke
0 setgray
[(1)] 0.2619 0.2966 0 1 Mshowa
0.5 0.30285 moveto
0.5 0.31535 lineto
stroke
0 setgray
[(2)] 0.5 0.2966 0 1 Mshowa
0.7381 0.30285 moveto
0.7381 0.31535 lineto
stroke
0 setgray
[(3)] 0.7381 0.2966 0 1 Mshowa
0.97619 0.30285 moveto
0.97619 0.31535 lineto
stroke
0 setgray
[(4)] 0.97619 0.2966 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.3091 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.06309 moveto
0.03006 0.06309 lineto
stroke
0 setgray
[(-150)] 0.01131 0.06309 1 0 Mshowa
0.01756 0.14509 moveto
0.03006 0.14509 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14509 1 0 Mshowa
0.01756 0.2271 moveto
0.03006 0.2271 lineto
stroke
0 setgray
[(-50)] 0.01131 0.2271 1 0 Mshowa
0.01756 0.3911 moveto
0.03006 0.3911 lineto
stroke
0 setgray
[(50)] 0.01131 0.3911 1 0 Mshowa
0.01756 0.47311 moveto
0.03006 0.47311 lineto
stroke
0 setgray
[(100)] 0.01131 0.47311 1 0 Mshowa
0.01756 0.55511 moveto
0.03006 0.55511 lineto
stroke
0 setgray
[(150)] 0.01131 0.55511 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.3091 moveto
0.06349 0.18986 lineto
0.08333 0.13023 lineto
0.09325 0.10042 lineto
0.10317 0.07061 lineto
0.10813 0.05571 lineto
0.1131 0.0408 lineto
0.11558 0.03335 lineto
0.11806 0.02589 lineto
0.1193 0.02217 lineto
0.12054 0.01844 lineto
0.12178 0.01472 lineto
0.12302 0.60141 lineto
0.12426 0.59769 lineto
0.1255 0.59396 lineto
0.12798 0.58651 lineto
0.13294 0.5716 lineto
0.14286 0.54179 lineto
0.18254 0.42255 lineto
0.22222 0.3034 lineto
0.2619 0.18564 lineto
0.30159 0.07573 lineto
0.31151 0.05075 lineto
0.31647 0.03873 lineto
0.32143 0.02704 lineto
0.32391 0.02132 lineto
0.32515 0.01849 lineto
0.32639 0.01568 lineto
0.32763 0.60332 lineto
0.32887 0.60055 lineto
0.33135 0.59508 lineto
0.34127 0.57403 lineto
0.38095 0.50226 lineto
0.42063 0.44676 lineto
0.46032 0.40295 lineto
0.5 0.3675 lineto
0.53968 0.33818 lineto
0.57937 0.31349 lineto
0.61905 0.2924 lineto
0.65873 0.27415 lineto
0.69841 0.25819 lineto
0.7381 0.24411 lineto
0.77778 0.23159 lineto
0.81746 0.22038 lineto
0.85714 0.21029 lineto
0.89683 0.20114 lineto
0.93651 0.19282 lineto
0.97619 0.18522 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{Graphics[{{Line[{{0., 
        3.471578879591826*10^-14}, 
       {0.005208333333333333, 
        -0.0003594526051991568}, 
       {0.01041666666666667, 
        -0.001437820921525558}, 
       {0.015625, -0.003235136453137756}, 
       {0.02083333333333333, 
        -0.005751451714752344}, 
       {0.02604166666666666, 
        -0.00898684024320294}, 
       {0.03125, -0.01294139661369595}, 
       {0.04166666666666666, 
        -0.02300849650356795}, 
       {0.05208333333333333, 
        -0.03595392966476099}, 
       {0.0625, -0.05177921281722711}, 
       {0.0833333333333333, 
        -0.0920770965650737}, 
       {0.1041666666666667, 
        -0.1439211092039424}, 
       {0.125, -0.2073357457749583}, 
       {0.1666666666666667, 
        -0.3690030927516469}, 
       {0.2083333333333333, 
        -0.5773896921872288}, 
       {0.25, -0.832902686730569}, 
       {0.3333333333333333, 
        -1.487459690119152}, 
       {0.4166666666666666, 
        -2.338160140313335}, 
       {0.5, -3.392706361860914}, 
       {0.6666666666666666, 
        -6.160110641597099}, 
       {0.833333333333333, -9.94261857135671}, 
       {1., -15.06345697427111}, 
       {1.166666666666667, 
        -21.87175389897445}, 
       {1.333333333333333, 
        -29.99068691447989}, 
       {1.5, -38.46529802229617}, 
       {1.666666666666667, 
        -46.66722500258157}, 
       {1.833333333333333, 
        -54.37854171420235}, 
       {2., -61.56734525564411}, 
       {2.166666666666667, 
        -68.26385149030713}, 
       {2.333333333333333, -74.5144863153529}, 
       {2.5, -80.3664327882557}, 
       {2.666666666666667, -85.8628260476381}, 
       {2.833333333333333, -91.0416474240684}, 
       {3., -95.935883901767}, 
       {3.166666666666667, 
        -100.5740764997851}, 
       {3.333333333333333, 
        -104.9809383926673}, 
       {3.5, -109.177931033516}, 
       {3.666666666666667, 
        -113.1837655624492}, 
       {3.833333333333333, 
        -117.0148265953728}, 
       {4., -120.6855259080566}}]}}, 
   PlotRange -> {-120, 20}, 
   DisplayFunction :> $DisplayFunction, 
   PlotRange -> All, 
   PlotLabel -> "Magnitude Response (dB)", 
   PlotRange -> {-120, 20}, 
   Ticks -> Automatic, 
   AxesLabel -> {"w", " "}, 
   {PlotRange -> {-120, 20}, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[{{Line[{{0., 0.}, 
       {0.1666666666666667, 
        -72.70722088485991}, 
       {0.25, -109.0608313272859}, 
       {0.2916666666666666, 
        -127.2376365484099}, 
       {0.3333333333333333, 
        -145.4144417682659}, 
       {0.3541666666666666, 
        -154.5028443753414}, 
       {0.375, -163.5912469750761}, 
       {0.3854166666666666, 
        -168.1354482686739}, 
       {0.3958333333333333, 
        -172.679649554391}, 
       {0.4010416666666666, 
        -174.9517501928788}, 
       {0.40625, -177.2238508274066}, 
       {0.4114583333333333, 
        -179.4959514569485}, 
       {0.4166666666666666, 
        178.2319479197664}, 
       {0.421875, 175.9598473043074}, 
       {0.4270833333333333, 
        173.6877466986064}, 
       {0.4375, 169.1435455264941}, 
       {0.4583333333333333, 
        160.0551434459147}, 
       {0.5, 141.8783422166074}, 
       {0.6666666666666666, 
        69.17227140204254}, 
       {0.833333333333333, 
        -3.478177119738019}, 
       {1., -75.27658059008432}, 
       {1.166666666666667, 
        -142.2917399896651}, 
       {1.208333333333333, -157.522554275801}, 
       {1.229166666666667, 
        -164.8505085932651}, 
       {1.25, -171.9792666737965}, 
       {1.260416666666667, 
        -175.4678552632926}, 
       {1.265625, -177.1930806545406}, 
       {1.270833333333333, -178.905565714267}, 
       {1.276041666666667, 179.3947020551647}, 
       {1.28125, 177.7077287248514}, 
       {1.291666666666667, 174.3720520447234}, 
       {1.333333333333333, 161.5368666038747}, 
       {1.5, 117.7736762123763}, 
       {1.666666666666667, 83.9373466899241}, 
       {1.833333333333333, 57.22355054267119}, 
       {2., 35.60600482666063}, 
       {2.166666666666667, 17.72917479326196}, 
       {2.333333333333333, 2.677740285779996}, 
       {2.5, -10.18438089429978}, 
       {2.666666666666667, 
        -21.31277521084096}, 
       {2.833333333333333, 
        -31.04276459602606}, 
       {3., -39.62705562007328}, 
       {3.166666666666667, 
        -47.26000878109004}, 
       {3.333333333333333, -54.0937611645821}, 
       {3.5, -60.24923532748299}, 
       {3.666666666666667, 
        -65.82384263569043}, 
       {3.833333333333333, 
        -70.89699171284271}, 
       {4., -75.53410381590598}}]}}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> 
     (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, 
    Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; ]
Since we could not specify stopband nor passband error, we can check to see what these values are:
:[font = input; startGroup; ]
20 Log[10, Abs[besfiltertrans /. w -> 1]]
:[font = output; inactive; output; endGroup; ]
-15.06345697427096
;[o]
-15.0635
:[font = input; startGroup; ]
20 Log[10, Abs[besfiltertrans /. w -> 2]]
:[font = output; inactive; output; endGroup; ]
-61.56734525564408
;[o]
-61.5673
:[font = text; inactive; ]
The following filter is a 10th-order Bessel filter with a cutoff frequency of 1 rad/sec:
:[font = text; inactive; endGroup; endGroup; endGroup; ]
CIIR[t, {1, 7.6138824, 27.460044, 61.948903, 97.108871, 110.90633, 93.825304, 58.316312, 25.16166, 7.2236472, 1} ]
:[font = section; inactive; startGroup; Cclosed; ]
Design of Other Analog Filters
:[font = text; inactive; ]
		Highpass, bandpass, and bandstop analog filters can be designed from lowpass filter prototypes.  Such a transformation reduces to a algebraic change of variables in the transfer function of the lowpass prototype.  These analog-to-analog transformations are well understood [Parks and Burrus, 201-206].
:[font = text; inactive; ]
		Design specifications, however, are generally given for the original filter, not the lowpass filter prototype.  Therefore, the design specification must be reinterpreted in terms of the lowpass filter prototype.
:[font = subsection; inactive; startGroup; Cclosed; ]
Highpass Filters
:[font = text; inactive; ]
		In this case, we want to design a highpass filter that rejects frequencies below w1 and pass frequencies above w2..  This is the same as lowpass filter prototype with wp = 1 / w2 and ws = 1 / w1 whose transfer function is adjusted by the substitution s -> 1 / s.  This algebraic substitution turns the complex plane inside out:  zero frequency maps to infinity, infinite frequency maps to zero, and unity maps to unity.  The highpass filter will have the same order as the lowpass prototype.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Implementation in Mathematica
:[font = text; inactive; ]
		A highpass filter can be obtained from a lowpass prototype by inverting the locations of the poles and zeroes [Parks and Burrus, 201-202].  The specifications for a highpass filter include the passband and stopband ripples (dp and ds) as well as the passband and stopband  frequencies (w1 and w2).  In order to convert these specifications into their equivalents for the lowpass filter prototype, wp = 1 / w2 and ws = 1 / w1; that is, the values of the passband and stopband frequencies are swapped then inverted.  This way, the highpass filter obtained by inverting the poles and zeroes will respond properly.  In Mathematica, the code for designhp does this:
:[font = input; ]
filtertransform::=			(* forward Laplace transform  *)
SignalProcessing`Analog`FilterDesign`Private`FilterTransferFunction;

tofilter::=
SignalProcessing`Analog`FilterDesign`Private`ToFilter;

designhp[ name_, t_, dp_, ds_, w1_, w2_, rest___ ] :=
Block [ {expdenom, expnumer, fir, hptrans, lowpass, lptrans, n, s},
        lowpass = DesignLPFilter[name, t, dp, ds, 1/w2, 1/w1];
        lptrans = filtertransform[lowpass, t, s];
        n = Exponent[ Denominator[lptrans], s ];
        hptrans = lptrans /. s -> 1/s;
        expnumer = Expand[s^n Numerator[hptrans]];
        expdenom = Expand[s^n Denominator[hptrans]];
        tofilter[ expnumer, expdenom, s, t ] ]
:[font = text; inactive; endGroup; ]
This is the same code used by "FilterDesign.m".  Note that filtertransform has been aliased to an object that takes a Laplace transform of filter structures.  The more general Laplace transform object LaPlace could have been used instead.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Design a highpass analog Butterworth filter
:[font = text; inactive; ]
		Design a highpass analog IIR Butterworth filter which rejects all frequencies up to 10 rad/sec and passes all frequencies above 20 rad/sec.  The maximum error in either the passband or the stopband is 0.01.
:[font = input; initialization; ]
*)
define[ hpfilter,
        DesignFilter[Analog, Butterworth,
                     Highpass, t, 0.01,
                     0.01, 10, 20] ]
(*
:[font = input; startGroup; Cclosed; ]
hpfilter
:[font = output; inactive; output; endGroup; ]
CFIR[t, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    8.2935479148246*10^-13}][CIIR[t, 
   {1, 0.3958599764153782, 
    0.07835256046379188, 0.0101645180107133, 
    0.000954163994378573, 
    0.00006760358118199662, 
    0.000003659073185437494, 
    1.494799462343597*10^-7, 
    4.41872941636152*10^-9, 
    8.56118498074177*10^-11, 
    8.2935479148246*10^-13}]]
;[o]
CFIR[t, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
 
              -13
    8.29355 10   }][CIIR[t, 
 
   {1, 0.39586, 0.0783526, 0.0101645, 
 
    0.000954164, 0.0000676036, 0.00000365907, 
 
             -7            -9            -11
    1.4948 10  , 4.41873 10  , 8.56118 10   , 
 
              -13
    8.29355 10   }]]
:[font = text; inactive; endGroup; ]
In this case, we do want to keep all of the coefficients even though numerically, they are very small.  The Mathematica object Chop is useful for zeroing coefficients smaller than 1.0E-10 (10^-10), but applying Chop to hpfilter would alter its highpass characteristics.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Verify that the filter meets specifications.
:[font = text; inactive; ]
The transfer function of the highpass filter is:
:[font = input; initialization; startGroup; ]
*)
define[ hpfiltertrans,
        TheFunction[
          CTFTransform[ hpfilter, t, w ] ] ]
(*
:[font = input; startGroup; Cclosed; ]
hpfiltertrans
:[font = output; inactive; output; endGroup; endGroup; ]
(-(8.2935479148246*10^-13)*w^10)/
  (1 + 0.3958599764153782*I*w - 
    0.07835256046379188*w^2 + 
    -0.0101645180107133*I*w^3 + 
    0.000954163994378573*w^4 + 
    0.00006760358118199662*I*w^5 - 
    0.000003659073185437494*w^6 + 
    -(1.494799462343597*10^-7)*I*w^7 + 
    4.41872941636152*10^-9*w^8 + 
    8.56118498074177*10^-11*I*w^9 - 
    8.2935479148246*10^-13*w^10)
;[o]
            -13  10
(-8.29355 10    w  ) / 
 
                                2
  (1 + 0.39586 I w - 0.0783526 w  + 
 
                  3                4
    -0.0101645 I w  + 0.000954164 w  + 
 
                    5                  6
    0.0000676036 I w  - 0.00000365907 w  + 
 
              -7    7             -9  8
    -1.4948 10   I w  + 4.41873 10   w  + 
 
              -11    9             -13  10
    8.56118 10    I w  - 8.29355 10    w  )
:[font = text; inactive; ]
Now, we can plot its magnitude and phase response
:[font = input; startGroup; Cclosed; ]

MagPhasePlot[ hpfiltertrans,
              {w, 0.1, 40},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.02381 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.2619 0.48193 0 1 Msboxa
[(20)] 0.5 0.48193 0 1 Msboxa
[(30)] 0.7381 0.48193 0 1 Msboxa
[(40)] 0.97619 0.48193 0 1 Msboxa
[(w)] 1.00625 0.49443 -1 0 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.2619 0.48818 moveto
0.2619 0.50068 lineto
stroke
0 setgray
[(10)] 0.2619 0.48193 0 1 Mshowa
0.5 0.48818 moveto
0.5 0.50068 lineto
stroke
0 setgray
[(20)] 0.5 0.48193 0 1 Mshowa
0.7381 0.48818 moveto
0.7381 0.50068 lineto
stroke
0 setgray
[(30)] 0.7381 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(40)] 0.97619 0.48193 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.49443 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02619 -2.23497 moveto
0.02743 -2.01036 lineto
0.02866 -1.85249 lineto
0.0299 -1.73065 lineto
0.03114 -1.63141 lineto
0.03361 -1.47528 lineto
0.03609 -1.35447 lineto
0.04103 -1.17269 lineto
0.04598 -1.03713 lineto
0.05588 -0.83904 lineto
0.06577 -0.69467 lineto
0.08557 -0.48726 lineto
0.10536 -0.33802 lineto
0.14494 -0.12561 lineto
0.18452 0.02618 lineto
0.22411 0.14437 lineto
0.26369 0.24118 lineto
0.30327 0.32312 lineto
0.34286 0.39364 lineto
0.36265 0.42453 lineto
0.38244 0.4511 lineto
0.39234 0.4621 lineto
0.40223 0.47122 lineto
0.41213 0.47836 lineto
0.41708 0.48121 lineto
0.42202 0.48362 lineto
0.42697 0.48564 lineto
0.43192 0.48732 lineto
0.43687 0.48869 lineto
0.44182 0.48981 lineto
0.45171 0.49144 lineto
0.45666 0.49203 lineto
0.46161 0.4925 lineto
0.46656 0.49288 lineto
0.4715 0.49318 lineto
0.47645 0.49342 lineto
0.4814 0.49361 lineto
0.49129 0.49389 lineto
0.49624 0.49399 lineto
0.50119 0.49408 lineto
0.50614 0.49414 lineto
0.51109 0.49419 lineto
0.51603 0.49424 lineto
0.52098 0.49427 lineto
0.53088 0.49432 lineto
0.53583 0.49434 lineto
0.54077 0.49436 lineto
0.54572 0.49437 lineto
0.55067 0.49438 lineto
0.55562 0.49439 lineto
Mistroke
0.56057 0.49439 lineto
0.56551 0.4944 lineto
0.57046 0.4944 lineto
0.57541 0.49441 lineto
0.58036 0.49441 lineto
0.59025 0.49442 lineto
0.5952 0.49442 lineto
0.60015 0.49442 lineto
0.6051 0.49442 lineto
0.61004 0.49442 lineto
0.61994 0.49442 lineto
0.62984 0.49442 lineto
0.63973 0.49443 lineto
0.64963 0.49443 lineto
0.65952 0.49443 lineto
0.66942 0.49443 lineto
0.67932 0.49443 lineto
0.68921 0.49443 lineto
0.69911 0.49443 lineto
0.709 0.49443 lineto
0.7189 0.49443 lineto
0.72879 0.49443 lineto
0.73869 0.49443 lineto
0.74859 0.49443 lineto
0.75848 0.49443 lineto
0.76838 0.49443 lineto
0.77827 0.49443 lineto
0.78817 0.49443 lineto
0.79807 0.49443 lineto
0.80796 0.49443 lineto
0.81786 0.49443 lineto
0.82775 0.49443 lineto
0.83765 0.49443 lineto
0.84754 0.49443 lineto
0.85744 0.49443 lineto
0.86734 0.49443 lineto
0.87723 0.49443 lineto
0.88713 0.49443 lineto
0.89702 0.49443 lineto
0.90692 0.49443 lineto
0.91682 0.49443 lineto
0.93661 0.49443 lineto
0.9465 0.49443 lineto
0.9564 0.49443 lineto
0.97619 0.49443 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02142 0.02387 0.30888 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.26011 0.29638 0 1 Msboxa
[(20)] 0.49881 0.29638 0 1 Msboxa
[(30)] 0.7375 0.29638 0 1 Msboxa
[(40)] 0.97619 0.29638 0 1 Msboxa
[(w)] 1.00625 0.30888 -1 0 Msboxa
[(-150)] 0.00892 0.06342 1 0 Msboxa
[(-100)] 0.00892 0.14524 1 0 Msboxa
[(-50)] 0.00892 0.22706 1 0 Msboxa
[(50)] 0.00892 0.39069 1 0 Msboxa
[(100)] 0.00892 0.47251 1 0 Msboxa
[(150)] 0.00892 0.55433 1 0 Msboxa
[( )] 0.02142 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30888 moveto
1 0.30888 lineto
stroke
0.26011 0.30263 moveto
0.26011 0.31513 lineto
stroke
0 setgray
[(10)] 0.26011 0.29638 0 1 Mshowa
0.49881 0.30263 moveto
0.49881 0.31513 lineto
stroke
0 setgray
[(20)] 0.49881 0.29638 0 1 Mshowa
0.7375 0.30263 moveto
0.7375 0.31513 lineto
stroke
0 setgray
[(30)] 0.7375 0.29638 0 1 Mshowa
0.97619 0.30263 moveto
0.97619 0.31513 lineto
stroke
0 setgray
[(40)] 0.97619 0.29638 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30888 -1 0 Mshowa
0.02142 0 moveto
0.02142 0.61803 lineto
stroke
0.01517 0.06342 moveto
0.02767 0.06342 lineto
stroke
0 setgray
[(-150)] 0.00892 0.06342 1 0 Mshowa
0.01517 0.14524 moveto
0.02767 0.14524 lineto
stroke
0 setgray
[(-100)] 0.00892 0.14524 1 0 Mshowa
0.01517 0.22706 moveto
0.02767 0.22706 lineto
stroke
0 setgray
[(-50)] 0.00892 0.22706 1 0 Mshowa
0.01517 0.39069 moveto
0.02767 0.39069 lineto
stroke
0 setgray
[(50)] 0.00892 0.39069 1 0 Mshowa
0.01517 0.47251 moveto
0.02767 0.47251 lineto
stroke
0 setgray
[(100)] 0.00892 0.47251 1 0 Mshowa
0.01517 0.55433 moveto
0.02767 0.55433 lineto
stroke
0 setgray
[(150)] 0.00892 0.55433 1 0 Mshowa
0 setgray
[( )] 0.02142 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.59971 moveto
0.06349 0.53792 lineto
0.10317 0.47563 lineto
0.14286 0.41236 lineto
0.18254 0.34749 lineto
0.22222 0.28025 lineto
0.2619 0.20949 lineto
0.30159 0.13323 lineto
0.32143 0.09189 lineto
0.33135 0.07008 lineto
0.34127 0.04731 lineto
0.34623 0.03551 lineto
0.34871 0.0295 lineto
0.35119 0.02342 lineto
0.35243 0.02034 lineto
0.35367 0.01725 lineto
0.35491 0.60322 lineto
0.35615 0.60008 lineto
0.35863 0.59375 lineto
0.36111 0.58733 lineto
0.38095 0.53282 lineto
0.42063 0.41655 lineto
0.46032 0.3219 lineto
0.5 0.25429 lineto
0.53968 0.20324 lineto
0.57937 0.16249 lineto
0.61905 0.12879 lineto
0.65873 0.10026 lineto
0.69841 0.0757 lineto
0.7381 0.05428 lineto
0.77778 0.0354 lineto
0.79762 0.02678 lineto
0.80754 0.02264 lineto
0.81746 0.01862 lineto
0.82242 0.01666 lineto
0.8249 0.01568 lineto
0.82614 0.0152 lineto
0.82738 0.01472 lineto
0.82862 0.60332 lineto
0.82986 0.60284 lineto
0.83234 0.60188 lineto
0.8373 0.6 lineto
0.85714 0.59268 lineto
0.89683 0.57914 lineto
0.93651 0.56686 lineto
0.97619 0.55567 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{Graphics[{{Line[{{0.1, -441.625192838442}, 
       {0.151953125, -405.2832656356704}, 
       {0.20390625, -379.7390853003595}, 
       {0.255859375, -360.0249259024554}, 
       {0.3078125, -343.9679424029009}, 
       {0.4117187500000001, -318.7050637255064}, 
       {0.5156250000000001, -299.1583996596419}, 
       {0.7234375000000002, -269.7449894316288}, 
       {0.93125, -247.8119356871722}, 
       {1.346875, -215.7597344702769}, 
       {1.7625, -192.3993677057548}, 
       {2.59375, -158.8395700272085}, 
       {3.425, -134.6930776727533}, 
       {5.0875, -100.3243083921899}, 
       {6.75, -75.76443838740744}, 
       {8.4125, -56.64018680586005}, 
       {10.075, -40.97652873146879}, 
       {11.7375, -27.71742385097353}, 
       {13.4, -16.30708411334327}, 
       {14.23125, -11.31026693849843}, 
       {15.0625, -7.009856463097513}, 
       {15.478125, -5.230016064360442}, 
       {15.89375, -3.75483608895247}, 
       {16.309375, -2.600529433059082}, 
       {16.5171875, -2.13915581420408}, 
       {16.725, -1.748371483074286}, 
       {16.9328125, -1.421396237344152}, 
       {17.140625, -1.15070881509329}, 
       {17.3484375, -0.928620437420655}, 
       {17.55625, -0.7477313991741308}, 
       {17.971875, -0.4831209316522012}, 
       {18.1796875, -0.3881702602017728}, 
       {18.3875, -0.3120013154204861}, 
       {18.5953125, -0.2509718151019893}, 
       {18.803125, -0.2020965590866366}, 
       {19.0109375, -0.1629520527825736}, 
       {19.21875, -0.1315845820437751}, 
       {19.634375, -0.0862270407918353}, 
       {19.8421875, -0.06998559065443147}, 
       {20.05, -0.05690724835651591}, 
       {20.2578125, -0.04635884938416641}, 
       {20.465625, -0.0378364304793991}, 
       {20.6734375, -0.03093868377198663}, 
       {20.88125, -0.02534578984999226}, 
       {21.296875, -0.01710528887498133}, 
       {21.5046875, -0.01409081606970907}, 
       {21.7125, -0.01162854583470017}, 
       {21.9203125, -0.00961364319609346}, 
       {22.128125, -0.007961834050464058}, 
       {22.3359375, -0.006605254815312726}, 
       {22.54375, -0.005489160316407821}, 
       {22.7515625, -0.004569309248900188}, 
       {22.959375, -0.003809884908968028}, 
       {23.1671875, -0.003181839155668984}, 
       {23.375, -0.002661571386046166}, 
       {23.790625, -0.001871082807109823}, 
       {23.9984375, -0.001572409445862973}, 
       {24.20625, -0.001323387832884395}, 
       {24.4140625, -0.001115441455915672}, 
       {24.621875, -0.000941529809394819}, 
       {25.0375, -0.0006736753627557984}, 
       {25.453125, -0.0004846822934982926}, 
       {25.86875, -0.000350571971909294}, 
       {26.284375, -0.0002548811734004823}, 
       {26.7, -0.0001862383245008451}, 
       {27.115625, -0.0001367427706711031}, 
       {27.53125, -0.0001008741642345919}, 
       {27.946875, -0.00007475406412226462}, 
       {28.3625, -0.00005564301255439808}, 
       {28.778125, -0.00004159600505966183}, 
       {29.19375, -0.00003122513619425006}, 
       {29.609375, -0.00002353518475169083}, 
       {30.025, -0.00001780911682702435}, 
       {30.440625, -0.0000135279384279913}, 
       {30.85625, -0.00001031431018637917}, 
       {31.271875, -0.000007892685013808953}, 
       {31.6875, -0.0000060609926754345}, 
       {32.103125, -0.000004670433198857737}, 
       {32.51875, -0.000003610992198413625}, 
       {32.934375, -0.000002801011753705236}, 
       {33.35, -0.000002179649801237686}, 
       {33.765625, -0.000001701404799895856}, 
       {34.18125000000001, -0.0000013321242062196}, 
       {34.596875, -0.000001046082888146005}, 
       {35.0125, -(8.23836672715927*10^-7)}, 
       {35.428125, -(6.506391672657179*10^-7)}, 
       {35.84375, -(5.152699128074557*10^-7)}, 
       {36.25937500000001, -(4.091639039349335*10^-7)}, 
       {36.675, -(3.257625447541409*10^-7)}, 
       {37.090625, -(2.600282735986527*10^-7)}, 
       {37.50625, -(2.08080187835838*10^-7)}, 
       {38.3375, -(1.342232849721555*10^-7)}, 
       {38.753125, -(1.081855018282737*10^-7)}, 
       {39.16875, -(8.73995975959651*10^-8)}, 
       {40., -(5.742537680904885*10^-8)}}]}}, 
   {PlotRange -> Automatic, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]
   , Graphics[{{Line[{{0.1, 177.7318794169191}, 
       {1.7625, 139.9696010148566}, 
       {3.425, 101.9086908042824}, 
       {5.0875, 63.24103233626657}, 
       {6.75, 23.59983274912111}, 
       {8.4125, -17.49379062820899}, 
       {10.075, -60.73986490768514}, 
       {11.7375, -107.343680007646}, 
       {12.56875, -132.6044335259464}, 
       {12.984375, -145.9353987444117}, 
       {13.4, -159.8500842246971}, 
       {13.6078125, -167.0580119859733}, 
       {13.71171875, -170.7303379608475}, 
       {13.815625, -174.4503520087515}, 
       {13.867578125, -176.3287133964444}, 
       {13.91953125, -178.2195496914908}, 
       {13.971484375, 179.8769701664283}, 
       {14.0234375, 177.9606868787388}, 
       {14.12734375, 174.0891305852892}, 
       {14.23125, 170.1647567168668}, 
       {15.0625, 136.8581956272261}, 
       {16.725, 65.800417414731}, 
       {18.3875, 7.958345405032551}, 
       {20.05, -33.36195370423575}, 
       {21.7125, -64.55605345507054}, 
       {23.375, -89.4599139157437}, 
       {25.0375, -110.0560351016902}, 
       {26.7, -127.4910083009211}, 
       {28.3625, -142.5000475581194}, 
       {30.025, -155.5892038949739}, 
       {31.6875, -167.1240846740251}, 
       {32.51875, -172.3968710198526}, 
       {32.934375, -174.9223672673375}, 
       {33.35, -177.378201534447}, 
       {33.5578125, -178.5809283538993}, 
       {33.66171875, -179.1761507509351}, 
       {33.713671875, -179.4722457219813}, 
       {33.765625, -179.7673370153171}, 
       {33.817578125, 179.9385700630146}, 
       {33.86953125, 179.6454702460386}, 
       {33.9734375, 179.062229051349}, 
       {34.18125000000001, 177.9074364206799}, 
       {35.0125, 173.438339823912}, 
       {36.675, 165.1607117396038}, 
       {38.3375, 157.6573563769547}, 
       {40., 150.8217339824724}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; endGroup; endGroup; ]
If one began the graph at w = 0, Mathematica generates a ParametricPlot::notpoint warning because the magnitude response of this highpass filter at DC (w = 0) is negative infinity.
:[font = subsection; inactive; startGroup; Cclosed; ]
Bandpass Filters
:[font = text; inactive; ]
		Four frequency parameters (w1, w2, w3, and w4), a passband error tolerance (deltap), and one stopband error tolerance (deltas) fully specify a bandpass filter.  In this case, the first stopband is (0, w1), the passband is (w2, w3), and the second stopband is (w4, infinity).  The bandpass filter will always have twice the order of the lowpass prototype.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Implementation in Mathematica
:[font = input; ]
filtertransform::=			(* forward Laplace transform  *)
SignalProcessing`Analog`FilterDesign`Private`FilterTransferFunction;

tofilter::=
SignalProcessing`Analog`FilterDesign`Private`ToFilter;

designbp[ name_, t_, dp_, ds_, w1_, w2_, w3_, w4_ ] :=
Block [ {bptrans, expdenom, expnumer, lowpass,
         lptrans, n, s, w0, wp, ws},
        w0 = Sqrt[ w2 w3 ];
        wp = N[ ( w3^2 - w0^2 ) / w3 ];
        ws = N[ Min[ (w4^2 - w0^2 ) / w4, (w0^2 - w1^2 ) / w1 ] ];
        If [ SameQ[name, Elliptic] && ! SameQ[w1 w4, w2 w3],
             Message[ DesignBPFilter::narrower ] ];
        lowpass = DesignLPFilter[name, t, dp, ds, wp, ws];
        lptrans = filtertransform[lowpass, t, s];
        n = Exponent[ Denominator[lptrans], s ];
        bptrans = lptrans /. (s -> (s^2 + w0^2) / s); (* 2x order *)
        expnumer = Expand[s^n Numerator[bptrans]];
        expdenom = Expand[s^n Denominator[bptrans]];
        tofilter[ expnumer, expdenom, s, t ] ]
:[font = text; inactive; endGroup; ]
This is the same code used by "FilterDesign.m".  Note that filtertransform has been aliased to an object that takes a Laplace transform of filter structures.  The more general Laplace transform object LaPlace could have been used instead.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Design a bandpass analog Chebyshev type I  filter
:[font = text; inactive; ]
		Design a bandpass analog IIR Chebyshev type I filter which rejects all frequencies up to 5 rad/sec, passes frequencies between 10 and 30 rad/sec, and rejects all frequencies above 35 rad/sec.  The maximum error in either the passband or the stopband is 0.01.
:[font = input; initialization; startGroup; ]
*)
define[ bpfilter,
        DesignFilter[Analog, ChebyshevI,
                     Bandpass, t, 0.01,
                     0.01, 10, 30, 70, 90] ]
(*
:[font = input; startGroup; Cclosed; ]
bpfilter
:[font = output; inactive; output; endGroup; endGroup; ]
CFIR[t, {0, 0, 0, 0, 0, 0, 0, 
    17965885259.73128}][CIIR[t, 
   {180108854100000000000000, 
    5.969009633350858*10^21, 
    8.13627515332595*10^20, 
    2.116357027199465*10^19, 
    1.432405352299323*10^18, 
    2.88371457335024*10^16, 1265077976821587., 
    19172986886643.53, 602418084200.756, 
    6539035313.719366, 154670699.9567351, 
    1088207.602387619, 19921.82650068143, 
    69.59635767310566, 1}]]
;[o]
                                        10
CFIR[t, {0, 0, 0, 0, 0, 0, 0, 1.79659 10  }]
 
   [CIIR[t, {180108854100000000000000, 
 
              21            20            19
    5.96901 10  , 8.13628 10  , 2.11636 10  , 
 
              18            16            15
    1.43241 10  , 2.88371 10  , 1.26508 10  , 
 
             13            11            9
    1.9173 10  , 6.02418 10  , 6.53904 10 , 
 
              8            6
    1.54671 10 , 1.08821 10 , 19921.8, 
 
    69.5964, 1}]]
:[font = text; inactive; endGroup; ]
In this case, we do want to keep all of the coefficients even though numerically, they are very small.  The Mathematica object Chop is useful for zeroing coefficients smaller than 1.0E-10 (10^-10), but applying Chop to bpfilter would alter its bandpass characteristics.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Verify that the filter meets specifications.
:[font = text; inactive; ]
The frequency-domain transfer function of the bandpass filter is:
:[font = input; initialization; startGroup; ]
*)
define[ bpfiltertrans,
        TheFunction[
          CTFTransform[ bpfilter, t, w ] ] ]
(*
:[font = input; startGroup; Cclosed; ]
bpfiltertrans
:[font = output; inactive; output; endGroup; endGroup; ]
(-17965885259.73128*I*w^7)/
  (180108854100000000000000 + 
    5.969009633350858*10^21*I*w - 
    8.13627515332595*10^20*w^2 + 
    -(2.116357027199465*10^19)*I*w^3 + 
    1.432405352299323*10^18*w^4 + 
    2.88371457335024*10^16*I*w^5 - 
    1265077976821587.*w^6 + 
    -19172986886643.53*I*w^7 + 
    602418084200.756*w^8 + 
    6539035313.719366*I*w^9 - 
    154670699.9567351*w^10 + 
    -1088207.602387619*I*w^11 + 
    19921.82650068143*w^12 + 
    69.59635767310566*I*w^13 - w^14)
;[o]
            10    7
(-1.79659 10   I w ) / 
 
  (180108854100000000000000 + 
 
              21                 20  2
    5.96901 10   I w - 8.13628 10   w  + 
 
               19    3             18  4
    -2.11636 10   I w  + 1.43241 10   w  + 
 
              16    5             15  6
    2.88371 10   I w  - 1.26508 10   w  + 
 
              13    7             11  8
    -1.9173 10   I w  + 6.02418 10   w  + 
 
              9    9             8  10
    6.53904 10  I w  - 1.54671 10  w   + 
 
               6    11            12
    -1.08821 10  I w   + 19921.8 w   + 
 
               13    14
    69.5964 I w   - w  )
:[font = text; inactive; ]
Now, we can plot its magnitude and phase response:
:[font = input; startGroup; Cclosed; ]

MagPhasePlot[ bpfiltertrans,
              {w, 1, 100},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(w)] 1.00625 0.61803 -1 0 Msboxa
[(-100)] 0.01131 0 1 0 Msboxa
[(-80)] 0.01131 0.12361 1 0 Msboxa
[(-60)] 0.01131 0.24721 1 0 Msboxa
[(-40)] 0.01131 0.37082 1 0 Msboxa
[(-20)] 0.01131 0.49443 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.61803 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-100)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-80)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-60)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-40)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-20)] 0.01131 0.49443 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.03333 -0.98878 moveto
0.03824 -0.83224 lineto
0.04315 -0.72182 lineto
0.04807 -0.63631 lineto
0.05298 -0.56641 lineto
0.0628 -0.45576 lineto
0.07262 -0.36928 lineto
0.09226 -0.23661 lineto
0.1119 -0.1342 lineto
0.15119 0.0265 lineto
0.19048 0.16098 lineto
0.22976 0.29043 lineto
0.26905 0.4359 lineto
0.28869 0.52935 lineto
0.2936 0.55687 lineto
0.29851 0.58468 lineto
0.30097 0.5971 lineto
0.30219 0.60243 lineto
0.30342 0.60698 lineto
0.30465 0.61066 lineto
0.30588 0.61346 lineto
0.30711 0.61545 lineto
0.30833 0.61675 lineto
0.30956 0.61751 lineto
0.31079 0.6179 lineto
0.31202 0.61803 lineto
0.31324 0.61801 lineto
0.3157 0.6178 lineto
0.31693 0.61768 lineto
0.31815 0.61759 lineto
0.31938 0.61753 lineto
0.32061 0.6175 lineto
0.32184 0.6175 lineto
0.32307 0.61753 lineto
0.32552 0.61763 lineto
0.32798 0.61777 lineto
0.33043 0.6179 lineto
0.33166 0.61795 lineto
0.33289 0.61799 lineto
0.33411 0.61802 lineto
0.33534 0.61803 lineto
0.33657 0.61803 lineto
0.3378 0.61802 lineto
0.33903 0.618 lineto
0.34025 0.61797 lineto
0.34271 0.61789 lineto
0.34762 0.61769 lineto
0.35007 0.61761 lineto
0.3513 0.61758 lineto
0.35253 0.61755 lineto
Mistroke
0.35376 0.61752 lineto
0.35499 0.61751 lineto
0.35621 0.6175 lineto
0.35744 0.61749 lineto
0.35867 0.6175 lineto
0.3599 0.61751 lineto
0.36112 0.61752 lineto
0.36235 0.61754 lineto
0.36481 0.6176 lineto
0.36726 0.61767 lineto
0.37217 0.61781 lineto
0.37463 0.61788 lineto
0.37708 0.61794 lineto
0.37831 0.61797 lineto
0.37954 0.61799 lineto
0.38077 0.618 lineto
0.38199 0.61802 lineto
0.38322 0.61803 lineto
0.38445 0.61803 lineto
0.38568 0.61803 lineto
0.3869 0.61803 lineto
0.38813 0.61802 lineto
0.38936 0.61801 lineto
0.39182 0.61798 lineto
0.39427 0.61794 lineto
0.39673 0.61789 lineto
0.40164 0.61777 lineto
0.40655 0.61765 lineto
0.409 0.6176 lineto
0.41146 0.61756 lineto
0.41269 0.61754 lineto
0.41391 0.61753 lineto
0.41514 0.61752 lineto
0.41637 0.61751 lineto
0.4176 0.6175 lineto
0.41882 0.6175 lineto
0.42005 0.61749 lineto
0.42128 0.6175 lineto
0.42251 0.6175 lineto
0.42374 0.61751 lineto
0.42619 0.61753 lineto
0.43601 0.61769 lineto
0.44092 0.61779 lineto
0.44583 0.61789 lineto
0.44829 0.61793 lineto
0.45074 0.61797 lineto
0.4532 0.618 lineto
0.45443 0.61801 lineto
0.45565 0.61802 lineto
0.45688 0.61803 lineto
Mistroke
0.45811 0.61803 lineto
0.45934 0.61803 lineto
0.46057 0.61803 lineto
0.46179 0.61803 lineto
0.46302 0.61803 lineto
0.46425 0.61802 lineto
0.46548 0.61801 lineto
0.46793 0.61799 lineto
0.47039 0.61796 lineto
0.4753 0.61789 lineto
0.48512 0.61771 lineto
0.49003 0.61762 lineto
0.49249 0.61758 lineto
0.49494 0.61755 lineto
0.4974 0.61753 lineto
0.49862 0.61752 lineto
0.49985 0.61751 lineto
0.50108 0.6175 lineto
0.50231 0.6175 lineto
0.50353 0.6175 lineto
0.50476 0.61749 lineto
0.50599 0.6175 lineto
0.50722 0.6175 lineto
0.50844 0.6175 lineto
0.50967 0.61751 lineto
0.51213 0.61753 lineto
0.51458 0.61755 lineto
0.51949 0.61762 lineto
0.5244 0.6177 lineto
0.53423 0.61788 lineto
0.53914 0.61795 lineto
0.54159 0.61798 lineto
0.54405 0.61801 lineto
0.54528 0.61802 lineto
0.5465 0.61802 lineto
0.54773 0.61803 lineto
0.54896 0.61803 lineto
0.55019 0.61803 lineto
0.55141 0.61803 lineto
0.55264 0.61803 lineto
0.55387 0.61803 lineto
0.5551 0.61802 lineto
0.55632 0.61801 lineto
0.55878 0.61799 lineto
0.56124 0.61796 lineto
0.56369 0.61793 lineto
0.57351 0.61776 lineto
0.57842 0.61767 lineto
0.58333 0.61758 lineto
0.58579 0.61755 lineto
Mistroke
0.58824 0.61753 lineto
0.58947 0.61752 lineto
0.5907 0.61751 lineto
0.59193 0.6175 lineto
0.59315 0.6175 lineto
0.59438 0.61749 lineto
0.59561 0.61749 lineto
0.59684 0.6175 lineto
0.59807 0.6175 lineto
0.59929 0.61751 lineto
0.60052 0.61752 lineto
0.60298 0.61754 lineto
0.60543 0.61758 lineto
0.60789 0.61762 lineto
0.6128 0.61771 lineto
0.61771 0.61782 lineto
0.62262 0.61792 lineto
0.62507 0.61796 lineto
0.62753 0.61799 lineto
0.62876 0.61801 lineto
0.62999 0.61802 lineto
0.63121 0.61803 lineto
0.63244 0.61803 lineto
0.63367 0.61803 lineto
0.6349 0.61803 lineto
0.63612 0.61803 lineto
0.63735 0.61802 lineto
0.63858 0.61801 lineto
0.63981 0.618 lineto
0.64226 0.61796 lineto
0.64717 0.61785 lineto
0.65208 0.61772 lineto
0.65454 0.61765 lineto
0.65699 0.61759 lineto
0.65822 0.61756 lineto
0.65945 0.61754 lineto
0.66068 0.61752 lineto
0.6619 0.61751 lineto
0.66313 0.6175 lineto
0.66436 0.61749 lineto
0.66559 0.6175 lineto
0.66682 0.61751 lineto
0.66804 0.61752 lineto
0.66927 0.61755 lineto
0.67173 0.61761 lineto
0.67418 0.6177 lineto
0.67664 0.61781 lineto
0.67909 0.61791 lineto
0.68032 0.61796 lineto
0.68155 0.618 lineto
Mistroke
0.68278 0.61803 lineto
0.684 0.61803 lineto
0.68523 0.61802 lineto
0.68646 0.61797 lineto
0.68769 0.61788 lineto
0.68891 0.61775 lineto
0.69014 0.61756 lineto
0.69137 0.6173 lineto
0.6926 0.61696 lineto
0.69382 0.61654 lineto
0.69628 0.61538 lineto
0.69874 0.61374 lineto
0.70119 0.61156 lineto
0.7061 0.60544 lineto
0.71101 0.59718 lineto
0.72083 0.57677 lineto
0.74048 0.53427 lineto
0.77976 0.46533 lineto
0.81905 0.41239 lineto
0.85833 0.36899 lineto
0.89762 0.33193 lineto
0.9369 0.29944 lineto
0.97619 0.27043 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.01419 0.00962 0.30904 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.20659 0.29654 0 1 Msboxa
[(40)] 0.39899 0.29654 0 1 Msboxa
[(60)] 0.59139 0.29654 0 1 Msboxa
[(80)] 0.78379 0.29654 0 1 Msboxa
[(100)] 0.97619 0.29654 0 1 Msboxa
[(w)] 1.00625 0.30904 -1 0 Msboxa
[(-150)] 0.00169 0.06347 1 0 Msboxa
[(-100)] 0.00169 0.14533 1 0 Msboxa
[(-50)] 0.00169 0.22718 1 0 Msboxa
[(50)] 0.00169 0.39089 1 0 Msboxa
[(100)] 0.00169 0.47275 1 0 Msboxa
[(150)] 0.00169 0.5546 1 0 Msboxa
[( )] 0.01419 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30904 moveto
1 0.30904 lineto
stroke
0.20659 0.30279 moveto
0.20659 0.31529 lineto
stroke
0 setgray
[(20)] 0.20659 0.29654 0 1 Mshowa
0.39899 0.30279 moveto
0.39899 0.31529 lineto
stroke
0 setgray
[(40)] 0.39899 0.29654 0 1 Mshowa
0.59139 0.30279 moveto
0.59139 0.31529 lineto
stroke
0 setgray
[(60)] 0.59139 0.29654 0 1 Mshowa
0.78379 0.30279 moveto
0.78379 0.31529 lineto
stroke
0 setgray
[(80)] 0.78379 0.29654 0 1 Mshowa
0.97619 0.30279 moveto
0.97619 0.31529 lineto
stroke
0 setgray
[(100)] 0.97619 0.29654 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30904 -1 0 Mshowa
0.01419 0 moveto
0.01419 0.61803 lineto
stroke
0.00794 0.06347 moveto
0.02044 0.06347 lineto
stroke
0 setgray
[(-150)] 0.00169 0.06347 1 0 Mshowa
0.00794 0.14533 moveto
0.02044 0.14533 lineto
stroke
0 setgray
[(-100)] 0.00169 0.14533 1 0 Mshowa
0.00794 0.22718 moveto
0.02044 0.22718 lineto
stroke
0 setgray
[(-50)] 0.00169 0.22718 1 0 Mshowa
0.00794 0.39089 moveto
0.02044 0.39089 lineto
stroke
0 setgray
[(50)] 0.00169 0.39089 1 0 Mshowa
0.00794 0.47275 moveto
0.02044 0.47275 lineto
stroke
0 setgray
[(100)] 0.00169 0.47275 1 0 Mshowa
0.00794 0.5546 moveto
0.02044 0.5546 lineto
stroke
0 setgray
[(150)] 0.00169 0.5546 1 0 Mshowa
0 setgray
[( )] 0.01419 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.15859 moveto
0.06349 0.14551 lineto
0.10317 0.13135 lineto
0.14286 0.11492 lineto
0.1627 0.10527 lineto
0.18254 0.09416 lineto
0.20238 0.08094 lineto
0.22222 0.06451 lineto
0.23214 0.05452 lineto
0.24206 0.0428 lineto
0.24702 0.03609 lineto
0.25198 0.02864 lineto
0.25446 0.0246 lineto
0.25694 0.0203 lineto
0.25818 0.01805 lineto
0.25942 0.01572 lineto
0.26066 0.60266 lineto
0.2619 0.60016 lineto
0.26438 0.59489 lineto
0.26687 0.58917 lineto
0.27183 0.57613 lineto
0.27679 0.56013 lineto
0.28175 0.53958 lineto
0.28423 0.52675 lineto
0.28671 0.51152 lineto
0.29167 0.47092 lineto
0.29663 0.41422 lineto
0.30159 0.35268 lineto
0.31151 0.26251 lineto
0.32143 0.19795 lineto
0.33135 0.14241 lineto
0.34127 0.09376 lineto
0.34623 0.0716 lineto
0.35119 0.05055 lineto
0.35367 0.04037 lineto
0.35615 0.03037 lineto
0.35739 0.02544 lineto
0.35863 0.02054 lineto
0.35987 0.01569 lineto
0.36111 0.60022 lineto
0.36359 0.59068 lineto
0.36607 0.58127 lineto
0.37103 0.56282 lineto
0.38095 0.52733 lineto
0.42063 0.40347 lineto
0.46032 0.29512 lineto
0.5 0.19616 lineto
0.51984 0.14883 lineto
0.53968 0.10132 lineto
0.5496 0.07743 lineto
Mistroke
0.55952 0.05354 lineto
0.56448 0.04161 lineto
0.56944 0.0297 lineto
0.57192 0.02375 lineto
0.57316 0.02078 lineto
0.5744 0.0178 lineto
0.57564 0.01483 lineto
0.57688 0.60121 lineto
0.57937 0.59526 lineto
0.61905 0.49677 lineto
0.63889 0.4426 lineto
0.65873 0.38447 lineto
0.69841 0.22419 lineto
0.70833 0.17392 lineto
0.71825 0.13367 lineto
0.72817 0.10442 lineto
0.7381 0.08295 lineto
0.74802 0.06652 lineto
0.75794 0.05342 lineto
0.77778 0.03346 lineto
0.7877 0.02556 lineto
0.79266 0.02199 lineto
0.79762 0.01864 lineto
0.8001 0.01703 lineto
0.80134 0.01625 lineto
0.80258 0.01548 lineto
0.80382 0.01472 lineto
0.80506 0.60332 lineto
0.80754 0.60185 lineto
0.81746 0.59634 lineto
0.85714 0.57882 lineto
0.89683 0.56602 lineto
0.93651 0.55612 lineto
0.97619 0.54815 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{Graphics[{{Line[{{1., -259.9872481089863}, 
       {1.515625, -234.6596375682049}, 
       {2.03125, -216.7924223931057}, 
       {2.546875, -202.9565379160389}, 
       {3.0625, -191.6466641424549}, 
       {4.09375, -173.7434477535358}, 
       {5.125, -159.7502326566524}, 
       {7.1875, -138.2847227459201}, 
       {9.25, -121.7133045865489}, 
       {13.375, -95.7125065971605}, 
       {17.5, -73.95286915954527}, 
       {21.625, -53.0072957626311}, 
       {25.75, -29.46964324623272}, 
       {27.8125, -14.34912904015126}, 
       {28.328125, -9.89719398763116}, 
       {28.84375, -5.396459153941887}, 
       {29.1015625, -3.387581188642484}, 
       {29.23046875, -2.524935907634382}, 
       {29.359375, -1.788580509027537}, 
       {29.48828125, -1.192918539408011}, 
       {29.6171875, -0.7398909897543356}, 
       {29.74609375, -0.4185663083379886}, 
       {29.875, -0.2084274526659124}, 
       {30.00390625, -0.0845675087899927}, 
       {30.1328125, -0.02247623649616417}, 
       {30.26171875, -0.001074269480010778}, 
       {30.390625, -0.003904230292485049}, 
       {30.6484375, -0.03848036977399191}, 
       {30.77734375, -0.0571164743138141}, 
       {30.90625, -0.07210011435353963}, 
       {31.03515625, -0.0821007408383594}, 
       {31.1640625, -0.0868182085752054}, 
       {31.29296875, -0.0866107091475597}, 
       {31.421875, -0.0822264744818727}, 
       {31.6796875, -0.06478474028550882}, 
       {31.9375, -0.04234739835891603}, 
       {32.1953125, -0.02156636388571595}, 
       {32.32421875, -0.01327506784789948}, 
       {32.453125, -0.006868647237412344}, 
       {32.58203125, -0.002531872633269486}, 
       {32.7109375, -0.0003227604610726159}, 
       {32.83984375, -0.0001905996086861369}, 
       {32.96875, -0.001995673761113439}, 
       {33.09765625, -0.00552936736198894}, 
       {33.2265625, -0.01053361452859088}, 
       {33.484375, -0.0237803857781583}, 
       {34., -0.05485746260400318}, 
       {34.2578125, -0.06851750035719058}, 
       {34.38671875, -0.07419344364117174}, 
       {34.515625, -0.07893062715908708}, 
       {34.64453125, -0.0826451983630175}, 
       {34.7734375, -0.0852861235657426}, 
       {34.90234375, -0.0868330178071523}, 
       {35.03125, -0.0872935390059004}, 
       {35.16015625, -0.0867004843923204}, 
       {35.2890625, -0.0851087032423991}, 
       {35.41796875, -0.0825919183592673}, 
       {35.546875, -0.07923953101068504}, 
       {35.8046875, -0.07044512550337978}, 
       {36.0625, -0.0596370610803055}, 
       {36.578125, -0.03585517911563201}, 
       {36.8359375, -0.0247094932599839}, 
       {37.09375, -0.01509091677327445}, 
       {37.22265625, -0.01104020234797017}, 
       {37.3515625, -0.007571463626967685}, 
       {37.48046875, -0.00472698198246617}, 
       {37.609375, -0.00253704653169915}, 
       {37.73828125, -0.001020139446369104}, 
       {37.8671875, -0.000183303662897608}, 
       {37.99609375, -0.00002267301131897801}, 
       {38.125, -0.0005241430513916109}, 
       {38.25390625, -0.00166416033418164}, 
       {38.3828125, -0.003410606871003353}, 
       {38.640625, -0.00855728609025004}, 
       {38.8984375, -0.01557340612662303}, 
       {39.15625, -0.02399585044625206}, 
       {39.671875, -0.04303869983079837}, 
       {40.1875, -0.06170372073968081}, 
       {40.4453125, -0.06979590748588418}, 
       {40.703125, -0.07659710186701359}, 
       {40.83203125, -0.07943104153648799}, 
       {40.9609375, -0.0818532023112672}, 
       {41.08984375, -0.0838444402338724}, 
       {41.21875, -0.0853906868543171}, 
       {41.34765625, -0.0864828822915496}, 
       {41.4765625, -0.0871168655494559}, 
       {41.60546875, -0.0872932263744538}, 
       {41.734375, -0.0870171224254448}, 
       {41.86328125, -0.0862980656178493}, 
       {41.9921875, -0.0851496813364539}, 
       {42.25, -0.0816383902488131}, 
       {43.28125, -0.05540970983145643}, 
       {43.796875, -0.03885352932743821}, 
       {44.3125, -0.02318605956181702}, 
       {44.5703125, -0.01636962830906612}, 
       {44.828125, -0.01053807414800477}, 
       {45.0859375, -0.005873086281855917}, 
       {45.21484375, -0.004022771359290798}, 
       {45.34375, -0.002511913183537723}, 
       {45.47265625, -0.001350250692495063}, 
       {45.6015625, -0.0005444781173203037}, 
       {45.73046875, -0.000098247793428509}, 
       {45.859375, -0.00001219858258260217}, 
       {45.98828125, -0.0002840089494666234}, 
       {46.1171875, -0.000908473547154516}, 
       {46.24609375, -0.001877602023790683}, 
       {46.375, -0.003180738413982805}, 
       {46.6328125, -0.006733930381205389}, 
       {46.890625, -0.01143515966436445}, 
       {47.40625, -0.02359557854383909}, 
       {48.4375, -0.0530823697840744}, 
       {48.953125, -0.06686543628137677}, 
       {49.2109375, -0.07280050145929168}, 
       {49.46875, -0.07787399515861373}, 
       {49.7265625, -0.0819504120551574}, 
       {49.85546875, -0.0835803693623725}, 
       {49.984375, -0.0849237175120838}, 
       {50.11328125, -0.0859721365677244}, 
       {50.2421875, -0.086719356681151}, 
       {50.37109375, -0.0871611784032144}, 
       {50.5, -0.0872954811007484}, 
       {50.62890625, -0.0871222198801613}, 
       {50.7578125, -0.0866434110962769}, 
       {50.88671875, -0.085863106748473}, 
       {51.015625, -0.0847873579679644}, 
       {51.2734375, -0.0817834337314516}, 
       {51.53125, -0.07771797901485318}, 
       {52.046875, -0.0668844528638879}, 
       {52.5625, -0.05347902247944141}, 
       {53.59375, -0.02495390711635762}, 
       {54.109375, -0.01299161442584031}, 
       {54.3671875, -0.00821685182795062}, 
       {54.625, -0.004439479129594449}, 
       {54.75390625, -0.002961089173536046}, 
       {54.8828125, -0.001771904434459359}, 
       {55.01171875, -0.000881212944527834}, 
       {55.140625, -0.0002962308185193731}, 
       {55.26953125, -0.00002203696146938522}, 
       {55.3984375, -0.00006152230263037922}, 
       {55.52734375, -0.000415354235990589}, 
       {55.65625, -0.001081956647566813}, 
       {55.78515625, -0.002057505768902503}, 
       {55.9140625, -0.00333594210000475}, 
       {56.171875, -0.006766243284574498}, 
       {56.4296875, -0.01128112745372749}, 
       {56.6875, -0.01675650743897582}, 
       {57.71875, -0.04484451160082428}, 
       {58.234375, -0.05969609713371061}, 
       {58.75, -0.07270691790689189}, 
       {59.0078125, -0.07799486007932774}, 
       {59.265625, -0.0822257834417802}, 
       {59.39453125, -0.0838963593491175}, 
       {59.5234375, -0.0852483677797155}, 
       {59.65234375, -0.0862680357895217}, 
       {59.78125, -0.0869439340445025}, 
       {59.91015625, -0.0872671112702878}, 
       {60.0390625, -0.0872312173884105}, 
       {60.16796875, -0.0868326143229202}, 
       {60.296875, -0.0860704733462838}, 
       {60.42578125, -0.0849468580237311}, 
       {60.5546875, -0.0834667914225079}, 
       {60.8125, -0.07947247853709127}, 
       {61.0703125, -0.07418836078010238}, 
       {61.328125, -0.06776383806037564}, 
       {61.84375, -0.05232422835144381}, 
       {62.359375, -0.03522683172138993}, 
       {62.875, -0.01905344112249489}, 
       {63.1328125, -0.01218503155827533}, 
       {63.390625, -0.006582704126930425}, 
       {63.51953125, -0.004353791173366789}, 
       {63.6484375, -0.002553095289512522}, 
       {63.77734375, -0.001211405495895154}, 
       {63.90625, -0.0003554523847842576}, 
       {64.03515625, -0.000007365297434862314}, 
       {64.1640625, -0.0001841433774987581}, 
       {64.29296875, -0.000897148346016563}, 
       {64.421875, -0.002151626922482575}, 
       {64.55078125, -0.00394627113925674}, 
       {64.6796875, -0.006272825085437929}, 
       {64.9375, -0.01245193231401318}, 
       {65.453125, -0.02999355501117244}, 
       {65.96875, -0.05155110633538289}, 
       {66.2265625, -0.06231654759648014}, 
       {66.484375, -0.07207812696435291}, 
       {66.61328125, -0.07632963973083663}, 
       {66.7421875, -0.080024900988038}, 
       {66.87109375, -0.0830630533897538}, 
       {67., -0.0853469464870183}, 
       {67.12890625, -0.0867854159964591}, 
       {67.2578125, -0.0872958740406994}, 
       {67.38671875, -0.0868072491293209}, 
       {67.515625, -0.0852633202736898}, 
       {67.64453125, -0.0826264948151633}, 
       {67.7734375, -0.07888208473782761}, 
       {68.03125, -0.0681559000800811}, 
       {68.2890625, -0.05362494251570307}, 
       {68.546875, -0.03657441684491118}, 
       {68.8046875, -0.01929157920719953}, 
       {68.93359375, -0.01162592906529552}, 
       {69.0625, -0.005370138008666379}, 
       {69.19140625, -0.00123290198222729}, 
       {69.3203125, -0.00004667131638823003}, 
       {69.44921875, -0.002776607494921974}, 
       {69.578125, -0.01052730290018502}, 
       {69.70703125, -0.02454608124937285}, 
       {69.8359375, -0.0462214809683498}, 
       {69.96484375, -0.07707536834938473}, 
       {70.09375, -0.118747091788473}, 
       {70.22265625, -0.1729682420186613}, 
       {70.3515625, -0.2415270001706856}, 
       {70.609375, -0.4288049922541253}, 
       {70.8671875, -0.6940271731075857}, 
       {71.125, -1.047788805820914}, 
       {71.640625, -2.037926434530529}, 
       {72.15625, -3.373729417943185}, 
       {73.1875, -6.676660110543157}, 
       {75.25, -13.55303019949263}, 
       {79.375, -24.70750839730755}, 
       {83.5, -33.27311073827862}, 
       {87.625, -40.29603832714113}, 
       {91.75, -46.29282405050404}, 
       {95.875, -51.54946975165407}, 
       {100., -56.24289781996507}}]}}, 
   {PlotRange -> Automatic, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]
   , Graphics[{{Line[{{1., -91.8999974969682}, 
       {5.125, -99.8894527059729}, 
       {9.25, -108.5358758281226}, 
       {13.375, -118.5718462553323}, 
       {15.4375, -124.4660294577018}, 
       {17.5, -131.2555323154385}, 
       {19.5625, -139.3329546978225}, 
       {21.625, -149.3637599760023}, 
       {22.65625, -155.4683569022165}, 
       {23.6875, -162.6284513981249}, 
       {24.203125, -166.7293784221582}, 
       {24.71875, -171.2754567044972}, 
       {24.9765625, -173.7470650570484}, 
       {25.234375, -176.3725098876492}, 
       {25.36328125, -177.7490192489553}, 
       {25.4921875, -179.1717849462274}, 
       {25.62109375, 179.3560381857952}, 
       {25.75, 177.8309629612585}, 
       {26.0078125, 174.6062126178017}, 
       {26.265625, 171.1173818498491}, 
       {26.78125, 163.1506504430716}, 
       {27.296875, 153.3777998502795}, 
       {27.8125, 140.8243360160964}, 
       {28.0703125, 132.9896129823518}, 
       {28.328125, 123.6861603102733}, 
       {28.84375, 98.8856413128328}, 
       {29.359375, 64.24765805945447}, 
       {29.875, 26.65602204690148}, 
       {30.90625, -28.42192020135314}, 
       {31.9375, -67.85400258764656}, 
       {32.96875, -101.7807891880797}, 
       {34., -131.5023912583529}, 
       {34.515625, -145.0359769716537}, 
       {35.03125, -157.8923649279436}, 
       {35.2890625, -164.1141719084301}, 
       {35.546875, -170.2199923535537}, 
       {35.67578125, -173.2336190937282}, 
       {35.8046875, -176.2229793266546}, 
       {35.93359375, -179.1893124916938}, 
       {36.0625, 177.8663003505206}, 
       {36.3203125, 172.0397985805773}, 
       {36.578125, 166.2917952812317}, 
       {37.09375, 155.0182813939508}, 
       {38.125, 133.343743533731}, 
       {42.25, 57.68267321614024}, 
       {46.375, -8.50210940556554}, 
       {50.5, -68.95121958479528}, 
       {52.5625, -97.8613250359832}, 
       {54.625, -126.8810620493137}, 
       {55.65625, -141.4732517177575}, 
       {56.6875, -156.0673014242969}, 
       {57.203125, -163.3525050959469}, 
       {57.71875, -170.6278566999134}, 
       {57.9765625, -174.2626414026015}, 
       {58.10546875, -176.0796088568816}, 
       {58.234375, -177.8964519765768}, 
       {58.36328125, -179.7133114480288}, 
       {58.4921875, 178.4696549519934}, 
       {58.75, 174.8343500953406}, 
       {62.875, 114.6769340428948}, 
       {64.9375, 81.5834003457508}, 
       {67., 46.07859593810731}, 
       {71.125, -51.83086699376054}, 
       {72.15625, -82.5354244611537}, 
       {73.1875, -107.121564574431}, 
       {74.21875, -124.9884423386574}, 
       {75.25, -138.0998158215483}, 
       {76.28125, -148.1361909200121}, 
       {77.3125, -156.1429000847634}, 
       {79.375, -168.3347144438899}, 
       {80.40625, -173.1582858292187}, 
       {80.921875, -175.338674162464}, 
       {81.4375, -177.3872219961513}, 
       {81.6953125, -178.3663940157988}, 
       {81.82421875, -178.8453842617623}, 
       {81.953125, -179.3175501859264}, 
       {82.08203125, -179.7830631255639}, 
       {82.2109375, 179.7579118408378}, 
       {82.46875, 178.858694700665}, 
       {83.5, 175.4921054482728}, 
       {87.625, 164.7915165995674}, 
       {91.75, 156.9752948817185}, 
       {95.875, 150.9257826448045}, 
       {100., 146.0595611938693}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; endGroup; endGroup; ]
Now, if the magnitude and phase response were plotted from 0 rad/sec to 100 rad/sec, then Mathematica would have plotted a ParametricPlot::notpoint warning because the magnitude response of this bandpass filter at DC (w = 0) is negative infinity.
:[font = subsection; inactive; startGroup; Cclosed; ]
Bandstop Filters
:[font = text; inactive; ]
		Four frequency parameters (w1, w2, w3, and w4), a passband error tolerance (deltap), and one stopband error tolerance (deltas) fully specify a bandpass filter.  In this case, the first passband is (0, w1), the stopband is (w2, w3), and the second passband is (w4, infinity).  The filter order of the bandstop filter is always twice that of its lowpass prototype.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Implementation in Mathematica
:[font = input; ]
filtertransform::=			(* forward Laplace transform  *)
SignalProcessing`Analog`FilterDesign`Private`FilterTransferFunction;

tofilter::=
SignalProcessing`Analog`FilterDesign`Private`ToFilter;

DesignBSFilter[ name_, t_, dp_, ds_, w1_, w2_, w3_, w4_ ] :=
Block [ {bstrans, denom, lowpass, lptrans, n, numer, s,
         w0, wp, ws, wsdenom1, wsdenom2},

         w0 = Sqrt[ w1 w4 ];
         wp = N[ w1 / ( w0^2 - w1^2 ) ];

         wsdenom1 = w0^2 - w2^2;			(* ws formula could *)
         wsdenom2 = w3^2 - w0^2;			(* have 0 in denom  *)
         ws = Which [ SameQ[wsdenom1, 0],
                        w3 / wsdenom2,
                      SameQ[wsdenom2, 0],
                        w2 / wsdenom1,
                      True,
                        Min[ w2 / wsdenom1, w3 / wsdenom2 ] ] // N;

         If [ SameQ[name, Elliptic] && ! SameQ[w1 w4, w2 w3],
              Message[ DesignBSFilter::narrower ] ];
         lowpass = DesignLPFilter[name, t, dp, ds, wp, ws];
         lptrans = FilterTransferFunction[lowpass, t, s];
         n = Exponent[ Denominator[lptrans], s ];
         bstrans = lptrans /. (s -> (s / (s^2 + w0^2)));
         numer = Distribute[(s^2 + w0^2)^n Numerator[bstrans]];
         denom = Distribute[(s^2 + w0^2)^n Denominator[bstrans]];
         ToFilter[ Expand[numer], Expand[denom], s, t ] ]
:[font = text; inactive; endGroup; ]
This is the same code used by "FilterDesign.m".  Note that filtertransform has been aliased to an object that takes a Laplace transform of filter structures.  The more general Laplace transform object LaPlace could have been used instead.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Design a bandstop analog elliptic IIR filter
:[font = text; inactive; ]
		Design a bandpass analog IIR Chebyshev type I filter which rejects all frequencies up to 5 rad/sec, passes frequencies between 10 and 30 rad/sec, and rejects all frequencies above 35 rad/sec.  The maximum error in either the passband or the stopband is 0.01.
:[font = input; ]
define[ bsfilter,
        DesignFilter[Analog, Elliptic,
                     Bandstop, t, 0.01,
                     0.01, 10, 30, 70, 90] ]
:[font = input; startGroup; Cclosed; ]
bsfilter
:[font = message; inactive; ]
SignalProcessing`Analog`FilterDesign`Private`DesignBSFil
     ter::narrower: 
   One of the transition bandwidths will be narrower
    than specified.
:[font = output; inactive; output; endGroup; ]
CFIR[t, {732774.8210917324, 0, 9708.90113789096, 0, 
    43.36969065133633, 0, 0.07688734519575741, 0, 
    0.00005354282796461276, 0, 1.479789839641969*10^-8, 
    0, 1.378845104332809*10^-12}][CIIR[t, 
   {740176.5869613457, 221707.696007961, 
    44500.96326619352, 5624.624772642595, 
    586.4537789208246, 36.88432091555759, 
    2.19538236096915, 0.04098257879506399, 
    0.0007240170110133636, 0.000007715534667548142, 
    6.782649484254462*10^-8, 3.754639299699588*10^-10, 
    1.392772832659403*10^-12}]]
;[o]
CFIR[t, {732775., 0, 9708.9, 0, 43.3697, 0, 0.0768873, 
 
                                  -8               -12
    0, 0.0000535428, 0, 1.47979 10  , 0, 1.37885 10   }]
 
   [CIIR[t, {740177., 221708., 44501., 5624.62, 
 
    586.454, 36.8843, 2.19538, 0.0409826, 0.000724017, 
 
                             -8            -10
    0.00000771553, 6.78265 10  , 3.75464 10   , 
 
              -12
    1.39277 10   }]]
:[font = text; inactive; endGroup; ]
The warning message simply informs the user that the one of the transition regions will be narrower than specified (this only occurs for bandstop and bandpass elliptic filters when w1 * w4  does not equal w2 * w3).  The resulting filter has coefficients that are small relative to 1. Sometimes, zero coefficients are calculated to be very small non-zero numbers.  In this case, however, want to keep all of the coefficients.  The Mathematica object Chop is useful for zeroing coefficients smaller than 1.0E-10 (10^-10), but applying Chop to bsfilter would alter its bandpass characteristics.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Verify that the filter meets specifications.
:[font = text; inactive; ]
		Here, we compute the continuous-time Fourier transform of the bandstop filter assigned to bsfilter.
:[font = input; ]
define[ bsfiltertrans,
        TheFunction[
          CTFTransform[ bsfilter, t, w ] ] ]
:[font = input; startGroup; Cclosed; ]
bsfiltertrans
:[font = output; inactive; output; endGroup; ]
(732774.8210917324 - 9708.90113789096*w^2 + 
    43.36969065133633*w^4 - 0.07688734519575741*w^6 + 
    0.00005354282796461276*w^8 - 
    1.479789839641969*10^-8*w^10 + 
    1.378845104332809*10^-12*w^12)/
  (740176.5869613457 + 221707.696007961*I*w - 
    44500.96326619352*w^2 + -5624.624772642595*I*w^3 + 
    586.4537789208246*w^4 + 36.88432091555759*I*w^5 - 
    2.19538236096915*w^6 + -0.04098257879506399*I*w^7 + 
    0.0007240170110133636*w^8 + 
    0.000007715534667548142*I*w^9 - 
    6.782649484254462*10^-8*w^10 + 
    -(3.754639299699588*10^-10)*I*w^11 + 
    1.392772832659403*10^-12*w^12)
;[o]
                   2            4              6
(732775. - 9708.9 w  + 43.3697 w  - 0.0768873 w  + 
 
                  8             -8  10
    0.0000535428 w  - 1.47979 10   w   + 
 
              -12  12
    1.37885 10    w  ) / 
 
                                   2               3
  (740177. + 221708. I w - 44501. w  + -5624.62 I w  + 
 
             4              5            6
    586.454 w  + 36.8843 I w  - 2.19538 w  + 
 
                  7                8
    -0.0409826 I w  + 0.000724017 w  + 
 
                     9             -8  10
    0.00000771553 I w  - 6.78265 10   w   + 
 
               -10    11             -12  12
    -3.75464 10    I w   + 1.39277 10    w  )
:[font = text; inactive; ]
Now, we can plot the magnitude and phase response:
:[font = input; startGroup; Cclosed; ]

MagPhasePlot[ bsfiltertrans,
              {w, 0, 120},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00794 0.61803 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.18254 0.60553 0 1 Msboxa
[(40)] 0.34127 0.60553 0 1 Msboxa
[(60)] 0.5 0.60553 0 1 Msboxa
[(80)] 0.65873 0.60553 0 1 Msboxa
[(100)] 0.81746 0.60553 0 1 Msboxa
[(120)] 0.97619 0.60553 0 1 Msboxa
[(w)] 1.00625 0.61803 -1 0 Msboxa
[(-100)] 0.01131 0 1 0 Msboxa
[(-80)] 0.01131 0.12361 1 0 Msboxa
[(-60)] 0.01131 0.24721 1 0 Msboxa
[(-40)] 0.01131 0.37082 1 0 Msboxa
[(-20)] 0.01131 0.49443 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.18254 0.61178 moveto
0.18254 0.62428 lineto
stroke
0 setgray
[(20)] 0.18254 0.60553 0 1 Mshowa
0.34127 0.61178 moveto
0.34127 0.62428 lineto
stroke
0 setgray
[(40)] 0.34127 0.60553 0 1 Mshowa
0.5 0.61178 moveto
0.5 0.62428 lineto
stroke
0 setgray
[(60)] 0.5 0.60553 0 1 Mshowa
0.65873 0.61178 moveto
0.65873 0.62428 lineto
stroke
0 setgray
[(80)] 0.65873 0.60553 0 1 Mshowa
0.81746 0.61178 moveto
0.81746 0.62428 lineto
stroke
0 setgray
[(100)] 0.81746 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(120)] 0.97619 0.60553 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.61803 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-100)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-80)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-60)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-40)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-20)] 0.01131 0.49443 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.61749 moveto
0.02505 0.6175 lineto
0.02629 0.6175 lineto
0.02753 0.61752 lineto
0.02877 0.61754 lineto
0.03125 0.61758 lineto
0.03373 0.61765 lineto
0.03869 0.6178 lineto
0.04117 0.61787 lineto
0.04365 0.61794 lineto
0.04489 0.61797 lineto
0.04613 0.61799 lineto
0.04737 0.61801 lineto
0.04861 0.61803 lineto
0.04985 0.61803 lineto
0.05109 0.61803 lineto
0.05233 0.61803 lineto
0.05357 0.61801 lineto
0.05481 0.61799 lineto
0.05605 0.61797 lineto
0.05853 0.6179 lineto
0.06349 0.61771 lineto
0.06597 0.61762 lineto
0.06721 0.61758 lineto
0.06845 0.61755 lineto
0.06969 0.61752 lineto
0.07093 0.6175 lineto
0.07217 0.61749 lineto
0.07341 0.6175 lineto
0.07465 0.61752 lineto
0.07589 0.61755 lineto
0.07837 0.61764 lineto
0.08085 0.61777 lineto
0.08333 0.61791 lineto
0.08457 0.61797 lineto
0.08581 0.61801 lineto
0.08705 0.61803 lineto
0.08829 0.61803 lineto
0.08953 0.61799 lineto
0.09077 0.61792 lineto
0.09325 0.61771 lineto
0.09449 0.6176 lineto
0.09573 0.61752 lineto
0.09697 0.6175 lineto
0.09821 0.61756 lineto
0.09945 0.61773 lineto
0.10069 0.61794 lineto
0.10193 0.61802 lineto
0.10317 0.61749 lineto
0.10441 0.61545 lineto
Mistroke
0.10565 0.6106 lineto
0.10689 0.6019 lineto
0.10813 0.58948 lineto
0.11062 0.55817 lineto
0.1131 0.52427 lineto
0.11806 0.45469 lineto
0.12054 0.41667 lineto
0.12178 0.39562 lineto
0.12302 0.37215 lineto
0.12426 0.34461 lineto
0.1255 0.30891 lineto
0.12674 0.24903 lineto
0.12798 0.20273 lineto
0.12922 0.26586 lineto
0.13046 0.28501 lineto
0.1317 0.29307 lineto
0.13294 0.29572 lineto
0.13418 0.29497 lineto
0.13542 0.29167 lineto
0.13666 0.28617 lineto
0.1379 0.27847 lineto
0.13914 0.26829 lineto
0.14038 0.25488 lineto
0.14286 0.20859 lineto
0.1441 0.14986 lineto
0.14534 0.14458 lineto
0.14658 0.20341 lineto
0.14782 0.22941 lineto
0.14906 0.24574 lineto
0.1503 0.25731 lineto
0.15154 0.26601 lineto
0.15278 0.27278 lineto
0.15402 0.27815 lineto
0.15526 0.28246 lineto
0.1565 0.28593 lineto
0.15774 0.28871 lineto
0.15898 0.29092 lineto
0.16022 0.29264 lineto
0.16146 0.29394 lineto
0.1627 0.29487 lineto
0.16394 0.29547 lineto
0.16518 0.29576 lineto
0.16642 0.29578 lineto
0.16766 0.29555 lineto
0.1689 0.29508 lineto
0.17014 0.29438 lineto
0.17262 0.29234 lineto
0.1751 0.28948 lineto
0.17758 0.2858 lineto
0.18006 0.28127 lineto
Mistroke
0.18254 0.27582 lineto
0.18502 0.26933 lineto
0.1875 0.26158 lineto
0.18998 0.25223 lineto
0.19246 0.24069 lineto
0.19494 0.22588 lineto
0.19618 0.21661 lineto
0.19742 0.20544 lineto
0.19866 0.19141 lineto
0.1999 0.17253 lineto
0.20114 0.14348 lineto
0.20238 0.07696 lineto
0.20362 0.09592 lineto
0.20486 0.14883 lineto
0.2061 0.17465 lineto
0.20734 0.19177 lineto
0.20858 0.20453 lineto
0.20982 0.21466 lineto
0.2123 0.23011 lineto
0.21478 0.24162 lineto
0.21726 0.25067 lineto
0.22222 0.26414 lineto
0.22718 0.2737 lineto
0.23214 0.28073 lineto
0.2371 0.28595 lineto
0.24206 0.28981 lineto
0.24454 0.29132 lineto
0.24702 0.29258 lineto
0.2495 0.29361 lineto
0.25198 0.29442 lineto
0.25322 0.29475 lineto
0.25446 0.29504 lineto
0.2557 0.29528 lineto
0.25694 0.29547 lineto
0.25818 0.29562 lineto
0.25942 0.29572 lineto
0.26066 0.29579 lineto
0.2619 0.29581 lineto
0.26314 0.29579 lineto
0.26438 0.29573 lineto
0.26563 0.29563 lineto
0.26687 0.29548 lineto
0.26935 0.29509 lineto
0.27183 0.29453 lineto
0.27679 0.29296 lineto
0.28175 0.29077 lineto
0.28671 0.28793 lineto
0.29167 0.28438 lineto
0.29663 0.28006 lineto
0.30159 0.27483 lineto
Mistroke
0.30655 0.26854 lineto
0.31151 0.2609 lineto
0.31647 0.25149 lineto
0.32143 0.23955 lineto
0.32391 0.23223 lineto
0.32639 0.22365 lineto
0.32887 0.2133 lineto
0.33135 0.20037 lineto
0.33259 0.19247 lineto
0.33383 0.18317 lineto
0.33507 0.1719 lineto
0.33631 0.1576 lineto
0.33755 0.13802 lineto
0.33879 0.10686 lineto
0.34003 0.02394 lineto
0.34127 0.07696 lineto
0.34251 0.1233 lineto
0.34375 0.14776 lineto
0.34499 0.16448 lineto
0.34623 0.17718 lineto
0.34871 0.19597 lineto
0.35119 0.20977 lineto
0.35615 0.22957 lineto
0.36111 0.24365 lineto
0.36607 0.25442 lineto
0.37103 0.26301 lineto
0.37599 0.27002 lineto
0.38095 0.27582 lineto
0.38591 0.28065 lineto
0.39087 0.28466 lineto
0.39583 0.28796 lineto
0.40079 0.29063 lineto
0.40575 0.29271 lineto
0.40823 0.29355 lineto
0.41071 0.29425 lineto
0.41319 0.29482 lineto
0.41567 0.29527 lineto
0.41691 0.29544 lineto
0.41815 0.29558 lineto
0.41939 0.29568 lineto
0.42063 0.29576 lineto
0.42188 0.2958 lineto
0.42312 0.29581 lineto
0.42436 0.29578 lineto
0.4256 0.29572 lineto
0.42684 0.29563 lineto
0.42808 0.2955 lineto
0.43056 0.29514 lineto
0.43304 0.29464 lineto
0.43552 0.29398 lineto
Mistroke
0.44048 0.2922 lineto
0.44544 0.28971 lineto
0.4504 0.28643 lineto
0.45536 0.28219 lineto
0.46032 0.2768 lineto
0.46528 0.26994 lineto
0.47024 0.26107 lineto
0.4752 0.24928 lineto
0.47768 0.24179 lineto
0.48016 0.23274 lineto
0.48264 0.22144 lineto
0.48388 0.2146 lineto
0.48512 0.20665 lineto
0.48636 0.19718 lineto
0.4876 0.18552 lineto
0.48884 0.17042 lineto
0.49008 0.14907 lineto
0.49132 0.11262 lineto
0.49256 -0.09674 lineto
0.4938 0.1108 lineto
0.49504 0.14874 lineto
0.49628 0.17085 lineto
0.49752 0.18652 lineto
0.5 0.20859 lineto
0.50248 0.22422 lineto
0.50496 0.23629 lineto
0.50992 0.25424 lineto
0.51488 0.26722 lineto
0.51984 0.27702 lineto
0.5248 0.28447 lineto
0.52728 0.28745 lineto
0.52976 0.28997 lineto
0.53224 0.29205 lineto
0.53472 0.29369 lineto
0.53596 0.29434 lineto
0.5372 0.29488 lineto
0.53844 0.2953 lineto
0.53968 0.29559 lineto
0.54092 0.29577 lineto
0.54216 0.2958 lineto
0.5434 0.29571 lineto
0.54464 0.29546 lineto
0.54588 0.29506 lineto
0.54712 0.29449 lineto
0.54836 0.29373 lineto
0.5496 0.29278 lineto
0.55084 0.29161 lineto
0.55208 0.2902 lineto
0.55456 0.2865 lineto
0.55704 0.28137 lineto
Mistroke
0.55828 0.27809 lineto
0.55952 0.27422 lineto
0.56076 0.2696 lineto
0.562 0.26404 lineto
0.56324 0.25723 lineto
0.56448 0.24869 lineto
0.56572 0.23757 lineto
0.56696 0.22222 lineto
0.5682 0.19851 lineto
0.56944 0.14968 lineto
0.57192 0.19436 lineto
0.57316 0.22573 lineto
0.5744 0.24651 lineto
0.57688 0.2752 lineto
0.57937 0.29581 lineto
0.58433 0.32619 lineto
0.58929 0.34934 lineto
0.59921 0.38547 lineto
0.61905 0.43995 lineto
0.65873 0.52427 lineto
0.67857 0.56119 lineto
0.68849 0.578 lineto
0.69841 0.59269 lineto
0.70337 0.59888 lineto
0.70833 0.60413 lineto
0.71329 0.6084 lineto
0.71825 0.61169 lineto
0.72073 0.61299 lineto
0.72321 0.61409 lineto
0.72569 0.61501 lineto
0.72817 0.61576 lineto
0.73065 0.61636 lineto
0.73313 0.61684 lineto
0.73562 0.61721 lineto
0.7381 0.61749 lineto
0.74058 0.6177 lineto
0.74182 0.61778 lineto
0.74306 0.61785 lineto
0.7443 0.6179 lineto
0.74554 0.61795 lineto
0.74678 0.61798 lineto
0.74802 0.618 lineto
0.74926 0.61802 lineto
0.7505 0.61803 lineto
0.75174 0.61803 lineto
0.75298 0.61803 lineto
0.75422 0.61803 lineto
0.75546 0.61802 lineto
0.75794 0.61799 lineto
0.76042 0.61796 lineto
Mistroke
0.7629 0.61791 lineto
0.76786 0.61782 lineto
0.77282 0.61774 lineto
0.77778 0.61766 lineto
0.78274 0.61759 lineto
0.78522 0.61757 lineto
0.7877 0.61755 lineto
0.79018 0.61753 lineto
0.79266 0.61751 lineto
0.7939 0.61751 lineto
0.79514 0.6175 lineto
0.79638 0.6175 lineto
0.79762 0.6175 lineto
0.79886 0.6175 lineto
0.8001 0.61749 lineto
0.80134 0.61749 lineto
0.80258 0.61749 lineto
0.80382 0.6175 lineto
0.80506 0.6175 lineto
0.8063 0.6175 lineto
0.80754 0.6175 lineto
0.81002 0.61751 lineto
0.8125 0.61752 lineto
0.81746 0.61755 lineto
0.8373 0.61769 lineto
0.85714 0.61784 lineto
0.86706 0.6179 lineto
0.87698 0.61795 lineto
0.88194 0.61797 lineto
0.8869 0.61799 lineto
0.89187 0.61801 lineto
0.89683 0.61802 lineto
0.89931 0.61802 lineto
0.90179 0.61802 lineto
0.90427 0.61803 lineto
0.90675 0.61803 lineto
0.90799 0.61803 lineto
0.90923 0.61803 lineto
0.91047 0.61803 lineto
0.91171 0.61803 lineto
0.91295 0.61803 lineto
0.91419 0.61803 lineto
0.91543 0.61803 lineto
0.91667 0.61803 lineto
0.91791 0.61803 lineto
0.91915 0.61803 lineto
0.92039 0.61803 lineto
0.92163 0.61803 lineto
0.92411 0.61803 lineto
0.92659 0.61803 lineto
Mistroke
0.93155 0.61802 lineto
0.93651 0.61801 lineto
0.94643 0.618 lineto
0.95635 0.61797 lineto
0.97619 0.61791 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00794 0.30934 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.18254 0.29684 0 1 Msboxa
[(40)] 0.34127 0.29684 0 1 Msboxa
[(60)] 0.5 0.29684 0 1 Msboxa
[(80)] 0.65873 0.29684 0 1 Msboxa
[(100)] 0.81746 0.29684 0 1 Msboxa
[(120)] 0.97619 0.29684 0 1 Msboxa
[(w)] 1.00625 0.30934 -1 0 Msboxa
[(-150)] 0.01131 0.0638 1 0 Msboxa
[(-100)] 0.01131 0.14565 1 0 Msboxa
[(-50)] 0.01131 0.2275 1 0 Msboxa
[(50)] 0.01131 0.39119 1 0 Msboxa
[(100)] 0.01131 0.47304 1 0 Msboxa
[(150)] 0.01131 0.55488 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30934 moveto
1 0.30934 lineto
stroke
0.18254 0.30309 moveto
0.18254 0.31559 lineto
stroke
0 setgray
[(20)] 0.18254 0.29684 0 1 Mshowa
0.34127 0.30309 moveto
0.34127 0.31559 lineto
stroke
0 setgray
[(40)] 0.34127 0.29684 0 1 Mshowa
0.5 0.30309 moveto
0.5 0.31559 lineto
stroke
0 setgray
[(60)] 0.5 0.29684 0 1 Mshowa
0.65873 0.30309 moveto
0.65873 0.31559 lineto
stroke
0 setgray
[(80)] 0.65873 0.29684 0 1 Mshowa
0.81746 0.30309 moveto
0.81746 0.31559 lineto
stroke
0 setgray
[(100)] 0.81746 0.29684 0 1 Mshowa
0.97619 0.30309 moveto
0.97619 0.31559 lineto
stroke
0 setgray
[(120)] 0.97619 0.29684 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30934 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.0638 moveto
0.03006 0.0638 lineto
stroke
0 setgray
[(-150)] 0.01131 0.0638 1 0 Mshowa
0.01756 0.14565 moveto
0.03006 0.14565 lineto
stroke
0 setgray
[(-100)] 0.01131 0.14565 1 0 Mshowa
0.01756 0.2275 moveto
0.03006 0.2275 lineto
stroke
0 setgray
[(-50)] 0.01131 0.2275 1 0 Mshowa
0.01756 0.39119 moveto
0.03006 0.39119 lineto
stroke
0 setgray
[(50)] 0.01131 0.39119 1 0 Mshowa
0.01756 0.47304 moveto
0.03006 0.47304 lineto
stroke
0 setgray
[(100)] 0.01131 0.47304 1 0 Mshowa
0.01756 0.55488 moveto
0.03006 0.55488 lineto
stroke
0 setgray
[(150)] 0.01131 0.55488 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30934 moveto
0.04365 0.2371 lineto
0.06349 0.15481 lineto
0.07341 0.10692 lineto
0.07837 0.07969 lineto
0.08085 0.06482 lineto
0.08333 0.0489 lineto
0.08457 0.04049 lineto
0.08581 0.03175 lineto
0.08705 0.02266 lineto
0.08829 0.60251 lineto
0.09077 0.5824 lineto
0.09325 0.56051 lineto
0.09573 0.53641 lineto
0.09821 0.5091 lineto
0.10317 0.43322 lineto
0.10565 0.37589 lineto
0.10813 0.31546 lineto
0.10938 0.29043 lineto
0.11062 0.26978 lineto
0.1131 0.23876 lineto
0.11558 0.21664 lineto
0.11806 0.19973 lineto
0.12054 0.18608 lineto
0.12302 0.17465 lineto
0.12426 0.16956 lineto
0.1255 0.16482 lineto
0.12674 0.16037 lineto
0.12798 0.45084 lineto
0.13046 0.44315 lineto
0.13294 0.43622 lineto
0.1379 0.42413 lineto
0.14038 0.41878 lineto
0.14162 0.41626 lineto
0.14286 0.41382 lineto
0.1441 0.41147 lineto
0.14534 0.11454 lineto
0.14782 0.11019 lineto
0.15278 0.10225 lineto
0.1627 0.08863 lineto
0.18254 0.06738 lineto
0.19246 0.05869 lineto
0.19742 0.05469 lineto
0.1999 0.05276 lineto
0.20114 0.05182 lineto
0.20238 0.05088 lineto
0.20362 0.34461 lineto
0.20486 0.3437 lineto
0.20734 0.3419 lineto
0.2123 0.33842 lineto
Mistroke
0.22222 0.33185 lineto
0.2619 0.30934 lineto
0.28175 0.29956 lineto
0.30159 0.29038 lineto
0.31151 0.28596 lineto
0.32143 0.28162 lineto
0.32639 0.27948 lineto
0.33135 0.27736 lineto
0.33383 0.2763 lineto
0.33631 0.27525 lineto
0.33755 0.27472 lineto
0.33879 0.2742 lineto
0.34003 0.27367 lineto
0.34127 0.5678 lineto
0.34375 0.56676 lineto
0.34623 0.56572 lineto
0.35119 0.56364 lineto
0.36111 0.55951 lineto
0.38095 0.5513 lineto
0.42063 0.53484 lineto
0.44048 0.52642 lineto
0.46032 0.51779 lineto
0.47024 0.51337 lineto
0.48016 0.50886 lineto
0.48512 0.50656 lineto
0.4876 0.50541 lineto
0.49008 0.50424 lineto
0.49132 0.50366 lineto
0.49256 0.50307 lineto
0.4938 0.20783 lineto
0.49504 0.20724 lineto
0.49752 0.20606 lineto
0.5 0.20486 lineto
0.51984 0.195 lineto
0.53968 0.18447 lineto
0.5496 0.17889 lineto
0.55952 0.17307 lineto
0.56448 0.17005 lineto
0.56696 0.16851 lineto
0.5682 0.16774 lineto
0.56944 0.16696 lineto
0.57068 0.46082 lineto
0.57192 0.46003 lineto
0.5744 0.45843 lineto
0.57937 0.45517 lineto
0.59921 0.44106 lineto
0.61905 0.42474 lineto
0.63889 0.40506 lineto
0.65873 0.37992 lineto
0.67857 0.34545 lineto
Mistroke
0.69841 0.2967 lineto
0.71825 0.23745 lineto
0.7381 0.18546 lineto
0.75794 0.14751 lineto
0.77778 0.11919 lineto
0.81746 0.07725 lineto
0.85714 0.04543 lineto
0.87698 0.03194 lineto
0.8869 0.02568 lineto
0.89187 0.02266 lineto
0.89683 0.01971 lineto
0.89931 0.01826 lineto
0.90179 0.01683 lineto
0.90303 0.01612 lineto
0.90427 0.01542 lineto
0.90551 0.01472 lineto
0.90675 0.60332 lineto
0.90923 0.60194 lineto
0.91171 0.60057 lineto
0.91667 0.59788 lineto
0.93651 0.58771 lineto
0.97619 0.56979 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
{Graphics[{{Line[{{0., -0.0872961080490018}, 
       {0.15625, -0.0868699742803682}, 
       {0.3125, -0.0855989632042631}, 
       {0.46875, -0.0835051736254866}, 
       {0.625, -0.0806251959791955}, 
       {0.9375, -0.07272314650433022}, 
       {1.25, -0.06245752858513089}, 
       {1.875, -0.03801571122399448}, 
       {2.1875, -0.02576758587119529}, 
       {2.5, -0.0148992571497599}, 
       {2.65625, -0.01030638170314666}, 
       {2.8125, -0.00643527485703873}, 
       {2.96875, -0.003394143048916847}, 
       {3.125, -0.00127757330886908}, 
       {3.28125, -0.0001634726732866985}, 
       {3.4375, -0.0001100597921610303}, 
       {3.59375, -0.001152986333002695}, 
       {3.75, -0.003302674323355008}, 
       {3.90625, -0.006541962762361704}, 
       {4.0625, -0.01082416246579721}, 
       {4.375, -0.02217491129235061}, 
       {5., -0.05186441925772413}, 
       {5.3125, -0.06679909185195999}, 
       {5.46875, -0.07337280938512464}, 
       {5.625, -0.07897426403605344}, 
       {5.78125, -0.0833271516608184}, 
       {5.9375, -0.0861735535113605}, 
       {6.09375, -0.0872873803997479}, 
       {6.25, -0.0864897393445909}, 
       {6.40625, -0.083666159192204}, 
       {6.5625, -0.07878543236751223}, 
       {6.875, -0.0632637111737209}, 
       {7.1875, -0.04208677658371052}, 
       {7.5, -0.01985829988152724}, 
       {7.65625, -0.01046247503548258}, 
       {7.8125, -0.003561287830866482}, 
       {7.96875, -0.000185222532836016}, 
       {8.125, -0.001234665883310041}, 
       {8.28125, -0.007304786707067042}, 
       {8.4375, -0.01846500668213656}, 
       {8.75, -0.05218613277882108}, 
       {8.90625, -0.07003661522807389}, 
       {9.0625, -0.0833418789973826}, 
       {9.21875, -0.0870077589432319}, 
       {9.375, -0.07624830058308049}, 
       {9.53125, -0.04946938243344682}, 
       {9.6875, -0.01461064165704194}, 
       {9.84375, -0.002046664735130278}, 
       {10., -0.0872961080489696}, 
       {10.15625, -0.4176117225445771}, 
       {10.3125, -1.203164982005821}, 
       {10.46875, -2.610431462281591}, 
       {10.625, -4.619806773738917}, 
       {10.9375, -9.68695695993045}, 
       {11.25, -15.17090593887234}, 
       {11.875, -26.42995443911756}, 
       {12.1875, -32.58194899904978}, 
       {12.34375, -35.98810778842673}, 
       {12.5, -39.78415659073889}, 
       {12.65625, -44.24166612473771}, 
       {12.8125, -50.01699030396442}, 
       {12.96875, -59.70576585183947}, 
       {13.125, -67.19682964981624}, 
       {13.28125, -56.98297503066998}, 
       {13.4375, -53.88414033783322}, 
       {13.59375, -52.58087472016856}, 
       {13.75, -52.15132578795728}, 
       {13.90625, -52.27255907379455}, 
       {14.0625, -52.80638406106601}, 
       {14.21875, -53.6974177826484}, 
       {14.375, -54.94266928332191}, 
       {14.53125, -56.58950359773727}, 
       {14.6875, -58.75957286769384}, 
       {15., -66.24885853069401}, 
       {15.15625, -75.75274626417051}, 
       {15.3125, -76.6059457432825}, 
       {15.46875, -67.08778664478743}, 
       {15.625, -62.88070721089844}, 
       {15.78125, -60.23841713823479}, 
       {15.9375, -58.36667870897958}, 
       {16.09375, -56.95884242521759}, 
       {16.25, -55.86337016129855}, 
       {16.40625, -54.99397118331251}, 
       {16.5625, -54.296718757507}, 
       {16.71875, -53.73562145203137}, 
       {16.875, -53.28545970809506}, 
       {17.03125, -52.92789348528562}, 
       {17.1875, -52.64919603537955}, 
       {17.34375, -52.43886045423113}, 
       {17.5, -52.28870432239879}, 
       {17.65625, -52.19227333609236}, 
       {17.8125, -52.14443223889}, 
       {17.96875, -52.14107750731522}, 
       {18.125, -52.17893184227642}, 
       {18.28125, -52.25539534404516}, 
       {18.4375, -52.36843717033288}, 
       {18.75, -52.69852955394242}, 
       {19.0625, -53.16189557068125}, 
       {19.375, -53.75733490587599}, 
       {19.6875, -54.48969695622581}, 
       {20., -55.37074341321892}, 
       {20.3125, -56.42125420265578}, 
       {20.625, -57.67522373899529}, 
       {20.9375, -59.18817456545444}, 
       {21.25, -61.05477724097027}, 
       {21.5625, -63.45111405874249}, 
       {21.71875, -64.95133412874172}, 
       {21.875, -66.75857295440198}, 
       {22.03125, -69.0290333023559}, 
       {22.1875, -72.08475893463159}, 
       {22.34375, -76.78460297905427}, 
       {22.5, -87.5482053938407}, 
       {22.65625, -84.4802894437489}, 
       {22.8125, -75.91852677559366}, 
       {22.96875, -71.74109428921575}, 
       {23.125, -68.97076374651171}, 
       {23.28125, -66.90595368396012}, 
       {23.4375, -65.26716382631642}, 
       {23.75, -62.76710874125491}, 
       {24.0625, -60.9048163421767}, 
       {24.375, -59.44069342646944}, 
       {25., -57.26123117626894}, 
       {25.625, -55.71491734858011}, 
       {26.25, -54.57769549485776}, 
       {26.875, -53.73158199116637}, 
       {27.5, -53.10705464304363}, 
       {27.8125, -52.86347052851261}, 
       {28.125, -52.66010038688621}, 
       {28.4375, -52.49369574279068}, 
       {28.75, -52.36157850528789}, 
       {28.90625, -52.30767095111142}, 
       {29.0625, -52.26153844991985}, 
       {29.21875, -52.22296512987138}, 
       {29.375, -52.19175572263921}, 
       {29.53125, -52.16773407488582}, 
       {29.6875, -52.15074184813516}, 
       {29.84375, -52.14063738496505}, 
       {30., -52.13729472295961}, 
       {30.15625, -52.14060274082969}, 
       {30.3125, -52.15046442362121}, 
       {30.46875, -52.16679623609219}, 
       {30.625, -52.18952759519507}, 
       {30.9375, -52.25396885268201}, 
       {31.25, -52.3434681188531}, 
       {31.875, -52.59729721643298}, 
       {32.5, -52.95219890115733}, 
       {33.125, -53.4125119136356}, 
       {33.75, -53.98623578782237}, 
       {34.375, -54.68602035309841}, 
       {35., -55.53091728326103}, 
       {35.625, -56.54946910394568}, 
       {36.25, -57.78537625872431}, 
       {36.875, -59.30865663406516}, 
       {37.5, -61.24005313012658}, 
       {37.8125, -62.42392750846089}, 
       {38.125, -63.81337812197345}, 
       {38.4375, -65.48665279918913}, 
       {38.75, -67.57969781257788}, 
       {38.90625, -68.85820294737215}, 
       {39.0625, -70.36185789266196}, 
       {39.21875, -72.18530567248401}, 
       {39.375, -74.49982602857182}, 
       {39.53125, -77.66789918558391}, 
       {39.6875, -82.7090208724499}, 
       {39.84375, -96.1272011560826}, 
       {40., -87.5482053938344}, 
       {40.15625, -80.0496559060609}, 
       {40.3125, -76.09116178717362}, 
       {40.46875, -73.38675581063652}, 
       {40.625, -71.33209978041437}, 
       {40.9375, -68.29058939419767}, 
       {41.25, -66.05813301992657}, 
       {41.875, -62.85425900348666}, 
       {42.5, -60.57641800965412}, 
       {43.125, -58.83329625207595}, 
       {43.75, -57.44376722418414}, 
       {44.375, -56.3093252931526}, 
       {45., -55.37074341321926}, 
       {45.625, -54.58996057510097}, 
       {46.25, -53.94141377580526}, 
       {46.875, -53.40747509352487}, 
       {47.5, -52.97587991641233}, 
       {48.125, -52.63820876267079}, 
       {48.4375, -52.50278118553452}, 
       {48.75, -52.38897057791471}, 
       {49.0625, -52.29645878095936}, 
       {49.375, -52.22505656514647}, 
       {49.53125, -52.1972464898742}, 
       {49.6875, -52.1746990572646}, 
       {49.84375, -52.1574252725027}, 
       {50., -52.14544381138455}, 
       {50.15625, -52.13878109926463}, 
       {50.3125, -52.13747143069654}, 
       {50.46875, -52.14155713106405}, 
       {50.625, -52.15108876198858}, 
       {50.78125, -52.16612537281107}, 
       {50.9375, -52.18673480102997}, 
       {51.25, -52.24498957440226}, 
       {51.5625, -52.32658641190957}, 
       {51.875, -52.4324282067446}, 
       {52.5, -52.72143850476147}, 
       {53.125, -53.12359820853869}, 
       {53.75, -53.65533269136989}, 
       {54.375, -54.34009325526812}, 
       {55., -55.21214582018418}, 
       {55.625, -56.32357943623821}, 
       {56.25, -57.75843697400467}, 
       {56.875, -59.66486261935183}, 
       {57.1875, -60.87746823987242}, 
       {57.5, -62.3425611595807}, 
       {57.8125, -64.16961226190323}, 
       {57.96875, -65.27632647899949}, 
       {58.125, -66.56339399893622}, 
       {58.28125, -68.09581078362284}, 
       {58.4375, -69.98223668270114}, 
       {58.59375, -72.42576368962769}, 
       {58.75, -75.88009260219883}, 
       {58.90625, -81.7772464742721}, 
       {59.0625, -115.6520865019309}, 
       {59.21875, -82.0717917261251}, 
       {59.375, -75.93291459085701}, 
       {59.53125, -72.35630894234546}, 
       {59.6875, -69.82065052705859}, 
       {60., -66.24885853069533}, 
       {60.3125, -63.71985810431664}, 
       {60.625, -61.76738963108878}, 
       {61.25, -58.86239102026438}, 
       {61.875, -56.76250516273099}, 
       {62.5, -55.17711958432388}, 
       {63.125, -53.971755405519}, 
       {63.4375, -53.48949155059682}, 
       {63.75, -53.08122634352866}, 
       {64.0625, -52.74480461441339}, 
       {64.375, -52.47986412563795}, 
       {64.53125, -52.37456742924104}, 
       {64.6875, -52.28781132082712}, 
       {64.84375, -52.22006840531085}, 
       {65., -52.17194651902082}, 
       {65.15625, -52.14420273506057}, 
       {65.3125, -52.13776151077701}, 
       {65.46875, -52.15373792887894}, 
       {65.625, -52.19346732977046}, 
       {65.78125, -52.25854311035417}, 
       {65.9375, -52.35086513724869}, 
       {66.09375, -52.47270218813814}, 
       {66.25, -52.62677324896607}, 
       {66.40625, -52.81635460823117}, 
       {66.5625, -53.04542292067373}, 
       {66.875, -53.64266905651116}, 
       {67.1875, -54.47389806875331}, 
       {67.34375, -55.0035791556007}, 
       {67.5, -55.63030343049308}, 
       {67.65625, -56.37714661498138}, 
       {67.8125, -57.27699711719981}, 
       {67.96875, -58.37900373317437}, 
       {68.125, -59.76138576755002}, 
       {68.28125, -61.56003636538885}, 
       {68.4375, -64.04419090155918}, 
       {68.59375, -67.88022832878451}, 
       {68.75, -75.78149772659314}, 
       {69.0625, -68.55119344649316}, 
       {69.21875, -63.47544716239439}, 
       {69.375, -60.11408699917904}, 
       {69.6875, -55.4723334499367}, 
       {70., -52.13729472296068}, 
       {70.625, -47.22153182139431}, 
       {71.25, -43.47521049479744}, 
       {72.5, -37.62976894983948}, 
       {75., -28.81442973526408}, 
       {80., -15.17090593887224}, 
       {82.5, -9.19754174636368}, 
       {83.75, -6.4775346149491}, 
       {85., -4.101317338357948}, 
       {85.625, -3.099668285216365}, 
       {86.25, -2.249183742637482}, 
       {86.875, -1.559347653945574}, 
       {87.5, -1.027175863300186}, 
       {87.8125, -0.815949097440293}, 
       {88.125, -0.6378272956278221}, 
       {88.4375, -0.4897371698635023}, 
       {88.75, -0.368427091173565}, 
       {89.0625, -0.2706164924562592}, 
       {89.375, -0.1931183510485665}, 
       {89.6875, -0.1329304781053648}, 
       {90., -0.087296108048991}, 
       {90.3125, -0.05373744678064341}, 
       {90.46875, -0.04079172677758432}, 
       {90.625, -0.03006742996796562}, 
       {90.78125, -0.0213358598584473}, 
       {90.9375, -0.01438530040854973}, 
       {91.09375, -0.00902034803513282}, 
       {91.25, -0.005061169684984152}, 
       {91.40625, -0.002342710940338944}, 
       {91.5625, -0.0007138744339664943}, 
       {91.71875, -0.00003668542149718782}, 
       {91.875, -0.0001854582740259899}, 
       {92.03125, -0.001045974904710674}, 
       {92.1875, -0.002514683742353431}, 
       {92.5, -0.006911192607626428}, 
       {92.8125, -0.01273131542808708}, 
       {93.125, -0.01945607489776378}, 
       {93.75, -0.03405202471800495}, 
       {94.375, -0.04835697875097333}, 
       {95., -0.061011386060772}, 
       {95.625, -0.07131642508676282}, 
       {95.9375, -0.07549266814038293}, 
       {96.25, -0.079006312831517}, 
       {96.5625, -0.0818658793866161}, 
       {96.875, -0.0840900073513669}, 
       {97.03125, -0.0849717544174871}, 
       {97.1875, -0.0857049778006564}, 
       {97.34375, -0.0862938238416265}, 
       {97.5, -0.0867426837084682}, 
       {97.65625, -0.0870561493673399}, 
       {97.8125, -0.0872389739577892}, 
       {97.96875, -0.0872960361811953}, 
       {98.125, -0.0872323083475805}, 
       {98.28125, -0.0870528277530742}, 
       {98.4375, -0.0867626710910979}, 
       {98.59375, -0.0863669316253704}, 
       {98.75, -0.0858706988753888}, 
       {99.0625, -0.0845969867880368}, 
       {99.375, -0.0829815414893842}, 
       {100., -0.07888008546541286}, 
       {102.5, -0.05581007453140566}, 
       {105., -0.03157111564298436}, 
       {106.25, -0.02143199468190123}, 
       {107.5, -0.01319857917767306}, 
       {108.125, -0.00984663965970394}, 
       {108.75, -0.007009241650956009}, 
       {109.375, -0.004679401097646111}, 
       {110., -0.002843642362931372}, 
       {110.3125, -0.00210539778125638}, 
       {110.625, -0.001483365695401619}, 
       {110.9375, -0.000974615243774739}, 
       {111.25, -0.0005760345457486878}, 
       {111.40625, -0.0004170429005690274}, 
       {111.5625, -0.0002843589838072892}, 
       {111.71875, -0.0001775551269060503}, 
       {111.875, -0.0000961972553813138}, 
       {112.03125, -0.0000398455892266369}, 
       {112.1875, -0.00000805531317834071}, 
       {112.34375, -(3.772175763516731*10^-7)}, 
       {112.5, -0.00001635831080754232}, 
       {112.65625, -0.00005554240408586972}, 
       {112.8125, -0.0001174706691442409}, 
       {112.96875, -0.0002016821708905674}, 
       {113.125, -0.0003077143737683295}, 
       {113.4375, -0.0005833856129096096}, 
       {113.75, -0.000940769860323858}, 
       {114.375, -0.001885846109722894}, 
       {115., -0.003113497257723201}, 
       {116.25, -0.006301842604938916}, 
       {117.5, -0.01028593621254914}, 
       {120., -0.01985829988153111}}]}}, 
   {PlotRange -> Automatic, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]
   , Graphics[{{Line[{{0., 0.}, 
       {2.5, -44.13211357993586}, 
       {5., -94.4013492895666}, 
       {6.25, -123.6609323844478}, 
       {6.875, -140.2958166796453}, 
       {7.1875, -149.3788705359391}, 
       {7.5, -159.1047866204347}, 
       {7.65625, -164.2419080761907}, 
       {7.8125, -169.579375730386}, 
       {7.96875, -175.1300551917639}, 
       {8.125, 179.0933658421221}, 
       {8.4375, 166.8092252487261}, 
       {8.75, 153.4344536166559}, 
       {9.0625, 138.7114966921821}, 
       {9.375, 122.0325182445842}, 
       {10., 75.67744919713539}, 
       {10.3125, 40.65315377029728}, 
       {10.625, 3.736549307639944}, 
       {10.78125, -11.5528076092745}, 
       {10.9375, -24.17143867469393}, 
       {11.25, -43.11674685272498}, 
       {11.5625, -56.63097723915642}, 
       {11.875, -66.96421248565977}, 
       {12.1875, -75.29953872891815}, 
       {12.5, -82.2818387626324}, 
       {12.65625, -85.3903055386655}, 
       {12.8125, -88.2897478397927}, 
       {12.96875, -91.0064718770953}, 
       {13.125, 86.4379331229757}, 
       {13.4375, 81.7412291400836}, 
       {13.75, 77.50760464914792}, 
       {14.375, 70.12045402630993}, 
       {14.6875, 66.85662199769983}, 
       {14.84375, 65.31390500626289}, 
       {15., 63.82514303895484}, 
       {15.15625, 62.38671400691588}, 
       {15.3125, -119.004658193471}, 
       {15.625, -121.6578572006033}, 
       {16.25, -126.5141294273845}, 
       {17.5, -134.8293354975936}, 
       {20., -147.8118617025617}, 
       {21.25, -153.1207532993625}, 
       {21.875, -155.5648538014825}, 
       {22.1875, -156.7416482719917}, 
       {22.34375, -157.3195092877306}, 
       {22.5, -157.890618996859}, 
       {22.65625, 21.54482793795252}, 
       {22.8125, 20.98664434150423}, 
       {23.125, 19.88867205985433}, 
       {23.75, 17.76167317736711}, 
       {25., 13.75103156540777}, {30., 0.}, 
       {32.5, -5.977236293547735}, 
       {35., -11.5853447709446}, 
       {36.25, -14.28671710096632}, 
       {37.5, -16.93487802246861}, 
       {38.125, -18.24208363006337}, 
       {38.75, -19.53954251500902}, 
       {39.0625, -20.18494814320743}, 
       {39.375, -20.82830784615498}, 
       {39.53125, -21.14925921589792}, 
       {39.6875, -21.46974522611701}, 
       {39.84375, -21.78978087808061}, 
       {40., 157.890618996859}, 
       {40.3125, 157.2526668223163}, 
       {40.625, 156.6162828142529}, 
       {41.25, 155.347769493394}, 
       {42.5, 152.8247329449709}, 
       {45., 147.8118617025617}, 
       {50., 137.7518791253317}, 
       {52.5, 132.6135315317194}, 
       {55., 127.3405333262273}, 
       {56.25, 124.6375709058895}, 
       {57.5, 121.8809343638969}, 
       {58.125, 120.4800921987943}, 
       {58.4375, 119.7735944810914}, 
       {58.75, 119.0628676186711}, 
       {58.90625, 118.7058753340597}, 
       {59.0625, 118.3477738074641}, 
       {59.21875, -62.01145475565635}, 
       {59.375, -62.37182838908854}, 
       {59.6875, -63.09608423686617}, 
       {60., -63.82514303895481}, 
       {62.5, -69.84995533187438}, 
       {65., -76.28476647158865}, 
       {66.25, -79.69213421400137}, 
       {67.5, -83.2505334414911}, 
       {68.125, -85.0933091804148}, 
       {68.4375, -86.0319722246869}, 
       {68.59375, -86.5058117827117}, 
       {68.75, -86.9827325596547}, 
       {68.90625, 92.5372066635683}, 
       {69.0625, 92.0539455308419}, 
       {69.375, 91.0775725395523}, 
       {70., 89.083577363174}, 
       {72.5, 80.4658207297331}, 
       {75., 70.49380540673708}, 
       {77.5, 58.47244767202166}, 
       {80., 43.1167468527247}, 
       {82.5, 22.06075392951273}, 
       {85., -7.72514668783577}, 
       {87.5, -43.92156375738302}, 
       {90., -75.67744919713523}, 
       {92.5, -98.8651620254674}, 
       {95., -116.1656378223473}, 
       {100., -141.785225723815}, 
       {105., -161.2212281842475}, 
       {107.5, -169.4651688826497}, 
       {108.75, -173.2894653147096}, 
       {109.375, -175.1335123824176}, 
       {110., -176.9342754718763}, 
       {110.3125, -177.8188918388607}, 
       {110.625, -178.693237459126}, 
       {110.78125, -179.1266133228025}, 
       {110.9375, -179.5574864891757}, 
       {111.09375, -179.9858781008359}, 
       {111.25, 179.5881909382844}, 
       {111.5625, 178.7436285115069}, 
       {111.875, 177.9086635562219}, 
       {112.5, 176.2668925693845}, 
       {115., 170.0533965102983}, 
       {120., 159.1047866204347}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = section; inactive; startGroup; Cclosed; ]
Tradeoffs Between Filter Design Parameters
:[font = subsection; inactive; startGroup; Cclosed; ]
Filter Length
:[font = text; inactive; ]
		All of the five classical filters require one key parameter---  filter length.  As the filter length increases, the transition between passband and stopband regions in the magnitude response will become sharper (that is, occur over a shorter range of frequencies).   We now demonstrate this through animation of a sequence of magnitude responses of a lowpass Butterworth filter.
:[font = text; inactive; ]
		A filter has a cutoff frequency of 22 rad/sec , -2 dB of attenuation at 20 rad/sec, and at least 10 dB of attenuation at 160 / 7 (about 22.85) rad/sec.  To meet specifications, we will need an eleventh-order Butterworth filter:
:[font = input; startGroup; ]
FilterParameters[bdelta1, bdelta2, bepsilon, bA, Eripple, ATT, nu]
:[font = output; inactive; output; endGroup; ]
{0.2056717652757185, 0.3162277660168379, 
  0.7647831015792084, 3.162277660168379, 
  2.466913365931468, 10., 0.2549277005264028}
;[o]
{0.205672, 0.316228, 0.764783, 3.16228, 2.46691, 10., 
 
  0.254928}
:[font = input; startGroup; ]
FilterOrder[Butterworth, 7/8, nu]
:[font = output; inactive; output; endGroup; ]
11
;[o]
11
:[font = text; inactive; ]
Because the specifications here are the same as those in the fourth-order Butterworth filter design example in the "Design of Lowpass Analog Filters" section (except that the cutoff frequency has been changed from 30 rad/sec to 23 rad/sec), the variables bdelta1 and bdelta2 already contain the design passband and stopband tolerance, respectively.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
The animation
:[font = text; inactive; ]
		Animate graphics by selecting the cell below with the magnitude response (choose the cell border with the downward pointing arrow) and hit COMMAND-y (or choose the option Animate Selected Graphics).  Note that the frequencies here are in rad/sec and the magnitude response is in decibels (dB):
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04529 0.49443 lineto
0.04772 0.49443 lineto
0.05015 0.49443 lineto
0.05258 0.49443 lineto
0.05501 0.49443 lineto
0.05744 0.49443 lineto
0.0623 0.49443 lineto
0.06473 0.49442 lineto
0.06716 0.49442 lineto
0.07202 0.49442 lineto
0.07688 0.49442 lineto
0.08175 0.49442 lineto
0.08661 0.49441 lineto
0.09147 0.49441 lineto
0.09633 0.4944 lineto
0.10119 0.4944 lineto
0.11091 0.49438 lineto
0.12063 0.49435 lineto
0.13036 0.49432 lineto
0.14008 0.49427 lineto
0.1498 0.49421 lineto
0.15952 0.49413 lineto
0.17897 0.49393 lineto
0.18869 0.49379 lineto
0.19841 0.49363 lineto
0.21786 0.49322 lineto
0.2373 0.49268 lineto
0.25675 0.49198 lineto
0.27619 0.49111 lineto
0.31508 0.4888 lineto
0.35397 0.48568 lineto
0.39286 0.48179 lineto
0.43175 0.47723 lineto
0.47063 0.47216 lineto
0.50952 0.46674 lineto
0.54841 0.46114 lineto
0.5873 0.45547 lineto
0.62619 0.44982 lineto
0.66508 0.44425 lineto
0.70397 0.43881 lineto
0.74286 0.43353 lineto
0.78175 0.4284 lineto
0.82063 0.42345 lineto
0.85952 0.41867 lineto
0.89841 0.41405 lineto
0.9373 0.4096 lineto
0.97619 0.4053 lineto
stroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 2)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05987 0.49443 lineto
0.0623 0.49443 lineto
0.06473 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07202 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.07932 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08661 0.49443 lineto
0.09147 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.10119 0.49443 lineto
0.10605 0.49443 lineto
0.11091 0.49443 lineto
0.11577 0.49442 lineto
0.12063 0.49442 lineto
0.1255 0.49442 lineto
0.13036 0.49442 lineto
0.14008 0.49441 lineto
0.14494 0.49441 lineto
0.1498 0.49441 lineto
0.15466 0.4944 lineto
0.15952 0.4944 lineto
0.16925 0.49438 lineto
0.17897 0.49436 lineto
0.18869 0.49433 lineto
0.19841 0.49429 lineto
0.20813 0.49423 lineto
0.21786 0.49416 lineto
0.22758 0.49407 lineto
0.2373 0.49396 lineto
0.24702 0.49382 lineto
0.25675 0.49365 lineto
0.26647 0.49343 lineto
Mistroke
0.27619 0.49318 lineto
0.29563 0.4925 lineto
0.31508 0.49156 lineto
0.33452 0.4903 lineto
0.35397 0.48867 lineto
0.39286 0.48415 lineto
0.43175 0.4779 lineto
0.47063 0.47016 lineto
0.50952 0.46138 lineto
0.54841 0.45205 lineto
0.5873 0.44254 lineto
0.62619 0.4331 lineto
0.66508 0.4239 lineto
0.70397 0.415 lineto
0.74286 0.40644 lineto
0.78175 0.39823 lineto
0.82063 0.39037 lineto
0.85952 0.38283 lineto
0.89841 0.37561 lineto
0.9373 0.36868 lineto
0.97619 0.36202 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 3)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.07932 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08661 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10605 0.49443 lineto
0.11091 0.49443 lineto
0.11334 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.1255 0.49443 lineto
0.13036 0.49443 lineto
0.13522 0.49443 lineto
0.14008 0.49443 lineto
0.14494 0.49443 lineto
0.1498 0.49443 lineto
0.15466 0.49442 lineto
0.15952 0.49442 lineto
Mistroke
0.16438 0.49442 lineto
0.16925 0.49442 lineto
0.17411 0.49442 lineto
0.17897 0.49442 lineto
0.18383 0.49442 lineto
0.18869 0.49441 lineto
0.19355 0.49441 lineto
0.19841 0.4944 lineto
0.20813 0.49439 lineto
0.213 0.49438 lineto
0.21786 0.49437 lineto
0.22758 0.49434 lineto
0.2373 0.49431 lineto
0.24702 0.49425 lineto
0.25675 0.49418 lineto
0.26647 0.49409 lineto
0.27619 0.49397 lineto
0.28591 0.49381 lineto
0.29563 0.4936 lineto
0.30536 0.49334 lineto
0.31508 0.493 lineto
0.3248 0.49259 lineto
0.33452 0.49208 lineto
0.35397 0.49071 lineto
0.37341 0.48877 lineto
0.39286 0.48614 lineto
0.4123 0.48274 lineto
0.43175 0.47855 lineto
0.47063 0.46806 lineto
0.50952 0.45554 lineto
0.54841 0.44207 lineto
0.5873 0.42843 lineto
0.62619 0.41507 lineto
0.66508 0.40219 lineto
0.70397 0.38987 lineto
0.74286 0.37813 lineto
0.78175 0.36694 lineto
0.82063 0.35628 lineto
0.85952 0.34609 lineto
0.89841 0.33636 lineto
0.9373 0.32704 lineto
0.97619 0.3181 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 4)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.06109 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10605 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11334 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.1255 0.49443 lineto
Mistroke
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.1498 0.49443 lineto
0.15466 0.49443 lineto
0.15952 0.49443 lineto
0.16438 0.49443 lineto
0.16925 0.49443 lineto
0.17411 0.49443 lineto
0.17897 0.49443 lineto
0.18383 0.49443 lineto
0.18869 0.49442 lineto
0.19355 0.49442 lineto
0.19841 0.49442 lineto
0.20327 0.49442 lineto
0.20813 0.49442 lineto
0.213 0.49442 lineto
0.21786 0.49442 lineto
0.22272 0.49441 lineto
0.22758 0.49441 lineto
0.2373 0.4944 lineto
0.24216 0.49439 lineto
0.24702 0.49438 lineto
0.25188 0.49437 lineto
0.25675 0.49435 lineto
0.26647 0.49431 lineto
0.27133 0.49429 lineto
0.27619 0.49426 lineto
0.28591 0.49418 lineto
0.29563 0.49408 lineto
0.30536 0.49393 lineto
0.31508 0.49373 lineto
0.3248 0.49346 lineto
0.33452 0.49311 lineto
0.34425 0.49265 lineto
0.35397 0.49206 lineto
0.36369 0.49131 lineto
0.37341 0.49037 lineto
0.38313 0.4892 lineto
0.39286 0.48779 lineto
0.4123 0.4841 lineto
0.43175 0.47919 lineto
0.47063 0.46585 lineto
0.50952 0.44928 lineto
0.54841 0.43143 lineto
0.5873 0.41358 lineto
Mistroke
0.62619 0.39632 lineto
0.66508 0.37985 lineto
0.70397 0.36421 lineto
0.74286 0.34938 lineto
0.78175 0.33529 lineto
0.82063 0.32189 lineto
0.85952 0.30912 lineto
0.89841 0.29692 lineto
0.9373 0.28525 lineto
0.97619 0.27406 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 5)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.06109 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10605 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
Mistroke
0.11334 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17897 0.49443 lineto
0.18383 0.49443 lineto
0.18869 0.49443 lineto
0.19355 0.49443 lineto
0.19841 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.213 0.49443 lineto
0.21786 0.49442 lineto
0.22272 0.49442 lineto
0.22758 0.49442 lineto
0.23244 0.49442 lineto
0.2373 0.49442 lineto
0.24216 0.49442 lineto
0.24702 0.49441 lineto
0.25188 0.49441 lineto
0.25675 0.4944 lineto
0.26647 0.49439 lineto
0.27133 0.49438 lineto
0.27619 0.49437 lineto
0.28105 0.49435 lineto
0.28591 0.49433 lineto
0.29563 0.49428 lineto
0.3005 0.49424 lineto
0.30536 0.4942 lineto
Mistroke
0.31022 0.49415 lineto
0.31508 0.49409 lineto
0.3248 0.49393 lineto
0.33452 0.4937 lineto
0.34425 0.49338 lineto
0.35397 0.49293 lineto
0.36369 0.49234 lineto
0.37341 0.49154 lineto
0.38313 0.49049 lineto
0.39286 0.48914 lineto
0.40258 0.48744 lineto
0.4123 0.48534 lineto
0.43175 0.4798 lineto
0.45119 0.47246 lineto
0.47063 0.46354 lineto
0.50952 0.44266 lineto
0.54841 0.42031 lineto
0.5873 0.39828 lineto
0.62619 0.3772 lineto
0.66508 0.35723 lineto
0.70397 0.33835 lineto
0.74286 0.32048 lineto
0.78175 0.30353 lineto
0.82063 0.28742 lineto
0.85952 0.27208 lineto
0.89841 0.25743 lineto
0.9373 0.24342 lineto
0.97619 0.23 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 6)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04772 0.49443 lineto
0.05015 0.49443 lineto
0.05258 0.49443 lineto
0.05379 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.05866 0.49443 lineto
0.05987 0.49443 lineto
0.06109 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06595 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08296 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
Mistroke
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.12063 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.213 0.49443 lineto
0.21786 0.49443 lineto
0.22272 0.49443 lineto
0.22758 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
0.24216 0.49442 lineto
0.24702 0.49442 lineto
0.25188 0.49442 lineto
0.25675 0.49442 lineto
0.26161 0.49442 lineto
0.26647 0.49441 lineto
0.27133 0.49441 lineto
0.27619 0.49441 lineto
Mistroke
0.28105 0.4944 lineto
0.28591 0.49439 lineto
0.29077 0.49438 lineto
0.29563 0.49436 lineto
0.3005 0.49435 lineto
0.30536 0.49432 lineto
0.31022 0.4943 lineto
0.31508 0.49426 lineto
0.3248 0.49417 lineto
0.32966 0.4941 lineto
0.33452 0.49402 lineto
0.34425 0.49381 lineto
0.34911 0.49366 lineto
0.35397 0.49349 lineto
0.35883 0.49328 lineto
0.36369 0.49303 lineto
0.37341 0.49238 lineto
0.38313 0.49148 lineto
0.39286 0.49024 lineto
0.40258 0.48859 lineto
0.4123 0.48644 lineto
0.43175 0.4804 lineto
0.45119 0.47187 lineto
0.47063 0.46114 lineto
0.50952 0.43575 lineto
0.54841 0.40888 lineto
0.5873 0.38271 lineto
0.62619 0.35789 lineto
0.66508 0.33448 lineto
0.70397 0.31239 lineto
0.74286 0.29152 lineto
0.78175 0.27173 lineto
0.82063 0.25293 lineto
0.85952 0.23503 lineto
0.89841 0.21794 lineto
0.9373 0.20159 lineto
0.97619 0.18593 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 7)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.05258 0.49443 lineto
0.05744 0.49443 lineto
0.0623 0.49443 lineto
0.06352 0.49443 lineto
0.06473 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08296 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09025 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09754 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
0.11456 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.11942 0.49443 lineto
0.12063 0.49443 lineto
0.12185 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12671 0.49443 lineto
Mistroke
0.12793 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.13522 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17654 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.21057 0.49443 lineto
0.213 0.49443 lineto
0.21543 0.49443 lineto
0.21786 0.49443 lineto
0.22272 0.49443 lineto
0.22515 0.49443 lineto
0.22758 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
0.24216 0.49443 lineto
0.24702 0.49443 lineto
0.25188 0.49443 lineto
0.25675 0.49442 lineto
0.26161 0.49442 lineto
0.26647 0.49442 lineto
0.27133 0.49442 lineto
0.27619 0.49442 lineto
0.28105 0.49442 lineto
Mistroke
0.28591 0.49441 lineto
0.29077 0.49441 lineto
0.29563 0.4944 lineto
0.3005 0.49439 lineto
0.30536 0.49438 lineto
0.31022 0.49437 lineto
0.31508 0.49435 lineto
0.31994 0.49432 lineto
0.3248 0.49429 lineto
0.32966 0.49425 lineto
0.33452 0.4942 lineto
0.33938 0.49414 lineto
0.34425 0.49406 lineto
0.34911 0.49396 lineto
0.35397 0.49384 lineto
0.35883 0.49369 lineto
0.36369 0.4935 lineto
0.37341 0.49299 lineto
0.37827 0.49264 lineto
0.38313 0.49223 lineto
0.39286 0.49112 lineto
0.40258 0.48957 lineto
0.4123 0.48743 lineto
0.42202 0.4846 lineto
0.43175 0.48098 lineto
0.45119 0.47126 lineto
0.47063 0.45865 lineto
0.50952 0.42861 lineto
0.54841 0.39722 lineto
0.5873 0.367 lineto
0.62619 0.3385 lineto
0.66508 0.31168 lineto
0.70397 0.28641 lineto
0.74286 0.26254 lineto
0.78175 0.23992 lineto
0.82063 0.21844 lineto
0.85952 0.19797 lineto
0.89841 0.17844 lineto
0.9373 0.15976 lineto
0.97619 0.14185 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 8)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.05258 0.49443 lineto
0.0623 0.49443 lineto
0.06473 0.49443 lineto
0.06716 0.49443 lineto
0.06838 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07567 0.49443 lineto
0.07688 0.49443 lineto
0.0781 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08904 0.49443 lineto
0.09025 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09511 0.49443 lineto
0.09633 0.49443 lineto
0.09754 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10241 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.1097 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
0.11456 0.49443 lineto
0.11577 0.49443 lineto
0.1182 0.49443 lineto
0.11942 0.49443 lineto
0.12063 0.49443 lineto
0.12185 0.49443 lineto
Mistroke
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12671 0.49443 lineto
0.12793 0.49443 lineto
0.12914 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.134 0.49443 lineto
0.13522 0.49443 lineto
0.13643 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14129 0.49443 lineto
0.14251 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.1498 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17654 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19112 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.20813 0.49443 lineto
0.21057 0.49443 lineto
0.213 0.49443 lineto
0.21543 0.49443 lineto
0.21786 0.49443 lineto
0.22272 0.49443 lineto
0.22515 0.49443 lineto
0.22758 0.49443 lineto
0.23001 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
Mistroke
0.23973 0.49443 lineto
0.24216 0.49443 lineto
0.24459 0.49443 lineto
0.24702 0.49443 lineto
0.25188 0.49443 lineto
0.25432 0.49443 lineto
0.25675 0.49443 lineto
0.26161 0.49443 lineto
0.26647 0.49443 lineto
0.27133 0.49443 lineto
0.27619 0.49442 lineto
0.28105 0.49442 lineto
0.28591 0.49442 lineto
0.29077 0.49442 lineto
0.29563 0.49442 lineto
0.3005 0.49441 lineto
0.30536 0.49441 lineto
0.31022 0.4944 lineto
0.31508 0.49439 lineto
0.31994 0.49438 lineto
0.3248 0.49436 lineto
0.32966 0.49433 lineto
0.33452 0.4943 lineto
0.33938 0.49426 lineto
0.34425 0.49421 lineto
0.34911 0.49415 lineto
0.35397 0.49406 lineto
0.35883 0.49395 lineto
0.36369 0.49381 lineto
0.36855 0.49364 lineto
0.37341 0.49342 lineto
0.37827 0.49314 lineto
0.38313 0.49279 lineto
0.388 0.49236 lineto
0.39286 0.49183 lineto
0.40258 0.49039 lineto
0.40744 0.48944 lineto
0.4123 0.48831 lineto
0.42202 0.48541 lineto
0.43175 0.48154 lineto
0.45119 0.47065 lineto
0.47063 0.45607 lineto
0.50952 0.42128 lineto
0.54841 0.38542 lineto
0.5873 0.35121 lineto
0.62619 0.31906 lineto
0.66508 0.28886 lineto
0.70397 0.26042 lineto
0.74286 0.23356 lineto
0.78175 0.20811 lineto
Mistroke
0.82063 0.18394 lineto
0.85952 0.16092 lineto
0.89841 0.13894 lineto
0.9373 0.11792 lineto
0.97619 0.09778 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 9)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.01905 0.49443 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(10)] 0.21429 0.48193 0 1 Msboxa
[(20)] 0.40476 0.48193 0 1 Msboxa
[(30)] 0.59524 0.48193 0 1 Msboxa
[(40)] 0.78571 0.48193 0 1 Msboxa
[(50)] 0.97619 0.48193 0 1 Msboxa
[(-80)] 0.01131 0 1 0 Msboxa
[(-60)] 0.01131 0.12361 1 0 Msboxa
[(-40)] 0.01131 0.24721 1 0 Msboxa
[(-20)] 0.01131 0.37082 1 0 Msboxa
[(20)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.49443 moveto
1 0.49443 lineto
stroke
0.21429 0.48818 moveto
0.21429 0.50068 lineto
stroke
0 setgray
[(10)] 0.21429 0.48193 0 1 Mshowa
0.40476 0.48818 moveto
0.40476 0.50068 lineto
stroke
0 setgray
[(20)] 0.40476 0.48193 0 1 Mshowa
0.59524 0.48818 moveto
0.59524 0.50068 lineto
stroke
0 setgray
[(30)] 0.59524 0.48193 0 1 Mshowa
0.78571 0.48818 moveto
0.78571 0.50068 lineto
stroke
0 setgray
[(40)] 0.78571 0.48193 0 1 Mshowa
0.97619 0.48818 moveto
0.97619 0.50068 lineto
stroke
0 setgray
[(50)] 0.97619 0.48193 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-80)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-60)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-40)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-20)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.61803 moveto
0.03006 0.61803 lineto
stroke
0 setgray
[(20)] 0.01131 0.61803 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.04286 0.49443 moveto
0.04407 0.49443 lineto
0.04529 0.49443 lineto
0.0465 0.49443 lineto
0.04772 0.49443 lineto
0.04893 0.49443 lineto
0.05015 0.49443 lineto
0.05136 0.49443 lineto
0.05258 0.49443 lineto
0.05501 0.49443 lineto
0.05623 0.49443 lineto
0.05744 0.49443 lineto
0.0623 0.49443 lineto
0.06716 0.49443 lineto
0.06959 0.49443 lineto
0.07081 0.49443 lineto
0.07202 0.49443 lineto
0.07324 0.49443 lineto
0.07445 0.49443 lineto
0.07688 0.49443 lineto
0.07932 0.49443 lineto
0.08053 0.49443 lineto
0.08175 0.49443 lineto
0.08296 0.49443 lineto
0.08418 0.49443 lineto
0.08539 0.49443 lineto
0.08661 0.49443 lineto
0.08782 0.49443 lineto
0.08904 0.49443 lineto
0.09025 0.49443 lineto
0.09147 0.49443 lineto
0.09268 0.49443 lineto
0.0939 0.49443 lineto
0.09633 0.49443 lineto
0.09876 0.49443 lineto
0.09998 0.49443 lineto
0.10119 0.49443 lineto
0.10362 0.49443 lineto
0.10484 0.49443 lineto
0.10605 0.49443 lineto
0.10727 0.49443 lineto
0.10848 0.49443 lineto
0.11091 0.49443 lineto
0.11213 0.49443 lineto
0.11334 0.49443 lineto
0.11456 0.49443 lineto
0.11577 0.49443 lineto
0.11699 0.49443 lineto
0.1182 0.49443 lineto
0.11942 0.49443 lineto
Mistroke
0.12063 0.49443 lineto
0.12185 0.49443 lineto
0.12307 0.49443 lineto
0.1255 0.49443 lineto
0.12671 0.49443 lineto
0.12793 0.49443 lineto
0.12914 0.49443 lineto
0.13036 0.49443 lineto
0.13279 0.49443 lineto
0.134 0.49443 lineto
0.13522 0.49443 lineto
0.13643 0.49443 lineto
0.13765 0.49443 lineto
0.14008 0.49443 lineto
0.14129 0.49443 lineto
0.14251 0.49443 lineto
0.14373 0.49443 lineto
0.14494 0.49443 lineto
0.14737 0.49443 lineto
0.14859 0.49443 lineto
0.1498 0.49443 lineto
0.15102 0.49443 lineto
0.15223 0.49443 lineto
0.15466 0.49443 lineto
0.15588 0.49443 lineto
0.15709 0.49443 lineto
0.15952 0.49443 lineto
0.16195 0.49443 lineto
0.16438 0.49443 lineto
0.16682 0.49443 lineto
0.16925 0.49443 lineto
0.17168 0.49443 lineto
0.17411 0.49443 lineto
0.17654 0.49443 lineto
0.17897 0.49443 lineto
0.1814 0.49443 lineto
0.18383 0.49443 lineto
0.18626 0.49443 lineto
0.18869 0.49443 lineto
0.19112 0.49443 lineto
0.19355 0.49443 lineto
0.19598 0.49443 lineto
0.19841 0.49443 lineto
0.20084 0.49443 lineto
0.20327 0.49443 lineto
0.2057 0.49443 lineto
0.20813 0.49443 lineto
0.21057 0.49443 lineto
0.213 0.49443 lineto
0.21543 0.49443 lineto
Mistroke
0.21786 0.49443 lineto
0.22029 0.49443 lineto
0.22272 0.49443 lineto
0.22515 0.49443 lineto
0.22758 0.49443 lineto
0.23001 0.49443 lineto
0.23244 0.49443 lineto
0.2373 0.49443 lineto
0.23973 0.49443 lineto
0.24216 0.49443 lineto
0.24459 0.49443 lineto
0.24702 0.49443 lineto
0.25188 0.49443 lineto
0.25432 0.49443 lineto
0.25675 0.49443 lineto
0.25918 0.49443 lineto
0.26161 0.49443 lineto
0.26647 0.49443 lineto
0.2689 0.49443 lineto
0.27133 0.49443 lineto
0.27376 0.49443 lineto
0.27619 0.49443 lineto
0.28105 0.49443 lineto
0.28348 0.49443 lineto
0.28591 0.49442 lineto
0.29077 0.49442 lineto
0.29563 0.49442 lineto
0.3005 0.49442 lineto
0.30536 0.49442 lineto
0.31022 0.49441 lineto
0.31508 0.49441 lineto
0.31994 0.4944 lineto
0.3248 0.49439 lineto
0.32966 0.49438 lineto
0.33452 0.49436 lineto
0.33938 0.49433 lineto
0.34425 0.4943 lineto
0.34911 0.49426 lineto
0.35397 0.4942 lineto
0.35883 0.49412 lineto
0.36369 0.49402 lineto
0.36855 0.49389 lineto
0.37341 0.49372 lineto
0.37827 0.4935 lineto
0.38313 0.49322 lineto
0.388 0.49285 lineto
0.39286 0.49239 lineto
0.40258 0.49109 lineto
0.40744 0.49019 lineto
0.4123 0.48909 lineto
Mistroke
0.42202 0.48616 lineto
0.43175 0.48208 lineto
0.44147 0.4767 lineto
0.45119 0.47002 lineto
0.47063 0.45341 lineto
0.50952 0.41381 lineto
0.54841 0.37353 lineto
0.5873 0.33537 lineto
0.62619 0.29959 lineto
0.66508 0.26602 lineto
0.70397 0.23442 lineto
0.74286 0.20458 lineto
0.78175 0.1763 lineto
0.82063 0.14944 lineto
0.85952 0.12386 lineto
0.89841 0.09944 lineto
0.9373 0.07609 lineto
0.97619 0.05371 lineto
Mfstroke
grestore
grestore
grestore
gsave
0 setgray
[(order = 10)] 0.21429 0.12361 -1 0 Mshowa
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Generating the animation
:[font = text; inactive; ]
		The following function generates a lowpass Butterworth filter of order i and caches time-domain expressions returned by AnalogFilter:
:[font = input; initialization; ]
*)
blpfilter[i_] :=
	blpfilter[i] =
		AnalogFilter[Butterworth, t, i, bepsilon, bA, 7/8, 22]
(*
:[font = text; inactive; ]
The following function computes the frequency response (as a function of w) of the lowpass Butterworth filters calculated by blpfilter and caches the frequency-domain expressions returned by CTFTransform:
:[font = input; initialization; ]
*)
blpfreqresp[i_] :=
	blpfreqresp[i] =
		TheFunction[ CTFTransform[blpfilter[i], t, w] ]
(*
:[font = text; inactive; ]
The following code generates the nine graphics cells grouped for the animation (remember that MagPhasePlot returns a list of two plots, magnitude and phase) :
:[font = input; endGroup; endGroup; ]
Block[ {order, orderstr, plots},
	For[ order = 2, order <= 10, order++,
		 orderstr = ToString[StringForm["order = ``", order]];
		 plots = MagPhasePlot[ blpfreqresp[order],
						       {w, 1, 50},
						       DisplayFunction -> Identity,
						       MagRangeScale -> Log,
						       PhaseRangeScale -> Null,
						       PlotRange -> { -80, 20 } ];
		 Show [ First[plots],
				Graphics[ Text[orderstr, {10, -60}, {-1, 0}] ],
				Graphics[ Point[{0, -80}] ],
				PlotLabel -> "Magnitude Response (dB)",
				PlotRange -> { -80, 20 },
				DisplayFunction :> $DisplayFunction ] ] ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Ripple Control Parameter
:[font = text; inactive; ]
		All five classical classes of filters have a ripple parameter (called Eripple in the definition of FilterParameters), but only elliptic filters and Chebyshev filters have magnitude responses that ripple.   The ripple control parameter scales the rippling effect.  In both animations below, we examine the effect of the ripple control parameter on the magnitude response of a bandpass elliptic filter that passes frequencies between 30 and 70 rad/sec and rejects those below 10 rad/sec and above 90 rad/sec.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Animation of passband response with varying ripple and fixed filter order
:[font = text; inactive; ]
		This sequence of frames demonstrates the effect of changing the allowable ripple in a bandpass elliptic analog filter while keeping the filter order constant.  The magnitude responses of the following bandpass filters corresponding to maximum ripples of 0.06 to 0.15 at increments of 0.01:
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -9.76036 moveto
0.026 -8.64213 lineto
0.02724 -8.04079 lineto
0.02848 -7.62706 lineto
0.02972 -7.31132 lineto
0.03219 -6.84157 lineto
0.03467 -6.49452 lineto
0.03715 -6.21926 lineto
0.03963 -5.9912 lineto
0.04458 -5.62691 lineto
0.05449 -5.10755 lineto
0.0644 -4.73788 lineto
0.07432 -4.45275 lineto
0.08423 -4.22273 lineto
0.10405 -3.87206 lineto
0.12387 -3.62333 lineto
0.13378 -3.52989 lineto
0.14369 -3.45627 lineto
0.14865 -3.42719 lineto
0.1536 -3.40362 lineto
0.15608 -3.39402 lineto
0.15856 -3.38596 lineto
0.16103 -3.37952 lineto
0.16227 -3.37693 lineto
0.16351 -3.37478 lineto
0.16475 -3.37309 lineto
0.16599 -3.37186 lineto
0.16723 -3.3711 lineto
0.16847 -3.37085 lineto
0.16971 -3.3711 lineto
0.17094 -3.37189 lineto
0.17218 -3.37323 lineto
0.17342 -3.37515 lineto
0.1759 -3.38079 lineto
0.17714 -3.38457 lineto
0.17838 -3.38903 lineto
0.18086 -3.4001 lineto
0.18333 -3.4143 lineto
0.18581 -3.43193 lineto
0.18829 -3.45342 lineto
0.19324 -3.50987 lineto
0.1982 -3.58872 lineto
0.20315 -3.69766 lineto
0.20563 -3.76703 lineto
0.20811 -3.84916 lineto
0.21307 -4.06526 lineto
0.21554 -4.20985 lineto
0.21802 -4.39064 lineto
0.2205 -4.62387 lineto
0.22298 -4.93972 lineto
Mistroke
0.22422 -5.14658 lineto
0.22545 -5.40482 lineto
0.22669 -5.74314 lineto
0.22793 -6.22385 lineto
0.22917 -7.03162 lineto
0.23041 -9.73566 lineto
0.23165 -7.3713 lineto
0.23289 -6.29505 lineto
0.23413 -5.68212 lineto
0.23536 -5.2452 lineto
0.23784 -4.61633 lineto
0.24032 -4.15318 lineto
0.2428 -3.77899 lineto
0.25271 -2.69057 lineto
0.26262 -1.88221 lineto
0.28244 -0.5659 lineto
0.29235 -0.0249 lineto
0.29731 0.19591 lineto
0.30226 0.37064 lineto
0.30474 0.43887 lineto
0.30722 0.49432 lineto
0.30969 0.53762 lineto
0.31093 0.55504 lineto
0.31217 0.56987 lineto
0.31341 0.58229 lineto
0.31465 0.59249 lineto
0.31589 0.60067 lineto
0.31713 0.60702 lineto
0.31837 0.61175 lineto
0.31961 0.61503 lineto
0.32084 0.61704 lineto
0.32208 0.61794 lineto
0.32332 0.6179 lineto
0.32456 0.61705 lineto
0.3258 0.61551 lineto
0.32704 0.61342 lineto
0.33199 0.60127 lineto
0.3419 0.57208 lineto
0.34686 0.55947 lineto
0.35182 0.5494 lineto
0.35429 0.54539 lineto
0.35677 0.54207 lineto
0.35925 0.53942 lineto
0.36049 0.53834 lineto
0.36173 0.53742 lineto
0.36297 0.53665 lineto
0.3642 0.53604 lineto
0.36544 0.53557 lineto
0.36668 0.53524 lineto
0.36792 0.53505 lineto
Mistroke
0.36916 0.53499 lineto
0.3704 0.53506 lineto
0.37164 0.53526 lineto
0.37288 0.53557 lineto
0.37411 0.53599 lineto
0.37659 0.53715 lineto
0.37907 0.53871 lineto
0.38155 0.54062 lineto
0.39146 0.55103 lineto
0.40137 0.56424 lineto
0.42119 0.59159 lineto
0.4311 0.60291 lineto
0.44101 0.61137 lineto
0.44597 0.61436 lineto
0.44844 0.61553 lineto
0.45092 0.61648 lineto
0.45216 0.61686 lineto
0.4534 0.6172 lineto
0.45464 0.61747 lineto
0.45588 0.61769 lineto
0.45712 0.61786 lineto
0.45836 0.61797 lineto
0.45959 0.61803 lineto
0.46083 0.61803 lineto
0.46207 0.61798 lineto
0.46331 0.61787 lineto
0.46579 0.6175 lineto
0.46703 0.61724 lineto
0.46827 0.61692 lineto
0.47074 0.61615 lineto
0.4757 0.61402 lineto
0.48065 0.61119 lineto
0.49057 0.6037 lineto
0.50048 0.59433 lineto
0.5203 0.57288 lineto
0.53021 0.56225 lineto
0.54012 0.55261 lineto
0.55003 0.54459 lineto
0.55499 0.54135 lineto
0.55994 0.53872 lineto
0.5649 0.53676 lineto
0.56737 0.53604 lineto
0.56861 0.53574 lineto
0.56985 0.5355 lineto
0.57109 0.5353 lineto
0.57233 0.53515 lineto
0.57357 0.53505 lineto
0.57481 0.535 lineto
0.57605 0.535 lineto
0.57728 0.53505 lineto
Mistroke
0.57852 0.53515 lineto
0.57976 0.5353 lineto
0.581 0.5355 lineto
0.58224 0.53576 lineto
0.58472 0.53642 lineto
0.58719 0.5373 lineto
0.58967 0.53839 lineto
0.59463 0.54122 lineto
0.59958 0.5449 lineto
0.60949 0.55473 lineto
0.6194 0.56747 lineto
0.62932 0.58223 lineto
0.63923 0.59744 lineto
0.64914 0.61055 lineto
0.65161 0.61309 lineto
0.65409 0.61518 lineto
0.65533 0.61604 lineto
0.65657 0.61677 lineto
0.65781 0.61734 lineto
0.65905 0.61774 lineto
0.66029 0.61798 lineto
0.66153 0.61803 lineto
0.66276 0.61788 lineto
0.664 0.61752 lineto
0.66524 0.61694 lineto
0.66648 0.61613 lineto
0.66772 0.61506 lineto
0.66896 0.61373 lineto
0.67144 0.61024 lineto
0.67391 0.60552 lineto
0.67639 0.59949 lineto
0.67887 0.59202 lineto
0.68382 0.57236 lineto
0.68878 0.54579 lineto
0.69374 0.5117 lineto
0.69869 0.46968 lineto
0.7086 0.36149 lineto
0.71851 0.22306 lineto
0.73833 -0.12306 lineto
0.77798 -0.93968 lineto
0.81762 -1.79791 lineto
0.85726 -2.72351 lineto
0.87708 -3.25671 lineto
0.8969 -3.8964 lineto
0.90682 -4.2901 lineto
0.91673 -4.77497 lineto
0.92168 -5.07363 lineto
0.92664 -5.43401 lineto
0.93159 -5.89594 lineto
0.93407 -6.19039 lineto
Mistroke
0.93655 -6.55629 lineto
0.93779 -6.77994 lineto
0.93903 -7.04441 lineto
0.9415 -7.79127 lineto
0.94274 -8.40015 lineto
0.94398 -9.52145 lineto
0.94522 -11.19027 lineto
0.94646 -8.92519 lineto
0.9477 -8.13329 lineto
0.94894 -7.64417 lineto
0.95017 -7.29069 lineto
0.95141 -7.01454 lineto
0.95389 -6.5974 lineto
0.95637 -6.28712 lineto
0.96132 -5.83871 lineto
0.96628 -5.51855 lineto
0.97124 -5.27232 lineto
0.97619 -5.07415 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.06)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -9.87468 moveto
0.026 -8.75646 lineto
0.02724 -8.15511 lineto
0.02848 -7.74138 lineto
0.02972 -7.42564 lineto
0.03219 -6.95589 lineto
0.03467 -6.60884 lineto
0.03715 -6.33358 lineto
0.03963 -6.10552 lineto
0.04458 -5.74122 lineto
0.05449 -5.22186 lineto
0.0644 -4.85217 lineto
0.07432 -4.56702 lineto
0.08423 -4.33698 lineto
0.10405 -3.98625 lineto
0.12387 -3.73747 lineto
0.13378 -3.644 lineto
0.14369 -3.57036 lineto
0.14865 -3.54126 lineto
0.1536 -3.51768 lineto
0.15608 -3.50808 lineto
0.15856 -3.50002 lineto
0.16103 -3.49357 lineto
0.16227 -3.49098 lineto
0.16351 -3.48884 lineto
0.16475 -3.48714 lineto
0.16599 -3.4859 lineto
0.16723 -3.48515 lineto
0.16847 -3.4849 lineto
0.16971 -3.48515 lineto
0.17094 -3.48594 lineto
0.17218 -3.48728 lineto
0.17342 -3.4892 lineto
0.1759 -3.49485 lineto
0.17714 -3.49863 lineto
0.17838 -3.50309 lineto
0.18086 -3.51416 lineto
0.18333 -3.52836 lineto
0.18581 -3.54601 lineto
0.18829 -3.5675 lineto
0.19324 -3.62397 lineto
0.1982 -3.70285 lineto
0.20315 -3.81182 lineto
0.20563 -3.8812 lineto
0.20811 -3.96335 lineto
0.21307 -4.17949 lineto
0.21554 -4.32409 lineto
0.21802 -4.5049 lineto
0.2205 -4.73815 lineto
0.22298 -5.05402 lineto
Mistroke
0.22422 -5.26088 lineto
0.22545 -5.51913 lineto
0.22669 -5.85746 lineto
0.22793 -6.33817 lineto
0.22917 -7.14594 lineto
0.23041 -9.84998 lineto
0.23165 -7.48563 lineto
0.23289 -6.40937 lineto
0.23413 -5.79643 lineto
0.23536 -5.35951 lineto
0.23784 -4.73061 lineto
0.24032 -4.26742 lineto
0.2428 -3.89316 lineto
0.25271 -2.80414 lineto
0.26262 -1.994 lineto
0.28244 -0.66197 lineto
0.29235 -0.09763 lineto
0.29731 0.1401 lineto
0.30226 0.33327 lineto
0.30474 0.41029 lineto
0.30722 0.47365 lineto
0.30969 0.52368 lineto
0.31217 0.56129 lineto
0.31341 0.57585 lineto
0.31465 0.58785 lineto
0.31589 0.59749 lineto
0.31713 0.605 lineto
0.31837 0.61059 lineto
0.31961 0.61447 lineto
0.32084 0.61685 lineto
0.32208 0.61793 lineto
0.32332 0.61788 lineto
0.32456 0.61687 lineto
0.3258 0.61505 lineto
0.32704 0.61256 lineto
0.33199 0.59821 lineto
0.3419 0.56388 lineto
0.34686 0.54914 lineto
0.35182 0.53739 lineto
0.35429 0.53272 lineto
0.35677 0.52886 lineto
0.35925 0.52578 lineto
0.36049 0.52453 lineto
0.36173 0.52346 lineto
0.36297 0.52257 lineto
0.3642 0.52185 lineto
0.36544 0.52131 lineto
0.36668 0.52093 lineto
0.36792 0.52071 lineto
0.36916 0.52064 lineto
Mistroke
0.3704 0.52072 lineto
0.37164 0.52095 lineto
0.37288 0.52131 lineto
0.37411 0.5218 lineto
0.37659 0.52315 lineto
0.37907 0.52496 lineto
0.38155 0.52717 lineto
0.39146 0.53929 lineto
0.40137 0.5547 lineto
0.42119 0.58679 lineto
0.4311 0.60013 lineto
0.44101 0.61014 lineto
0.44597 0.61369 lineto
0.44844 0.61507 lineto
0.45092 0.61619 lineto
0.45216 0.61665 lineto
0.4534 0.61704 lineto
0.45464 0.61737 lineto
0.45588 0.61763 lineto
0.45712 0.61783 lineto
0.45836 0.61796 lineto
0.45959 0.61803 lineto
0.46083 0.61803 lineto
0.46207 0.61796 lineto
0.46331 0.61784 lineto
0.46579 0.6174 lineto
0.46703 0.61709 lineto
0.46827 0.61672 lineto
0.47074 0.6158 lineto
0.4757 0.61328 lineto
0.48065 0.60993 lineto
0.49057 0.60107 lineto
0.50048 0.59002 lineto
0.5203 0.56481 lineto
0.53021 0.55238 lineto
0.54012 0.54114 lineto
0.55003 0.53179 lineto
0.55499 0.52803 lineto
0.55994 0.52497 lineto
0.5649 0.52269 lineto
0.56737 0.52185 lineto
0.56861 0.52151 lineto
0.56985 0.52123 lineto
0.57109 0.521 lineto
0.57233 0.52083 lineto
0.57357 0.52071 lineto
0.57481 0.52065 lineto
0.57605 0.52065 lineto
0.57728 0.5207 lineto
0.57852 0.52082 lineto
Mistroke
0.57976 0.52099 lineto
0.581 0.52123 lineto
0.58224 0.52153 lineto
0.58472 0.5223 lineto
0.58719 0.52332 lineto
0.58967 0.52459 lineto
0.59463 0.52787 lineto
0.59958 0.53215 lineto
0.60949 0.5436 lineto
0.6194 0.55848 lineto
0.62932 0.57578 lineto
0.63923 0.59368 lineto
0.64914 0.60917 lineto
0.65161 0.61217 lineto
0.65409 0.61466 lineto
0.65533 0.61568 lineto
0.65657 0.61653 lineto
0.65781 0.61721 lineto
0.65905 0.61769 lineto
0.66029 0.61797 lineto
0.66153 0.61803 lineto
0.66276 0.61785 lineto
0.664 0.61743 lineto
0.66524 0.61674 lineto
0.66648 0.61577 lineto
0.66772 0.61451 lineto
0.66896 0.61294 lineto
0.67144 0.6088 lineto
0.67391 0.60322 lineto
0.67639 0.5961 lineto
0.67887 0.58729 lineto
0.68382 0.56421 lineto
0.68878 0.53319 lineto
0.69869 0.4454 lineto
0.7086 0.32301 lineto
0.71851 0.16978 lineto
0.73833 -0.20161 lineto
0.77798 -1.0436 lineto
0.81762 -1.90936 lineto
0.85726 -2.83711 lineto
0.87708 -3.3707 lineto
0.8969 -4.0106 lineto
0.90682 -4.40435 lineto
0.91673 -4.88926 lineto
0.92168 -5.18793 lineto
0.92664 -5.54832 lineto
0.93159 -6.01026 lineto
0.93407 -6.30471 lineto
0.93655 -6.67061 lineto
0.93779 -6.89426 lineto
Mistroke
0.93903 -7.15873 lineto
0.9415 -7.90559 lineto
0.94274 -8.51447 lineto
0.94398 -9.63578 lineto
0.94522 -11.3046 lineto
0.94646 -9.03951 lineto
0.9477 -8.24761 lineto
0.94894 -7.7585 lineto
0.95017 -7.40501 lineto
0.95141 -7.12887 lineto
0.95389 -6.71173 lineto
0.95637 -6.40145 lineto
0.96132 -5.95302 lineto
0.96628 -5.63287 lineto
0.97124 -5.38662 lineto
0.97619 -5.18845 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.07)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -9.97531 moveto
0.026 -8.85708 lineto
0.02724 -8.25574 lineto
0.02848 -7.842 lineto
0.02972 -7.52627 lineto
0.03219 -7.05652 lineto
0.03467 -6.70946 lineto
0.03715 -6.4342 lineto
0.03963 -6.20614 lineto
0.04458 -5.84184 lineto
0.05449 -5.32247 lineto
0.0644 -4.95277 lineto
0.07432 -4.66761 lineto
0.08423 -4.43755 lineto
0.10405 -4.08678 lineto
0.12387 -3.83795 lineto
0.13378 -3.74446 lineto
0.14369 -3.6708 lineto
0.14865 -3.6417 lineto
0.1536 -3.61811 lineto
0.15608 -3.6085 lineto
0.15856 -3.60044 lineto
0.16103 -3.59399 lineto
0.16227 -3.59141 lineto
0.16351 -3.58926 lineto
0.16475 -3.58756 lineto
0.16599 -3.58632 lineto
0.16723 -3.58557 lineto
0.16847 -3.58531 lineto
0.16971 -3.58557 lineto
0.17094 -3.58636 lineto
0.17218 -3.5877 lineto
0.17342 -3.58962 lineto
0.1759 -3.59527 lineto
0.17714 -3.59905 lineto
0.17838 -3.60351 lineto
0.18086 -3.61459 lineto
0.18333 -3.62879 lineto
0.18581 -3.64644 lineto
0.18829 -3.66794 lineto
0.19324 -3.72443 lineto
0.1982 -3.80332 lineto
0.20315 -3.91232 lineto
0.20563 -3.98171 lineto
0.20811 -4.06387 lineto
0.21307 -4.28004 lineto
0.21554 -4.42466 lineto
0.21802 -4.60548 lineto
0.2205 -4.83875 lineto
0.22298 -5.15463 lineto
Mistroke
0.22422 -5.36149 lineto
0.22545 -5.61974 lineto
0.22669 -5.95808 lineto
0.22793 -6.43879 lineto
0.22917 -7.24657 lineto
0.23041 -9.95061 lineto
0.23165 -7.58625 lineto
0.23289 -6.51 lineto
0.23413 -5.89705 lineto
0.23536 -5.46012 lineto
0.23784 -4.8312 lineto
0.24032 -4.36798 lineto
0.2428 -3.99367 lineto
0.25271 -2.90419 lineto
0.26262 -2.09272 lineto
0.28244 -0.74858 lineto
0.29235 -0.1653 lineto
0.29731 0.08695 lineto
0.30226 0.29674 lineto
0.30474 0.38199 lineto
0.30722 0.45296 lineto
0.30969 0.50959 lineto
0.31217 0.55255 lineto
0.31341 0.56927 lineto
0.31465 0.58309 lineto
0.31589 0.59423 lineto
0.31713 0.60291 lineto
0.31837 0.60939 lineto
0.31961 0.6139 lineto
0.32084 0.61666 lineto
0.32208 0.61791 lineto
0.32332 0.61785 lineto
0.32456 0.61668 lineto
0.3258 0.61457 lineto
0.32704 0.61168 lineto
0.33199 0.59505 lineto
0.3419 0.55552 lineto
0.34686 0.53863 lineto
0.35182 0.52521 lineto
0.35429 0.51988 lineto
0.35677 0.51548 lineto
0.35925 0.51198 lineto
0.36049 0.51055 lineto
0.36173 0.50933 lineto
0.36297 0.50832 lineto
0.3642 0.50751 lineto
0.36544 0.50689 lineto
0.36668 0.50646 lineto
0.36792 0.50621 lineto
0.36916 0.50613 lineto
Mistroke
0.3704 0.50622 lineto
0.37164 0.50648 lineto
0.37288 0.50689 lineto
0.37411 0.50745 lineto
0.37659 0.50898 lineto
0.37907 0.51104 lineto
0.38155 0.51357 lineto
0.39146 0.52738 lineto
0.40137 0.545 lineto
0.42119 0.58187 lineto
0.4311 0.59728 lineto
0.44101 0.60888 lineto
0.44597 0.61298 lineto
0.44844 0.61459 lineto
0.45092 0.61589 lineto
0.45216 0.61642 lineto
0.4534 0.61688 lineto
0.45464 0.61726 lineto
0.45588 0.61757 lineto
0.45712 0.61779 lineto
0.45836 0.61795 lineto
0.45959 0.61802 lineto
0.46083 0.61803 lineto
0.46207 0.61795 lineto
0.46331 0.61781 lineto
0.46579 0.6173 lineto
0.46703 0.61694 lineto
0.46827 0.6165 lineto
0.47074 0.61544 lineto
0.4757 0.61252 lineto
0.48065 0.60863 lineto
0.49057 0.59837 lineto
0.50048 0.58559 lineto
0.5203 0.55659 lineto
0.53021 0.54234 lineto
0.54012 0.52948 lineto
0.55003 0.51882 lineto
0.55499 0.51454 lineto
0.55994 0.51106 lineto
0.5649 0.50846 lineto
0.56737 0.50751 lineto
0.56861 0.50712 lineto
0.56985 0.5068 lineto
0.57109 0.50654 lineto
0.57233 0.50634 lineto
0.57357 0.50621 lineto
0.57481 0.50614 lineto
0.57605 0.50614 lineto
0.57728 0.5062 lineto
0.57852 0.50634 lineto
Mistroke
0.57976 0.50653 lineto
0.581 0.5068 lineto
0.58224 0.50714 lineto
0.58472 0.50802 lineto
0.58719 0.50918 lineto
0.58967 0.51062 lineto
0.59463 0.51436 lineto
0.59958 0.51924 lineto
0.60949 0.5323 lineto
0.6194 0.54932 lineto
0.62932 0.56919 lineto
0.63923 0.58983 lineto
0.64914 0.60775 lineto
0.65161 0.61123 lineto
0.65409 0.61411 lineto
0.65533 0.6153 lineto
0.65657 0.61629 lineto
0.65781 0.61707 lineto
0.65905 0.61763 lineto
0.66029 0.61796 lineto
0.66153 0.61803 lineto
0.66276 0.61782 lineto
0.664 0.61733 lineto
0.66524 0.61653 lineto
0.66648 0.61541 lineto
0.66772 0.61394 lineto
0.66896 0.61212 lineto
0.67144 0.60731 lineto
0.67391 0.60086 lineto
0.67639 0.59261 lineto
0.67887 0.58245 lineto
0.68382 0.55589 lineto
0.68878 0.52042 lineto
0.69869 0.42121 lineto
0.7086 0.28547 lineto
0.71851 0.11887 lineto
0.73833 -0.2741 lineto
0.77798 -1.13633 lineto
0.81762 -2.00782 lineto
0.85726 -2.9372 lineto
0.87708 -3.47108 lineto
0.8969 -4.11113 lineto
0.90682 -4.50493 lineto
0.91673 -4.98986 lineto
0.92168 -5.28854 lineto
0.92664 -5.64894 lineto
0.93159 -6.11088 lineto
0.93407 -6.40533 lineto
0.93655 -6.77123 lineto
0.93779 -6.99488 lineto
Mistroke
0.93903 -7.25936 lineto
0.9415 -8.00622 lineto
0.94274 -8.6151 lineto
0.94398 -9.7364 lineto
0.94522 -11.40522 lineto
0.94646 -9.14014 lineto
0.9477 -8.34824 lineto
0.94894 -7.85912 lineto
0.95017 -7.50564 lineto
0.95141 -7.22949 lineto
0.95389 -6.81235 lineto
0.95637 -6.50207 lineto
0.96132 -6.05364 lineto
0.96628 -5.73348 lineto
0.97124 -5.48724 lineto
0.97619 -5.28906 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.08)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.06551 moveto
0.026 -8.94728 lineto
0.02724 -8.34594 lineto
0.02848 -7.9322 lineto
0.02972 -7.61647 lineto
0.03219 -7.14671 lineto
0.03467 -6.79966 lineto
0.03715 -6.5244 lineto
0.03963 -6.29634 lineto
0.04458 -5.93203 lineto
0.05449 -5.41265 lineto
0.0644 -5.04294 lineto
0.07432 -4.75777 lineto
0.08423 -4.5277 lineto
0.10405 -4.1769 lineto
0.12387 -3.92804 lineto
0.13378 -3.83453 lineto
0.14369 -3.76086 lineto
0.14865 -3.73175 lineto
0.1536 -3.70815 lineto
0.15608 -3.69854 lineto
0.15856 -3.69048 lineto
0.16103 -3.68403 lineto
0.16227 -3.68144 lineto
0.16351 -3.67929 lineto
0.16475 -3.67759 lineto
0.16599 -3.67636 lineto
0.16723 -3.67561 lineto
0.16847 -3.67535 lineto
0.16971 -3.67561 lineto
0.17094 -3.6764 lineto
0.17218 -3.67774 lineto
0.17342 -3.67966 lineto
0.1759 -3.68531 lineto
0.17714 -3.68909 lineto
0.17838 -3.69355 lineto
0.18086 -3.70464 lineto
0.18333 -3.71884 lineto
0.18581 -3.7365 lineto
0.18829 -3.758 lineto
0.19324 -3.8145 lineto
0.1982 -3.8934 lineto
0.20315 -4.00241 lineto
0.20563 -4.07182 lineto
0.20811 -4.15399 lineto
0.21307 -4.37018 lineto
0.21554 -4.51481 lineto
0.21802 -4.69564 lineto
0.2205 -4.92892 lineto
0.22298 -5.24481 lineto
Mistroke
0.22422 -5.45168 lineto
0.22545 -5.70994 lineto
0.22669 -6.04827 lineto
0.22793 -6.52899 lineto
0.22917 -7.33676 lineto
0.23041 -10.0408 lineto
0.23165 -7.67645 lineto
0.23289 -6.60019 lineto
0.23413 -5.98724 lineto
0.23536 -5.55031 lineto
0.23784 -4.92138 lineto
0.24032 -4.45813 lineto
0.2428 -4.08378 lineto
0.25271 -2.99395 lineto
0.26262 -2.18143 lineto
0.28244 -0.82767 lineto
0.29235 -0.22871 lineto
0.29731 0.03614 lineto
0.30226 0.26098 lineto
0.30474 0.35395 lineto
0.30722 0.43223 lineto
0.30969 0.49534 lineto
0.31217 0.54363 lineto
0.31341 0.56254 lineto
0.31465 0.57821 lineto
0.31589 0.59087 lineto
0.31713 0.60077 lineto
0.31837 0.60816 lineto
0.31961 0.6133 lineto
0.32084 0.61647 lineto
0.32208 0.61789 lineto
0.32332 0.61782 lineto
0.32456 0.61648 lineto
0.3258 0.61407 lineto
0.32704 0.61077 lineto
0.33199 0.59181 lineto
0.3419 0.54698 lineto
0.34686 0.52794 lineto
0.35182 0.51285 lineto
0.35429 0.50687 lineto
0.35677 0.50194 lineto
0.35925 0.49801 lineto
0.36049 0.49641 lineto
0.36173 0.49505 lineto
0.36297 0.49392 lineto
0.3642 0.49301 lineto
0.36544 0.49231 lineto
0.36668 0.49183 lineto
0.36792 0.49155 lineto
0.36916 0.49147 lineto
Mistroke
0.3704 0.49157 lineto
0.37164 0.49185 lineto
0.37288 0.49231 lineto
0.37411 0.49294 lineto
0.37659 0.49466 lineto
0.37907 0.49696 lineto
0.38155 0.49979 lineto
0.39146 0.51529 lineto
0.40137 0.53511 lineto
0.42119 0.57682 lineto
0.4311 0.59435 lineto
0.44101 0.60757 lineto
0.44597 0.61226 lineto
0.44844 0.61409 lineto
0.45092 0.61558 lineto
0.45216 0.61619 lineto
0.4534 0.61671 lineto
0.45464 0.61715 lineto
0.45588 0.6175 lineto
0.45712 0.61776 lineto
0.45836 0.61793 lineto
0.45959 0.61802 lineto
0.46083 0.61802 lineto
0.46207 0.61794 lineto
0.46331 0.61777 lineto
0.46579 0.61719 lineto
0.46703 0.61678 lineto
0.46827 0.61628 lineto
0.47074 0.61506 lineto
0.4757 0.61172 lineto
0.48065 0.60728 lineto
0.49057 0.59558 lineto
0.50048 0.58105 lineto
0.5203 0.54819 lineto
0.53021 0.53212 lineto
0.54012 0.51765 lineto
0.55003 0.50568 lineto
0.55499 0.50088 lineto
0.55994 0.49698 lineto
0.5649 0.49407 lineto
0.56737 0.493 lineto
0.56861 0.49257 lineto
0.56985 0.49221 lineto
0.57109 0.49192 lineto
0.57233 0.4917 lineto
0.57357 0.49155 lineto
0.57481 0.49148 lineto
0.57605 0.49147 lineto
0.57728 0.49155 lineto
0.57852 0.49169 lineto
Mistroke
0.57976 0.49191 lineto
0.581 0.49221 lineto
0.58224 0.49259 lineto
0.58472 0.49358 lineto
0.58719 0.49487 lineto
0.58967 0.49649 lineto
0.59463 0.50068 lineto
0.59958 0.50615 lineto
0.60949 0.52082 lineto
0.6194 0.53999 lineto
0.62932 0.56245 lineto
0.63923 0.58586 lineto
0.64914 0.60628 lineto
0.65161 0.61026 lineto
0.65409 0.61355 lineto
0.65533 0.6149 lineto
0.65657 0.61604 lineto
0.65781 0.61693 lineto
0.65905 0.61758 lineto
0.66029 0.61795 lineto
0.66153 0.61803 lineto
0.66276 0.61779 lineto
0.664 0.61723 lineto
0.66524 0.61632 lineto
0.66648 0.61503 lineto
0.66772 0.61336 lineto
0.66896 0.61127 lineto
0.67144 0.60579 lineto
0.67391 0.59842 lineto
0.67639 0.58903 lineto
0.67887 0.57748 lineto
0.68382 0.54741 lineto
0.68878 0.50747 lineto
0.69869 0.39711 lineto
0.7086 0.24876 lineto
0.71851 0.07003 lineto
0.73833 -0.34159 lineto
0.77798 -1.22032 lineto
0.81762 -2.09633 lineto
0.85726 -3.02697 lineto
0.87708 -3.56109 lineto
0.8969 -4.20126 lineto
0.90682 -4.59508 lineto
0.91673 -5.08004 lineto
0.92168 -5.37873 lineto
0.92664 -5.73913 lineto
0.93159 -6.20107 lineto
0.93407 -6.49553 lineto
0.93655 -6.86143 lineto
0.93779 -7.08508 lineto
Mistroke
0.93903 -7.34955 lineto
0.9415 -8.09642 lineto
0.94274 -8.7053 lineto
0.94398 -9.8266 lineto
0.94522 -11.49542 lineto
0.94646 -9.23034 lineto
0.9477 -8.43844 lineto
0.94894 -7.94932 lineto
0.95017 -7.59584 lineto
0.95141 -7.31969 lineto
0.95389 -6.90255 lineto
0.95637 -6.59226 lineto
0.96132 -6.14384 lineto
0.96628 -5.82367 lineto
0.97124 -5.57743 lineto
0.97619 -5.37924 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.09)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.14751 moveto
0.026 -9.02929 lineto
0.02724 -8.42794 lineto
0.02848 -8.01421 lineto
0.02972 -7.69847 lineto
0.03219 -7.22872 lineto
0.03467 -6.88166 lineto
0.03715 -6.6064 lineto
0.03963 -6.37834 lineto
0.04458 -6.01404 lineto
0.05449 -5.49465 lineto
0.0644 -5.12493 lineto
0.07432 -4.83975 lineto
0.08423 -4.60967 lineto
0.10405 -4.25885 lineto
0.12387 -4.00996 lineto
0.13378 -3.91644 lineto
0.14369 -3.84275 lineto
0.14865 -3.81364 lineto
0.1536 -3.79004 lineto
0.15608 -3.78043 lineto
0.15856 -3.77236 lineto
0.16103 -3.76591 lineto
0.16227 -3.76332 lineto
0.16351 -3.76117 lineto
0.16475 -3.75947 lineto
0.16599 -3.75824 lineto
0.16723 -3.75749 lineto
0.16847 -3.75723 lineto
0.16971 -3.75749 lineto
0.17094 -3.75828 lineto
0.17218 -3.75962 lineto
0.17342 -3.76154 lineto
0.1759 -3.76719 lineto
0.17714 -3.77097 lineto
0.17838 -3.77543 lineto
0.18086 -3.78652 lineto
0.18333 -3.80073 lineto
0.18581 -3.81838 lineto
0.18829 -3.83989 lineto
0.19324 -3.8964 lineto
0.1982 -3.97532 lineto
0.20315 -4.08434 lineto
0.20563 -4.15375 lineto
0.20811 -4.23593 lineto
0.21307 -4.45214 lineto
0.21554 -4.59678 lineto
0.21802 -4.77762 lineto
0.2205 -5.01091 lineto
0.22298 -5.3268 lineto
Mistroke
0.22422 -5.53368 lineto
0.22545 -5.79194 lineto
0.22669 -6.13027 lineto
0.22793 -6.61099 lineto
0.22917 -7.41877 lineto
0.23041 -10.12281 lineto
0.23165 -7.75846 lineto
0.23289 -6.6822 lineto
0.23413 -6.06925 lineto
0.23536 -5.6323 lineto
0.23784 -5.00336 lineto
0.24032 -4.5401 lineto
0.2428 -4.16572 lineto
0.25271 -3.0756 lineto
0.26262 -2.26224 lineto
0.28244 -0.90067 lineto
0.29235 -0.28849 lineto
0.29731 -0.01263 lineto
0.30226 0.22592 lineto
0.30474 0.32615 lineto
0.30722 0.41145 lineto
0.30969 0.48092 lineto
0.31217 0.53454 lineto
0.31341 0.55565 lineto
0.31465 0.5732 lineto
0.31589 0.58742 lineto
0.31713 0.59855 lineto
0.31837 0.60688 lineto
0.31961 0.61269 lineto
0.32084 0.61626 lineto
0.32208 0.61787 lineto
0.32332 0.6178 lineto
0.32456 0.61628 lineto
0.3258 0.61355 lineto
0.32704 0.60983 lineto
0.33199 0.58848 lineto
0.3419 0.53828 lineto
0.34686 0.51707 lineto
0.35182 0.50031 lineto
0.35429 0.49369 lineto
0.35677 0.48822 lineto
0.35925 0.48387 lineto
0.36049 0.4821 lineto
0.36173 0.4806 lineto
0.36297 0.47935 lineto
0.3642 0.47834 lineto
0.36544 0.47757 lineto
0.36668 0.47704 lineto
0.36792 0.47673 lineto
0.36916 0.47664 lineto
Mistroke
0.3704 0.47675 lineto
0.37164 0.47706 lineto
0.37288 0.47757 lineto
0.37411 0.47826 lineto
0.37659 0.48017 lineto
0.37907 0.48271 lineto
0.38155 0.48584 lineto
0.39146 0.50302 lineto
0.40137 0.52505 lineto
0.42119 0.57164 lineto
0.4311 0.59133 lineto
0.44101 0.60622 lineto
0.44597 0.61151 lineto
0.44844 0.61358 lineto
0.45092 0.61526 lineto
0.45216 0.61595 lineto
0.4534 0.61654 lineto
0.45464 0.61704 lineto
0.45588 0.61743 lineto
0.45712 0.61772 lineto
0.45836 0.61792 lineto
0.45959 0.61802 lineto
0.46083 0.61802 lineto
0.46207 0.61793 lineto
0.46331 0.61774 lineto
0.46579 0.61708 lineto
0.46703 0.61661 lineto
0.46827 0.61606 lineto
0.47074 0.61468 lineto
0.4757 0.61091 lineto
0.48065 0.6059 lineto
0.49057 0.59272 lineto
0.50048 0.57639 lineto
0.5203 0.53962 lineto
0.53021 0.52172 lineto
0.54012 0.50564 lineto
0.55003 0.49237 lineto
0.55499 0.48705 lineto
0.55994 0.48273 lineto
0.5649 0.47951 lineto
0.56737 0.47834 lineto
0.56861 0.47786 lineto
0.56985 0.47746 lineto
0.57109 0.47714 lineto
0.57233 0.47689 lineto
0.57357 0.47673 lineto
0.57481 0.47665 lineto
0.57605 0.47664 lineto
0.57728 0.47672 lineto
0.57852 0.47689 lineto
Mistroke
0.57976 0.47713 lineto
0.581 0.47746 lineto
0.58224 0.47788 lineto
0.58472 0.47897 lineto
0.58719 0.48041 lineto
0.58967 0.48219 lineto
0.59463 0.48683 lineto
0.59958 0.49288 lineto
0.60949 0.50916 lineto
0.6194 0.53048 lineto
0.62932 0.55555 lineto
0.63923 0.58179 lineto
0.64914 0.60477 lineto
0.65161 0.60925 lineto
0.65409 0.61297 lineto
0.65533 0.6145 lineto
0.65657 0.61578 lineto
0.65781 0.61679 lineto
0.65905 0.61752 lineto
0.66029 0.61794 lineto
0.66153 0.61802 lineto
0.66276 0.61776 lineto
0.664 0.61712 lineto
0.66524 0.61609 lineto
0.66648 0.61464 lineto
0.66772 0.61275 lineto
0.66896 0.61039 lineto
0.67144 0.60421 lineto
0.67391 0.59592 lineto
0.67639 0.58535 lineto
0.67887 0.57238 lineto
0.68382 0.53875 lineto
0.68878 0.49435 lineto
0.69869 0.37308 lineto
0.7086 0.21282 lineto
0.71851 0.02303 lineto
0.73833 -0.40487 lineto
0.77798 -1.29732 lineto
0.81762 -2.17698 lineto
0.85726 -3.10864 lineto
0.87708 -3.64295 lineto
0.8969 -4.2832 lineto
0.90682 -4.67706 lineto
0.91673 -5.16203 lineto
0.92168 -5.46072 lineto
0.92664 -5.82113 lineto
0.93159 -6.28308 lineto
0.93407 -6.57753 lineto
0.93655 -6.94344 lineto
0.93779 -7.16709 lineto
Mistroke
0.93903 -7.43156 lineto
0.9415 -8.17842 lineto
0.94274 -8.7873 lineto
0.94398 -9.90861 lineto
0.94522 -11.57743 lineto
0.94646 -9.31234 lineto
0.9477 -8.52044 lineto
0.94894 -8.03133 lineto
0.95017 -7.67784 lineto
0.95141 -7.4017 lineto
0.95389 -6.98455 lineto
0.95637 -6.67427 lineto
0.96132 -6.22584 lineto
0.96628 -5.90568 lineto
0.97124 -5.65943 lineto
0.97619 -5.46124 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.1)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.22292 moveto
0.026 -9.1047 lineto
0.02724 -8.50335 lineto
0.02848 -8.08962 lineto
0.02972 -7.77388 lineto
0.03219 -7.30413 lineto
0.03467 -6.95707 lineto
0.03715 -6.68181 lineto
0.03963 -6.45375 lineto
0.04458 -6.08944 lineto
0.05449 -5.57005 lineto
0.0644 -5.20033 lineto
0.07432 -4.91514 lineto
0.08423 -4.68505 lineto
0.10405 -4.33421 lineto
0.12387 -4.08529 lineto
0.13378 -3.99176 lineto
0.14369 -3.91807 lineto
0.14865 -3.88895 lineto
0.1536 -3.86535 lineto
0.15608 -3.85573 lineto
0.15856 -3.84767 lineto
0.16103 -3.84122 lineto
0.16227 -3.83863 lineto
0.16351 -3.83648 lineto
0.16475 -3.83478 lineto
0.16599 -3.83354 lineto
0.16723 -3.83279 lineto
0.16847 -3.83253 lineto
0.16971 -3.83279 lineto
0.17094 -3.83358 lineto
0.17218 -3.83492 lineto
0.17342 -3.83684 lineto
0.1759 -3.84249 lineto
0.17714 -3.84628 lineto
0.17838 -3.85074 lineto
0.18086 -3.86183 lineto
0.18333 -3.87604 lineto
0.18581 -3.8937 lineto
0.18829 -3.9152 lineto
0.19324 -3.97172 lineto
0.1982 -4.05065 lineto
0.20315 -4.15969 lineto
0.20563 -4.2291 lineto
0.20811 -4.31129 lineto
0.21307 -4.52751 lineto
0.21554 -4.67216 lineto
0.21802 -4.85301 lineto
0.2205 -5.0863 lineto
0.22298 -5.4022 lineto
Mistroke
0.22422 -5.60908 lineto
0.22545 -5.86734 lineto
0.22669 -6.20568 lineto
0.22793 -6.6864 lineto
0.22917 -7.49418 lineto
0.23041 -10.19822 lineto
0.23165 -7.83386 lineto
0.23289 -6.75761 lineto
0.23413 -6.14465 lineto
0.23536 -5.70771 lineto
0.23784 -5.07876 lineto
0.24032 -4.61547 lineto
0.2428 -4.24107 lineto
0.25271 -3.15072 lineto
0.26262 -2.33667 lineto
0.28244 -0.96862 lineto
0.29235 -0.34517 lineto
0.29731 -0.05957 lineto
0.30226 0.1915 lineto
0.30474 0.29858 lineto
0.30722 0.39063 lineto
0.30969 0.46633 lineto
0.31217 0.52527 lineto
0.31341 0.5486 lineto
0.31465 0.56807 lineto
0.31589 0.58387 lineto
0.31713 0.59627 lineto
0.31837 0.60557 lineto
0.31961 0.61206 lineto
0.32084 0.61605 lineto
0.32208 0.61786 lineto
0.32332 0.61777 lineto
0.32456 0.61607 lineto
0.3258 0.61302 lineto
0.32704 0.60886 lineto
0.33199 0.58505 lineto
0.3419 0.52939 lineto
0.34686 0.50601 lineto
0.35182 0.48759 lineto
0.35429 0.48032 lineto
0.35677 0.47433 lineto
0.35925 0.46956 lineto
0.36049 0.46763 lineto
0.36173 0.46598 lineto
0.36297 0.46461 lineto
0.3642 0.46351 lineto
0.36544 0.46267 lineto
0.36668 0.46208 lineto
0.36792 0.46174 lineto
0.36916 0.46164 lineto
Mistroke
0.3704 0.46177 lineto
0.37164 0.46211 lineto
0.37288 0.46266 lineto
0.37411 0.46342 lineto
0.37659 0.4655 lineto
0.37907 0.46829 lineto
0.38155 0.47172 lineto
0.39146 0.49056 lineto
0.40137 0.5148 lineto
0.42119 0.56633 lineto
0.4311 0.58822 lineto
0.44101 0.60483 lineto
0.44597 0.61074 lineto
0.44844 0.61306 lineto
0.45092 0.61493 lineto
0.45216 0.6157 lineto
0.4534 0.61637 lineto
0.45464 0.61692 lineto
0.45588 0.61736 lineto
0.45712 0.61769 lineto
0.45836 0.61791 lineto
0.45959 0.61802 lineto
0.46083 0.61802 lineto
0.46207 0.61792 lineto
0.46331 0.61771 lineto
0.46579 0.61697 lineto
0.46703 0.61645 lineto
0.46827 0.61582 lineto
0.47074 0.61428 lineto
0.4757 0.61007 lineto
0.48065 0.60447 lineto
0.49057 0.58977 lineto
0.50048 0.57161 lineto
0.5203 0.53088 lineto
0.53021 0.51113 lineto
0.54012 0.49344 lineto
0.55003 0.47887 lineto
0.55499 0.47304 lineto
0.55994 0.46832 lineto
0.5649 0.46479 lineto
0.56737 0.4635 lineto
0.56861 0.46298 lineto
0.56985 0.46254 lineto
0.57109 0.46219 lineto
0.57233 0.46192 lineto
0.57357 0.46174 lineto
0.57481 0.46165 lineto
0.57605 0.46165 lineto
0.57728 0.46174 lineto
0.57852 0.46192 lineto
Mistroke
0.57976 0.46218 lineto
0.581 0.46255 lineto
0.58224 0.463 lineto
0.58472 0.46419 lineto
0.58719 0.46577 lineto
0.58967 0.46772 lineto
0.59463 0.4728 lineto
0.59958 0.47944 lineto
0.60949 0.49731 lineto
0.6194 0.52079 lineto
0.62932 0.54849 lineto
0.63923 0.57761 lineto
0.64914 0.60321 lineto
0.65161 0.60821 lineto
0.65409 0.61237 lineto
0.65533 0.61408 lineto
0.65657 0.61551 lineto
0.65781 0.61664 lineto
0.65905 0.61746 lineto
0.66029 0.61792 lineto
0.66153 0.61802 lineto
0.66276 0.61773 lineto
0.664 0.61702 lineto
0.66524 0.61586 lineto
0.66648 0.61424 lineto
0.66772 0.61212 lineto
0.66896 0.60949 lineto
0.67144 0.60258 lineto
0.67391 0.59333 lineto
0.67639 0.58157 lineto
0.67887 0.56715 lineto
0.68382 0.52991 lineto
0.68878 0.48105 lineto
0.69869 0.3491 lineto
0.71851 -0.02233 lineto
0.73833 -0.46456 lineto
0.77798 -1.36861 lineto
0.81762 -2.25128 lineto
0.85726 -3.18377 lineto
0.87708 -3.71823 lineto
0.8969 -4.35856 lineto
0.90682 -4.75244 lineto
0.91673 -5.23743 lineto
0.92168 -5.53612 lineto
0.92664 -5.89653 lineto
0.93159 -6.35848 lineto
0.93407 -6.65294 lineto
0.93655 -7.01884 lineto
0.93779 -7.2425 lineto
0.93903 -7.50697 lineto
Mistroke
0.9415 -8.25383 lineto
0.94274 -8.86271 lineto
0.94398 -9.98402 lineto
0.94522 -11.65284 lineto
0.94646 -9.38775 lineto
0.9477 -8.59585 lineto
0.94894 -8.10674 lineto
0.95017 -7.75325 lineto
0.95141 -7.4771 lineto
0.95389 -7.05996 lineto
0.95637 -6.74968 lineto
0.96132 -6.30125 lineto
0.96628 -5.98108 lineto
0.97124 -5.73483 lineto
0.97619 -5.53664 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.11)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.29291 moveto
0.026 -9.17469 lineto
0.02724 -8.57334 lineto
0.02848 -8.15961 lineto
0.02972 -7.84387 lineto
0.03219 -7.37412 lineto
0.03467 -7.02706 lineto
0.03715 -6.7518 lineto
0.03963 -6.52374 lineto
0.04458 -6.15943 lineto
0.05449 -5.64003 lineto
0.0644 -5.27031 lineto
0.07432 -4.98511 lineto
0.08423 -4.75502 lineto
0.10405 -4.40416 lineto
0.12387 -4.15522 lineto
0.13378 -4.06169 lineto
0.14369 -3.98798 lineto
0.14865 -3.95886 lineto
0.1536 -3.93525 lineto
0.15608 -3.92564 lineto
0.15856 -3.91757 lineto
0.16103 -3.91112 lineto
0.16227 -3.90853 lineto
0.16351 -3.90638 lineto
0.16475 -3.90468 lineto
0.16599 -3.90345 lineto
0.16723 -3.90269 lineto
0.16847 -3.90244 lineto
0.16971 -3.9027 lineto
0.17094 -3.90349 lineto
0.17218 -3.90483 lineto
0.17342 -3.90675 lineto
0.1759 -3.9124 lineto
0.17714 -3.91618 lineto
0.17838 -3.92065 lineto
0.18086 -3.93174 lineto
0.18333 -3.94595 lineto
0.18581 -3.96361 lineto
0.18829 -3.98512 lineto
0.19324 -4.04164 lineto
0.1982 -4.12058 lineto
0.20315 -4.22962 lineto
0.20563 -4.29905 lineto
0.20811 -4.38124 lineto
0.21307 -4.59747 lineto
0.21554 -4.74213 lineto
0.21802 -4.92298 lineto
0.2205 -5.15628 lineto
0.22298 -5.47219 lineto
Mistroke
0.22422 -5.67907 lineto
0.22545 -5.93733 lineto
0.22669 -6.27567 lineto
0.22793 -6.75639 lineto
0.22917 -7.56417 lineto
0.23041 -10.26821 lineto
0.23165 -7.90386 lineto
0.23289 -6.8276 lineto
0.23413 -6.21464 lineto
0.23536 -5.77769 lineto
0.23784 -5.14873 lineto
0.24032 -4.68544 lineto
0.2428 -4.31102 lineto
0.25271 -3.22047 lineto
0.26262 -2.40585 lineto
0.28244 -1.03233 lineto
0.29235 -0.39915 lineto
0.29731 -0.10491 lineto
0.30226 0.15766 lineto
0.30474 0.2712 lineto
0.30722 0.36975 lineto
0.30969 0.45157 lineto
0.31217 0.51581 lineto
0.31341 0.54139 lineto
0.31465 0.56279 lineto
0.31589 0.58022 lineto
0.31713 0.59393 lineto
0.31837 0.60421 lineto
0.31961 0.6114 lineto
0.32084 0.61583 lineto
0.32208 0.61784 lineto
0.32332 0.61774 lineto
0.32456 0.61586 lineto
0.3258 0.61248 lineto
0.32704 0.60786 lineto
0.33199 0.58152 lineto
0.3419 0.52033 lineto
0.34686 0.49476 lineto
0.35182 0.47468 lineto
0.35429 0.46677 lineto
0.35677 0.46026 lineto
0.35925 0.45508 lineto
0.36049 0.45298 lineto
0.36173 0.45118 lineto
0.36297 0.44969 lineto
0.3642 0.4485 lineto
0.36544 0.44759 lineto
0.36668 0.44696 lineto
0.36792 0.44659 lineto
0.36916 0.44648 lineto
Mistroke
0.3704 0.44661 lineto
0.37164 0.44699 lineto
0.37288 0.44759 lineto
0.37411 0.44841 lineto
0.37659 0.45067 lineto
0.37907 0.4537 lineto
0.38155 0.45742 lineto
0.39146 0.47792 lineto
0.40137 0.50436 lineto
0.42119 0.56089 lineto
0.4311 0.58503 lineto
0.44101 0.60339 lineto
0.44597 0.60995 lineto
0.44844 0.61251 lineto
0.45092 0.61459 lineto
0.45216 0.61545 lineto
0.4534 0.61618 lineto
0.45464 0.61679 lineto
0.45588 0.61728 lineto
0.45712 0.61765 lineto
0.45836 0.61789 lineto
0.45959 0.61802 lineto
0.46083 0.61802 lineto
0.46207 0.6179 lineto
0.46331 0.61767 lineto
0.46579 0.61685 lineto
0.46703 0.61627 lineto
0.46827 0.61558 lineto
0.47074 0.61387 lineto
0.4757 0.6092 lineto
0.48065 0.60299 lineto
0.49057 0.58673 lineto
0.50048 0.56669 lineto
0.5203 0.52195 lineto
0.53021 0.50035 lineto
0.54012 0.48106 lineto
0.55003 0.4652 lineto
0.55499 0.45886 lineto
0.55994 0.45372 lineto
0.5649 0.44989 lineto
0.56737 0.4485 lineto
0.56861 0.44793 lineto
0.56985 0.44746 lineto
0.57109 0.44707 lineto
0.57233 0.44678 lineto
0.57357 0.44659 lineto
0.57481 0.44649 lineto
0.57605 0.44649 lineto
0.57728 0.44658 lineto
0.57852 0.44677 lineto
Mistroke
0.57976 0.44707 lineto
0.581 0.44746 lineto
0.58224 0.44795 lineto
0.58472 0.44925 lineto
0.58719 0.45095 lineto
0.58967 0.45308 lineto
0.59463 0.4586 lineto
0.59958 0.46581 lineto
0.60949 0.48527 lineto
0.6194 0.51091 lineto
0.63923 0.57331 lineto
0.64914 0.6016 lineto
0.65161 0.60714 lineto
0.65409 0.61175 lineto
0.65533 0.61364 lineto
0.65657 0.61523 lineto
0.65781 0.61649 lineto
0.65905 0.61739 lineto
0.66029 0.61791 lineto
0.66153 0.61802 lineto
0.66276 0.6177 lineto
0.664 0.6169 lineto
0.66524 0.61562 lineto
0.66648 0.61382 lineto
0.66772 0.61148 lineto
0.66896 0.60856 lineto
0.67144 0.60091 lineto
0.67391 0.59067 lineto
0.67887 0.56179 lineto
0.68382 0.5209 lineto
0.68878 0.46757 lineto
0.69869 0.32517 lineto
0.71851 -0.06622 lineto
0.73833 -0.52118 lineto
0.77798 -1.43515 lineto
0.81762 -2.32035 lineto
0.85726 -3.25354 lineto
0.87708 -3.78812 lineto
0.8969 -4.42852 lineto
0.90682 -4.82241 lineto
0.91673 -5.30741 lineto
0.92168 -5.60611 lineto
0.92664 -5.96652 lineto
0.93159 -6.42847 lineto
0.93407 -6.72293 lineto
0.93655 -7.08883 lineto
0.93779 -7.31249 lineto
0.93903 -7.57696 lineto
0.9415 -8.32382 lineto
0.94274 -8.9327 lineto
Mistroke
0.94398 -10.05401 lineto
0.94522 -11.72283 lineto
0.94646 -9.45774 lineto
0.9477 -8.66584 lineto
0.94894 -8.17673 lineto
0.95017 -7.82324 lineto
0.95141 -7.5471 lineto
0.95389 -7.12995 lineto
0.95637 -6.81967 lineto
0.96132 -6.37124 lineto
0.96628 -6.05107 lineto
0.97124 -5.80481 lineto
0.97619 -5.60663 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.12)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.35838 moveto
0.026 -9.24016 lineto
0.02724 -8.63881 lineto
0.02848 -8.22508 lineto
0.02972 -7.90934 lineto
0.03219 -7.43959 lineto
0.03467 -7.09253 lineto
0.03715 -6.81727 lineto
0.03963 -6.58921 lineto
0.04458 -6.2249 lineto
0.05449 -5.7055 lineto
0.0644 -5.33577 lineto
0.07432 -5.05057 lineto
0.08423 -4.82047 lineto
0.10405 -4.46959 lineto
0.12387 -4.22064 lineto
0.13378 -4.1271 lineto
0.14369 -4.05338 lineto
0.14865 -4.02426 lineto
0.1536 -4.00065 lineto
0.15608 -3.99104 lineto
0.15856 -3.98297 lineto
0.16103 -3.97652 lineto
0.16227 -3.97393 lineto
0.16351 -3.97178 lineto
0.16475 -3.97008 lineto
0.16599 -3.96884 lineto
0.16723 -3.96809 lineto
0.16847 -3.96783 lineto
0.16971 -3.96809 lineto
0.17094 -3.96888 lineto
0.17218 -3.97022 lineto
0.17342 -3.97214 lineto
0.1759 -3.97779 lineto
0.17714 -3.98158 lineto
0.17838 -3.98604 lineto
0.18086 -3.99713 lineto
0.18333 -4.01135 lineto
0.18581 -4.02901 lineto
0.18829 -4.05052 lineto
0.19324 -4.10705 lineto
0.1982 -4.186 lineto
0.20315 -4.29505 lineto
0.20563 -4.36447 lineto
0.20811 -4.44667 lineto
0.21307 -4.66292 lineto
0.21554 -4.80757 lineto
0.21802 -4.98843 lineto
0.2205 -5.22174 lineto
0.22298 -5.53765 lineto
Mistroke
0.22422 -5.74453 lineto
0.22545 -6.00279 lineto
0.22669 -6.34114 lineto
0.22793 -6.82186 lineto
0.22917 -7.62964 lineto
0.23041 -10.33368 lineto
0.23165 -7.96933 lineto
0.23289 -6.89306 lineto
0.23413 -6.28011 lineto
0.23536 -5.84316 lineto
0.23784 -5.21419 lineto
0.24032 -4.75088 lineto
0.2428 -4.37645 lineto
0.25271 -3.28573 lineto
0.26262 -2.47063 lineto
0.28244 -1.09245 lineto
0.29235 -0.45078 lineto
0.29731 -0.14879 lineto
0.30226 0.12436 lineto
0.30474 0.244 lineto
0.30722 0.34882 lineto
0.30969 0.43662 lineto
0.31217 0.50616 lineto
0.31341 0.53401 lineto
0.31465 0.55738 lineto
0.31589 0.57646 lineto
0.31713 0.5915 lineto
0.31837 0.60281 lineto
0.31961 0.61073 lineto
0.32084 0.61561 lineto
0.32208 0.61782 lineto
0.32332 0.61771 lineto
0.32456 0.61563 lineto
0.3258 0.61191 lineto
0.32704 0.60683 lineto
0.33199 0.57788 lineto
0.3419 0.51107 lineto
0.34686 0.48332 lineto
0.35182 0.46158 lineto
0.35429 0.45304 lineto
0.35677 0.446 lineto
0.35925 0.44041 lineto
0.36049 0.43814 lineto
0.36173 0.43621 lineto
0.36297 0.43461 lineto
0.3642 0.43332 lineto
0.36544 0.43234 lineto
0.36668 0.43166 lineto
0.36792 0.43126 lineto
0.36916 0.43114 lineto
Mistroke
0.3704 0.43128 lineto
0.37164 0.43169 lineto
0.37288 0.43234 lineto
0.37411 0.43322 lineto
0.37659 0.43566 lineto
0.37907 0.43892 lineto
0.38155 0.44294 lineto
0.39146 0.46508 lineto
0.40137 0.49373 lineto
0.42119 0.55529 lineto
0.4311 0.58173 lineto
0.44101 0.60191 lineto
0.44597 0.60912 lineto
0.44844 0.61195 lineto
0.45092 0.61424 lineto
0.45216 0.61518 lineto
0.4534 0.61599 lineto
0.45464 0.61667 lineto
0.45588 0.61721 lineto
0.45712 0.61761 lineto
0.45836 0.61788 lineto
0.45959 0.61802 lineto
0.46083 0.61802 lineto
0.46207 0.61789 lineto
0.46331 0.61763 lineto
0.46579 0.61673 lineto
0.46703 0.61609 lineto
0.46827 0.61533 lineto
0.47074 0.61344 lineto
0.4757 0.6083 lineto
0.48065 0.60147 lineto
0.49057 0.58361 lineto
0.50048 0.56165 lineto
0.5203 0.51284 lineto
0.53021 0.48938 lineto
0.54012 0.46848 lineto
0.55003 0.45133 lineto
0.55499 0.44449 lineto
0.55994 0.43895 lineto
0.5649 0.43482 lineto
0.56737 0.43331 lineto
0.56861 0.43271 lineto
0.56985 0.43219 lineto
0.57109 0.43178 lineto
0.57233 0.43147 lineto
0.57357 0.43126 lineto
0.57481 0.43115 lineto
0.57605 0.43115 lineto
0.57728 0.43125 lineto
0.57852 0.43146 lineto
Mistroke
0.57976 0.43177 lineto
0.581 0.4322 lineto
0.58224 0.43273 lineto
0.58472 0.43412 lineto
0.58719 0.43597 lineto
0.58967 0.43826 lineto
0.59463 0.44421 lineto
0.59958 0.452 lineto
0.60949 0.47304 lineto
0.6194 0.50084 lineto
0.63923 0.56889 lineto
0.64914 0.59994 lineto
0.65161 0.60604 lineto
0.65409 0.61111 lineto
0.65533 0.61319 lineto
0.65657 0.61494 lineto
0.65781 0.61633 lineto
0.65905 0.61733 lineto
0.66029 0.6179 lineto
0.66153 0.61802 lineto
0.66276 0.61766 lineto
0.664 0.61679 lineto
0.66524 0.61538 lineto
0.66648 0.61339 lineto
0.66772 0.61081 lineto
0.66896 0.6076 lineto
0.67144 0.59918 lineto
0.67391 0.58793 lineto
0.67887 0.55628 lineto
0.68382 0.51169 lineto
0.68878 0.45389 lineto
0.69869 0.30128 lineto
0.71851 -0.10881 lineto
0.73833 -0.57513 lineto
0.77798 -1.49769 lineto
0.81762 -2.38504 lineto
0.85726 -3.31881 lineto
0.87708 -3.8535 lineto
0.8969 -4.49395 lineto
0.90682 -4.88786 lineto
0.91673 -5.37287 lineto
0.92168 -5.67157 lineto
0.92664 -6.03198 lineto
0.93159 -6.49394 lineto
0.93407 -6.7884 lineto
0.93655 -7.1543 lineto
0.93779 -7.37796 lineto
0.93903 -7.64243 lineto
0.9415 -8.38929 lineto
0.94274 -8.99817 lineto
Mistroke
0.94398 -10.11948 lineto
0.94522 -11.7883 lineto
0.94646 -9.52321 lineto
0.9477 -8.73131 lineto
0.94894 -8.2422 lineto
0.95017 -7.88871 lineto
0.95141 -7.61256 lineto
0.95389 -7.19542 lineto
0.95637 -6.88514 lineto
0.96132 -6.4367 lineto
0.96628 -6.11653 lineto
0.97124 -5.87028 lineto
0.97619 -5.67209 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.13)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.42003 moveto
0.026 -9.3018 lineto
0.02724 -8.70046 lineto
0.02848 -8.28672 lineto
0.02972 -7.97099 lineto
0.03219 -7.50123 lineto
0.03467 -7.15417 lineto
0.03715 -6.87891 lineto
0.03963 -6.65085 lineto
0.04458 -6.28654 lineto
0.05449 -5.76714 lineto
0.0644 -5.39741 lineto
0.07432 -5.1122 lineto
0.08423 -4.88209 lineto
0.10405 -4.53121 lineto
0.12387 -4.28224 lineto
0.13378 -4.18869 lineto
0.14369 -4.11497 lineto
0.14865 -4.08585 lineto
0.1536 -4.06224 lineto
0.15608 -4.05262 lineto
0.15856 -4.04455 lineto
0.16103 -4.0381 lineto
0.16227 -4.03551 lineto
0.16351 -4.03336 lineto
0.16475 -4.03166 lineto
0.16599 -4.03042 lineto
0.16723 -4.02967 lineto
0.16847 -4.02941 lineto
0.16971 -4.02967 lineto
0.17094 -4.03046 lineto
0.17218 -4.03181 lineto
0.17342 -4.03372 lineto
0.1759 -4.03938 lineto
0.17714 -4.04316 lineto
0.17838 -4.04763 lineto
0.18086 -4.05872 lineto
0.18333 -4.07293 lineto
0.18581 -4.0906 lineto
0.18829 -4.11211 lineto
0.19324 -4.16865 lineto
0.1982 -4.24759 lineto
0.20315 -4.35665 lineto
0.20563 -4.42608 lineto
0.20811 -4.50829 lineto
0.21307 -4.72454 lineto
0.21554 -4.8692 lineto
0.21802 -5.05007 lineto
0.2205 -5.28337 lineto
0.22298 -5.59929 lineto
Mistroke
0.22422 -5.80617 lineto
0.22545 -6.06443 lineto
0.22669 -6.40278 lineto
0.22793 -6.8835 lineto
0.22917 -7.69128 lineto
0.23041 -10.39533 lineto
0.23165 -8.03097 lineto
0.23289 -6.95471 lineto
0.23413 -6.34175 lineto
0.23536 -5.9048 lineto
0.23784 -5.27583 lineto
0.24032 -4.81251 lineto
0.2428 -4.43806 lineto
0.25271 -3.3472 lineto
0.26262 -2.53169 lineto
0.28244 -1.14947 lineto
0.29235 -0.50034 lineto
0.29731 -0.19139 lineto
0.30226 0.09155 lineto
0.30722 0.32781 lineto
0.30969 0.4215 lineto
0.31217 0.49632 lineto
0.31341 0.52645 lineto
0.31465 0.55182 lineto
0.31589 0.57259 lineto
0.31713 0.589 lineto
0.31837 0.60137 lineto
0.31961 0.61003 lineto
0.32084 0.61538 lineto
0.32208 0.6178 lineto
0.32332 0.61768 lineto
0.32456 0.6154 lineto
0.3258 0.61132 lineto
0.32704 0.60576 lineto
0.33199 0.57414 lineto
0.3419 0.50162 lineto
0.34686 0.47168 lineto
0.35182 0.44829 lineto
0.35429 0.43911 lineto
0.35677 0.43155 lineto
0.35925 0.42556 lineto
0.36049 0.42313 lineto
0.36173 0.42106 lineto
0.36297 0.41934 lineto
0.3642 0.41796 lineto
0.36544 0.41691 lineto
0.36668 0.41618 lineto
0.36792 0.41575 lineto
0.36916 0.41562 lineto
0.3704 0.41578 lineto
Mistroke
0.37164 0.41621 lineto
0.37288 0.41691 lineto
0.37411 0.41785 lineto
0.37659 0.42047 lineto
0.37907 0.42397 lineto
0.38155 0.42827 lineto
0.39146 0.45205 lineto
0.40137 0.4829 lineto
0.42119 0.54956 lineto
0.4311 0.57834 lineto
0.44101 0.60038 lineto
0.44597 0.60827 lineto
0.44844 0.61137 lineto
0.45092 0.61388 lineto
0.45216 0.61491 lineto
0.4534 0.6158 lineto
0.45464 0.61654 lineto
0.45588 0.61713 lineto
0.45712 0.61757 lineto
0.45836 0.61786 lineto
0.45959 0.61801 lineto
0.46083 0.61802 lineto
0.46207 0.61788 lineto
0.46331 0.61759 lineto
0.46579 0.61661 lineto
0.46703 0.61591 lineto
0.46827 0.61507 lineto
0.47074 0.613 lineto
0.4757 0.60737 lineto
0.48065 0.5999 lineto
0.49057 0.58039 lineto
0.50048 0.55646 lineto
0.5203 0.50354 lineto
0.53021 0.47821 lineto
0.54012 0.4557 lineto
0.55003 0.43728 lineto
0.55499 0.42993 lineto
0.55994 0.424 lineto
0.5649 0.41957 lineto
0.56737 0.41795 lineto
0.56861 0.4173 lineto
0.56985 0.41675 lineto
0.57109 0.41631 lineto
0.57233 0.41598 lineto
0.57357 0.41575 lineto
0.57481 0.41564 lineto
0.57605 0.41564 lineto
0.57728 0.41574 lineto
0.57852 0.41597 lineto
0.57976 0.4163 lineto
Mistroke
0.581 0.41676 lineto
0.58224 0.41733 lineto
0.58472 0.41882 lineto
0.58719 0.42079 lineto
0.58967 0.42325 lineto
0.59463 0.42963 lineto
0.59958 0.43799 lineto
0.60949 0.46061 lineto
0.6194 0.49057 lineto
0.63923 0.56435 lineto
0.64914 0.59822 lineto
0.65161 0.60489 lineto
0.65409 0.61045 lineto
0.65533 0.61273 lineto
0.65657 0.61465 lineto
0.65781 0.61617 lineto
0.65905 0.61726 lineto
0.66029 0.61789 lineto
0.66153 0.61802 lineto
0.66276 0.61762 lineto
0.664 0.61667 lineto
0.66524 0.61512 lineto
0.66648 0.61295 lineto
0.66772 0.61012 lineto
0.66896 0.6066 lineto
0.67144 0.59739 lineto
0.67391 0.5851 lineto
0.67887 0.55063 lineto
0.68382 0.50229 lineto
0.68878 0.44003 lineto
0.69869 0.27742 lineto
0.73833 -0.62675 lineto
0.77798 -1.55681 lineto
0.81762 -2.44601 lineto
0.85726 -3.38029 lineto
0.87708 -3.91507 lineto
0.8969 -4.55557 lineto
0.90682 -4.94949 lineto
0.91673 -5.4345 lineto
0.92168 -5.73321 lineto
0.92664 -6.09363 lineto
0.93159 -6.55558 lineto
0.93407 -6.85004 lineto
0.93655 -7.21595 lineto
0.93779 -7.4396 lineto
0.93903 -7.70407 lineto
0.9415 -8.45094 lineto
0.94274 -9.05982 lineto
0.94398 -10.18112 lineto
0.94522 -11.84994 lineto
Mistroke
0.94646 -9.58486 lineto
0.9477 -8.79296 lineto
0.94894 -8.30384 lineto
0.95017 -7.95036 lineto
0.95141 -7.67421 lineto
0.95389 -7.25706 lineto
0.95637 -6.94678 lineto
0.96132 -6.49835 lineto
0.96628 -6.17818 lineto
0.97124 -5.93192 lineto
0.97619 -5.73373 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.14)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.4784 moveto
0.026 -9.36018 lineto
0.02724 -8.75883 lineto
0.02848 -8.3451 lineto
0.02972 -8.02936 lineto
0.03219 -7.55961 lineto
0.03467 -7.21255 lineto
0.03715 -6.93728 lineto
0.03963 -6.70922 lineto
0.04458 -6.34491 lineto
0.05449 -5.82551 lineto
0.0644 -5.45577 lineto
0.07432 -5.17057 lineto
0.08423 -4.94045 lineto
0.10405 -4.58956 lineto
0.12387 -4.34058 lineto
0.13378 -4.24702 lineto
0.14369 -4.1733 lineto
0.14865 -4.14417 lineto
0.1536 -4.12056 lineto
0.15608 -4.11095 lineto
0.15856 -4.10287 lineto
0.16103 -4.09642 lineto
0.16227 -4.09383 lineto
0.16351 -4.09168 lineto
0.16475 -4.08998 lineto
0.16599 -4.08874 lineto
0.16723 -4.08799 lineto
0.16847 -4.08773 lineto
0.16971 -4.08799 lineto
0.17094 -4.08878 lineto
0.17218 -4.09013 lineto
0.17342 -4.09204 lineto
0.1759 -4.0977 lineto
0.17714 -4.10148 lineto
0.17838 -4.10595 lineto
0.18086 -4.11704 lineto
0.18333 -4.13126 lineto
0.18581 -4.14892 lineto
0.18829 -4.17044 lineto
0.19324 -4.22698 lineto
0.1982 -4.30593 lineto
0.20315 -4.415 lineto
0.20563 -4.48443 lineto
0.20811 -4.56664 lineto
0.21307 -4.7829 lineto
0.21554 -4.92756 lineto
0.21802 -5.10843 lineto
0.2205 -5.34174 lineto
0.22298 -5.65766 lineto
Mistroke
0.22422 -5.86454 lineto
0.22545 -6.12281 lineto
0.22669 -6.46115 lineto
0.22793 -6.94188 lineto
0.22917 -7.74966 lineto
0.23041 -10.4537 lineto
0.23165 -8.08935 lineto
0.23289 -7.01308 lineto
0.23413 -6.40012 lineto
0.23536 -5.96317 lineto
0.23784 -5.33419 lineto
0.24032 -4.87087 lineto
0.2428 -4.4964 lineto
0.25271 -3.40543 lineto
0.26262 -2.58955 lineto
0.28244 -1.20382 lineto
0.29235 -0.54807 lineto
0.29731 -0.23281 lineto
0.30226 0.05918 lineto
0.30722 0.30673 lineto
0.30969 0.40619 lineto
0.31217 0.48627 lineto
0.31341 0.51872 lineto
0.31465 0.54612 lineto
0.31589 0.56861 lineto
0.31713 0.58643 lineto
0.31837 0.59987 lineto
0.31961 0.60931 lineto
0.32084 0.61513 lineto
0.32208 0.61777 lineto
0.32332 0.61765 lineto
0.32456 0.61516 lineto
0.3258 0.61072 lineto
0.32704 0.60466 lineto
0.33199 0.57029 lineto
0.3419 0.49198 lineto
0.34686 0.45983 lineto
0.35182 0.43479 lineto
0.35429 0.42498 lineto
0.35677 0.41692 lineto
0.35925 0.41052 lineto
0.36049 0.40793 lineto
0.36173 0.40572 lineto
0.36297 0.40389 lineto
0.3642 0.40242 lineto
0.36544 0.4013 lineto
0.36668 0.40052 lineto
0.36792 0.40006 lineto
0.36916 0.39993 lineto
0.3704 0.40009 lineto
Mistroke
0.37164 0.40055 lineto
0.37288 0.40129 lineto
0.37411 0.4023 lineto
0.37659 0.40509 lineto
0.37907 0.40882 lineto
0.38155 0.41342 lineto
0.39146 0.43882 lineto
0.40137 0.47187 lineto
0.42119 0.54366 lineto
0.4311 0.57485 lineto
0.44101 0.5988 lineto
0.44597 0.60739 lineto
0.44844 0.61076 lineto
0.45092 0.6135 lineto
0.45216 0.61463 lineto
0.4534 0.61559 lineto
0.45464 0.6164 lineto
0.45588 0.61704 lineto
0.45712 0.61753 lineto
0.45836 0.61785 lineto
0.45959 0.61801 lineto
0.46083 0.61802 lineto
0.46207 0.61786 lineto
0.46331 0.61755 lineto
0.46579 0.61648 lineto
0.46703 0.61571 lineto
0.46827 0.6148 lineto
0.47074 0.61255 lineto
0.4757 0.60641 lineto
0.48065 0.59827 lineto
0.49057 0.57707 lineto
0.50048 0.55114 lineto
0.5203 0.49404 lineto
0.53021 0.46683 lineto
0.54012 0.44272 lineto
0.55003 0.42303 lineto
0.55499 0.41519 lineto
0.55994 0.40885 lineto
0.5649 0.40413 lineto
0.56737 0.40241 lineto
0.56861 0.40172 lineto
0.56985 0.40113 lineto
0.57109 0.40066 lineto
0.57233 0.40031 lineto
0.57357 0.40007 lineto
0.57481 0.39994 lineto
0.57605 0.39994 lineto
0.57728 0.40006 lineto
0.57852 0.40029 lineto
0.57976 0.40065 lineto
Mistroke
0.581 0.40114 lineto
0.58224 0.40174 lineto
0.58472 0.40334 lineto
0.58719 0.40544 lineto
0.58967 0.40806 lineto
0.59463 0.41487 lineto
0.59958 0.42379 lineto
0.60949 0.44797 lineto
0.6194 0.4801 lineto
0.63923 0.55967 lineto
0.64914 0.59645 lineto
0.65161 0.60371 lineto
0.65409 0.60976 lineto
0.65533 0.61225 lineto
0.65657 0.61434 lineto
0.65781 0.616 lineto
0.65905 0.61719 lineto
0.66029 0.61787 lineto
0.66153 0.61802 lineto
0.66276 0.61759 lineto
0.664 0.61655 lineto
0.66524 0.61486 lineto
0.66648 0.61249 lineto
0.66772 0.6094 lineto
0.66896 0.60557 lineto
0.67144 0.59554 lineto
0.67391 0.58219 lineto
0.67887 0.54483 lineto
0.68382 0.4927 lineto
0.68878 0.42596 lineto
0.69869 0.25357 lineto
0.73833 -0.67632 lineto
0.77798 -1.613 lineto
0.81762 -2.50381 lineto
0.85726 -3.43852 lineto
0.87708 -3.97338 lineto
0.8969 -4.61392 lineto
0.90682 -5.00785 lineto
0.91673 -5.49287 lineto
0.92168 -5.79158 lineto
0.92664 -6.152 lineto
0.93159 -6.61396 lineto
0.93407 -6.90842 lineto
0.93655 -7.27432 lineto
0.93779 -7.49797 lineto
0.93903 -7.76245 lineto
0.9415 -8.50931 lineto
0.94274 -9.11819 lineto
0.94398 -10.2395 lineto
0.94522 -11.90832 lineto
Mistroke
0.94646 -9.64323 lineto
0.9477 -8.85133 lineto
0.94894 -8.36222 lineto
0.95017 -8.00873 lineto
0.95141 -7.73258 lineto
0.95389 -7.31544 lineto
0.95637 -7.00515 lineto
0.96132 -6.55672 lineto
0.96628 -6.23655 lineto
0.97124 -5.99029 lineto
0.97619 -5.7921 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.15)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.15451 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-4)] 0.01131 0 1 0 Msboxa
[(-3.5)] 0.01131 0.07725 1 0 Msboxa
[(-3)] 0.01131 0.15451 1 0 Msboxa
[(-2.5)] 0.01131 0.23176 1 0 Msboxa
[(-2)] 0.01131 0.30902 1 0 Msboxa
[(-1.5)] 0.01131 0.38627 1 0 Msboxa
[(-1)] 0.01131 0.46353 1 0 Msboxa
[(-0.5)] 0.01131 0.54078 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-4)] 0.01131 0 1 0 Mshowa
0.01756 0.07725 moveto
0.03006 0.07725 lineto
stroke
0 setgray
[(-3.5)] 0.01131 0.07725 1 0 Mshowa
0.01756 0.15451 moveto
0.03006 0.15451 lineto
stroke
0 setgray
[(-3)] 0.01131 0.15451 1 0 Mshowa
0.01756 0.23176 moveto
0.03006 0.23176 lineto
stroke
0 setgray
[(-2.5)] 0.01131 0.23176 1 0 Mshowa
0.01756 0.30902 moveto
0.03006 0.30902 lineto
stroke
0 setgray
[(-2)] 0.01131 0.30902 1 0 Mshowa
0.01756 0.38627 moveto
0.03006 0.38627 lineto
stroke
0 setgray
[(-1.5)] 0.01131 0.38627 1 0 Mshowa
0.01756 0.46353 moveto
0.03006 0.46353 lineto
stroke
0 setgray
[(-1)] 0.01131 0.46353 1 0 Mshowa
0.01756 0.54078 moveto
0.03006 0.54078 lineto
stroke
0 setgray
[(-0.5)] 0.01131 0.54078 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -10.53395 moveto
0.026 -9.41573 lineto
0.02724 -8.81439 lineto
0.02848 -8.40065 lineto
0.02972 -8.08491 lineto
0.03219 -7.61516 lineto
0.03467 -7.2681 lineto
0.03715 -6.99284 lineto
0.03963 -6.76478 lineto
0.04458 -6.40046 lineto
0.05449 -5.88106 lineto
0.0644 -5.51132 lineto
0.07432 -5.22611 lineto
0.08423 -4.99599 lineto
0.10405 -4.64509 lineto
0.12387 -4.3961 lineto
0.13378 -4.30254 lineto
0.14369 -4.22881 lineto
0.14865 -4.19968 lineto
0.1536 -4.17607 lineto
0.15608 -4.16645 lineto
0.15856 -4.15838 lineto
0.16103 -4.15193 lineto
0.16227 -4.14934 lineto
0.16351 -4.14718 lineto
0.16475 -4.14548 lineto
0.16599 -4.14425 lineto
0.16723 -4.1435 lineto
0.16847 -4.14324 lineto
0.16971 -4.1435 lineto
0.17094 -4.14429 lineto
0.17218 -4.14563 lineto
0.17342 -4.14755 lineto
0.1759 -4.1532 lineto
0.17714 -4.15699 lineto
0.17838 -4.16145 lineto
0.18086 -4.17255 lineto
0.18333 -4.18676 lineto
0.18581 -4.20443 lineto
0.18829 -4.22595 lineto
0.19324 -4.28249 lineto
0.1982 -4.36145 lineto
0.20315 -4.47052 lineto
0.20563 -4.53995 lineto
0.20811 -4.62216 lineto
0.21307 -4.83843 lineto
0.21554 -4.9831 lineto
0.21802 -5.16397 lineto
0.2205 -5.39728 lineto
0.22298 -5.7132 lineto
Mistroke
0.22422 -5.92009 lineto
0.22545 -6.17836 lineto
0.22669 -6.5167 lineto
0.22793 -6.99743 lineto
0.22917 -7.80521 lineto
0.23041 -10.50925 lineto
0.23165 -8.1449 lineto
0.23289 -7.06863 lineto
0.23413 -6.45567 lineto
0.23536 -6.01872 lineto
0.23784 -5.38974 lineto
0.24032 -4.92641 lineto
0.2428 -4.55193 lineto
0.25271 -3.46085 lineto
0.26262 -2.64465 lineto
0.28244 -1.25584 lineto
0.29235 -0.59418 lineto
0.30226 0.02722 lineto
0.30722 0.28557 lineto
0.30969 0.39069 lineto
0.31217 0.47603 lineto
0.31341 0.5108 lineto
0.31465 0.54026 lineto
0.31589 0.56451 lineto
0.31713 0.58377 lineto
0.31837 0.59833 lineto
0.31961 0.60856 lineto
0.32084 0.61488 lineto
0.32208 0.61775 lineto
0.32332 0.61761 lineto
0.32456 0.61492 lineto
0.3258 0.61009 lineto
0.32704 0.60351 lineto
0.33199 0.56633 lineto
0.3419 0.48213 lineto
0.34686 0.44777 lineto
0.35182 0.42109 lineto
0.35429 0.41066 lineto
0.35677 0.40208 lineto
0.35925 0.39529 lineto
0.36049 0.39254 lineto
0.36173 0.39019 lineto
0.36297 0.38825 lineto
0.3642 0.38669 lineto
0.36544 0.3855 lineto
0.36668 0.38467 lineto
0.36792 0.38419 lineto
0.36916 0.38404 lineto
0.3704 0.38422 lineto
0.37164 0.38471 lineto
Mistroke
0.37288 0.38549 lineto
0.37411 0.38657 lineto
0.37659 0.38952 lineto
0.37907 0.39348 lineto
0.38155 0.39836 lineto
0.39146 0.42538 lineto
0.40137 0.46063 lineto
0.42119 0.53762 lineto
0.4311 0.57125 lineto
0.44101 0.59716 lineto
0.44597 0.60648 lineto
0.44844 0.61014 lineto
0.45092 0.61311 lineto
0.45216 0.61433 lineto
0.4534 0.61538 lineto
0.45464 0.61626 lineto
0.45588 0.61696 lineto
0.45712 0.61748 lineto
0.45836 0.61783 lineto
0.45959 0.61801 lineto
0.46083 0.61801 lineto
0.46207 0.61785 lineto
0.46331 0.61751 lineto
0.46579 0.61634 lineto
0.46703 0.61551 lineto
0.46827 0.61452 lineto
0.47074 0.61208 lineto
0.4757 0.60541 lineto
0.48065 0.5966 lineto
0.49057 0.57364 lineto
0.50048 0.54567 lineto
0.5203 0.48434 lineto
0.53021 0.45525 lineto
0.54012 0.42954 lineto
0.55003 0.40858 lineto
0.55499 0.40025 lineto
0.55994 0.39352 lineto
0.5649 0.38851 lineto
0.56737 0.38668 lineto
0.56861 0.38594 lineto
0.56985 0.38532 lineto
0.57109 0.38482 lineto
0.57233 0.38445 lineto
0.57357 0.38419 lineto
0.57481 0.38406 lineto
0.57605 0.38406 lineto
0.57728 0.38418 lineto
0.57852 0.38443 lineto
0.57976 0.38481 lineto
0.581 0.38533 lineto
Mistroke
0.58224 0.38597 lineto
0.58472 0.38766 lineto
0.58719 0.38989 lineto
0.58967 0.39267 lineto
0.59463 0.39991 lineto
0.59958 0.40939 lineto
0.60949 0.43513 lineto
0.6194 0.46943 lineto
0.63923 0.55487 lineto
0.64914 0.59462 lineto
0.65161 0.60249 lineto
0.65409 0.60905 lineto
0.65533 0.61175 lineto
0.65657 0.61402 lineto
0.65781 0.61582 lineto
0.65905 0.61711 lineto
0.66029 0.61786 lineto
0.66153 0.61802 lineto
0.66276 0.61755 lineto
0.664 0.61642 lineto
0.66524 0.61458 lineto
0.66648 0.61201 lineto
0.66772 0.60866 lineto
0.66896 0.60451 lineto
0.67144 0.59364 lineto
0.67391 0.57918 lineto
0.67887 0.53887 lineto
0.68382 0.48291 lineto
0.68878 0.4117 lineto
0.69869 0.22972 lineto
0.73833 -0.72408 lineto
0.77798 -1.66663 lineto
0.81762 -2.55885 lineto
0.85726 -3.49394 lineto
0.87708 -4.02887 lineto
0.8969 -4.66945 lineto
0.90682 -5.06339 lineto
0.91673 -5.54842 lineto
0.92168 -5.84713 lineto
0.92664 -6.20755 lineto
0.93159 -6.66951 lineto
0.93407 -6.96397 lineto
0.93655 -7.32987 lineto
0.93779 -7.55353 lineto
0.93903 -7.818 lineto
0.9415 -8.56486 lineto
0.94274 -9.17375 lineto
0.94398 -10.29505 lineto
0.94522 -11.96387 lineto
0.94646 -9.69878 lineto
Mistroke
0.9477 -8.90689 lineto
0.94894 -8.41777 lineto
0.95017 -8.06428 lineto
0.95141 -7.78814 lineto
0.95389 -7.37099 lineto
0.95637 -7.06071 lineto
0.96132 -6.61227 lineto
0.96628 -6.2921 lineto
0.97124 -6.04584 lineto
0.97619 -5.84765 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.46353 -1 0 Mshowa
0 setgray
[(0.16)] 0.78571 0.33992 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; endGroup; ]
		What can you say about the effect of varying the ripple control parameter?  By changing the ripple control parameter, do you always change the filter order?
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Animation of passband response with varying ripple and filter order
:[font = text; inactive; ]
		In this animation, we vary the ripple control parameter so that the filter order increases by two each frame.  That is, the ripple control parameters { 0.45, 0.25, 0.1, 0.035, 0.01 } correspond bandpass elliptic filters of order {2, 4, 6, 8, 10}:
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.12361 [
[(Magnitude Response \(dB\) order =  2)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-5)] 0.01131 0 1 0 Msboxa
[(-4)] 0.01131 0.12361 1 0 Msboxa
[(-3)] 0.01131 0.24721 1 0 Msboxa
[(-2)] 0.01131 0.37082 1 0 Msboxa
[(-1)] 0.01131 0.49443 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  2)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-5)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-4)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-3)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-2)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-1)] 0.01131 0.49443 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -6.55503 moveto
0.026 -5.66041 lineto
0.02724 -5.17926 lineto
0.02848 -4.84816 lineto
0.02972 -4.59543 lineto
0.03219 -4.21925 lineto
0.03467 -3.94108 lineto
0.03715 -3.72022 lineto
0.03963 -3.53698 lineto
0.04458 -3.24354 lineto
0.05449 -2.82235 lineto
0.0644 -2.51852 lineto
0.08423 -2.08214 lineto
0.10405 -1.76424 lineto
0.14369 -1.29491 lineto
0.18333 -0.93368 lineto
0.22298 -0.62388 lineto
0.26262 -0.34033 lineto
0.30226 -0.07165 lineto
0.3419 0.18225 lineto
0.38155 0.40578 lineto
0.40137 0.49568 lineto
0.41128 0.53272 lineto
0.42119 0.56361 lineto
0.4311 0.58781 lineto
0.43606 0.59729 lineto
0.44101 0.60498 lineto
0.44349 0.60816 lineto
0.44597 0.61089 lineto
0.44844 0.61317 lineto
0.45092 0.61501 lineto
0.45216 0.61577 lineto
0.4534 0.61641 lineto
0.45464 0.61695 lineto
0.45588 0.61738 lineto
0.45712 0.6177 lineto
0.45836 0.61791 lineto
0.45959 0.61802 lineto
0.46083 0.61802 lineto
0.46207 0.61792 lineto
0.46331 0.61772 lineto
0.46455 0.61741 lineto
0.46579 0.617 lineto
0.46703 0.61649 lineto
0.46827 0.61588 lineto
0.47074 0.61437 lineto
0.4757 0.61022 lineto
0.48065 0.60462 lineto
0.49057 0.58945 lineto
0.50048 0.56963 lineto
Mistroke
0.54012 0.45886 lineto
0.57976 0.32593 lineto
0.6194 0.19272 lineto
0.65905 0.06778 lineto
0.69869 -0.04667 lineto
0.73833 -0.15082 lineto
0.77798 -0.24568 lineto
0.81762 -0.33241 lineto
0.85726 -0.4121 lineto
0.8969 -0.48569 lineto
0.93655 -0.55401 lineto
0.97619 -0.61771 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.49443 -1 0 Mshowa
0 setgray
[(0.45)] 0.78571 0.37082 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.12361 [
[(Magnitude Response \(dB\) order =  4)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-5)] 0.01131 0 1 0 Msboxa
[(-4)] 0.01131 0.12361 1 0 Msboxa
[(-3)] 0.01131 0.24721 1 0 Msboxa
[(-2)] 0.01131 0.37082 1 0 Msboxa
[(-1)] 0.01131 0.49443 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  4)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-5)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-4)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-3)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-2)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-1)] 0.01131 0.49443 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -1.61454 moveto
0.026 -1.61462 lineto
0.02724 -1.61475 lineto
0.02848 -1.61494 lineto
0.02972 -1.61518 lineto
0.03219 -1.61585 lineto
0.03467 -1.61675 lineto
0.03715 -1.61788 lineto
0.03963 -1.61925 lineto
0.04458 -1.62271 lineto
0.04954 -1.62715 lineto
0.05449 -1.63259 lineto
0.0644 -1.64665 lineto
0.07432 -1.66529 lineto
0.08423 -1.68906 lineto
0.09414 -1.71873 lineto
0.10405 -1.75533 lineto
0.12387 -1.8555 lineto
0.13378 -1.92381 lineto
0.14369 -2.00927 lineto
0.1536 -2.11814 lineto
0.16351 -2.26068 lineto
0.16847 -2.34979 lineto
0.17342 -2.45526 lineto
0.17838 -2.58246 lineto
0.18333 -2.73974 lineto
0.18829 -2.94127 lineto
0.19077 -3.06614 lineto
0.19324 -3.21392 lineto
0.19572 -3.39336 lineto
0.1982 -3.61933 lineto
0.20068 -3.92039 lineto
0.20192 -4.11678 lineto
0.20315 -4.36327 lineto
0.22298 -2.86763 lineto
0.23289 -2.22158 lineto
0.2428 -1.74888 lineto
0.26262 -1.0107 lineto
0.28244 -0.39161 lineto
0.30226 0.14626 lineto
0.31217 0.36153 lineto
0.31713 0.44736 lineto
0.32208 0.51578 lineto
0.32704 0.56587 lineto
0.32952 0.58416 lineto
0.33199 0.59818 lineto
0.33323 0.60367 lineto
0.33447 0.6082 lineto
0.33571 0.61182 lineto
0.33695 0.61456 lineto
Mistroke
0.33819 0.61648 lineto
0.33943 0.61762 lineto
0.34067 0.61803 lineto
0.3419 0.61776 lineto
0.38155 0.46603 lineto
0.39146 0.42651 lineto
0.40137 0.39296 lineto
0.41128 0.36556 lineto
0.42119 0.34407 lineto
0.42615 0.33541 lineto
0.4311 0.32809 lineto
0.43606 0.32203 lineto
0.44101 0.3172 lineto
0.44349 0.31522 lineto
0.44597 0.31354 lineto
0.44844 0.31213 lineto
0.45092 0.31101 lineto
0.45216 0.31055 lineto
0.4534 0.31015 lineto
0.45464 0.30983 lineto
0.45588 0.30957 lineto
0.45712 0.30937 lineto
0.45836 0.30924 lineto
0.45959 0.30918 lineto
0.46083 0.30918 lineto
0.46207 0.30924 lineto
0.46331 0.30936 lineto
0.46455 0.30955 lineto
0.46579 0.3098 lineto
0.46703 0.31011 lineto
0.46827 0.31048 lineto
0.47074 0.3114 lineto
0.4757 0.31395 lineto
0.48065 0.31742 lineto
0.49057 0.32703 lineto
0.50048 0.34003 lineto
0.5203 0.37542 lineto
0.54012 0.42187 lineto
0.57976 0.53471 lineto
0.58967 0.56222 lineto
0.59958 0.58652 lineto
0.60454 0.59679 lineto
0.60949 0.60541 lineto
0.61445 0.61205 lineto
0.61693 0.61452 lineto
0.61817 0.61552 lineto
0.6194 0.61637 lineto
0.62064 0.61704 lineto
0.62188 0.61755 lineto
0.62312 0.61788 lineto
Mistroke
0.62436 0.61803 lineto
0.6256 0.61799 lineto
0.62684 0.61776 lineto
0.62808 0.61733 lineto
0.62932 0.61671 lineto
0.63055 0.61588 lineto
0.63179 0.61484 lineto
0.63427 0.61212 lineto
0.63675 0.60852 lineto
0.63923 0.60401 lineto
0.64418 0.59219 lineto
0.64914 0.57655 lineto
0.65905 0.5337 lineto
0.66896 0.47609 lineto
0.67887 0.40541 lineto
0.69869 0.2344 lineto
0.73833 -0.16417 lineto
0.77798 -0.57308 lineto
0.81762 -0.97272 lineto
0.85726 -1.37063 lineto
0.8969 -1.78446 lineto
0.93655 -2.24281 lineto
0.97619 -2.80168 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.49443 -1 0 Mshowa
0 setgray
[(0.25)] 0.78571 0.37082 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.12361 [
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-5)] 0.01131 0 1 0 Msboxa
[(-4)] 0.01131 0.12361 1 0 Msboxa
[(-3)] 0.01131 0.24721 1 0 Msboxa
[(-2)] 0.01131 0.37082 1 0 Msboxa
[(-1)] 0.01131 0.49443 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  6)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-5)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-4)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-3)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-2)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-1)] 0.01131 0.49443 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -7.9944 moveto
0.026 -7.09982 lineto
0.02724 -6.61875 lineto
0.02848 -6.28776 lineto
0.02972 -6.03517 lineto
0.03219 -5.65937 lineto
0.03467 -5.38172 lineto
0.03715 -5.16151 lineto
0.03963 -4.97907 lineto
0.04458 -4.68762 lineto
0.05449 -4.27211 lineto
0.0644 -3.97634 lineto
0.07432 -3.74819 lineto
0.08423 -3.56413 lineto
0.10405 -3.28347 lineto
0.12387 -3.08436 lineto
0.13378 -3.00954 lineto
0.14369 -2.95059 lineto
0.14865 -2.9273 lineto
0.1536 -2.90842 lineto
0.15608 -2.90073 lineto
0.15856 -2.89428 lineto
0.16103 -2.88912 lineto
0.16227 -2.88705 lineto
0.16351 -2.88533 lineto
0.16475 -2.88397 lineto
0.16599 -2.88298 lineto
0.16723 -2.88238 lineto
0.16847 -2.88218 lineto
0.16971 -2.88238 lineto
0.17094 -2.88302 lineto
0.17218 -2.88409 lineto
0.17342 -2.88562 lineto
0.1759 -2.89014 lineto
0.17714 -2.89317 lineto
0.17838 -2.89674 lineto
0.18086 -2.90561 lineto
0.18333 -2.91697 lineto
0.18581 -2.9311 lineto
0.18829 -2.9483 lineto
0.19324 -2.99351 lineto
0.1982 -3.05665 lineto
0.20315 -3.14387 lineto
0.20563 -3.1994 lineto
0.20811 -3.26514 lineto
0.21307 -3.43811 lineto
0.21554 -3.55382 lineto
0.21802 -3.69849 lineto
0.2205 -3.88512 lineto
0.22298 -4.13784 lineto
Mistroke
0.22422 -4.30334 lineto
0.22545 -4.50994 lineto
0.22669 -4.78061 lineto
0.22793 -5.16519 lineto
0.22917 -5.81141 lineto
0.23041 -7.97464 lineto
0.23165 -6.08316 lineto
0.23289 -5.22215 lineto
0.23413 -4.73179 lineto
0.23536 -4.38224 lineto
0.23784 -3.87908 lineto
0.24032 -3.50847 lineto
0.2428 -3.20897 lineto
0.25271 -2.33687 lineto
0.26262 -1.68619 lineto
0.28244 -0.59693 lineto
0.29235 -0.10719 lineto
0.29731 0.11351 lineto
0.30226 0.30434 lineto
0.30474 0.38453 lineto
0.30722 0.45277 lineto
0.30969 0.50834 lineto
0.31217 0.55124 lineto
0.31341 0.56813 lineto
0.31465 0.58217 lineto
0.31589 0.59354 lineto
0.31713 0.60245 lineto
0.31837 0.60911 lineto
0.31961 0.61376 lineto
0.32084 0.61662 lineto
0.32208 0.61791 lineto
0.32332 0.61784 lineto
0.32456 0.61663 lineto
0.3258 0.61445 lineto
0.32704 0.61147 lineto
0.33199 0.59439 lineto
0.3419 0.55423 lineto
0.34686 0.53726 lineto
0.35182 0.52386 lineto
0.35429 0.51856 lineto
0.35677 0.51418 lineto
0.35925 0.51071 lineto
0.36049 0.50929 lineto
0.36173 0.50809 lineto
0.36297 0.50708 lineto
0.3642 0.50628 lineto
0.36544 0.50567 lineto
0.36668 0.50524 lineto
0.36792 0.50499 lineto
0.36916 0.50492 lineto
Mistroke
0.3704 0.50501 lineto
0.37164 0.50526 lineto
0.37288 0.50566 lineto
0.37411 0.50622 lineto
0.37659 0.50774 lineto
0.37907 0.50978 lineto
0.38155 0.51228 lineto
0.39146 0.52602 lineto
0.40137 0.54365 lineto
0.42119 0.58092 lineto
0.4311 0.59667 lineto
0.44101 0.60858 lineto
0.44597 0.61282 lineto
0.44844 0.61447 lineto
0.45092 0.61582 lineto
0.45216 0.61637 lineto
0.4534 0.61684 lineto
0.45464 0.61724 lineto
0.45588 0.61755 lineto
0.45712 0.61779 lineto
0.45836 0.61794 lineto
0.45959 0.61802 lineto
0.46083 0.61803 lineto
0.46207 0.61795 lineto
0.46331 0.6178 lineto
0.46579 0.61727 lineto
0.46703 0.6169 lineto
0.46827 0.61645 lineto
0.47074 0.61535 lineto
0.4757 0.61233 lineto
0.48065 0.60832 lineto
0.49057 0.59778 lineto
0.50048 0.58472 lineto
0.5203 0.55531 lineto
0.53021 0.54098 lineto
0.54012 0.52812 lineto
0.55003 0.5175 lineto
0.55499 0.51324 lineto
0.55994 0.50979 lineto
0.5649 0.50722 lineto
0.56737 0.50628 lineto
0.56861 0.50589 lineto
0.56985 0.50558 lineto
0.57109 0.50532 lineto
0.57233 0.50512 lineto
0.57357 0.50499 lineto
0.57481 0.50492 lineto
0.57605 0.50492 lineto
0.57728 0.50499 lineto
0.57852 0.50512 lineto
Mistroke
0.57976 0.50531 lineto
0.581 0.50558 lineto
0.58224 0.50591 lineto
0.58472 0.50678 lineto
0.58719 0.50793 lineto
0.58967 0.50936 lineto
0.59463 0.51307 lineto
0.59958 0.51791 lineto
0.60949 0.53093 lineto
0.6194 0.54799 lineto
0.62932 0.56805 lineto
0.63923 0.58904 lineto
0.64914 0.60742 lineto
0.65161 0.61101 lineto
0.65409 0.61398 lineto
0.65533 0.6152 lineto
0.65657 0.61623 lineto
0.65781 0.61704 lineto
0.65905 0.61762 lineto
0.66029 0.61796 lineto
0.66153 0.61803 lineto
0.66276 0.61782 lineto
0.664 0.61731 lineto
0.66524 0.61648 lineto
0.66648 0.61532 lineto
0.66772 0.61381 lineto
0.66896 0.61192 lineto
0.67144 0.60697 lineto
0.67391 0.60034 lineto
0.67639 0.59189 lineto
0.67887 0.58151 lineto
0.68382 0.55461 lineto
0.68878 0.51909 lineto
0.69869 0.42207 lineto
0.7086 0.29386 lineto
0.71851 0.14203 lineto
0.73833 -0.20029 lineto
0.77798 -0.91425 lineto
0.81762 -1.61798 lineto
0.85726 -2.36331 lineto
0.87708 -2.79075 lineto
0.8969 -3.30296 lineto
0.90682 -3.61804 lineto
0.91673 -4.00602 lineto
0.92168 -4.24497 lineto
0.92664 -4.53329 lineto
0.93159 -4.90285 lineto
0.93407 -5.13842 lineto
0.93655 -5.43114 lineto
0.93779 -5.61006 lineto
Mistroke
0.93903 -5.82164 lineto
0.9415 -6.41913 lineto
0.94274 -6.90624 lineto
0.94398 -7.80328 lineto
0.94522 -9.13834 lineto
0.94646 -7.32627 lineto
0.9477 -6.69275 lineto
0.94894 -6.30145 lineto
0.95017 -6.01867 lineto
0.95141 -5.79775 lineto
0.95389 -5.46403 lineto
0.95637 -5.21581 lineto
0.96132 -4.85707 lineto
0.96628 -4.60093 lineto
0.97124 -4.40393 lineto
0.97619 -4.24539 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.49443 -1 0 Mshowa
0 setgray
[(0.1)] 0.78571 0.37082 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.12361 [
[(Magnitude Response \(dB\) order =  8)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-5)] 0.01131 0 1 0 Msboxa
[(-4)] 0.01131 0.12361 1 0 Msboxa
[(-3)] 0.01131 0.24721 1 0 Msboxa
[(-2)] 0.01131 0.37082 1 0 Msboxa
[(-1)] 0.01131 0.49443 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order =  8)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-5)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-4)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-3)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-2)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-1)] 0.01131 0.49443 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -4.18309 moveto
0.026 -4.18339 lineto
0.02724 -4.18393 lineto
0.02848 -4.1847 lineto
0.02972 -4.18571 lineto
0.03219 -4.18844 lineto
0.03467 -4.19213 lineto
0.03715 -4.19679 lineto
0.03963 -4.20243 lineto
0.04458 -4.21675 lineto
0.04954 -4.23524 lineto
0.05449 -4.25815 lineto
0.0644 -4.31853 lineto
0.07432 -4.40143 lineto
0.08423 -4.51248 lineto
0.09414 -4.66096 lineto
0.09909 -4.75387 lineto
0.10405 -4.86312 lineto
0.109 -4.99323 lineto
0.11396 -5.15104 lineto
0.11891 -5.34762 lineto
0.12387 -5.60273 lineto
0.12882 -5.95722 lineto
0.1313 -6.19969 lineto
0.13254 -6.34757 lineto
0.13378 -6.52099 lineto
0.13502 -6.73017 lineto
0.13626 -6.99302 lineto
0.1375 -7.34564 lineto
0.13874 -7.88034 lineto
0.14369 -7.35177 lineto
0.14493 -6.98244 lineto
0.14617 -6.70647 lineto
0.14865 -6.30179 lineto
0.15112 -6.00556 lineto
0.1536 -5.77151 lineto
0.15856 -5.4131 lineto
0.16351 -5.14283 lineto
0.16847 -4.92738 lineto
0.17342 -4.75035 lineto
0.17838 -4.60271 lineto
0.18333 -4.4793 lineto
0.18829 -4.37731 lineto
0.19324 -4.29559 lineto
0.19572 -4.26236 lineto
0.1982 -4.23442 lineto
0.20068 -4.21205 lineto
0.20192 -4.20307 lineto
0.20315 -4.19564 lineto
0.20439 -4.18984 lineto
Mistroke
0.20563 -4.18576 lineto
0.20687 -4.18348 lineto
0.20811 -4.18313 lineto
0.20935 -4.18483 lineto
0.21059 -4.18874 lineto
0.21183 -4.19503 lineto
0.21307 -4.20392 lineto
0.22298 -4.40916 lineto
0.22545 -4.52068 lineto
0.22669 -4.59211 lineto
0.22793 -4.6773 lineto
0.22917 -4.78003 lineto
0.23041 -4.90586 lineto
0.23165 -5.06352 lineto
0.23289 -5.26786 lineto
0.23413 -5.54739 lineto
0.23536 -5.96865 lineto
0.2366 -6.76447 lineto
0.23784 -8.51919 lineto
0.23908 -6.33382 lineto
0.24032 -5.62041 lineto
0.24156 -5.16643 lineto
0.2428 -4.8257 lineto
0.24528 -4.31264 lineto
0.24775 -3.91823 lineto
0.25271 -3.30132 lineto
0.25766 -2.80169 lineto
0.26262 -2.36308 lineto
0.28244 -0.84257 lineto
0.29235 -0.14669 lineto
0.29731 0.15785 lineto
0.29978 0.28697 lineto
0.30226 0.39524 lineto
0.30474 0.48017 lineto
0.30598 0.51374 lineto
0.30722 0.54163 lineto
0.30846 0.56422 lineto
0.30969 0.58197 lineto
0.31093 0.59543 lineto
0.31217 0.60517 lineto
0.31341 0.61177 lineto
0.31465 0.61578 lineto
0.31589 0.61769 lineto
0.31713 0.61797 lineto
0.31837 0.61699 lineto
0.31961 0.6151 lineto
0.32208 0.60961 lineto
0.32704 0.59681 lineto
0.32952 0.59118 lineto
0.33199 0.5866 lineto
Mistroke
0.33323 0.58475 lineto
0.33447 0.5832 lineto
0.33571 0.58195 lineto
0.33695 0.581 lineto
0.33819 0.58033 lineto
0.33943 0.57993 lineto
0.34067 0.57978 lineto
0.3419 0.57988 lineto
0.36173 0.59956 lineto
0.36668 0.60559 lineto
0.37164 0.6107 lineto
0.37659 0.61456 lineto
0.37907 0.61596 lineto
0.38031 0.61653 lineto
0.38155 0.617 lineto
0.38279 0.61739 lineto
0.38403 0.61768 lineto
0.38526 0.61788 lineto
0.3865 0.618 lineto
0.38774 0.61803 lineto
0.38898 0.61798 lineto
0.39022 0.61785 lineto
0.39146 0.61764 lineto
0.3927 0.61736 lineto
0.39394 0.617 lineto
0.39641 0.61609 lineto
0.39889 0.61493 lineto
0.40137 0.61356 lineto
0.41128 0.60652 lineto
0.42119 0.59837 lineto
0.4311 0.59071 lineto
0.44101 0.58467 lineto
0.44597 0.58249 lineto
0.44844 0.58163 lineto
0.45092 0.58094 lineto
0.45216 0.58065 lineto
0.4534 0.5804 lineto
0.45464 0.5802 lineto
0.45588 0.58004 lineto
0.45712 0.57991 lineto
0.45836 0.57983 lineto
0.45959 0.57979 lineto
0.46083 0.57979 lineto
0.50048 0.59657 lineto
0.5203 0.60946 lineto
0.52525 0.61212 lineto
0.53021 0.61437 lineto
0.53269 0.61532 lineto
0.53516 0.61614 lineto
0.53764 0.61682 lineto
Mistroke
0.54012 0.61735 lineto
0.54136 0.61756 lineto
0.5426 0.61773 lineto
0.54384 0.61787 lineto
0.54507 0.61796 lineto
0.54631 0.61802 lineto
0.54755 0.61803 lineto
0.54879 0.61801 lineto
0.55003 0.61794 lineto
0.55127 0.61784 lineto
0.55251 0.61769 lineto
0.55499 0.61728 lineto
0.55746 0.6167 lineto
0.55994 0.61597 lineto
0.5649 0.61406 lineto
0.56985 0.61159 lineto
0.57976 0.60529 lineto
0.58967 0.59788 lineto
0.59958 0.59042 lineto
0.60454 0.58706 lineto
0.60949 0.58416 lineto
0.61445 0.58187 lineto
0.61693 0.58101 lineto
0.61817 0.58066 lineto
0.6194 0.58037 lineto
0.62064 0.58013 lineto
0.62188 0.57995 lineto
0.62312 0.57984 lineto
0.62436 0.57979 lineto
0.6256 0.5798 lineto
0.62684 0.57988 lineto
0.62808 0.58003 lineto
0.62932 0.58025 lineto
0.63055 0.58054 lineto
0.63179 0.5809 lineto
0.63427 0.58185 lineto
0.63675 0.58309 lineto
0.63923 0.58463 lineto
0.64418 0.58858 lineto
0.64914 0.59357 lineto
0.65905 0.60554 lineto
0.664 0.61142 lineto
0.66648 0.61396 lineto
0.66772 0.61507 lineto
0.66896 0.61604 lineto
0.6702 0.61684 lineto
0.67144 0.61746 lineto
0.67267 0.61787 lineto
0.67391 0.61803 lineto
0.67515 0.61792 lineto
Mistroke
0.67639 0.61751 lineto
0.67763 0.61675 lineto
0.67887 0.61562 lineto
0.68135 0.6121 lineto
0.68259 0.60962 lineto
0.68382 0.60662 lineto
0.6863 0.59887 lineto
0.68878 0.58852 lineto
0.69126 0.57527 lineto
0.69374 0.55883 lineto
0.69869 0.51541 lineto
0.70365 0.45696 lineto
0.7086 0.38333 lineto
0.71851 0.19552 lineto
0.73833 -0.27869 lineto
0.77798 -1.28824 lineto
0.81762 -2.26757 lineto
0.85726 -3.34117 lineto
0.86717 -3.66036 lineto
0.87708 -4.02358 lineto
0.88699 -4.461 lineto
0.89195 -4.72631 lineto
0.8969 -5.04366 lineto
0.89938 -5.23158 lineto
0.90186 -5.44831 lineto
0.90682 -6.0295 lineto
0.90929 -6.46819 lineto
0.91053 -6.76835 lineto
0.91177 -7.17505 lineto
0.91301 -7.8173 lineto
0.91425 -9.54764 lineto
0.91549 -8.39678 lineto
0.91673 -7.49688 lineto
0.91797 -7.02308 lineto
0.9192 -6.70186 lineto
0.92044 -6.45992 lineto
0.92168 -6.26668 lineto
0.92416 -5.96993 lineto
0.92664 -5.74708 lineto
0.93159 -5.42487 lineto
0.93655 -5.19704 lineto
0.9415 -5.02463 lineto
0.94646 -4.88862 lineto
0.95141 -4.77832 lineto
0.95637 -4.6871 lineto
0.96628 -4.54571 lineto
0.97619 -4.44267 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.49443 -1 0 Mshowa
0 setgray
[(0.035)] 0.78571 0.37082 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.12361 [
[(Magnitude Response \(dB\) order = 10)] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(-5)] 0.01131 0 1 0 Msboxa
[(-4)] 0.01131 0.12361 1 0 Msboxa
[(-3)] 0.01131 0.24721 1 0 Msboxa
[(-2)] 0.01131 0.37082 1 0 Msboxa
[(-1)] 0.01131 0.49443 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\) order = 10)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-5)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-4)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-3)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-2)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-1)] 0.01131 0.49443 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02476 -9.9765 moveto
0.026 -9.08201 lineto
0.02724 -8.60112 lineto
0.02848 -8.27039 lineto
0.02972 -8.01813 lineto
0.03219 -7.64324 lineto
0.03467 -7.36682 lineto
0.03715 -7.14815 lineto
0.03963 -6.96757 lineto
0.04458 -6.68084 lineto
0.04954 -6.45867 lineto
0.05449 -6.27882 lineto
0.0644 -6.00237 lineto
0.07432 -5.80001 lineto
0.08423 -5.64915 lineto
0.09414 -5.53864 lineto
0.09909 -5.49667 lineto
0.10405 -5.46309 lineto
0.10653 -5.44941 lineto
0.109 -5.4378 lineto
0.11148 -5.42827 lineto
0.11396 -5.42087 lineto
0.1152 -5.41797 lineto
0.11644 -5.41563 lineto
0.11767 -5.41383 lineto
0.11891 -5.41259 lineto
0.12015 -5.41193 lineto
0.12139 -5.41185 lineto
0.12263 -5.41235 lineto
0.12387 -5.41346 lineto
0.12511 -5.41519 lineto
0.12635 -5.41755 lineto
0.12882 -5.42422 lineto
0.1313 -5.43362 lineto
0.13378 -5.44592 lineto
0.13626 -5.46132 lineto
0.13874 -5.48004 lineto
0.14369 -5.52861 lineto
0.14865 -5.59449 lineto
0.1536 -5.6818 lineto
0.15856 -5.79671 lineto
0.16351 -5.94904 lineto
0.16847 -6.15571 lineto
0.17094 -6.28866 lineto
0.17342 -6.45003 lineto
0.1759 -6.6514 lineto
0.17838 -6.91358 lineto
0.18086 -7.28029 lineto
0.18209 -7.53337 lineto
0.18333 -7.87276 lineto
Mistroke
0.22298 -5.41181 lineto
0.26262 -2.95753 lineto
0.28244 -1.02922 lineto
0.2874 -0.5731 lineto
0.29235 -0.13969 lineto
0.29483 0.05643 lineto
0.29731 0.22877 lineto
0.29978 0.3697 lineto
0.30102 0.42681 lineto
0.30226 0.47483 lineto
0.3035 0.5141 lineto
0.30474 0.54525 lineto
0.30598 0.56921 lineto
0.30722 0.58698 lineto
0.30846 0.59965 lineto
0.30969 0.60822 lineto
0.31093 0.61361 lineto
0.31217 0.61661 lineto
0.31341 0.61788 lineto
0.31465 0.61794 lineto
0.31589 0.61722 lineto
0.31713 0.61603 lineto
0.31961 0.61313 lineto
0.32208 0.61043 lineto
0.32332 0.60934 lineto
0.32456 0.60848 lineto
0.3258 0.60785 lineto
0.32704 0.60745 lineto
0.32828 0.60726 lineto
0.32952 0.60727 lineto
0.33076 0.60747 lineto
0.33199 0.60781 lineto
0.33447 0.60886 lineto
0.33695 0.61024 lineto
0.3419 0.61329 lineto
0.34686 0.61592 lineto
0.3481 0.61643 lineto
0.34934 0.61688 lineto
0.35058 0.61725 lineto
0.35182 0.61755 lineto
0.35305 0.61778 lineto
0.35429 0.61793 lineto
0.35553 0.61802 lineto
0.35677 0.61803 lineto
0.35801 0.61798 lineto
0.35925 0.61787 lineto
0.36049 0.6177 lineto
0.36173 0.61747 lineto
0.3642 0.61689 lineto
0.36668 0.61615 lineto
Mistroke
0.37164 0.61436 lineto
0.37659 0.61243 lineto
0.38155 0.61061 lineto
0.3865 0.60909 lineto
0.38898 0.60849 lineto
0.39146 0.60799 lineto
0.3927 0.60779 lineto
0.39394 0.60763 lineto
0.39517 0.60749 lineto
0.39641 0.60738 lineto
0.39765 0.6073 lineto
0.39889 0.60726 lineto
0.40013 0.60724 lineto
0.40137 0.60726 lineto
0.40261 0.6073 lineto
0.40385 0.60737 lineto
0.40509 0.60747 lineto
0.40632 0.60759 lineto
0.4088 0.60791 lineto
0.41128 0.60832 lineto
0.42119 0.61061 lineto
0.4311 0.61337 lineto
0.44101 0.61585 lineto
0.44597 0.61681 lineto
0.44844 0.61719 lineto
0.45092 0.61751 lineto
0.45216 0.61764 lineto
0.4534 0.61775 lineto
0.45464 0.61784 lineto
0.45588 0.61792 lineto
0.45712 0.61797 lineto
0.45836 0.61801 lineto
0.45959 0.61803 lineto
0.46083 0.61803 lineto
0.46207 0.61801 lineto
0.46331 0.61798 lineto
0.46579 0.61785 lineto
0.46703 0.61776 lineto
0.46827 0.61766 lineto
0.47074 0.6174 lineto
0.4757 0.6167 lineto
0.48065 0.61579 lineto
0.50048 0.61122 lineto
0.50543 0.61012 lineto
0.51039 0.60914 lineto
0.51534 0.60833 lineto
0.51782 0.608 lineto
0.5203 0.60773 lineto
0.52278 0.60751 lineto
0.52401 0.60743 lineto
Mistroke
0.52525 0.60736 lineto
0.52649 0.60731 lineto
0.52773 0.60727 lineto
0.52897 0.60725 lineto
0.53021 0.60724 lineto
0.53145 0.60726 lineto
0.53269 0.60728 lineto
0.53392 0.60733 lineto
0.53516 0.60739 lineto
0.53764 0.60756 lineto
0.54012 0.60779 lineto
0.54507 0.60843 lineto
0.55003 0.60929 lineto
0.55994 0.61149 lineto
0.56985 0.61398 lineto
0.57481 0.61517 lineto
0.57976 0.61623 lineto
0.58472 0.6171 lineto
0.58719 0.61744 lineto
0.58967 0.61771 lineto
0.59091 0.61781 lineto
0.59215 0.6179 lineto
0.59339 0.61797 lineto
0.59463 0.61801 lineto
0.59587 0.61803 lineto
0.59711 0.61803 lineto
0.59834 0.61801 lineto
0.59958 0.61796 lineto
0.60082 0.61789 lineto
0.60206 0.6178 lineto
0.60454 0.61755 lineto
0.60702 0.61721 lineto
0.60949 0.61677 lineto
0.61445 0.61567 lineto
0.6194 0.61429 lineto
0.62932 0.61112 lineto
0.63427 0.60959 lineto
0.63675 0.60891 lineto
0.63923 0.60832 lineto
0.6417 0.60784 lineto
0.64294 0.60764 lineto
0.64418 0.60749 lineto
0.64542 0.60736 lineto
0.64666 0.60728 lineto
0.6479 0.60725 lineto
0.64914 0.60725 lineto
0.65038 0.60731 lineto
0.65161 0.60741 lineto
0.65285 0.60756 lineto
0.65409 0.60776 lineto
Mistroke
0.65657 0.60832 lineto
0.65905 0.60909 lineto
0.664 0.61117 lineto
0.66896 0.61378 lineto
0.67144 0.61513 lineto
0.67391 0.61637 lineto
0.67515 0.61692 lineto
0.67639 0.61738 lineto
0.67763 0.61773 lineto
0.67887 0.61796 lineto
0.68011 0.61803 lineto
0.68135 0.61791 lineto
0.68259 0.61757 lineto
0.68382 0.61696 lineto
0.68506 0.61604 lineto
0.6863 0.61478 lineto
0.68754 0.61311 lineto
0.68878 0.61099 lineto
0.69002 0.60836 lineto
0.69126 0.60515 lineto
0.69374 0.59679 lineto
0.69621 0.58536 lineto
0.69869 0.57033 lineto
0.70117 0.55114 lineto
0.70365 0.5273 lineto
0.7086 0.46401 lineto
0.71356 0.37852 lineto
0.71851 0.27126 lineto
0.73833 -0.30673 lineto
0.77798 -1.59718 lineto
0.81762 -2.83648 lineto
0.85726 -4.21891 lineto
0.86717 -4.6502 lineto
0.87708 -5.16893 lineto
0.88204 -5.48603 lineto
0.88699 -5.87189 lineto
0.89195 -6.38423 lineto
0.89443 -6.73219 lineto
0.89567 -6.94793 lineto
0.8969 -7.20816 lineto
0.89814 -7.53903 lineto
0.89938 -7.99984 lineto
0.90062 -8.78379 lineto
0.90186 -12.25417 lineto
0.9031 -8.73759 lineto
0.90434 -8.03184 lineto
0.90558 -7.62157 lineto
0.90682 -7.33434 lineto
0.90929 -6.93876 lineto
0.91053 -6.79234 lineto
Mistroke
0.91177 -6.66777 lineto
0.91425 -6.46525 lineto
0.91673 -6.30606 lineto
0.92168 -6.06941 lineto
0.92664 -5.9012 lineto
0.93159 -5.77619 lineto
0.93655 -5.68091 lineto
0.9415 -5.60734 lineto
0.94646 -5.55029 lineto
0.95141 -5.50626 lineto
0.95637 -5.47274 lineto
0.96132 -5.4479 lineto
0.9638 -5.43829 lineto
0.96628 -5.43036 lineto
0.96876 -5.42398 lineto
0.97124 -5.41904 lineto
0.97371 -5.41545 lineto
0.97495 -5.41413 lineto
0.97619 -5.41312 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.02381 0.61803 Mdot
grestore
gsave
0.008 setlinewidth
0.02381 0 Mdot
0.02381 0.61803 Mdot
grestore
gsave
0 setgray
[(ripple:)] 0.78571 0.49443 -1 0 Mshowa
0 setgray
[(0.01)] 0.78571 0.37082 -1 0 Mshowa
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; endGroup; ]
		Examine the filter orders.  Why are they all even?  That is, are bandpass filter designs based on a lowpass filter prototype always even?
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Generating the animation
:[font = text; inactive; ]
		The function ebpfreqresp takes the desired ripple as the lone argument and a graph of the magnitude response of a bandpass elliptic filter.  The reason for a function is that for the animation to make sense we had to change the title of each plot to include the filter order.
:[font = input; initialization; ]
*)
ebpfreqresp[ripple_, {mindB_, maxdB_}, {ripx_, ripy_}] :=
Block [	{filter, format, label, order = "Error", plot,
		 response, s, step, t, transferfunction, w},
		Off[ DesignFilter::narrower ];
		filter = DesignFilter[Analog, Elliptic, Bandpass, t,
				 			  ripple, ripple, 10, 30, 70, 90];
		On[ DesignFilter::narrower ];
				 			  
		(* find filter order *)
		transferfunction = TheFunction[LaPlace[filter, t, s]];
		order = Exponent[Denominator[transferfunction], s];
		
		(* compute frequency response and make magnitude plot *)
		response = transferfunction /. s -> I w;
	 	plot = MagPhasePlot[ response,
							 {w, 0.1, 100},
							 DisplayFunction -> Identity,
							 MagRangeScale -> Log,
							 PhaseRangeScale -> Null,
							 PlotRange -> { mindB, maxdB } ];
							 
		(* adjust the plot title to include filter order *)
		format = If [ order > 9, "``", " ``" ];
		label = "Magnitude Response (dB) order = " ~StringJoin~
				ToString[StringForm[format, order]];
		step = ( maxdB - mindB ) / 5;
		Show [ plot,
				Graphics[ Point[{0, mindB}], Point[{0, maxdB}] ],
				Graphics[ Text["ripple:", {ripx, ripy}, {-1, 0}],
					Text[ripple, {ripx, ripy - step}, {-1, 0}] ],
				DisplayFunction :> $DisplayFunction,
				PlotLabel -> label,
				PlotRange -> { mindB, maxdB } ] ]
(*
:[font = text; inactive; ]
The following code generates the  graphics cells grouped for the animation.  In the first animation, we keep the filter order constant and vary the ripple control parameter:
:[font = input; ]
Map[ ebpfreqresp[#1, {-4, 0}, {80, -1}]&,
	 { .06, .07, .08, .09, .10,
	   .11, .12, .13, .14, .15, .16 } ]
:[font = text; inactive; ]
The second animation varies the filter order by two each frame:
:[font = input; endGroup; endGroup; endGroup; ]
Map[ ebpfreqresp[#1, {-5, 0}, {80, -1}]&,
	 { 0.45, 0.25, 0.1, 0.035, 0.01 } ]
:[font = section; inactive; startGroup; Cclosed; ]
Manipulating Filter Objects
:[font = text; inactive; ]
		At this point, we have generated a variety of filter structures whose magnitude responses meet given specifications.  Once we generate a filter object, we can then use it in other expressions (modulation), specify an alternate input function (in lieu of the Dirac delta function) to it, transform it, or plot its frequency response.  We can also quantize the filter coefficients (or its poles and zeroes) to get a better feeling to how the implemented filter might behave (for example, it is difficult to get more than three digits of accuracy when using resistors, capacitors, and inductors).
:[font = subsection; inactive; startGroup; Cclosed; ]
Transform of a Filter Expression
:[font = text; inactive; ]
		For example, we will take the Laplace transform of an analog filter shifted in the frequency domain by w0 rad.  The filter is the fourth order Butterworth filter which was previously designed and assigned to the Mathematica variable bfilter:
:[font = input; startGroup; Cclosed; ]

bfilter
:[font = output; inactive; output; endGroup; ]
234256*CIIR[t, {234256., 27824.56490000732, 
    1652.479364188578, 57.48877045456058, 1}]
;[o]
234256 CIIR[t, {234256., 27824.6, 1652.48, 57.4888, 1}]
:[font = input; startGroup; Cclosed; ]

LaPlace[ Exp[I w0 t] bfilter, t, s ]
:[font = output; inactive; output; endGroup; endGroup; ]
LTransData[234256/
   (234256. + 27824.56490000732*(s + -I*w0) + 
     1652.479364188578*(s + -I*w0)^2 + 
     57.48877045456058*(s + -I*w0)^3 + (s + -I*w0)^4), 
  Rminus[-Re[-I*w0]], Rplus[DirectedInfinity[1]], 
  LVariables[s]]
;[o]
LTransData[234256 / 
 
   (234256. + 27824.6 (s + -I w0) + 
 
                        2                      3
     1652.48 (s + -I w0)  + 57.4888 (s + -I w0)  + 
 
                4
     (s + -I w0) ), Rminus[-Re[-I w0]], Rplus[Infinity], 
 
  LVariables[s]]
:[font = subsection; inactive; startGroup; Cclosed; ]
Symbolic Filtering (Symbolic Convolution)
:[font = text; inactive; ]
		The output of an analog filter is the convolution of the input function with the impulse response of the filter.  If the input function has a Laplace transform, then the filter output is simply the inverse Laplace transform of the product of the Laplace transform of the filter and the Laplace transform of the input function.  This is purely symbolic convolution. 
:[font = text; inactive; ]
		As an example of this, we will use the fourth-order Butterworth filter design earlier in the notebook and assigned to the variable bfilter:
:[font = input; startGroup; ]
bfilter
:[font = output; inactive; output; endGroup; ]
234256*CIIR[t, {234256., 27824.56490000732, 
    1652.479364188578, 57.48877045456058, 1}, 
   Roots -> {22*E^((5*I)/8*Pi), 22*E^((7*I)/8*Pi), 
     22*E^((9*I)/8*Pi), 22*E^((11*I)/8*Pi)}]
;[o]
234256 CIIR[t, {234256., 27824.6, 1652.48, 57.4888, 1}]
:[font = text; inactive; ]
We will use this to filter a sum of two right-sided sinusoids:
:[font = input; startGroup; ]
input =
Cos[w0 t] CStep[t] + Cos[w1 t] CStep[t]
:[font = output; inactive; output; endGroup; ]
CStep[t]*Cos[t*w0] + CStep[t]*Cos[t*w1]
;[o]
CStep[t] Cos[t w0] + CStep[t] Cos[t w1]
:[font = input; startGroup; ]
conv =
LaPlace[ Convolve[t][input, bfilter], t, s ]
:[font = output; inactive; output; endGroup; ]
LTransData[(234256*(s/(s^2 + w0^2) + s/(s^2 + w1^2)))/
   (234256. + 27824.56490000732*s + 1652.479364188578*s^2 + 
     57.48877045456058*s^3 + s^4), Rminus[0], 
  Rplus[DirectedInfinity[1]], LVariables[s]]
;[o]
LTransData[
 
                         s          s
              234256 (-------- + --------)
                       2     2    2     2
                      s  + w0    s  + w1
   --------------------------------------------------, 
                                  2            3    4
   234256. + 27824.6 s + 1652.48 s  + 57.4888 s  + s
 
  Rminus[0], Rplus[Infinity], LVariables[s]]
:[font = input; startGroup; ]
InvLaPlace[ conv ]
:[font = print; inactive; startGroup; ]
Breaking up the denominator of
:[font = print; inactive; ]
                      s          s
           234256 (-------- + --------)
                    2     2    2     2
                   s  + w0    s  + w1
--------------------------------------------------
                               2            3    4
234256. + 27824.6 s + 1652.48 s  + 57.4888 s  + s
:[font = print; inactive; ]
into its approximate roots
:[font = print; inactive; ]
            3       2       2
(234256 (2 s  + s w0  + s w1 )) / 
 
  ((8.41904 - 20.3253 I + s) (8.41904 + 20.3253 I + s) 
 
    (20.3253 - 8.41904 I + s) (20.3253 + 8.41904 I + s) 
 
      2     2    2     2
    (s  + w0 ) (s  + w1 ))
:[font = print; inactive; ]
Option Apart is not All so partial
:[font = print; inactive; ]
fractions decomposition on real-valued
:[font = print; inactive; ]
poles was not performed
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
(234256*(2*s^3 + s*w0^2 + s*w1^2))/
  ((8.41903551201782 - 20.32534971523457*I + s)*
    (8.41903551201782 + 20.32534971523457*I + s)*
    (20.32534971528209 - 8.41903551199771*I + s)*
    (20.32534971528209 + 8.41903551199771*I + s)*(s^2 + w0^2)*
    (s^2 + w1^2))
;[o]
            3       2       2
(234256 (2 s  + s w0  + s w1 )) / 
 
  ((8.41904 - 20.3253 I + s) (8.41904 + 20.3253 I + s) 
 
    (20.3253 - 8.41904 I + s) (20.3253 + 8.41904 I + s) 
 
      2     2    2     2
    (s  + w0 ) (s  + w1 ))
:[font = subsection; inactive; startGroup; Cclosed; ]
Coefficient Quantization
:[font = text; inactive; ]
		For example, let's look at the frequency response of the Chebyshev type I bandpass filter previously design and assigned to the Mathematica variable bpfilter.  It has a frequency response of bpfiltertrans.  Without coefficient quantization, it is a bandpass filter that rejects frequencies below 10 rad/sec and above 90 rad/sec and that passes frequencies between 30 rad/sec and 70 rad/sec, as shown below.
:[font = input; startGroup; Cclosed; ]

MagPhasePlot[ bpfiltertrans,
              {w, 1, 100},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(w)] 1.00625 0.61803 -1 0 Msboxa
[(-100)] 0.01131 0 1 0 Msboxa
[(-80)] 0.01131 0.12361 1 0 Msboxa
[(-60)] 0.01131 0.24721 1 0 Msboxa
[(-40)] 0.01131 0.37082 1 0 Msboxa
[(-20)] 0.01131 0.49443 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.61803 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-100)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-80)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-60)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-40)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-20)] 0.01131 0.49443 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.03333 -0.98878 moveto
0.03824 -0.83224 lineto
0.04315 -0.72182 lineto
0.04807 -0.63631 lineto
0.05298 -0.56641 lineto
0.0628 -0.45576 lineto
0.07262 -0.36928 lineto
0.09226 -0.23661 lineto
0.1119 -0.1342 lineto
0.15119 0.0265 lineto
0.19048 0.16098 lineto
0.22976 0.29043 lineto
0.26905 0.4359 lineto
0.28869 0.52935 lineto
0.2936 0.55687 lineto
0.29851 0.58468 lineto
0.30097 0.5971 lineto
0.30219 0.60243 lineto
0.30342 0.60698 lineto
0.30465 0.61066 lineto
0.30588 0.61346 lineto
0.30711 0.61545 lineto
0.30833 0.61675 lineto
0.30956 0.61751 lineto
0.31079 0.6179 lineto
0.31202 0.61803 lineto
0.31324 0.61801 lineto
0.3157 0.6178 lineto
0.31693 0.61768 lineto
0.31815 0.61759 lineto
0.31938 0.61753 lineto
0.32061 0.6175 lineto
0.32184 0.6175 lineto
0.32307 0.61753 lineto
0.32552 0.61763 lineto
0.32798 0.61777 lineto
0.33043 0.6179 lineto
0.33166 0.61795 lineto
0.33289 0.61799 lineto
0.33411 0.61802 lineto
0.33534 0.61803 lineto
0.33657 0.61803 lineto
0.3378 0.61802 lineto
0.33903 0.618 lineto
0.34025 0.61797 lineto
0.34271 0.61789 lineto
0.34762 0.61769 lineto
0.35007 0.61761 lineto
0.3513 0.61758 lineto
0.35253 0.61755 lineto
Mistroke
0.35376 0.61752 lineto
0.35499 0.61751 lineto
0.35621 0.6175 lineto
0.35744 0.61749 lineto
0.35867 0.6175 lineto
0.3599 0.61751 lineto
0.36112 0.61752 lineto
0.36235 0.61754 lineto
0.36481 0.6176 lineto
0.36726 0.61767 lineto
0.37217 0.61781 lineto
0.37463 0.61788 lineto
0.37708 0.61794 lineto
0.37831 0.61797 lineto
0.37954 0.61799 lineto
0.38077 0.618 lineto
0.38199 0.61802 lineto
0.38322 0.61803 lineto
0.38445 0.61803 lineto
0.38568 0.61803 lineto
0.3869 0.61803 lineto
0.38813 0.61802 lineto
0.38936 0.61801 lineto
0.39182 0.61798 lineto
0.39427 0.61794 lineto
0.39673 0.61789 lineto
0.40164 0.61777 lineto
0.40655 0.61765 lineto
0.409 0.6176 lineto
0.41146 0.61756 lineto
0.41269 0.61754 lineto
0.41391 0.61753 lineto
0.41514 0.61752 lineto
0.41637 0.61751 lineto
0.4176 0.6175 lineto
0.41882 0.6175 lineto
0.42005 0.61749 lineto
0.42128 0.6175 lineto
0.42251 0.6175 lineto
0.42374 0.61751 lineto
0.42619 0.61753 lineto
0.43601 0.61769 lineto
0.44092 0.61779 lineto
0.44583 0.61789 lineto
0.44829 0.61793 lineto
0.45074 0.61797 lineto
0.4532 0.618 lineto
0.45443 0.61801 lineto
0.45565 0.61802 lineto
0.45688 0.61803 lineto
Mistroke
0.45811 0.61803 lineto
0.45934 0.61803 lineto
0.46057 0.61803 lineto
0.46179 0.61803 lineto
0.46302 0.61803 lineto
0.46425 0.61802 lineto
0.46548 0.61801 lineto
0.46793 0.61799 lineto
0.47039 0.61796 lineto
0.4753 0.61789 lineto
0.48512 0.61771 lineto
0.49003 0.61762 lineto
0.49249 0.61758 lineto
0.49494 0.61755 lineto
0.4974 0.61753 lineto
0.49862 0.61752 lineto
0.49985 0.61751 lineto
0.50108 0.6175 lineto
0.50231 0.6175 lineto
0.50353 0.6175 lineto
0.50476 0.61749 lineto
0.50599 0.6175 lineto
0.50722 0.6175 lineto
0.50844 0.6175 lineto
0.50967 0.61751 lineto
0.51213 0.61753 lineto
0.51458 0.61755 lineto
0.51949 0.61762 lineto
0.5244 0.6177 lineto
0.53423 0.61788 lineto
0.53914 0.61795 lineto
0.54159 0.61798 lineto
0.54405 0.61801 lineto
0.54528 0.61802 lineto
0.5465 0.61802 lineto
0.54773 0.61803 lineto
0.54896 0.61803 lineto
0.55019 0.61803 lineto
0.55141 0.61803 lineto
0.55264 0.61803 lineto
0.55387 0.61803 lineto
0.5551 0.61802 lineto
0.55632 0.61801 lineto
0.55878 0.61799 lineto
0.56124 0.61796 lineto
0.56369 0.61793 lineto
0.57351 0.61776 lineto
0.57842 0.61767 lineto
0.58333 0.61758 lineto
0.58579 0.61755 lineto
Mistroke
0.58824 0.61753 lineto
0.58947 0.61752 lineto
0.5907 0.61751 lineto
0.59193 0.6175 lineto
0.59315 0.6175 lineto
0.59438 0.61749 lineto
0.59561 0.61749 lineto
0.59684 0.6175 lineto
0.59807 0.6175 lineto
0.59929 0.61751 lineto
0.60052 0.61752 lineto
0.60298 0.61754 lineto
0.60543 0.61758 lineto
0.60789 0.61762 lineto
0.6128 0.61771 lineto
0.61771 0.61782 lineto
0.62262 0.61792 lineto
0.62507 0.61796 lineto
0.62753 0.61799 lineto
0.62876 0.61801 lineto
0.62999 0.61802 lineto
0.63121 0.61803 lineto
0.63244 0.61803 lineto
0.63367 0.61803 lineto
0.6349 0.61803 lineto
0.63612 0.61803 lineto
0.63735 0.61802 lineto
0.63858 0.61801 lineto
0.63981 0.618 lineto
0.64226 0.61796 lineto
0.64717 0.61785 lineto
0.65208 0.61772 lineto
0.65454 0.61765 lineto
0.65699 0.61759 lineto
0.65822 0.61756 lineto
0.65945 0.61754 lineto
0.66068 0.61752 lineto
0.6619 0.61751 lineto
0.66313 0.6175 lineto
0.66436 0.61749 lineto
0.66559 0.6175 lineto
0.66682 0.61751 lineto
0.66804 0.61752 lineto
0.66927 0.61755 lineto
0.67173 0.61761 lineto
0.67418 0.6177 lineto
0.67664 0.61781 lineto
0.67909 0.61791 lineto
0.68032 0.61796 lineto
0.68155 0.618 lineto
Mistroke
0.68278 0.61803 lineto
0.684 0.61803 lineto
0.68523 0.61802 lineto
0.68646 0.61797 lineto
0.68769 0.61788 lineto
0.68891 0.61775 lineto
0.69014 0.61756 lineto
0.69137 0.6173 lineto
0.6926 0.61696 lineto
0.69382 0.61654 lineto
0.69628 0.61538 lineto
0.69874 0.61374 lineto
0.70119 0.61156 lineto
0.7061 0.60544 lineto
0.71101 0.59718 lineto
0.72083 0.57677 lineto
0.74048 0.53427 lineto
0.77976 0.46533 lineto
0.81905 0.41239 lineto
0.85833 0.36899 lineto
0.89762 0.33193 lineto
0.9369 0.29944 lineto
0.97619 0.27043 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.01419 0.00962 0.30904 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.20659 0.29654 0 1 Msboxa
[(40)] 0.39899 0.29654 0 1 Msboxa
[(60)] 0.59139 0.29654 0 1 Msboxa
[(80)] 0.78379 0.29654 0 1 Msboxa
[(100)] 0.97619 0.29654 0 1 Msboxa
[(w)] 1.00625 0.30904 -1 0 Msboxa
[(-150)] 0.00169 0.06347 1 0 Msboxa
[(-100)] 0.00169 0.14533 1 0 Msboxa
[(-50)] 0.00169 0.22718 1 0 Msboxa
[(50)] 0.00169 0.39089 1 0 Msboxa
[(100)] 0.00169 0.47275 1 0 Msboxa
[(150)] 0.00169 0.5546 1 0 Msboxa
[( )] 0.01419 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30904 moveto
1 0.30904 lineto
stroke
0.20659 0.30279 moveto
0.20659 0.31529 lineto
stroke
0 setgray
[(20)] 0.20659 0.29654 0 1 Mshowa
0.39899 0.30279 moveto
0.39899 0.31529 lineto
stroke
0 setgray
[(40)] 0.39899 0.29654 0 1 Mshowa
0.59139 0.30279 moveto
0.59139 0.31529 lineto
stroke
0 setgray
[(60)] 0.59139 0.29654 0 1 Mshowa
0.78379 0.30279 moveto
0.78379 0.31529 lineto
stroke
0 setgray
[(80)] 0.78379 0.29654 0 1 Mshowa
0.97619 0.30279 moveto
0.97619 0.31529 lineto
stroke
0 setgray
[(100)] 0.97619 0.29654 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30904 -1 0 Mshowa
0.01419 0 moveto
0.01419 0.61803 lineto
stroke
0.00794 0.06347 moveto
0.02044 0.06347 lineto
stroke
0 setgray
[(-150)] 0.00169 0.06347 1 0 Mshowa
0.00794 0.14533 moveto
0.02044 0.14533 lineto
stroke
0 setgray
[(-100)] 0.00169 0.14533 1 0 Mshowa
0.00794 0.22718 moveto
0.02044 0.22718 lineto
stroke
0 setgray
[(-50)] 0.00169 0.22718 1 0 Mshowa
0.00794 0.39089 moveto
0.02044 0.39089 lineto
stroke
0 setgray
[(50)] 0.00169 0.39089 1 0 Mshowa
0.00794 0.47275 moveto
0.02044 0.47275 lineto
stroke
0 setgray
[(100)] 0.00169 0.47275 1 0 Mshowa
0.00794 0.5546 moveto
0.02044 0.5546 lineto
stroke
0 setgray
[(150)] 0.00169 0.5546 1 0 Mshowa
0 setgray
[( )] 0.01419 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.15859 moveto
0.06349 0.14551 lineto
0.10317 0.13135 lineto
0.14286 0.11492 lineto
0.1627 0.10527 lineto
0.18254 0.09416 lineto
0.20238 0.08094 lineto
0.22222 0.06451 lineto
0.23214 0.05452 lineto
0.24206 0.0428 lineto
0.24702 0.03609 lineto
0.25198 0.02864 lineto
0.25446 0.0246 lineto
0.25694 0.0203 lineto
0.25818 0.01805 lineto
0.25942 0.01572 lineto
0.26066 0.60266 lineto
0.2619 0.60016 lineto
0.26438 0.59489 lineto
0.26687 0.58917 lineto
0.27183 0.57613 lineto
0.27679 0.56013 lineto
0.28175 0.53958 lineto
0.28423 0.52675 lineto
0.28671 0.51152 lineto
0.29167 0.47092 lineto
0.29663 0.41422 lineto
0.30159 0.35268 lineto
0.31151 0.26251 lineto
0.32143 0.19795 lineto
0.33135 0.14241 lineto
0.34127 0.09376 lineto
0.34623 0.0716 lineto
0.35119 0.05055 lineto
0.35367 0.04037 lineto
0.35615 0.03037 lineto
0.35739 0.02544 lineto
0.35863 0.02054 lineto
0.35987 0.01569 lineto
0.36111 0.60022 lineto
0.36359 0.59068 lineto
0.36607 0.58127 lineto
0.37103 0.56282 lineto
0.38095 0.52733 lineto
0.42063 0.40347 lineto
0.46032 0.29512 lineto
0.5 0.19616 lineto
0.51984 0.14883 lineto
0.53968 0.10132 lineto
0.5496 0.07743 lineto
Mistroke
0.55952 0.05354 lineto
0.56448 0.04161 lineto
0.56944 0.0297 lineto
0.57192 0.02375 lineto
0.57316 0.02078 lineto
0.5744 0.0178 lineto
0.57564 0.01483 lineto
0.57688 0.60121 lineto
0.57937 0.59526 lineto
0.61905 0.49677 lineto
0.63889 0.4426 lineto
0.65873 0.38447 lineto
0.69841 0.22419 lineto
0.70833 0.17392 lineto
0.71825 0.13367 lineto
0.72817 0.10442 lineto
0.7381 0.08295 lineto
0.74802 0.06652 lineto
0.75794 0.05342 lineto
0.77778 0.03346 lineto
0.7877 0.02556 lineto
0.79266 0.02199 lineto
0.79762 0.01864 lineto
0.8001 0.01703 lineto
0.80134 0.01625 lineto
0.80258 0.01548 lineto
0.80382 0.01472 lineto
0.80506 0.60332 lineto
0.80754 0.60185 lineto
0.81746 0.59634 lineto
0.85714 0.57882 lineto
0.89683 0.56602 lineto
0.93651 0.55612 lineto
0.97619 0.54815 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{Graphics[{{Line[{{1., -259.9872481089863}, 
       {1.515625, -234.6596375682049}, 
       {2.03125, -216.7924223931057}, 
       {2.546875, -202.9565379160389}, 
       {3.0625, -191.6466641424549}, 
       {4.09375, -173.7434477535358}, 
       {5.125, -159.7502326566524}, 
       {7.1875, -138.2847227459201}, 
       {9.25, -121.7133045865489}, 
       {13.375, -95.7125065971605}, 
       {17.5, -73.95286915954527}, 
       {21.625, -53.0072957626311}, 
       {25.75, -29.46964324623272}, 
       {27.8125, -14.34912904015126}, 
       {28.328125, -9.89719398763116}, 
       {28.84375, -5.396459153941887}, 
       {29.1015625, -3.387581188642484}, 
       {29.23046875, -2.524935907634382}, 
       {29.359375, -1.788580509027537}, 
       {29.48828125, -1.192918539408011}, 
       {29.6171875, -0.7398909897543356}, 
       {29.74609375, -0.4185663083379886}, 
       {29.875, -0.2084274526659124}, 
       {30.00390625, -0.0845675087899927}, 
       {30.1328125, -0.02247623649616417}, 
       {30.26171875, -0.001074269480010778}, 
       {30.390625, -0.003904230292485049}, 
       {30.6484375, -0.03848036977399191}, 
       {30.77734375, -0.0571164743138141}, 
       {30.90625, -0.07210011435353963}, 
       {31.03515625, -0.0821007408383594}, 
       {31.1640625, -0.0868182085752054}, 
       {31.29296875, -0.0866107091475597}, 
       {31.421875, -0.0822264744818727}, 
       {31.6796875, -0.06478474028550882}, 
       {31.9375, -0.04234739835891603}, 
       {32.1953125, -0.02156636388571595}, 
       {32.32421875, -0.01327506784789948}, 
       {32.453125, -0.006868647237412344}, 
       {32.58203125, -0.002531872633269486}, 
       {32.7109375, -0.0003227604610726159}, 
       {32.83984375, -0.0001905996086861369}, 
       {32.96875, -0.001995673761113439}, 
       {33.09765625, -0.00552936736198894}, 
       {33.2265625, -0.01053361452859088}, 
       {33.484375, -0.0237803857781583}, 
       {34., -0.05485746260400318}, 
       {34.2578125, -0.06851750035719058}, 
       {34.38671875, -0.07419344364117174}, 
       {34.515625, -0.07893062715908708}, 
       {34.64453125, -0.0826451983630175}, 
       {34.7734375, -0.0852861235657426}, 
       {34.90234375, -0.0868330178071523}, 
       {35.03125, -0.0872935390059004}, 
       {35.16015625, -0.0867004843923204}, 
       {35.2890625, -0.0851087032423991}, 
       {35.41796875, -0.0825919183592673}, 
       {35.546875, -0.07923953101068504}, 
       {35.8046875, -0.07044512550337978}, 
       {36.0625, -0.0596370610803055}, 
       {36.578125, -0.03585517911563201}, 
       {36.8359375, -0.0247094932599839}, 
       {37.09375, -0.01509091677327445}, 
       {37.22265625, -0.01104020234797017}, 
       {37.3515625, -0.007571463626967685}, 
       {37.48046875, -0.00472698198246617}, 
       {37.609375, -0.00253704653169915}, 
       {37.73828125, -0.001020139446369104}, 
       {37.8671875, -0.000183303662897608}, 
       {37.99609375, -0.00002267301131897801}, 
       {38.125, -0.0005241430513916109}, 
       {38.25390625, -0.00166416033418164}, 
       {38.3828125, -0.003410606871003353}, 
       {38.640625, -0.00855728609025004}, 
       {38.8984375, -0.01557340612662303}, 
       {39.15625, -0.02399585044625206}, 
       {39.671875, -0.04303869983079837}, 
       {40.1875, -0.06170372073968081}, 
       {40.4453125, -0.06979590748588418}, 
       {40.703125, -0.07659710186701359}, 
       {40.83203125, -0.07943104153648799}, 
       {40.9609375, -0.0818532023112672}, 
       {41.08984375, -0.0838444402338724}, 
       {41.21875, -0.0853906868543171}, 
       {41.34765625, -0.0864828822915496}, 
       {41.4765625, -0.0871168655494559}, 
       {41.60546875, -0.0872932263744538}, 
       {41.734375, -0.0870171224254448}, 
       {41.86328125, -0.0862980656178493}, 
       {41.9921875, -0.0851496813364539}, 
       {42.25, -0.0816383902488131}, 
       {43.28125, -0.05540970983145643}, 
       {43.796875, -0.03885352932743821}, 
       {44.3125, -0.02318605956181702}, 
       {44.5703125, -0.01636962830906612}, 
       {44.828125, -0.01053807414800477}, 
       {45.0859375, -0.005873086281855917}, 
       {45.21484375, -0.004022771359290798}, 
       {45.34375, -0.002511913183537723}, 
       {45.47265625, -0.001350250692495063}, 
       {45.6015625, -0.0005444781173203037}, 
       {45.73046875, -0.000098247793428509}, 
       {45.859375, -0.00001219858258260217}, 
       {45.98828125, -0.0002840089494666234}, 
       {46.1171875, -0.000908473547154516}, 
       {46.24609375, -0.001877602023790683}, 
       {46.375, -0.003180738413982805}, 
       {46.6328125, -0.006733930381205389}, 
       {46.890625, -0.01143515966436445}, 
       {47.40625, -0.02359557854383909}, 
       {48.4375, -0.0530823697840744}, 
       {48.953125, -0.06686543628137677}, 
       {49.2109375, -0.07280050145929168}, 
       {49.46875, -0.07787399515861373}, 
       {49.7265625, -0.0819504120551574}, 
       {49.85546875, -0.0835803693623725}, 
       {49.984375, -0.0849237175120838}, 
       {50.11328125, -0.0859721365677244}, 
       {50.2421875, -0.086719356681151}, 
       {50.37109375, -0.0871611784032144}, 
       {50.5, -0.0872954811007484}, 
       {50.62890625, -0.0871222198801613}, 
       {50.7578125, -0.0866434110962769}, 
       {50.88671875, -0.085863106748473}, 
       {51.015625, -0.0847873579679644}, 
       {51.2734375, -0.0817834337314516}, 
       {51.53125, -0.07771797901485318}, 
       {52.046875, -0.0668844528638879}, 
       {52.5625, -0.05347902247944141}, 
       {53.59375, -0.02495390711635762}, 
       {54.109375, -0.01299161442584031}, 
       {54.3671875, -0.00821685182795062}, 
       {54.625, -0.004439479129594449}, 
       {54.75390625, -0.002961089173536046}, 
       {54.8828125, -0.001771904434459359}, 
       {55.01171875, -0.000881212944527834}, 
       {55.140625, -0.0002962308185193731}, 
       {55.26953125, -0.00002203696146938522}, 
       {55.3984375, -0.00006152230263037922}, 
       {55.52734375, -0.000415354235990589}, 
       {55.65625, -0.001081956647566813}, 
       {55.78515625, -0.002057505768902503}, 
       {55.9140625, -0.00333594210000475}, 
       {56.171875, -0.006766243284574498}, 
       {56.4296875, -0.01128112745372749}, 
       {56.6875, -0.01675650743897582}, 
       {57.71875, -0.04484451160082428}, 
       {58.234375, -0.05969609713371061}, 
       {58.75, -0.07270691790689189}, 
       {59.0078125, -0.07799486007932774}, 
       {59.265625, -0.0822257834417802}, 
       {59.39453125, -0.0838963593491175}, 
       {59.5234375, -0.0852483677797155}, 
       {59.65234375, -0.0862680357895217}, 
       {59.78125, -0.0869439340445025}, 
       {59.91015625, -0.0872671112702878}, 
       {60.0390625, -0.0872312173884105}, 
       {60.16796875, -0.0868326143229202}, 
       {60.296875, -0.0860704733462838}, 
       {60.42578125, -0.0849468580237311}, 
       {60.5546875, -0.0834667914225079}, 
       {60.8125, -0.07947247853709127}, 
       {61.0703125, -0.07418836078010238}, 
       {61.328125, -0.06776383806037564}, 
       {61.84375, -0.05232422835144381}, 
       {62.359375, -0.03522683172138993}, 
       {62.875, -0.01905344112249489}, 
       {63.1328125, -0.01218503155827533}, 
       {63.390625, -0.006582704126930425}, 
       {63.51953125, -0.004353791173366789}, 
       {63.6484375, -0.002553095289512522}, 
       {63.77734375, -0.001211405495895154}, 
       {63.90625, -0.0003554523847842576}, 
       {64.03515625, -0.000007365297434862314}, 
       {64.1640625, -0.0001841433774987581}, 
       {64.29296875, -0.000897148346016563}, 
       {64.421875, -0.002151626922482575}, 
       {64.55078125, -0.00394627113925674}, 
       {64.6796875, -0.006272825085437929}, 
       {64.9375, -0.01245193231401318}, 
       {65.453125, -0.02999355501117244}, 
       {65.96875, -0.05155110633538289}, 
       {66.2265625, -0.06231654759648014}, 
       {66.484375, -0.07207812696435291}, 
       {66.61328125, -0.07632963973083663}, 
       {66.7421875, -0.080024900988038}, 
       {66.87109375, -0.0830630533897538}, 
       {67., -0.0853469464870183}, 
       {67.12890625, -0.0867854159964591}, 
       {67.2578125, -0.0872958740406994}, 
       {67.38671875, -0.0868072491293209}, 
       {67.515625, -0.0852633202736898}, 
       {67.64453125, -0.0826264948151633}, 
       {67.7734375, -0.07888208473782761}, 
       {68.03125, -0.0681559000800811}, 
       {68.2890625, -0.05362494251570307}, 
       {68.546875, -0.03657441684491118}, 
       {68.8046875, -0.01929157920719953}, 
       {68.93359375, -0.01162592906529552}, 
       {69.0625, -0.005370138008666379}, 
       {69.19140625, -0.00123290198222729}, 
       {69.3203125, -0.00004667131638823003}, 
       {69.44921875, -0.002776607494921974}, 
       {69.578125, -0.01052730290018502}, 
       {69.70703125, -0.02454608124937285}, 
       {69.8359375, -0.0462214809683498}, 
       {69.96484375, -0.07707536834938473}, 
       {70.09375, -0.118747091788473}, 
       {70.22265625, -0.1729682420186613}, 
       {70.3515625, -0.2415270001706856}, 
       {70.609375, -0.4288049922541253}, 
       {70.8671875, -0.6940271731075857}, 
       {71.125, -1.047788805820914}, 
       {71.640625, -2.037926434530529}, 
       {72.15625, -3.373729417943185}, 
       {73.1875, -6.676660110543157}, 
       {75.25, -13.55303019949263}, 
       {79.375, -24.70750839730755}, 
       {83.5, -33.27311073827862}, 
       {87.625, -40.29603832714113}, 
       {91.75, -46.29282405050404}, 
       {95.875, -51.54946975165407}, 
       {100., -56.24289781996507}}]}}, 
   {PlotRange -> Automatic, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]
   , Graphics[{{Line[{{1., -91.8999974969682}, 
       {5.125, -99.8894527059729}, 
       {9.25, -108.5358758281226}, 
       {13.375, -118.5718462553323}, 
       {15.4375, -124.4660294577018}, 
       {17.5, -131.2555323154385}, 
       {19.5625, -139.3329546978225}, 
       {21.625, -149.3637599760023}, 
       {22.65625, -155.4683569022165}, 
       {23.6875, -162.6284513981249}, 
       {24.203125, -166.7293784221582}, 
       {24.71875, -171.2754567044972}, 
       {24.9765625, -173.7470650570484}, 
       {25.234375, -176.3725098876492}, 
       {25.36328125, -177.7490192489553}, 
       {25.4921875, -179.1717849462274}, 
       {25.62109375, 179.3560381857952}, 
       {25.75, 177.8309629612585}, 
       {26.0078125, 174.6062126178017}, 
       {26.265625, 171.1173818498491}, 
       {26.78125, 163.1506504430716}, 
       {27.296875, 153.3777998502795}, 
       {27.8125, 140.8243360160964}, 
       {28.0703125, 132.9896129823518}, 
       {28.328125, 123.6861603102733}, 
       {28.84375, 98.8856413128328}, 
       {29.359375, 64.24765805945447}, 
       {29.875, 26.65602204690148}, 
       {30.90625, -28.42192020135314}, 
       {31.9375, -67.85400258764656}, 
       {32.96875, -101.7807891880797}, 
       {34., -131.5023912583529}, 
       {34.515625, -145.0359769716537}, 
       {35.03125, -157.8923649279436}, 
       {35.2890625, -164.1141719084301}, 
       {35.546875, -170.2199923535537}, 
       {35.67578125, -173.2336190937282}, 
       {35.8046875, -176.2229793266546}, 
       {35.93359375, -179.1893124916938}, 
       {36.0625, 177.8663003505206}, 
       {36.3203125, 172.0397985805773}, 
       {36.578125, 166.2917952812317}, 
       {37.09375, 155.0182813939508}, 
       {38.125, 133.343743533731}, 
       {42.25, 57.68267321614024}, 
       {46.375, -8.50210940556554}, 
       {50.5, -68.95121958479528}, 
       {52.5625, -97.8613250359832}, 
       {54.625, -126.8810620493137}, 
       {55.65625, -141.4732517177575}, 
       {56.6875, -156.0673014242969}, 
       {57.203125, -163.3525050959469}, 
       {57.71875, -170.6278566999134}, 
       {57.9765625, -174.2626414026015}, 
       {58.10546875, -176.0796088568816}, 
       {58.234375, -177.8964519765768}, 
       {58.36328125, -179.7133114480288}, 
       {58.4921875, 178.4696549519934}, 
       {58.75, 174.8343500953406}, 
       {62.875, 114.6769340428948}, 
       {64.9375, 81.5834003457508}, 
       {67., 46.07859593810731}, 
       {71.125, -51.83086699376054}, 
       {72.15625, -82.5354244611537}, 
       {73.1875, -107.121564574431}, 
       {74.21875, -124.9884423386574}, 
       {75.25, -138.0998158215483}, 
       {76.28125, -148.1361909200121}, 
       {77.3125, -156.1429000847634}, 
       {79.375, -168.3347144438899}, 
       {80.40625, -173.1582858292187}, 
       {80.921875, -175.338674162464}, 
       {81.4375, -177.3872219961513}, 
       {81.6953125, -178.3663940157988}, 
       {81.82421875, -178.8453842617623}, 
       {81.953125, -179.3175501859264}, 
       {82.08203125, -179.7830631255639}, 
       {82.2109375, 179.7579118408378}, 
       {82.46875, 178.858694700665}, 
       {83.5, 175.4921054482728}, 
       {87.625, 164.7915165995674}, 
       {91.75, 156.9752948817185}, 
       {95.875, 150.9257826448045}, 
       {100., 146.0595611938693}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; ]

Now, we will quantize the filter coefficients to 3 digits:
:[font = input; startGroup; Cclosed; ]

MagPhasePlot[ N[bpfiltertrans, 3],
              {w, 1, 100},
              MagRangeScale -> Log ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.61803 0.00618 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.60553 0 1 Msboxa
[(40)] 0.40476 0.60553 0 1 Msboxa
[(60)] 0.59524 0.60553 0 1 Msboxa
[(80)] 0.78571 0.60553 0 1 Msboxa
[(100)] 0.97619 0.60553 0 1 Msboxa
[(w)] 1.00625 0.61803 -1 0 Msboxa
[(-100)] 0.01131 0 1 0 Msboxa
[(-80)] 0.01131 0.12361 1 0 Msboxa
[(-60)] 0.01131 0.24721 1 0 Msboxa
[(-40)] 0.01131 0.37082 1 0 Msboxa
[(-20)] 0.01131 0.49443 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.62528 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.61803 moveto
1 0.61803 lineto
stroke
0.21429 0.61178 moveto
0.21429 0.62428 lineto
stroke
0 setgray
[(20)] 0.21429 0.60553 0 1 Mshowa
0.40476 0.61178 moveto
0.40476 0.62428 lineto
stroke
0 setgray
[(40)] 0.40476 0.60553 0 1 Mshowa
0.59524 0.61178 moveto
0.59524 0.62428 lineto
stroke
0 setgray
[(60)] 0.59524 0.60553 0 1 Mshowa
0.78571 0.61178 moveto
0.78571 0.62428 lineto
stroke
0 setgray
[(80)] 0.78571 0.60553 0 1 Mshowa
0.97619 0.61178 moveto
0.97619 0.62428 lineto
stroke
0 setgray
[(100)] 0.97619 0.60553 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.61803 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0 moveto
0.03006 0 lineto
stroke
0 setgray
[(-100)] 0.01131 0 1 0 Mshowa
0.01756 0.12361 moveto
0.03006 0.12361 lineto
stroke
0 setgray
[(-80)] 0.01131 0.12361 1 0 Mshowa
0.01756 0.24721 moveto
0.03006 0.24721 lineto
stroke
0 setgray
[(-60)] 0.01131 0.24721 1 0 Mshowa
0.01756 0.37082 moveto
0.03006 0.37082 lineto
stroke
0 setgray
[(-40)] 0.01131 0.37082 1 0 Mshowa
0.01756 0.49443 moveto
0.03006 0.49443 lineto
stroke
0 setgray
[(-20)] 0.01131 0.49443 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.03333 -0.98878 moveto
0.03824 -0.83224 lineto
0.04315 -0.72182 lineto
0.04807 -0.63631 lineto
0.05298 -0.56641 lineto
0.0628 -0.45576 lineto
0.07262 -0.36928 lineto
0.09226 -0.23661 lineto
0.1119 -0.1342 lineto
0.15119 0.0265 lineto
0.19048 0.16098 lineto
0.22976 0.29043 lineto
0.26905 0.4359 lineto
0.28869 0.52935 lineto
0.2936 0.55687 lineto
0.29851 0.58468 lineto
0.30097 0.5971 lineto
0.30219 0.60243 lineto
0.30342 0.60698 lineto
0.30465 0.61066 lineto
0.30588 0.61346 lineto
0.30711 0.61545 lineto
0.30833 0.61675 lineto
0.30956 0.61751 lineto
0.31079 0.6179 lineto
0.31202 0.61803 lineto
0.31324 0.61801 lineto
0.3157 0.6178 lineto
0.31693 0.61768 lineto
0.31815 0.61759 lineto
0.31938 0.61753 lineto
0.32061 0.6175 lineto
0.32184 0.6175 lineto
0.32307 0.61753 lineto
0.32552 0.61763 lineto
0.32798 0.61777 lineto
0.33043 0.6179 lineto
0.33166 0.61795 lineto
0.33289 0.61799 lineto
0.33411 0.61802 lineto
0.33534 0.61803 lineto
0.33657 0.61803 lineto
0.3378 0.61802 lineto
0.33903 0.618 lineto
0.34025 0.61797 lineto
0.34271 0.61789 lineto
0.34762 0.61769 lineto
0.35007 0.61761 lineto
0.3513 0.61758 lineto
0.35253 0.61755 lineto
Mistroke
0.35376 0.61752 lineto
0.35499 0.61751 lineto
0.35621 0.6175 lineto
0.35744 0.61749 lineto
0.35867 0.6175 lineto
0.3599 0.61751 lineto
0.36112 0.61752 lineto
0.36235 0.61754 lineto
0.36481 0.6176 lineto
0.36726 0.61767 lineto
0.37217 0.61781 lineto
0.37463 0.61788 lineto
0.37708 0.61794 lineto
0.37831 0.61797 lineto
0.37954 0.61799 lineto
0.38077 0.618 lineto
0.38199 0.61802 lineto
0.38322 0.61803 lineto
0.38445 0.61803 lineto
0.38568 0.61803 lineto
0.3869 0.61803 lineto
0.38813 0.61802 lineto
0.38936 0.61801 lineto
0.39182 0.61798 lineto
0.39427 0.61794 lineto
0.39673 0.61789 lineto
0.40164 0.61777 lineto
0.40655 0.61765 lineto
0.409 0.6176 lineto
0.41146 0.61756 lineto
0.41269 0.61754 lineto
0.41391 0.61753 lineto
0.41514 0.61752 lineto
0.41637 0.61751 lineto
0.4176 0.6175 lineto
0.41882 0.6175 lineto
0.42005 0.61749 lineto
0.42128 0.6175 lineto
0.42251 0.6175 lineto
0.42374 0.61751 lineto
0.42619 0.61753 lineto
0.43601 0.61769 lineto
0.44092 0.61779 lineto
0.44583 0.61789 lineto
0.44829 0.61793 lineto
0.45074 0.61797 lineto
0.4532 0.618 lineto
0.45443 0.61801 lineto
0.45565 0.61802 lineto
0.45688 0.61803 lineto
Mistroke
0.45811 0.61803 lineto
0.45934 0.61803 lineto
0.46057 0.61803 lineto
0.46179 0.61803 lineto
0.46302 0.61803 lineto
0.46425 0.61802 lineto
0.46548 0.61801 lineto
0.46793 0.61799 lineto
0.47039 0.61796 lineto
0.4753 0.61789 lineto
0.48512 0.61771 lineto
0.49003 0.61762 lineto
0.49249 0.61758 lineto
0.49494 0.61755 lineto
0.4974 0.61753 lineto
0.49862 0.61752 lineto
0.49985 0.61751 lineto
0.50108 0.6175 lineto
0.50231 0.6175 lineto
0.50353 0.6175 lineto
0.50476 0.61749 lineto
0.50599 0.6175 lineto
0.50722 0.6175 lineto
0.50844 0.6175 lineto
0.50967 0.61751 lineto
0.51213 0.61753 lineto
0.51458 0.61755 lineto
0.51949 0.61762 lineto
0.5244 0.6177 lineto
0.53423 0.61788 lineto
0.53914 0.61795 lineto
0.54159 0.61798 lineto
0.54405 0.61801 lineto
0.54528 0.61802 lineto
0.5465 0.61802 lineto
0.54773 0.61803 lineto
0.54896 0.61803 lineto
0.55019 0.61803 lineto
0.55141 0.61803 lineto
0.55264 0.61803 lineto
0.55387 0.61803 lineto
0.5551 0.61802 lineto
0.55632 0.61801 lineto
0.55878 0.61799 lineto
0.56124 0.61796 lineto
0.56369 0.61793 lineto
0.57351 0.61776 lineto
0.57842 0.61767 lineto
0.58333 0.61758 lineto
0.58579 0.61755 lineto
Mistroke
0.58824 0.61753 lineto
0.58947 0.61752 lineto
0.5907 0.61751 lineto
0.59193 0.6175 lineto
0.59315 0.6175 lineto
0.59438 0.61749 lineto
0.59561 0.61749 lineto
0.59684 0.6175 lineto
0.59807 0.6175 lineto
0.59929 0.61751 lineto
0.60052 0.61752 lineto
0.60298 0.61754 lineto
0.60543 0.61758 lineto
0.60789 0.61762 lineto
0.6128 0.61771 lineto
0.61771 0.61782 lineto
0.62262 0.61792 lineto
0.62507 0.61796 lineto
0.62753 0.61799 lineto
0.62876 0.61801 lineto
0.62999 0.61802 lineto
0.63121 0.61803 lineto
0.63244 0.61803 lineto
0.63367 0.61803 lineto
0.6349 0.61803 lineto
0.63612 0.61803 lineto
0.63735 0.61802 lineto
0.63858 0.61801 lineto
0.63981 0.618 lineto
0.64226 0.61796 lineto
0.64717 0.61785 lineto
0.65208 0.61772 lineto
0.65454 0.61765 lineto
0.65699 0.61759 lineto
0.65822 0.61756 lineto
0.65945 0.61754 lineto
0.66068 0.61752 lineto
0.6619 0.61751 lineto
0.66313 0.6175 lineto
0.66436 0.61749 lineto
0.66559 0.6175 lineto
0.66682 0.61751 lineto
0.66804 0.61752 lineto
0.66927 0.61755 lineto
0.67173 0.61761 lineto
0.67418 0.6177 lineto
0.67664 0.61781 lineto
0.67909 0.61791 lineto
0.68032 0.61796 lineto
0.68155 0.618 lineto
Mistroke
0.68278 0.61803 lineto
0.684 0.61803 lineto
0.68523 0.61802 lineto
0.68646 0.61797 lineto
0.68769 0.61788 lineto
0.68891 0.61775 lineto
0.69014 0.61756 lineto
0.69137 0.6173 lineto
0.6926 0.61696 lineto
0.69382 0.61654 lineto
0.69628 0.61538 lineto
0.69874 0.61374 lineto
0.70119 0.61156 lineto
0.7061 0.60544 lineto
0.71101 0.59718 lineto
0.72083 0.57677 lineto
0.74048 0.53427 lineto
0.77976 0.46533 lineto
0.81905 0.41239 lineto
0.85833 0.36899 lineto
0.89762 0.33193 lineto
0.9369 0.29944 lineto
0.97619 0.27043 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.01419 0.00962 0.30904 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.20659 0.29654 0 1 Msboxa
[(40)] 0.39899 0.29654 0 1 Msboxa
[(60)] 0.59139 0.29654 0 1 Msboxa
[(80)] 0.78379 0.29654 0 1 Msboxa
[(100)] 0.97619 0.29654 0 1 Msboxa
[(w)] 1.00625 0.30904 -1 0 Msboxa
[(-150)] 0.00169 0.06347 1 0 Msboxa
[(-100)] 0.00169 0.14533 1 0 Msboxa
[(-50)] 0.00169 0.22718 1 0 Msboxa
[(50)] 0.00169 0.39089 1 0 Msboxa
[(100)] 0.00169 0.47275 1 0 Msboxa
[(150)] 0.00169 0.5546 1 0 Msboxa
[( )] 0.01419 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30904 moveto
1 0.30904 lineto
stroke
0.20659 0.30279 moveto
0.20659 0.31529 lineto
stroke
0 setgray
[(20)] 0.20659 0.29654 0 1 Mshowa
0.39899 0.30279 moveto
0.39899 0.31529 lineto
stroke
0 setgray
[(40)] 0.39899 0.29654 0 1 Mshowa
0.59139 0.30279 moveto
0.59139 0.31529 lineto
stroke
0 setgray
[(60)] 0.59139 0.29654 0 1 Mshowa
0.78379 0.30279 moveto
0.78379 0.31529 lineto
stroke
0 setgray
[(80)] 0.78379 0.29654 0 1 Mshowa
0.97619 0.30279 moveto
0.97619 0.31529 lineto
stroke
0 setgray
[(100)] 0.97619 0.29654 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30904 -1 0 Mshowa
0.01419 0 moveto
0.01419 0.61803 lineto
stroke
0.00794 0.06347 moveto
0.02044 0.06347 lineto
stroke
0 setgray
[(-150)] 0.00169 0.06347 1 0 Mshowa
0.00794 0.14533 moveto
0.02044 0.14533 lineto
stroke
0 setgray
[(-100)] 0.00169 0.14533 1 0 Mshowa
0.00794 0.22718 moveto
0.02044 0.22718 lineto
stroke
0 setgray
[(-50)] 0.00169 0.22718 1 0 Mshowa
0.00794 0.39089 moveto
0.02044 0.39089 lineto
stroke
0 setgray
[(50)] 0.00169 0.39089 1 0 Mshowa
0.00794 0.47275 moveto
0.02044 0.47275 lineto
stroke
0 setgray
[(100)] 0.00169 0.47275 1 0 Mshowa
0.00794 0.5546 moveto
0.02044 0.5546 lineto
stroke
0 setgray
[(150)] 0.00169 0.5546 1 0 Mshowa
0 setgray
[( )] 0.01419 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.15859 moveto
0.06349 0.14551 lineto
0.10317 0.13135 lineto
0.14286 0.11492 lineto
0.1627 0.10527 lineto
0.18254 0.09416 lineto
0.20238 0.08094 lineto
0.22222 0.06451 lineto
0.23214 0.05452 lineto
0.24206 0.0428 lineto
0.24702 0.03609 lineto
0.25198 0.02864 lineto
0.25446 0.0246 lineto
0.25694 0.0203 lineto
0.25818 0.01805 lineto
0.25942 0.01572 lineto
0.26066 0.60266 lineto
0.2619 0.60016 lineto
0.26438 0.59489 lineto
0.26687 0.58917 lineto
0.27183 0.57613 lineto
0.27679 0.56013 lineto
0.28175 0.53958 lineto
0.28423 0.52675 lineto
0.28671 0.51152 lineto
0.29167 0.47092 lineto
0.29663 0.41422 lineto
0.30159 0.35268 lineto
0.31151 0.26251 lineto
0.32143 0.19795 lineto
0.33135 0.14241 lineto
0.34127 0.09376 lineto
0.34623 0.0716 lineto
0.35119 0.05055 lineto
0.35367 0.04037 lineto
0.35615 0.03037 lineto
0.35739 0.02544 lineto
0.35863 0.02054 lineto
0.35987 0.01569 lineto
0.36111 0.60022 lineto
0.36359 0.59068 lineto
0.36607 0.58127 lineto
0.37103 0.56282 lineto
0.38095 0.52733 lineto
0.42063 0.40347 lineto
0.46032 0.29512 lineto
0.5 0.19616 lineto
0.51984 0.14883 lineto
0.53968 0.10132 lineto
0.5496 0.07743 lineto
Mistroke
0.55952 0.05354 lineto
0.56448 0.04161 lineto
0.56944 0.0297 lineto
0.57192 0.02375 lineto
0.57316 0.02078 lineto
0.5744 0.0178 lineto
0.57564 0.01483 lineto
0.57688 0.60121 lineto
0.57937 0.59526 lineto
0.61905 0.49677 lineto
0.63889 0.4426 lineto
0.65873 0.38447 lineto
0.69841 0.22419 lineto
0.70833 0.17392 lineto
0.71825 0.13367 lineto
0.72817 0.10442 lineto
0.7381 0.08295 lineto
0.74802 0.06652 lineto
0.75794 0.05342 lineto
0.77778 0.03346 lineto
0.7877 0.02556 lineto
0.79266 0.02199 lineto
0.79762 0.01864 lineto
0.8001 0.01703 lineto
0.80134 0.01625 lineto
0.80258 0.01548 lineto
0.80382 0.01472 lineto
0.80506 0.60332 lineto
0.80754 0.60185 lineto
0.81746 0.59634 lineto
0.85714 0.57882 lineto
0.89683 0.56602 lineto
0.93651 0.55612 lineto
0.97619 0.54815 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
{Graphics[{{Line[{{1., -259.9872481089863}, 
       {1.515625, -234.6596375682049}, 
       {2.03125, -216.7924223931057}, 
       {2.546875, -202.9565379160389}, 
       {3.0625, -191.6466641424549}, 
       {4.09375, -173.7434477535358}, 
       {5.125, -159.7502326566524}, 
       {7.1875, -138.2847227459201}, 
       {9.25, -121.7133045865489}, 
       {13.375, -95.7125065971605}, 
       {17.5, -73.95286915954527}, 
       {21.625, -53.0072957626311}, 
       {25.75, -29.46964324623272}, 
       {27.8125, -14.34912904015126}, 
       {28.328125, -9.89719398763116}, 
       {28.84375, -5.396459153941887}, 
       {29.1015625, -3.387581188642484}, 
       {29.23046875, -2.524935907634382}, 
       {29.359375, -1.788580509027537}, 
       {29.48828125, -1.192918539408011}, 
       {29.6171875, -0.7398909897543356}, 
       {29.74609375, -0.4185663083379886}, 
       {29.875, -0.2084274526659124}, 
       {30.00390625, -0.0845675087899927}, 
       {30.1328125, -0.02247623649616417}, 
       {30.26171875, -0.001074269480010778}, 
       {30.390625, -0.003904230292485049}, 
       {30.6484375, -0.03848036977399191}, 
       {30.77734375, -0.0571164743138141}, 
       {30.90625, -0.07210011435353963}, 
       {31.03515625, -0.0821007408383594}, 
       {31.1640625, -0.0868182085752054}, 
       {31.29296875, -0.0866107091475597}, 
       {31.421875, -0.0822264744818727}, 
       {31.6796875, -0.06478474028550882}, 
       {31.9375, -0.04234739835891603}, 
       {32.1953125, -0.02156636388571595}, 
       {32.32421875, -0.01327506784789948}, 
       {32.453125, -0.006868647237412344}, 
       {32.58203125, -0.002531872633269486}, 
       {32.7109375, -0.0003227604610726159}, 
       {32.83984375, -0.0001905996086861369}, 
       {32.96875, -0.001995673761113439}, 
       {33.09765625, -0.00552936736198894}, 
       {33.2265625, -0.01053361452859088}, 
       {33.484375, -0.0237803857781583}, 
       {34., -0.05485746260400318}, 
       {34.2578125, -0.06851750035719058}, 
       {34.38671875, -0.07419344364117174}, 
       {34.515625, -0.07893062715908708}, 
       {34.64453125, -0.0826451983630175}, 
       {34.7734375, -0.0852861235657426}, 
       {34.90234375, -0.0868330178071523}, 
       {35.03125, -0.0872935390059004}, 
       {35.16015625, -0.0867004843923204}, 
       {35.2890625, -0.0851087032423991}, 
       {35.41796875, -0.0825919183592673}, 
       {35.546875, -0.07923953101068504}, 
       {35.8046875, -0.07044512550337978}, 
       {36.0625, -0.0596370610803055}, 
       {36.578125, -0.03585517911563201}, 
       {36.8359375, -0.0247094932599839}, 
       {37.09375, -0.01509091677327445}, 
       {37.22265625, -0.01104020234797017}, 
       {37.3515625, -0.007571463626967685}, 
       {37.48046875, -0.00472698198246617}, 
       {37.609375, -0.00253704653169915}, 
       {37.73828125, -0.001020139446369104}, 
       {37.8671875, -0.000183303662897608}, 
       {37.99609375, -0.00002267301131897801}, 
       {38.125, -0.0005241430513916109}, 
       {38.25390625, -0.00166416033418164}, 
       {38.3828125, -0.003410606871003353}, 
       {38.640625, -0.00855728609025004}, 
       {38.8984375, -0.01557340612662303}, 
       {39.15625, -0.02399585044625206}, 
       {39.671875, -0.04303869983079837}, 
       {40.1875, -0.06170372073968081}, 
       {40.4453125, -0.06979590748588418}, 
       {40.703125, -0.07659710186701359}, 
       {40.83203125, -0.07943104153648799}, 
       {40.9609375, -0.0818532023112672}, 
       {41.08984375, -0.0838444402338724}, 
       {41.21875, -0.0853906868543171}, 
       {41.34765625, -0.0864828822915496}, 
       {41.4765625, -0.0871168655494559}, 
       {41.60546875, -0.0872932263744538}, 
       {41.734375, -0.0870171224254448}, 
       {41.86328125, -0.0862980656178493}, 
       {41.9921875, -0.0851496813364539}, 
       {42.25, -0.0816383902488131}, 
       {43.28125, -0.05540970983145643}, 
       {43.796875, -0.03885352932743821}, 
       {44.3125, -0.02318605956181702}, 
       {44.5703125, -0.01636962830906612}, 
       {44.828125, -0.01053807414800477}, 
       {45.0859375, -0.005873086281855917}, 
       {45.21484375, -0.004022771359290798}, 
       {45.34375, -0.002511913183537723}, 
       {45.47265625, -0.001350250692495063}, 
       {45.6015625, -0.0005444781173203037}, 
       {45.73046875, -0.000098247793428509}, 
       {45.859375, -0.00001219858258260217}, 
       {45.98828125, -0.0002840089494666234}, 
       {46.1171875, -0.000908473547154516}, 
       {46.24609375, -0.001877602023790683}, 
       {46.375, -0.003180738413982805}, 
       {46.6328125, -0.006733930381205389}, 
       {46.890625, -0.01143515966436445}, 
       {47.40625, -0.02359557854383909}, 
       {48.4375, -0.0530823697840744}, 
       {48.953125, -0.06686543628137677}, 
       {49.2109375, -0.07280050145929168}, 
       {49.46875, -0.07787399515861373}, 
       {49.7265625, -0.0819504120551574}, 
       {49.85546875, -0.0835803693623725}, 
       {49.984375, -0.0849237175120838}, 
       {50.11328125, -0.0859721365677244}, 
       {50.2421875, -0.086719356681151}, 
       {50.37109375, -0.0871611784032144}, 
       {50.5, -0.0872954811007484}, 
       {50.62890625, -0.0871222198801613}, 
       {50.7578125, -0.0866434110962769}, 
       {50.88671875, -0.085863106748473}, 
       {51.015625, -0.0847873579679644}, 
       {51.2734375, -0.0817834337314516}, 
       {51.53125, -0.07771797901485318}, 
       {52.046875, -0.0668844528638879}, 
       {52.5625, -0.05347902247944141}, 
       {53.59375, -0.02495390711635762}, 
       {54.109375, -0.01299161442584031}, 
       {54.3671875, -0.00821685182795062}, 
       {54.625, -0.004439479129594449}, 
       {54.75390625, -0.002961089173536046}, 
       {54.8828125, -0.001771904434459359}, 
       {55.01171875, -0.000881212944527834}, 
       {55.140625, -0.0002962308185193731}, 
       {55.26953125, -0.00002203696146938522}, 
       {55.3984375, -0.00006152230263037922}, 
       {55.52734375, -0.000415354235990589}, 
       {55.65625, -0.001081956647566813}, 
       {55.78515625, -0.002057505768902503}, 
       {55.9140625, -0.00333594210000475}, 
       {56.171875, -0.006766243284574498}, 
       {56.4296875, -0.01128112745372749}, 
       {56.6875, -0.01675650743897582}, 
       {57.71875, -0.04484451160082428}, 
       {58.234375, -0.05969609713371061}, 
       {58.75, -0.07270691790689189}, 
       {59.0078125, -0.07799486007932774}, 
       {59.265625, -0.0822257834417802}, 
       {59.39453125, -0.0838963593491175}, 
       {59.5234375, -0.0852483677797155}, 
       {59.65234375, -0.0862680357895217}, 
       {59.78125, -0.0869439340445025}, 
       {59.91015625, -0.0872671112702878}, 
       {60.0390625, -0.0872312173884105}, 
       {60.16796875, -0.0868326143229202}, 
       {60.296875, -0.0860704733462838}, 
       {60.42578125, -0.0849468580237311}, 
       {60.5546875, -0.0834667914225079}, 
       {60.8125, -0.07947247853709127}, 
       {61.0703125, -0.07418836078010238}, 
       {61.328125, -0.06776383806037564}, 
       {61.84375, -0.05232422835144381}, 
       {62.359375, -0.03522683172138993}, 
       {62.875, -0.01905344112249489}, 
       {63.1328125, -0.01218503155827533}, 
       {63.390625, -0.006582704126930425}, 
       {63.51953125, -0.004353791173366789}, 
       {63.6484375, -0.002553095289512522}, 
       {63.77734375, -0.001211405495895154}, 
       {63.90625, -0.0003554523847842576}, 
       {64.03515625, -0.000007365297434862314}, 
       {64.1640625, -0.0001841433774987581}, 
       {64.29296875, -0.000897148346016563}, 
       {64.421875, -0.002151626922482575}, 
       {64.55078125, -0.00394627113925674}, 
       {64.6796875, -0.006272825085437929}, 
       {64.9375, -0.01245193231401318}, 
       {65.453125, -0.02999355501117244}, 
       {65.96875, -0.05155110633538289}, 
       {66.2265625, -0.06231654759648014}, 
       {66.484375, -0.07207812696435291}, 
       {66.61328125, -0.07632963973083663}, 
       {66.7421875, -0.080024900988038}, 
       {66.87109375, -0.0830630533897538}, 
       {67., -0.0853469464870183}, 
       {67.12890625, -0.0867854159964591}, 
       {67.2578125, -0.0872958740406994}, 
       {67.38671875, -0.0868072491293209}, 
       {67.515625, -0.0852633202736898}, 
       {67.64453125, -0.0826264948151633}, 
       {67.7734375, -0.07888208473782761}, 
       {68.03125, -0.0681559000800811}, 
       {68.2890625, -0.05362494251570307}, 
       {68.546875, -0.03657441684491118}, 
       {68.8046875, -0.01929157920719953}, 
       {68.93359375, -0.01162592906529552}, 
       {69.0625, -0.005370138008666379}, 
       {69.19140625, -0.00123290198222729}, 
       {69.3203125, -0.00004667131638823003}, 
       {69.44921875, -0.002776607494921974}, 
       {69.578125, -0.01052730290018502}, 
       {69.70703125, -0.02454608124937285}, 
       {69.8359375, -0.0462214809683498}, 
       {69.96484375, -0.07707536834938473}, 
       {70.09375, -0.118747091788473}, 
       {70.22265625, -0.1729682420186613}, 
       {70.3515625, -0.2415270001706856}, 
       {70.609375, -0.4288049922541253}, 
       {70.8671875, -0.6940271731075857}, 
       {71.125, -1.047788805820914}, 
       {71.640625, -2.037926434530529}, 
       {72.15625, -3.373729417943185}, 
       {73.1875, -6.676660110543157}, 
       {75.25, -13.55303019949263}, 
       {79.375, -24.70750839730755}, 
       {83.5, -33.27311073827862}, 
       {87.625, -40.29603832714113}, 
       {91.75, -46.29282405050404}, 
       {95.875, -51.54946975165407}, 
       {100., -56.24289781996507}}]}}, 
   {PlotRange -> Automatic, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, 
    AxesLabel -> None, Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}], 
  Graphics[{{Line[{{1., -91.8999974969682}, 
       {5.125, -99.8894527059729}, 
       {9.25, -108.5358758281226}, 
       {13.375, -118.5718462553323}, 
       {15.4375, -124.4660294577018}, 
       {17.5, -131.2555323154385}, 
       {19.5625, -139.3329546978225}, 
       {21.625, -149.3637599760023}, 
       {22.65625, -155.4683569022165}, 
       {23.6875, -162.6284513981249}, 
       {24.203125, -166.7293784221582}, 
       {24.71875, -171.2754567044972}, 
       {24.9765625, -173.7470650570484}, 
       {25.234375, -176.3725098876492}, 
       {25.36328125, -177.7490192489553}, 
       {25.4921875, -179.1717849462274}, 
       {25.62109375, 179.3560381857952}, 
       {25.75, 177.8309629612585}, 
       {26.0078125, 174.6062126178017}, 
       {26.265625, 171.1173818498491}, 
       {26.78125, 163.1506504430716}, 
       {27.296875, 153.3777998502795}, 
       {27.8125, 140.8243360160964}, 
       {28.0703125, 132.9896129823518}, 
       {28.328125, 123.6861603102733}, 
       {28.84375, 98.8856413128328}, 
       {29.359375, 64.24765805945447}, 
       {29.875, 26.65602204690148}, 
       {30.90625, -28.42192020135314}, 
       {31.9375, -67.85400258764656}, 
       {32.96875, -101.7807891880797}, 
       {34., -131.5023912583529}, 
       {34.515625, -145.0359769716537}, 
       {35.03125, -157.8923649279436}, 
       {35.2890625, -164.1141719084301}, 
       {35.546875, -170.2199923535537}, 
       {35.67578125, -173.2336190937282}, 
       {35.8046875, -176.2229793266546}, 
       {35.93359375, -179.1893124916938}, 
       {36.0625, 177.8663003505206}, 
       {36.3203125, 172.0397985805773}, 
       {36.578125, 166.2917952812317}, 
       {37.09375, 155.0182813939508}, 
       {38.125, 133.343743533731}, 
       {42.25, 57.68267321614024}, 
       {46.375, -8.50210940556554}, 
       {50.5, -68.95121958479528}, 
       {52.5625, -97.8613250359832}, 
       {54.625, -126.8810620493137}, 
       {55.65625, -141.4732517177575}, 
       {56.6875, -156.0673014242969}, 
       {57.203125, -163.3525050959469}, 
       {57.71875, -170.6278566999134}, 
       {57.9765625, -174.2626414026015}, 
       {58.10546875, -176.0796088568816}, 
       {58.234375, -177.8964519765768}, 
       {58.36328125, -179.7133114480288}, 
       {58.4921875, 178.4696549519934}, 
       {58.75, 174.8343500953406}, 
       {62.875, 114.6769340428948}, 
       {64.9375, 81.5834003457508}, 
       {67., 46.07859593810731}, 
       {71.125, -51.83086699376054}, 
       {72.15625, -82.5354244611537}, 
       {73.1875, -107.121564574431}, 
       {74.21875, -124.9884423386574}, 
       {75.25, -138.0998158215483}, 
       {76.28125, -148.1361909200121}, 
       {77.3125, -156.1429000847634}, 
       {79.375, -168.3347144438899}, 
       {80.40625, -173.1582858292187}, 
       {80.921875, -175.338674162464}, 
       {81.4375, -177.3872219961513}, 
       {81.6953125, -178.3663940157988}, 
       {81.82421875, -178.8453842617623}, 
       {81.953125, -179.3175501859264}, 
       {82.08203125, -179.7830631255639}, 
       {82.2109375, 179.7579118408378}, 
       {82.46875, 178.858694700665}, 
       {83.5, 175.4921054482728}, 
       {87.625, 164.7915165995674}, 
       {91.75, 156.9752948817185}, 
       {95.875, 150.9257826448045}, 
       {100., 146.0595611938693}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)