(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]

The Discrete-Time
Fourier Transform
:[font = special4; inactive; center; ]

by
:[font = subtitle; inactive; ]
James Proctor, Jose Crespo,
Brian Evans, and James McClellan
:[font = special4; inactive; center; ]

Digital Signal Processing Laboratory
School of Electrical Engineering
Georgia Institute of Technology
Atlanta, GA  30332-0250

:[font = special5; inactive; center; ]
e-mail:  evans@eedsp.gatech.edu

:[font = special3; inactive; wordwrap; ]
NOTE:  A Notebook is completely defined by a portable ASCII file but  machine-dependent binary information (bitmaps, etc.) is generated as side information to speed up the display of parts of the Notebook.   Mathematica 1.2 generates missing side information as needed whereas Mathematica 2.0 and higher generates all missing side information when a Notebook is opened.    Mathematica 2.0 and higher will display the message "Rendering ..." in the header of the Notebook when it is generating bitmaps for PostScript graphics contained in the Notebook.  This particular Notebook contains some 60 or so graphics cells whose bitmaps will require an 1.2 Mb of memory (60 cells x 20 kb/cell) to store.  The ASCII version of this Notebook occupies 660 kb.
:[font = text; inactive; ]
		What you are reading is a Mathematica Notebook.  It is a collection of cells containing text, graphics, animation, equations, tables, and "live" Mathematica code arranged in a tree structure.  You can read this Notebook sequentially as if it were a book.  You also have the option of tinkering with the mathematics underlying the subject which appear in the form of Mathematica commands.   Because the information is presented in a hierarchy, you can select more information on a topic either by searching for more information on a subject via the Find menu option or by opening up a closed section of cells.  A closed section is delimited by a cell bar containing a downward pointing half arrow:
:[font = special3; inactive; startGroup; Cclosed; center; ]
Example of a section with more information in it
(Open by clicking twice on the half arrow)
:[font = special3; inactive; center; ]
Here is more information
:[font = special3; inactive; center; ]
and more information.
:[font = special3; inactive; endGroup; center; ]
and more information.
:[font = text; inactive; ]
		Fonts are indicative of what the cell is.  For example, this cell is normal-sized text.  The next cell is "live" Mathematica code, and the cell after that contains the output of the "live" code:
:[font = input; startGroup; ]
2 + 2
:[font = output; inactive; output; endGroup; ]
4
;[o]
4
:[font = text; inactive; ]
You can have the Mathematica kernel evaluate code by selecting the cell with the code in it and then hitting either SHIFT-RETURN or ENTER.  The RETURN key by itself is only useful for formatting text.
:[font = text; inactive; ]
		Note that this Notebook is written so that each closed group of cells expands to fill the length of one screen.  So, please expand this notebook window so that it fills the length of the screen.
:[font = text; inactive; ]
		As a reminder, in order to open a section below, just move the mouse to the downward-pointing arrow and double click. To get help information for any command, place the cursor in an input cell and type ?Command (like ?ZTransform).
:[font = special1; inactive; ]

Table of Contents

:[font = section; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; ]
		Fourier analysis of discrete sequences is a staple of time-series analysis and discrete-time signal processing.  Classical Fourier analysis typically relies on Fourier Series, whereas signal processing generally uses the discrete-time and discrete Fourier transforms.  The Fourier techniques have continuous-time counterparts, but the motivation for both sets of techniques is quite different: 
:[font = smalltext; inactive; endGroup; ]
		"While continuous-time Fourier analysis can be traced to the investigation of problems in mathematical physics in the 1700's, the tools for analyzing discrete-time signals and systems have their own distinct roots.  In particular, discrete-time concepts and methods are fundamental to the discipline of numerical analysis. Formulas for the processing of discrete sers of data points to produce numerical approximations for interpolation, integration, and differentiation were being investigated as early as the time of Newton in the 1600's...  In the 1940s and 1950s major steps forward were taken in the development of discrete-time techniques in general and in the use of the tools of discrete-time Fourier analysis in particular.  The reasons for this push forward were the increasing use and capabilities of digital computers and the development of design methods for sampled-data systems, that is, discrete-time systems for the processing of sampled continuous-time signals."  [Oppenheim & Willsky, 1983]
:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = text; inactive; ]
You need to evaluate the following statement before running the examples that appear in this section.  It has been specified as an initialization cell so it may have been evaluated when you opened the notebook.
:[font = input; initialization; startGroup; ]
*)
Needs [ "SignalProcessing`Digital`" ]
(*
:[font = print; inactive; startGroup; ]
Loading version 2.42 of the digital signal\
 
  processing packages ...
:[font = print; inactive; ]
Supporting routines for the z-transform rule\
 
  bases are loaded.
:[font = print; inactive; ]
The forward z-transform rules have been loaded.
:[font = print; inactive; ]
The inverse z-transform rules have been loaded.
:[font = print; inactive; ]
The discrete-time Fourier transform (DTFT) rule\
 
  bases are loaded.
:[font = print; inactive; ]
Correlation functions are now loaded.
:[font = print; inactive; ]
ZSolve, a difference equation solver, is loaded.
:[font = print; inactive; ]
The digital signal analyzer is now loaded.
:[font = print; inactive; ]
The discrete Fourier transform (DFT) rule bases\
 
  are loaded.
:[font = message; inactive; ]
digital::loaded: 
   Routines, objects, and rules for the digital
    signal processing packages have been loaded
    successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
Digital signal processing extensions have been\
 
  loaded.
:[font = print; inactive; ]
Good starting points are the objects DSPAnalyze\
 
  and ZTransform.
:[font = print; inactive; ]
Active packages are maintained in $Packages.
:[font = print; inactive; ]
  Evaluate SPsignals for a list of all new\
 
  signals (functions).
:[font = print; inactive; ]
  Evaluate SPoperators for a list of all new\
 
  operators (systems).
:[font = print; inactive; ]
  Evaluate SPfunctions for a list of all new\
 
  routines.
:[font = print; inactive; ]
Note that all signal processing expressions will
:[font = print; inactive; ]
be automatically simplified.
:[font = print; inactive; endGroup; endGroup; endGroup; ]

:[font = section; inactive; startGroup; Cclosed; ]
Fourier Series
:[font = text; inactive; ]
	The goal of the Fourier Series is to approximate the behavior of a piecewise continuous function x(t) over an interval of length T using an infinite number of sinusoids.  Sinusoids are periodic functions, so the Fourier Series approximation assumes that x(t) is periodic with period T.
:[font = text; inactive; ]
	The Fourier Series approximation uses sinusoids of different amplitudes and harmonic frequencies.  For example, a Fourier Series might use cos(k w0 t) for k = 1 to infinity where w0 is the fundamental frequency.  The frequencies w0, 2 w0, 3 w0, and so forth are the harmonic frequencies of w0.
:[font = subsection; inactive; startGroup; Cclosed; ]
Approximating Functions with Sinusoids
:[font = text; inactive; ]
	Cosine functions are even functions with respect to the origin since cos(-t) = cos(t).  Therefore, a set of cosine functions are excellent choices for approximating even functions like t^2.  In the same way, a set of sine functions are well suited for approximating odd functions like t.   Piecewise-continuous Functions that are neither odd nor even can be decomposed into a sum of odd and even components:
:[font = print; inactive; locked; center; ]
           1                 
x    (t) = - [ x(t) - x(-t) ]
 odd       2                 
:[font = smalltext; inactive; ]

:[font = print; inactive; locked; center; ]
           1                 
x    (t) = - [ x(t) + x(-t) ]
 even      2                 
:[font = smalltext; inactive; ]

:[font = print; inactive; locked; center; ]
x(t) = x   (t) + x    (t)
        odd       even   
:[font = text; inactive; endGroup; ]
Therefore, both cosine and sine functions are needed to approximate general piecewise-continuous functions.
:[font = subsection; inactive; startGroup; Cclosed; ]
Definition of Fourier Series
:[font = text; inactive; ]
	The Fourier Series generates an approximation to x(t) 
:[font = postscript; inactive; PostScript; output; pictureLeft = 155; pictureWidth = 126; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.373016 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.373016 scale
1 string
126 47 1 [126 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FF8FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FC71FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C7E00007FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFE0703FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C7E0000700003F1F8FC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE381FFFFFFFFFFFE0703FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000001FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80000000001FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFC7FFFFF8FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFF81FFFFFFFF
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFE3FFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFF1FFFFFFFF
E3F1C7FFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFE3FFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFF
FC71FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFF1FFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFF
FC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
E07FC0FFF1FFFC0FFFE3FFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFF81F8
1C71FFE001FFFFFFFFFFFFFFFFFFFFFFFFC0
FC0E001F81FFE071FFE07FFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFE00E00
E38E07007E3FFFFFFFFFFFFFFFFFFFFFFFC0
FF8E07FF81FFE07FFFE07FFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFE07FC0
FF8FFF03FFC7FFFFFFFFFFFFFFFFFFFFFFC0
FF803FFF81FFE07FFFE07FFF0000001FFFFFFFFFFFFFFFF8FFFFFFE07FC0
FFF1FF000FFFFFFFFFFFFFFFFFFFFFFFFFC0
FFF03FFF81FFFC7FFFE07FFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFE07FF8
1F81FF03F03FFFFFFFFFFFFFFFFFFFFFFFC0
FF8007FF81FFFC0FFFE07FFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFC7FF8
1FFFFFE3FE07FFFFFFFFFFFFFFFFFFFFFFC0
FF81C0FF81FFFC0FFFE07FFF0000001FFFFFFFFFFFFFFE07FFFFFFFC0FC0
1FFFFFE07E0703FFFFFFFFFFFFFE3FFFFFC0
FC01F81FF1FFE0003FE3FFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFF000
E3FFFFFF803F1C7FFFFFFFFFFFF1C7FFFFC0
FFFFFFFFF1FFFF81FFE3FFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FFFFFFFFFFFFFC7FFFFFFFFFFFF1C7FFFFC0
FFFFFFFFFE3FFFF1FF1FFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8FC7FC7FC0E07E3FE3FFC0
FF8FF8FFFE3FFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF1FFFFFFFF
FFFFFFFFFFFFFF8FC7E38E3F1F8FFF1C7FC0
FF81C0FFFFC7FFFFF8FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF1FFFFFFFF
FFFFFFFFFFFFFF8FF8E3FFC7E3F1FF1FFFC0
FFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF81FFFFFFFF
FFFFFFFFFFFFFFF1F81FFFC7E3F1FFE3FFC0
FFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000001FFFFFFFF
FFFFFFFFFFFFFFF1F8E3FFF8FC7E3FE3FFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF81FF1C0FFF1FF1FF000FC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFC7FC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF1FF03FFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81C0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E3F1FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81C0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
using the set of complex-valued Fourier coefficients
:[font = postscript; inactive; PostScript; output; pictureLeft = 143; pictureWidth = 157; pictureHeight = 40; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.254777 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.254777 scale
1 string
157 40 1 [157 0 0 40 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFE00FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF03FFC7FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFE07FC7FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFC7FF8FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFE3FE3FFFFFFFFFFFFFFFFFFFFC0FFFFFFFC7FF8FFFFFFFFFFFFFF8
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFE3F1C7FFFFFFFFFFFFFFFE3FFC0FF8FFFFC7FF8FFFFFFFFFFFFFC7
FFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFC71FFFFFFFFFFFFFFFFFE07FC0FC0FFFFC7FFF1FFFFFFFFFFFFC7
FFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFC0FFFFFFFFFFFFFFFFFFFC0000000FFFFC71FF1F8FFFFFFFFFE3F
FFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FF81F81C71FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E00000FF81FF03FE3F
FFF03FFF8FFF000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03F03FE07E
E00E00E38E07FFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFF03800703F
FF81C7FF81F803F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01C01C7038E
E07FC0FF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFE381FF03F
FF81FFFF81F81FFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF81FF03FE
E07FC0FFF1FFFFFE0000003FFFFFFFFFFFFFFFFFC7FFFFFFFFFE00FFF03F
FF81FFFF81F8007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF81FF03FE
E07FF81F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFC0FFF03F
FFF1FFFF81F81F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFF1FFE3FE
FC7FF81FFFFFFFFFFFFFFFFFFFF000000000FFFFC7FFFFFFFFFE001FF03F
FFF03FFF81FF1FF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF03FE07E
FC0FC01FFFFFFFFE0000003FFFFFFFFFFFFFFFFFC7FFFFFFFFFE0703F03F
FFF03FFF81FF03F03FFFFE07FFFFFFFFFFFFFFF1FFFFFFF81F803FE07E
FFF000E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFF007E07E3F
FF8000FF8FFFFC01FFFFFE38FFFFFFFFFFFFFF8E3FFFFFFFE00E3F0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFE3F
FFFE07FF8FFFFFFFFFFFFFF8FFFFFFFFFFFFFF8E3FFFFFFFFFFE3FFC0E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFC7
FFFFC7FC7FFFFFFFFFFFFFFF1FF1FF1FF0381FF1FF1FFFFFFFFE07FF8E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFC7
FFFFFFFC7FFFFFFFFFFFFFFF1FF1F8E38FC7E3FFF8E3FFFFFFFE07FFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFF8
FFFFFFE3FFFFFFFFFFFFFFFF1FFE38FFF1F8FC7FF8FFFFFFFFFE07FFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000FFFFFFFC7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE3FE07FFF1F8FC7FFF1FFFFFFFF007FFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFC7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF80001FFE3FE38FFFE3F1F8FFF1FFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFC7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF03FFC703FFC7FC7FF8007FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFC0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFE3FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFF81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE3FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
As the number of terms grows, the approximation to x(t) gets better, as demonstrated by the following example.
:[font = subsubsection; inactive; startGroup; Cclosed; preserveAspect; ]
Example: Approximating a Square Wave
:[font = text; inactive; ]
		For example, consider one and a half periods of a square wave.  The animation below will show how the Fourier series (shown in thin lines) approaches the square wave (shown in thick lines):
:[font = subsubtitle; inactive; left; ]
(select the downward pointing arrow and hit COMMAND-Y;
 use the upward and downward ">>" buttons at the
 bottom of the window to change the animation speed)
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.43408 lineto
0.10317 0.53774 lineto
0.12302 0.57577 lineto
0.13294 0.59055 lineto
0.14286 0.60227 lineto
0.14782 0.60694 lineto
0.15278 0.61081 lineto
0.15774 0.61386 lineto
0.1627 0.61608 lineto
0.16518 0.61688 lineto
0.16642 0.6172 lineto
0.16766 0.61747 lineto
0.1689 0.61769 lineto
0.17014 0.61785 lineto
0.17138 0.61796 lineto
0.17262 0.61802 lineto
0.17386 0.61803 lineto
0.1751 0.61799 lineto
0.17634 0.61789 lineto
0.17758 0.61774 lineto
0.17882 0.61754 lineto
0.18006 0.61728 lineto
0.18254 0.61661 lineto
0.18502 0.61574 lineto
0.1875 0.61466 lineto
0.19246 0.61187 lineto
0.19742 0.60826 lineto
0.20238 0.60385 lineto
0.2123 0.59262 lineto
0.22222 0.57833 lineto
0.24206 0.54116 lineto
0.2619 0.49396 lineto
0.30159 0.37794 lineto
0.34127 0.25013 lineto
0.38095 0.13239 lineto
0.40079 0.08377 lineto
0.42063 0.04488 lineto
0.43056 0.02964 lineto
0.44048 0.01742 lineto
0.44544 0.01249 lineto
0.4504 0.00837 lineto
0.45536 0.00506 lineto
0.45784 0.00371 lineto
0.46032 0.00257 lineto
0.4628 0.00164 lineto
0.46528 0.00091 lineto
0.46652 0.00063 lineto
0.46776 0.0004 lineto
0.469 0.00022 lineto
Mistroke
0.47024 0.0001 lineto
0.47148 2e-05 lineto
0.47272 0 lineto
0.47396 3e-05 lineto
0.4752 0.00011 lineto
0.47644 0.00025 lineto
0.47768 0.00044 lineto
0.47892 0.00068 lineto
0.48016 0.00097 lineto
0.48512 0.00266 lineto
0.4876 0.00382 lineto
0.49008 0.00518 lineto
0.49504 0.00853 lineto
0.5 0.01269 lineto
0.50992 0.02341 lineto
0.51984 0.03723 lineto
0.53968 0.07352 lineto
0.57937 0.17465 lineto
0.61905 0.29876 lineto
0.65873 0.42464 lineto
0.67857 0.48141 lineto
0.69841 0.53072 lineto
0.71825 0.57045 lineto
0.72817 0.58617 lineto
0.7381 0.59887 lineto
0.74306 0.60406 lineto
0.74802 0.60844 lineto
0.75298 0.61201 lineto
0.75794 0.61476 lineto
0.76042 0.61583 lineto
0.7629 0.61668 lineto
0.76538 0.61733 lineto
0.76662 0.61758 lineto
0.76786 0.61777 lineto
0.7691 0.61791 lineto
0.77034 0.618 lineto
0.77158 0.61803 lineto
0.77282 0.61802 lineto
0.77406 0.61795 lineto
0.7753 0.61783 lineto
0.77654 0.61765 lineto
0.77778 0.61743 lineto
0.78026 0.61682 lineto
0.78274 0.616 lineto
0.7877 0.61374 lineto
0.79266 0.61066 lineto
0.79762 0.60675 lineto
0.80754 0.59654 lineto
0.81746 0.58321 lineto
0.8373 0.5478 lineto
Mistroke
0.85714 0.50207 lineto
0.89683 0.3879 lineto
0.93651 0.26023 lineto
0.97619 0.14091 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.04365 0.4332 lineto
0.05357 0.48705 lineto
0.06349 0.53183 lineto
0.07341 0.56579 lineto
0.07837 0.57841 lineto
0.08085 0.58362 lineto
0.08333 0.5881 lineto
0.08581 0.59185 lineto
0.08829 0.5949 lineto
0.09077 0.59725 lineto
0.09325 0.59893 lineto
0.09449 0.59952 lineto
0.09573 0.59995 lineto
0.09697 0.60023 lineto
0.09821 0.60035 lineto
0.09945 0.60033 lineto
0.10069 0.60015 lineto
0.10193 0.59984 lineto
0.10317 0.59939 lineto
0.10565 0.59809 lineto
0.10813 0.5963 lineto
0.11062 0.59406 lineto
0.1131 0.5914 lineto
0.12302 0.57748 lineto
0.13294 0.56051 lineto
0.14286 0.5434 lineto
0.14782 0.53563 lineto
0.15278 0.5288 lineto
0.15774 0.52315 lineto
0.1627 0.51888 lineto
0.16518 0.51732 lineto
0.16642 0.51668 lineto
0.16766 0.51615 lineto
0.1689 0.51572 lineto
0.17014 0.51539 lineto
0.17138 0.51517 lineto
0.17262 0.51505 lineto
0.17386 0.51504 lineto
0.1751 0.51513 lineto
0.17634 0.51532 lineto
0.17758 0.51562 lineto
0.17882 0.51602 lineto
0.18006 0.51653 lineto
0.18254 0.51784 lineto
0.18502 0.51955 lineto
0.1875 0.52163 lineto
0.19246 0.52686 lineto
0.20238 0.54084 lineto
0.2123 0.55772 lineto
Mistroke
0.22222 0.57491 lineto
0.22718 0.58272 lineto
0.23214 0.58951 lineto
0.23462 0.59241 lineto
0.2371 0.59492 lineto
0.23958 0.59701 lineto
0.24206 0.59862 lineto
0.2433 0.59924 lineto
0.24454 0.59973 lineto
0.24578 0.60008 lineto
0.24702 0.60029 lineto
0.24826 0.60036 lineto
0.2495 0.60028 lineto
0.25074 0.60005 lineto
0.25198 0.59966 lineto
0.25322 0.59911 lineto
0.25446 0.5984 lineto
0.25694 0.59648 lineto
0.25942 0.59388 lineto
0.2619 0.59057 lineto
0.26687 0.58181 lineto
0.27183 0.57013 lineto
0.28175 0.538 lineto
0.29167 0.49485 lineto
0.30159 0.44229 lineto
0.32143 0.31927 lineto
0.34127 0.19409 lineto
0.35119 0.13901 lineto
0.36111 0.09265 lineto
0.37103 0.05689 lineto
0.37599 0.04333 lineto
0.38095 0.03271 lineto
0.38591 0.02499 lineto
0.38839 0.0222 lineto
0.38963 0.02106 lineto
0.39087 0.0201 lineto
0.39211 0.01929 lineto
0.39335 0.01866 lineto
0.39459 0.01818 lineto
0.39583 0.01786 lineto
0.39707 0.0177 lineto
0.39831 0.01769 lineto
0.39955 0.01782 lineto
0.40079 0.01809 lineto
0.40203 0.01851 lineto
0.40327 0.01905 lineto
0.40575 0.02053 lineto
0.40823 0.02249 lineto
0.41071 0.02489 lineto
0.42063 0.03805 lineto
Mistroke
0.44048 0.07202 lineto
0.4504 0.08717 lineto
0.45536 0.09322 lineto
0.45784 0.09576 lineto
0.46032 0.09795 lineto
0.4628 0.09976 lineto
0.46528 0.10119 lineto
0.46652 0.10175 lineto
0.46776 0.10221 lineto
0.469 0.10256 lineto
0.47024 0.10281 lineto
0.47148 0.10296 lineto
0.47272 0.10301 lineto
0.47396 0.10294 lineto
0.4752 0.10278 lineto
0.47644 0.10251 lineto
0.47768 0.10213 lineto
0.47892 0.10166 lineto
0.48016 0.10108 lineto
0.5 0.07968 lineto
0.51984 0.04577 lineto
0.5248 0.03771 lineto
0.52976 0.03056 lineto
0.53472 0.02466 lineto
0.5372 0.0223 lineto
0.53968 0.02038 lineto
0.54216 0.01895 lineto
0.5434 0.01842 lineto
0.54464 0.01803 lineto
0.54588 0.01778 lineto
0.54712 0.01768 lineto
0.54836 0.01772 lineto
0.5496 0.01791 lineto
0.55084 0.01825 lineto
0.55208 0.01876 lineto
0.55332 0.01942 lineto
0.55456 0.02025 lineto
0.55704 0.02242 lineto
0.55952 0.02527 lineto
0.56448 0.03311 lineto
0.56944 0.04386 lineto
0.57937 0.07415 lineto
0.58929 0.11563 lineto
0.59921 0.16683 lineto
0.61905 0.28853 lineto
0.63889 0.41453 lineto
0.64881 0.47077 lineto
0.65873 0.51867 lineto
0.66369 0.53883 lineto
0.66865 0.55621 lineto
Mistroke
0.67361 0.57071 lineto
0.67857 0.58226 lineto
0.68105 0.58694 lineto
0.68353 0.5909 lineto
0.68601 0.59413 lineto
0.68849 0.59668 lineto
0.68973 0.59769 lineto
0.69097 0.59854 lineto
0.69221 0.59922 lineto
0.69345 0.59974 lineto
0.69469 0.6001 lineto
0.69593 0.6003 lineto
0.69717 0.60036 lineto
0.69841 0.60027 lineto
0.69965 0.60003 lineto
0.70089 0.59965 lineto
0.70213 0.59914 lineto
0.70337 0.5985 lineto
0.70833 0.59472 lineto
0.71081 0.59217 lineto
0.71329 0.58923 lineto
0.71825 0.58239 lineto
0.7381 0.54869 lineto
0.74802 0.53303 lineto
0.75298 0.5266 lineto
0.75794 0.52143 lineto
0.76042 0.51938 lineto
0.7629 0.51771 lineto
0.76538 0.51643 lineto
0.76662 0.51594 lineto
0.76786 0.51556 lineto
0.7691 0.51528 lineto
0.77034 0.5151 lineto
0.77158 0.51503 lineto
0.77282 0.51506 lineto
0.77406 0.5152 lineto
0.7753 0.51544 lineto
0.77654 0.51579 lineto
0.77778 0.51624 lineto
0.78026 0.51744 lineto
0.78274 0.51904 lineto
0.7877 0.52337 lineto
0.79266 0.52908 lineto
0.79762 0.53596 lineto
0.81746 0.56957 lineto
0.82738 0.58532 lineto
0.83234 0.59165 lineto
0.83482 0.59428 lineto
0.8373 0.59648 lineto
0.83978 0.59823 lineto
Mistroke
0.84102 0.59892 lineto
0.84226 0.59948 lineto
0.8435 0.59991 lineto
0.84474 0.6002 lineto
0.84598 0.60034 lineto
0.84722 0.60034 lineto
0.84846 0.60019 lineto
0.8497 0.59989 lineto
0.85094 0.59943 lineto
0.85218 0.59881 lineto
0.85466 0.59707 lineto
0.85714 0.59466 lineto
0.85962 0.59155 lineto
0.8621 0.58773 lineto
0.86706 0.57791 lineto
0.87202 0.56516 lineto
0.87698 0.54948 lineto
0.8869 0.50971 lineto
0.89683 0.45992 lineto
0.93651 0.21306 lineto
0.97619 0.03913 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.03373 0.40357 lineto
0.04365 0.48655 lineto
0.04861 0.5207 lineto
0.05357 0.54885 lineto
0.05853 0.57056 lineto
0.06101 0.57894 lineto
0.06349 0.58569 lineto
0.06597 0.59085 lineto
0.06721 0.59285 lineto
0.06845 0.59448 lineto
0.06969 0.59574 lineto
0.07093 0.59664 lineto
0.07217 0.5972 lineto
0.07341 0.59743 lineto
0.07465 0.59734 lineto
0.07589 0.59694 lineto
0.07713 0.59626 lineto
0.07837 0.59531 lineto
0.07961 0.59411 lineto
0.08085 0.59266 lineto
0.08333 0.58912 lineto
0.09325 0.56907 lineto
0.10317 0.54656 lineto
0.10813 0.537 lineto
0.11062 0.533 lineto
0.1131 0.52962 lineto
0.11558 0.52691 lineto
0.11682 0.52582 lineto
0.11806 0.52491 lineto
0.1193 0.52419 lineto
0.12054 0.52365 lineto
0.12178 0.5233 lineto
0.12302 0.52313 lineto
0.12426 0.52314 lineto
0.1255 0.52333 lineto
0.12674 0.5237 lineto
0.12798 0.52424 lineto
0.13046 0.52582 lineto
0.13294 0.528 lineto
0.13542 0.53072 lineto
0.1379 0.53391 lineto
0.14286 0.54134 lineto
0.15278 0.55776 lineto
0.15774 0.56519 lineto
0.1627 0.57117 lineto
0.16518 0.57344 lineto
0.16642 0.57437 lineto
0.16766 0.57516 lineto
0.1689 0.5758 lineto
Mistroke
0.17014 0.57629 lineto
0.17138 0.57662 lineto
0.17262 0.5768 lineto
0.17386 0.57682 lineto
0.1751 0.57669 lineto
0.17634 0.57639 lineto
0.17758 0.57595 lineto
0.17882 0.57535 lineto
0.18006 0.5746 lineto
0.18254 0.57268 lineto
0.1875 0.56728 lineto
0.19246 0.56025 lineto
0.20238 0.54391 lineto
0.20734 0.53615 lineto
0.20982 0.5327 lineto
0.2123 0.52967 lineto
0.21478 0.52714 lineto
0.21602 0.52608 lineto
0.21726 0.52517 lineto
0.2185 0.52442 lineto
0.21974 0.52383 lineto
0.22098 0.52342 lineto
0.22222 0.52318 lineto
0.22346 0.52311 lineto
0.2247 0.52323 lineto
0.22594 0.52353 lineto
0.22718 0.52402 lineto
0.22842 0.52469 lineto
0.22966 0.52555 lineto
0.23214 0.52781 lineto
0.23462 0.53077 lineto
0.2371 0.53438 lineto
0.24206 0.54332 lineto
0.25198 0.56542 lineto
0.25694 0.57664 lineto
0.2619 0.58648 lineto
0.26438 0.5905 lineto
0.26687 0.59373 lineto
0.26811 0.59501 lineto
0.26935 0.59603 lineto
0.27059 0.59679 lineto
0.27183 0.59726 lineto
0.27307 0.59743 lineto
0.27431 0.59729 lineto
0.27555 0.59683 lineto
0.27679 0.59602 lineto
0.27803 0.59486 lineto
0.27927 0.59334 lineto
0.28175 0.58916 lineto
0.28423 0.58343 lineto
Mistroke
0.28671 0.57609 lineto
0.29167 0.55648 lineto
0.29663 0.53035 lineto
0.30159 0.49804 lineto
0.32143 0.32439 lineto
0.33135 0.22903 lineto
0.34127 0.14351 lineto
0.34623 0.10759 lineto
0.35119 0.07746 lineto
0.35615 0.05368 lineto
0.35863 0.04425 lineto
0.36111 0.03646 lineto
0.36359 0.03029 lineto
0.36483 0.02779 lineto
0.36607 0.02569 lineto
0.36731 0.02396 lineto
0.36855 0.02261 lineto
0.36979 0.02161 lineto
0.37103 0.02096 lineto
0.37227 0.02064 lineto
0.37351 0.02064 lineto
0.37475 0.02095 lineto
0.37599 0.02156 lineto
0.37847 0.02357 lineto
0.37971 0.02495 lineto
0.38095 0.02656 lineto
0.40079 0.06808 lineto
0.40575 0.07819 lineto
0.41071 0.08634 lineto
0.41319 0.08948 lineto
0.41567 0.09194 lineto
0.41691 0.09289 lineto
0.41815 0.09367 lineto
0.41939 0.09426 lineto
0.42063 0.09466 lineto
0.42188 0.09488 lineto
0.42312 0.09492 lineto
0.42436 0.09477 lineto
0.4256 0.09445 lineto
0.42684 0.09396 lineto
0.42808 0.09329 lineto
0.43056 0.09149 lineto
0.43304 0.08911 lineto
0.43552 0.08621 lineto
0.44048 0.07918 lineto
0.4504 0.06284 lineto
0.45536 0.05508 lineto
0.46032 0.04857 lineto
0.4628 0.04598 lineto
0.46528 0.0439 lineto
Mistroke
0.46652 0.04308 lineto
0.46776 0.0424 lineto
0.469 0.04187 lineto
0.47024 0.04149 lineto
0.47148 0.04127 lineto
0.47272 0.0412 lineto
0.47396 0.0413 lineto
0.4752 0.04154 lineto
0.47644 0.04195 lineto
0.47768 0.04251 lineto
0.47892 0.04321 lineto
0.48016 0.04407 lineto
0.5 0.0715 lineto
0.50496 0.07952 lineto
0.50992 0.08648 lineto
0.5124 0.08934 lineto
0.51488 0.09168 lineto
0.51612 0.09263 lineto
0.51736 0.09342 lineto
0.5186 0.09406 lineto
0.51984 0.09452 lineto
0.52108 0.09481 lineto
0.52232 0.09492 lineto
0.52356 0.09485 lineto
0.5248 0.0946 lineto
0.52604 0.09417 lineto
0.52728 0.09354 lineto
0.52852 0.09274 lineto
0.52976 0.09175 lineto
0.53968 0.07778 lineto
0.5496 0.0563 lineto
0.55456 0.04488 lineto
0.55952 0.03447 lineto
0.56448 0.02626 lineto
0.56572 0.02469 lineto
0.56696 0.02335 lineto
0.5682 0.02226 lineto
0.56944 0.02143 lineto
0.57068 0.02088 lineto
0.57192 0.02062 lineto
0.57316 0.02067 lineto
0.5744 0.02105 lineto
0.57564 0.02176 lineto
0.57688 0.02282 lineto
0.57813 0.02424 lineto
0.57937 0.02604 lineto
0.58185 0.03077 lineto
0.58433 0.03708 lineto
0.58929 0.05459 lineto
0.59425 0.07867 lineto
Mistroke
0.59921 0.10906 lineto
0.61905 0.27832 lineto
0.62897 0.37418 lineto
0.63889 0.462 lineto
0.64385 0.49959 lineto
0.64881 0.53164 lineto
0.65377 0.55749 lineto
0.65625 0.56797 lineto
0.65873 0.5768 lineto
0.66121 0.584 lineto
0.66369 0.58959 lineto
0.66493 0.5918 lineto
0.66617 0.59363 lineto
0.66741 0.59509 lineto
0.66865 0.59619 lineto
0.66989 0.59693 lineto
0.67113 0.59734 lineto
0.67237 0.59742 lineto
0.67361 0.5972 lineto
0.67485 0.59667 lineto
0.67609 0.59587 lineto
0.67857 0.59348 lineto
0.68105 0.59017 lineto
0.68353 0.58609 lineto
0.68849 0.57616 lineto
0.69841 0.55346 lineto
0.70337 0.54288 lineto
0.70833 0.53404 lineto
0.71081 0.53048 lineto
0.71329 0.52758 lineto
0.71577 0.52539 lineto
0.71701 0.52456 lineto
0.71825 0.52392 lineto
0.71949 0.52347 lineto
0.72073 0.5232 lineto
0.72197 0.52311 lineto
0.72321 0.52321 lineto
0.72445 0.52348 lineto
0.72569 0.52393 lineto
0.72693 0.52454 lineto
0.72817 0.52532 lineto
0.73065 0.52734 lineto
0.73313 0.52992 lineto
0.7381 0.53647 lineto
0.74802 0.55258 lineto
0.75794 0.56756 lineto
0.76042 0.57046 lineto
0.7629 0.57287 lineto
0.76538 0.57474 lineto
0.76662 0.57547 lineto
Mistroke
0.76786 0.57604 lineto
0.7691 0.57646 lineto
0.77034 0.57672 lineto
0.77158 0.57683 lineto
0.77282 0.57678 lineto
0.77406 0.57657 lineto
0.7753 0.57621 lineto
0.77654 0.5757 lineto
0.77778 0.57503 lineto
0.78026 0.57326 lineto
0.78274 0.57094 lineto
0.7877 0.56489 lineto
0.79762 0.54919 lineto
0.80258 0.54099 lineto
0.80754 0.53361 lineto
0.81002 0.53046 lineto
0.8125 0.52778 lineto
0.81498 0.52565 lineto
0.81622 0.52481 lineto
0.81746 0.52414 lineto
0.8187 0.52362 lineto
0.81994 0.52329 lineto
0.82118 0.52312 lineto
0.82242 0.52314 lineto
0.82366 0.52334 lineto
0.8249 0.52373 lineto
0.82614 0.5243 lineto
0.82738 0.52506 lineto
0.82986 0.52712 lineto
0.83234 0.52989 lineto
0.83482 0.53333 lineto
0.8373 0.53738 lineto
0.84722 0.55807 lineto
0.85218 0.56957 lineto
0.85714 0.58043 lineto
0.8621 0.58947 lineto
0.86458 0.59293 lineto
0.86582 0.59434 lineto
0.86706 0.5955 lineto
0.8683 0.59641 lineto
0.86954 0.59704 lineto
0.87078 0.59737 lineto
0.87202 0.59741 lineto
0.87326 0.59712 lineto
0.8745 0.5965 lineto
0.87574 0.59554 lineto
0.87698 0.59422 lineto
0.87822 0.59253 lineto
0.87946 0.59046 lineto
0.88194 0.58516 lineto
Mistroke
0.88442 0.57826 lineto
0.8869 0.56973 lineto
0.89187 0.54774 lineto
0.89683 0.51931 lineto
0.90675 0.44531 lineto
0.91667 0.35494 lineto
0.92659 0.25889 lineto
0.93651 0.16903 lineto
0.94147 0.12985 lineto
0.94643 0.09595 lineto
0.95139 0.06808 lineto
0.95635 0.04667 lineto
0.95883 0.03843 lineto
0.96131 0.03182 lineto
0.96379 0.0268 lineto
0.96503 0.02486 lineto
0.96627 0.02331 lineto
0.96751 0.02211 lineto
0.96875 0.02127 lineto
0.96999 0.02077 lineto
0.97123 0.0206 lineto
0.97247 0.02075 lineto
0.97371 0.02119 lineto
0.97495 0.02192 lineto
0.97619 0.02292 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.03373 0.43298 lineto
0.03869 0.48638 lineto
0.04365 0.53042 lineto
0.04861 0.56345 lineto
0.05109 0.57561 lineto
0.05233 0.5806 lineto
0.05357 0.58487 lineto
0.05481 0.58843 lineto
0.05605 0.59131 lineto
0.05729 0.59353 lineto
0.05853 0.5951 lineto
0.05977 0.59605 lineto
0.06101 0.59642 lineto
0.06225 0.59624 lineto
0.06349 0.59554 lineto
0.06473 0.59436 lineto
0.06597 0.59274 lineto
0.06721 0.59071 lineto
0.06845 0.58833 lineto
0.07341 0.5761 lineto
0.07837 0.5616 lineto
0.08333 0.54747 lineto
0.08581 0.54123 lineto
0.08829 0.53585 lineto
0.09077 0.53149 lineto
0.09325 0.52827 lineto
0.09449 0.52711 lineto
0.09573 0.52625 lineto
0.09697 0.5257 lineto
0.09821 0.52546 lineto
0.09945 0.52551 lineto
0.10069 0.52586 lineto
0.10193 0.52648 lineto
0.10317 0.52737 lineto
0.1131 0.54179 lineto
0.11806 0.55141 lineto
0.12302 0.56047 lineto
0.1255 0.56433 lineto
0.12798 0.56753 lineto
0.12922 0.56884 lineto
0.13046 0.56996 lineto
0.1317 0.57085 lineto
0.13294 0.57153 lineto
0.13418 0.57198 lineto
0.13542 0.5722 lineto
0.13666 0.5722 lineto
0.1379 0.57197 lineto
0.13914 0.57152 lineto
0.14038 0.57085 lineto
Mistroke
0.14162 0.56998 lineto
0.14286 0.56892 lineto
0.15278 0.55536 lineto
0.15774 0.54723 lineto
0.1627 0.54001 lineto
0.16518 0.53713 lineto
0.16642 0.53593 lineto
0.16766 0.5349 lineto
0.1689 0.53406 lineto
0.17014 0.53341 lineto
0.17138 0.53297 lineto
0.17262 0.53273 lineto
0.18254 0.53811 lineto
0.19246 0.55276 lineto
0.19742 0.56072 lineto
0.1999 0.56427 lineto
0.20238 0.56731 lineto
0.20362 0.5686 lineto
0.20486 0.56971 lineto
0.2061 0.57063 lineto
0.20734 0.57135 lineto
0.20858 0.57186 lineto
0.20982 0.57215 lineto
0.21106 0.57222 lineto
0.2123 0.57206 lineto
0.21354 0.57167 lineto
0.21478 0.57106 lineto
0.21602 0.57022 lineto
0.21726 0.56917 lineto
0.22222 0.563 lineto
0.23214 0.54482 lineto
0.2371 0.53574 lineto
0.23958 0.53193 lineto
0.24206 0.52886 lineto
0.2433 0.52766 lineto
0.24454 0.5267 lineto
0.24578 0.526 lineto
0.24702 0.52558 lineto
0.24826 0.52544 lineto
0.2495 0.52561 lineto
0.25074 0.52607 lineto
0.25198 0.52684 lineto
0.25322 0.52792 lineto
0.25446 0.5293 lineto
0.25694 0.53295 lineto
0.25942 0.53769 lineto
0.2619 0.54341 lineto
0.27183 0.57159 lineto
0.27679 0.58485 lineto
0.27927 0.59009 lineto
Mistroke
0.28051 0.59222 lineto
0.28175 0.59396 lineto
0.28299 0.59526 lineto
0.28423 0.5961 lineto
0.28547 0.59643 lineto
0.28671 0.59621 lineto
0.28795 0.59542 lineto
0.28919 0.59402 lineto
0.29043 0.59199 lineto
0.29167 0.58929 lineto
0.29291 0.58591 lineto
0.29415 0.58184 lineto
0.29663 0.57154 lineto
0.29911 0.55832 lineto
0.30159 0.54219 lineto
0.31151 0.45087 lineto
0.32143 0.32951 lineto
0.33135 0.20363 lineto
0.33631 0.14776 lineto
0.34127 0.10051 lineto
0.34375 0.08077 lineto
0.34623 0.06385 lineto
0.34871 0.04983 lineto
0.35119 0.03873 lineto
0.35243 0.03427 lineto
0.35367 0.03051 lineto
0.35491 0.02744 lineto
0.35615 0.02505 lineto
0.35739 0.0233 lineto
0.35863 0.02218 lineto
0.35987 0.02166 lineto
0.36111 0.02169 lineto
0.36235 0.02225 lineto
0.36359 0.02331 lineto
0.36483 0.02481 lineto
0.36607 0.02673 lineto
0.37103 0.03766 lineto
0.38095 0.06624 lineto
0.38591 0.07886 lineto
0.38839 0.08389 lineto
0.39087 0.08785 lineto
0.39211 0.08939 lineto
0.39335 0.09064 lineto
0.39459 0.09158 lineto
0.39583 0.09221 lineto
0.39707 0.09254 lineto
0.39831 0.09257 lineto
0.39955 0.0923 lineto
0.40079 0.09175 lineto
0.40203 0.09094 lineto
Mistroke
0.40327 0.08986 lineto
0.40575 0.08702 lineto
0.41071 0.07917 lineto
0.41567 0.0697 lineto
0.42063 0.06029 lineto
0.4256 0.05246 lineto
0.42808 0.04953 lineto
0.42932 0.04836 lineto
0.43056 0.04741 lineto
0.4318 0.04667 lineto
0.43304 0.04616 lineto
0.43428 0.04587 lineto
0.43552 0.04581 lineto
0.43676 0.04598 lineto
0.438 0.04637 lineto
0.43924 0.04698 lineto
0.44048 0.04779 lineto
0.44172 0.0488 lineto
0.44296 0.04999 lineto
0.44544 0.05287 lineto
0.4504 0.06011 lineto
0.45536 0.06825 lineto
0.46032 0.0759 lineto
0.4628 0.07914 lineto
0.46528 0.08179 lineto
0.46652 0.08287 lineto
0.46776 0.08377 lineto
0.469 0.08447 lineto
0.47024 0.08497 lineto
0.47148 0.08526 lineto
0.47272 0.08535 lineto
0.47396 0.08522 lineto
0.4752 0.08489 lineto
0.47644 0.08436 lineto
0.47768 0.08362 lineto
0.47892 0.08269 lineto
0.48016 0.08159 lineto
0.49008 0.06789 lineto
0.49504 0.05976 lineto
0.49752 0.05598 lineto
0.5 0.05259 lineto
0.50248 0.04977 lineto
0.50496 0.04763 lineto
0.5062 0.04686 lineto
0.50744 0.04629 lineto
0.50868 0.04594 lineto
0.50992 0.04581 lineto
0.51116 0.04591 lineto
0.5124 0.04623 lineto
0.51364 0.04678 lineto
Mistroke
0.51488 0.04756 lineto
0.51984 0.05276 lineto
0.52232 0.05644 lineto
0.5248 0.06068 lineto
0.52976 0.07013 lineto
0.53472 0.07956 lineto
0.5372 0.08375 lineto
0.53968 0.08731 lineto
0.54216 0.09007 lineto
0.5434 0.0911 lineto
0.54464 0.09187 lineto
0.54588 0.09237 lineto
0.54712 0.09258 lineto
0.54836 0.0925 lineto
0.5496 0.09212 lineto
0.55084 0.09143 lineto
0.55208 0.09044 lineto
0.55456 0.08754 lineto
0.55704 0.08349 lineto
0.55952 0.07837 lineto
0.56944 0.05108 lineto
0.5744 0.03709 lineto
0.57688 0.03114 lineto
0.57813 0.02858 lineto
0.57937 0.02636 lineto
0.58061 0.02451 lineto
0.58185 0.02309 lineto
0.58309 0.02212 lineto
0.58433 0.02165 lineto
0.58557 0.02171 lineto
0.58681 0.02234 lineto
0.58805 0.02357 lineto
0.58929 0.02543 lineto
0.59177 0.03112 lineto
0.59301 0.03501 lineto
0.59425 0.0396 lineto
0.59921 0.06523 lineto
0.60169 0.08241 lineto
0.60417 0.10239 lineto
0.60913 0.15007 lineto
0.61905 0.26816 lineto
0.62897 0.39522 lineto
0.63393 0.45329 lineto
0.63889 0.50355 lineto
0.64385 0.54373 lineto
0.64633 0.55961 lineto
0.64881 0.57256 lineto
0.65129 0.58261 lineto
0.65253 0.58656 lineto
0.65377 0.58982 lineto
Mistroke
0.65501 0.59239 lineto
0.65625 0.59431 lineto
0.65749 0.5956 lineto
0.65873 0.59629 lineto
0.65997 0.59641 lineto
0.66121 0.59599 lineto
0.66245 0.59506 lineto
0.66369 0.59368 lineto
0.66493 0.59187 lineto
0.66617 0.58968 lineto
0.66865 0.58433 lineto
0.67857 0.55631 lineto
0.68353 0.54287 lineto
0.68601 0.53723 lineto
0.68849 0.53258 lineto
0.68973 0.53066 lineto
0.69097 0.52904 lineto
0.69221 0.52771 lineto
0.69345 0.52668 lineto
0.69469 0.52597 lineto
0.69593 0.52556 lineto
0.69717 0.52545 lineto
0.69841 0.52563 lineto
0.69965 0.5261 lineto
0.70089 0.52685 lineto
0.70213 0.52785 lineto
0.70337 0.5291 lineto
0.70833 0.53611 lineto
0.71825 0.55485 lineto
0.72321 0.56333 lineto
0.72569 0.56672 lineto
0.72693 0.56815 lineto
0.72817 0.56937 lineto
0.72941 0.57039 lineto
0.73065 0.57118 lineto
0.73189 0.57176 lineto
0.73313 0.57211 lineto
0.73437 0.57223 lineto
0.73562 0.57212 lineto
0.73686 0.57179 lineto
0.7381 0.57124 lineto
0.73934 0.57049 lineto
0.74058 0.56953 lineto
0.74306 0.56707 lineto
0.74802 0.56039 lineto
0.75794 0.54444 lineto
0.76042 0.5409 lineto
0.7629 0.53786 lineto
0.76538 0.53544 lineto
0.76662 0.53449 lineto
Mistroke
0.76786 0.53374 lineto
0.7691 0.53318 lineto
0.77034 0.53283 lineto
0.77158 0.53269 lineto
0.77282 0.53276 lineto
0.77406 0.53303 lineto
0.7753 0.53351 lineto
0.77654 0.53419 lineto
0.77778 0.53507 lineto
0.78026 0.53736 lineto
0.78274 0.5403 lineto
0.7877 0.54758 lineto
0.79266 0.55572 lineto
0.79762 0.56334 lineto
0.8001 0.56654 lineto
0.80258 0.56912 lineto
0.80382 0.57015 lineto
0.80506 0.57098 lineto
0.8063 0.57161 lineto
0.80754 0.57202 lineto
0.80878 0.57221 lineto
0.81002 0.57218 lineto
0.81126 0.57191 lineto
0.8125 0.57142 lineto
0.81746 0.56727 lineto
0.82738 0.55099 lineto
0.83234 0.54137 lineto
0.83482 0.53689 lineto
0.8373 0.53291 lineto
0.83978 0.52962 lineto
0.84102 0.52829 lineto
0.84226 0.52719 lineto
0.8435 0.52635 lineto
0.84474 0.52577 lineto
0.84598 0.52548 lineto
0.84722 0.52548 lineto
0.84846 0.52578 lineto
0.8497 0.52638 lineto
0.85094 0.52729 lineto
0.85218 0.52851 lineto
0.85466 0.53183 lineto
0.85714 0.53629 lineto
0.8621 0.54805 lineto
0.86706 0.56226 lineto
0.87202 0.57671 lineto
0.87698 0.58878 lineto
0.87822 0.5911 lineto
0.87946 0.59305 lineto
0.8807 0.5946 lineto
0.88194 0.5957 lineto
Mistroke
0.88318 0.59631 lineto
0.88442 0.5964 lineto
0.88566 0.59593 lineto
0.8869 0.59487 lineto
0.88814 0.59318 lineto
0.88938 0.59085 lineto
0.89187 0.58416 lineto
0.89311 0.57977 lineto
0.89435 0.57465 lineto
0.89683 0.56223 lineto
0.90179 0.52869 lineto
0.90675 0.48419 lineto
0.91667 0.37001 lineto
0.92659 0.24248 lineto
0.93155 0.18252 lineto
0.93651 0.12949 lineto
0.94147 0.08591 lineto
0.94395 0.06821 lineto
0.94643 0.05339 lineto
0.94891 0.04149 lineto
0.95015 0.03663 lineto
0.95139 0.03249 lineto
0.95263 0.02904 lineto
0.95387 0.02628 lineto
0.95511 0.02418 lineto
0.95635 0.02272 lineto
0.95759 0.02187 lineto
0.95883 0.0216 lineto
0.96007 0.02188 lineto
0.96131 0.02267 lineto
0.96379 0.02563 lineto
0.96503 0.02772 lineto
0.96627 0.03016 lineto
0.97619 0.05708 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02877 0.3883 lineto
0.03373 0.46066 lineto
0.03869 0.52025 lineto
0.04117 0.54394 lineto
0.04365 0.56318 lineto
0.04489 0.57108 lineto
0.04613 0.57785 lineto
0.04737 0.58349 lineto
0.04861 0.58803 lineto
0.04985 0.5915 lineto
0.05109 0.59395 lineto
0.05233 0.59542 lineto
0.05357 0.59596 lineto
0.06349 0.57591 lineto
0.06845 0.5581 lineto
0.07093 0.54948 lineto
0.07341 0.54177 lineto
0.07589 0.53538 lineto
0.07837 0.5306 lineto
0.07961 0.52887 lineto
0.08085 0.52761 lineto
0.08209 0.52681 lineto
0.08333 0.52646 lineto
0.08457 0.52657 lineto
0.08581 0.52711 lineto
0.08705 0.52806 lineto
0.08829 0.52939 lineto
0.09325 0.53774 lineto
0.09821 0.54881 lineto
0.10317 0.55957 lineto
0.10565 0.56397 lineto
0.10813 0.56735 lineto
0.10938 0.5686 lineto
0.11062 0.56954 lineto
0.11186 0.57015 lineto
0.1131 0.57044 lineto
0.11434 0.5704 lineto
0.11558 0.57005 lineto
0.11682 0.56938 lineto
0.11806 0.56843 lineto
0.12302 0.56218 lineto
0.13294 0.5449 lineto
0.13542 0.54126 lineto
0.13666 0.53973 lineto
0.1379 0.53842 lineto
0.13914 0.53734 lineto
0.14038 0.53652 lineto
0.14162 0.53597 lineto
0.14286 0.53569 lineto
Mistroke
0.1627 0.55821 lineto
0.16518 0.56159 lineto
0.16642 0.56304 lineto
0.16766 0.56429 lineto
0.1689 0.56532 lineto
0.17014 0.56612 lineto
0.17138 0.56667 lineto
0.17262 0.56697 lineto
0.17386 0.567 lineto
0.1751 0.56678 lineto
0.17634 0.5663 lineto
0.17758 0.56556 lineto
0.17882 0.56459 lineto
0.18006 0.5634 lineto
0.18254 0.56043 lineto
0.19246 0.54494 lineto
0.19494 0.54146 lineto
0.19618 0.53996 lineto
0.19742 0.53865 lineto
0.19866 0.53755 lineto
0.1999 0.53669 lineto
0.20114 0.53608 lineto
0.20238 0.53574 lineto
0.20362 0.53567 lineto
0.20486 0.53587 lineto
0.2061 0.53635 lineto
0.20734 0.53709 lineto
0.20858 0.5381 lineto
0.20982 0.53935 lineto
0.2123 0.5425 lineto
0.22222 0.55959 lineto
0.2247 0.56356 lineto
0.22718 0.56683 lineto
0.22842 0.56812 lineto
0.22966 0.56915 lineto
0.2309 0.56989 lineto
0.23214 0.57034 lineto
0.23338 0.57046 lineto
0.23462 0.57026 lineto
0.23586 0.56974 lineto
0.2371 0.56889 lineto
0.24206 0.56248 lineto
0.24702 0.55242 lineto
0.25198 0.54111 lineto
0.25446 0.53593 lineto
0.25694 0.53157 lineto
0.25818 0.52981 lineto
0.25942 0.52839 lineto
0.26066 0.52733 lineto
0.2619 0.52668 lineto
Mistroke
0.26314 0.52645 lineto
0.26438 0.52667 lineto
0.26563 0.52734 lineto
0.26687 0.52848 lineto
0.26935 0.53213 lineto
0.27059 0.53462 lineto
0.27183 0.53752 lineto
0.28175 0.57036 lineto
0.28423 0.57894 lineto
0.28671 0.58643 lineto
0.28795 0.58955 lineto
0.28919 0.59215 lineto
0.29043 0.59413 lineto
0.29167 0.59543 lineto
0.29291 0.59596 lineto
0.29415 0.59565 lineto
0.29539 0.59445 lineto
0.29663 0.59227 lineto
0.29787 0.58909 lineto
0.29911 0.58484 lineto
0.30035 0.57951 lineto
0.30159 0.57305 lineto
0.32143 0.33462 lineto
0.33135 0.17929 lineto
0.33631 0.1151 lineto
0.33879 0.08868 lineto
0.34127 0.06659 lineto
0.34375 0.04901 lineto
0.34499 0.04193 lineto
0.34623 0.03598 lineto
0.34747 0.03114 lineto
0.34871 0.02738 lineto
0.34995 0.02466 lineto
0.35119 0.02293 lineto
0.35243 0.02213 lineto
0.35367 0.02221 lineto
0.35491 0.0231 lineto
0.35615 0.02472 lineto
0.35739 0.02699 lineto
0.35863 0.02983 lineto
0.36111 0.03691 lineto
0.37103 0.07148 lineto
0.37351 0.07875 lineto
0.37599 0.08459 lineto
0.37723 0.08688 lineto
0.37847 0.08873 lineto
0.37971 0.09013 lineto
0.38095 0.09105 lineto
0.40079 0.06168 lineto
0.40327 0.05676 lineto
Mistroke
0.40575 0.05271 lineto
0.40699 0.05108 lineto
0.40823 0.04975 lineto
0.40947 0.04872 lineto
0.41071 0.04802 lineto
0.41195 0.04764 lineto
0.41319 0.04759 lineto
0.41443 0.04786 lineto
0.41567 0.04844 lineto
0.41815 0.05047 lineto
0.41939 0.05187 lineto
0.42063 0.0535 lineto
0.4256 0.06161 lineto
0.43056 0.07052 lineto
0.43304 0.07453 lineto
0.43552 0.0779 lineto
0.43676 0.07928 lineto
0.438 0.08042 lineto
0.43924 0.08131 lineto
0.44048 0.08194 lineto
0.44172 0.08229 lineto
0.44296 0.08237 lineto
0.4442 0.08217 lineto
0.44544 0.08171 lineto
0.44792 0.08002 lineto
0.44916 0.07882 lineto
0.4504 0.07742 lineto
0.46032 0.06223 lineto
0.4628 0.05853 lineto
0.46528 0.05537 lineto
0.46652 0.05407 lineto
0.46776 0.05297 lineto
0.469 0.05211 lineto
0.47024 0.05149 lineto
0.47148 0.05112 lineto
0.47272 0.05101 lineto
0.47396 0.05117 lineto
0.4752 0.05158 lineto
0.47644 0.05225 lineto
0.47768 0.05315 lineto
0.47892 0.05429 lineto
0.48016 0.05563 lineto
0.49008 0.07064 lineto
0.49256 0.07442 lineto
0.49504 0.07768 lineto
0.49628 0.07905 lineto
0.49752 0.0802 lineto
0.49876 0.08113 lineto
0.5 0.08181 lineto
0.50124 0.08223 lineto
Mistroke
0.50248 0.08238 lineto
0.50372 0.08225 lineto
0.50496 0.08185 lineto
0.5062 0.08117 lineto
0.50744 0.08024 lineto
0.50992 0.07764 lineto
0.5124 0.0742 lineto
0.51488 0.07014 lineto
0.51984 0.06121 lineto
0.52232 0.05694 lineto
0.5248 0.0532 lineto
0.52728 0.05024 lineto
0.52852 0.04914 lineto
0.52976 0.04832 lineto
0.531 0.04779 lineto
0.53224 0.04757 lineto
0.53348 0.04768 lineto
0.53472 0.04812 lineto
0.53596 0.04888 lineto
0.5372 0.04996 lineto
0.53968 0.05303 lineto
0.54216 0.05717 lineto
0.54464 0.06214 lineto
0.5496 0.07336 lineto
0.55208 0.07887 lineto
0.55456 0.0838 lineto
0.55704 0.08777 lineto
0.55828 0.08929 lineto
0.55952 0.09045 lineto
0.56076 0.09122 lineto
0.562 0.09156 lineto
0.56324 0.09147 lineto
0.56448 0.09092 lineto
0.56572 0.08991 lineto
0.56696 0.08844 lineto
0.56944 0.08414 lineto
0.57192 0.07816 lineto
0.5744 0.07078 lineto
0.57937 0.05341 lineto
0.58433 0.03622 lineto
0.58681 0.02929 lineto
0.58805 0.02654 lineto
0.58929 0.02438 lineto
0.59053 0.02289 lineto
0.59177 0.02214 lineto
0.59301 0.02221 lineto
0.59425 0.02316 lineto
0.59549 0.02507 lineto
0.59673 0.02797 lineto
0.59921 0.03695 lineto
Mistroke
0.60045 0.0431 lineto
0.60169 0.05038 lineto
0.60417 0.06836 lineto
0.60913 0.11764 lineto
0.61409 0.18243 lineto
0.61905 0.25805 lineto
0.62897 0.41569 lineto
0.63393 0.48401 lineto
0.63641 0.513 lineto
0.63889 0.53788 lineto
0.64137 0.55835 lineto
0.64385 0.57428 lineto
0.64509 0.58053 lineto
0.64633 0.58567 lineto
0.64757 0.58973 lineto
0.64881 0.59273 lineto
0.65005 0.59473 lineto
0.65129 0.59577 lineto
0.65253 0.59593 lineto
0.65377 0.59525 lineto
0.65501 0.59383 lineto
0.65625 0.59173 lineto
0.65873 0.58583 lineto
0.66369 0.56957 lineto
0.66865 0.55178 lineto
0.67113 0.54377 lineto
0.67361 0.53698 lineto
0.67485 0.53415 lineto
0.67609 0.53174 lineto
0.67733 0.52976 lineto
0.67857 0.52824 lineto
0.67981 0.52719 lineto
0.68105 0.5266 lineto
0.68229 0.52646 lineto
0.68353 0.52676 lineto
0.68477 0.52749 lineto
0.68601 0.52861 lineto
0.68725 0.5301 lineto
0.68849 0.53191 lineto
0.69841 0.55291 lineto
0.70089 0.55822 lineto
0.70337 0.56286 lineto
0.70461 0.56483 lineto
0.70585 0.56653 lineto
0.70709 0.56795 lineto
0.70833 0.56906 lineto
0.70957 0.56986 lineto
0.71081 0.57032 lineto
0.71205 0.57046 lineto
0.71329 0.57028 lineto
Mistroke
0.71453 0.56978 lineto
0.71577 0.56899 lineto
0.71701 0.56791 lineto
0.71825 0.56657 lineto
0.72817 0.5503 lineto
0.73065 0.546 lineto
0.73313 0.54219 lineto
0.73437 0.54055 lineto
0.73562 0.53911 lineto
0.73686 0.5379 lineto
0.7381 0.53694 lineto
0.73934 0.53624 lineto
0.74058 0.53581 lineto
0.74182 0.53566 lineto
0.74306 0.53578 lineto
0.7443 0.53617 lineto
0.74554 0.53683 lineto
0.74802 0.53887 lineto
0.7505 0.54175 lineto
0.75298 0.54527 lineto
0.75794 0.55326 lineto
0.76042 0.55719 lineto
0.7629 0.56072 lineto
0.76538 0.56363 lineto
0.76662 0.56478 lineto
0.76786 0.56571 lineto
0.7691 0.5664 lineto
0.77034 0.56684 lineto
0.77158 0.56702 lineto
0.77282 0.56693 lineto
0.77406 0.56659 lineto
0.7753 0.566 lineto
0.77654 0.56515 lineto
0.77778 0.56408 lineto
0.78026 0.56132 lineto
0.78274 0.55789 lineto
0.7877 0.54995 lineto
0.79018 0.54598 lineto
0.79266 0.54236 lineto
0.79514 0.53934 lineto
0.79638 0.53813 lineto
0.79762 0.53713 lineto
0.79886 0.53638 lineto
0.8001 0.53589 lineto
0.80134 0.53567 lineto
0.80258 0.53572 lineto
0.80382 0.53605 lineto
0.80506 0.53665 lineto
0.8063 0.53751 lineto
0.80754 0.53863 lineto
Mistroke
0.81002 0.54156 lineto
0.8125 0.54525 lineto
0.81746 0.55396 lineto
0.82242 0.56253 lineto
0.8249 0.56601 lineto
0.82614 0.56744 lineto
0.82738 0.56862 lineto
0.82862 0.56952 lineto
0.82986 0.57013 lineto
0.8311 0.57043 lineto
0.83234 0.57041 lineto
0.83358 0.57007 lineto
0.83482 0.5694 lineto
0.83606 0.5684 lineto
0.8373 0.5671 lineto
0.83978 0.56362 lineto
0.84226 0.55914 lineto
0.84722 0.54831 lineto
0.85218 0.53729 lineto
0.85466 0.53266 lineto
0.8559 0.53074 lineto
0.85714 0.52913 lineto
0.85838 0.52786 lineto
0.85962 0.52699 lineto
0.86086 0.52652 lineto
0.8621 0.52649 lineto
0.86334 0.52691 lineto
0.86458 0.5278 lineto
0.86582 0.52914 lineto
0.86706 0.53095 lineto
0.86954 0.53588 lineto
0.87202 0.54241 lineto
0.87698 0.55889 lineto
0.88194 0.57666 lineto
0.88442 0.58452 lineto
0.88566 0.5879 lineto
0.8869 0.59079 lineto
0.88814 0.59312 lineto
0.88938 0.59481 lineto
0.89062 0.59577 lineto
0.89187 0.59593 lineto
0.89311 0.59522 lineto
0.89435 0.59359 lineto
0.89559 0.59096 lineto
0.89683 0.58731 lineto
0.89807 0.58257 lineto
0.89931 0.57673 lineto
0.90179 0.56166 lineto
0.90427 0.54202 lineto
0.90675 0.51794 lineto
Mistroke
0.91667 0.38489 lineto
0.92659 0.22634 lineto
0.93155 0.15443 lineto
0.93651 0.09551 lineto
0.93899 0.0722 lineto
0.94147 0.05338 lineto
0.94271 0.04567 lineto
0.94395 0.03911 lineto
0.94519 0.03366 lineto
0.94643 0.02931 lineto
0.94767 0.02602 lineto
0.94891 0.02376 lineto
0.95015 0.02246 lineto
0.95139 0.02207 lineto
0.95263 0.02252 lineto
0.95387 0.02374 lineto
0.95635 0.02821 lineto
0.95759 0.03128 lineto
0.95883 0.03481 lineto
0.96131 0.04287 lineto
0.96627 0.06072 lineto
0.97619 0.08778 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02877 0.40353 lineto
0.03373 0.48625 lineto
0.03621 0.52017 lineto
0.03869 0.54803 lineto
0.04117 0.56943 lineto
0.04241 0.57766 lineto
0.04365 0.58428 lineto
0.06349 0.54806 lineto
0.06597 0.53936 lineto
0.06721 0.53575 lineto
0.06845 0.53273 lineto
0.06969 0.53032 lineto
0.07093 0.52856 lineto
0.07217 0.52745 lineto
0.07341 0.52699 lineto
0.07465 0.52717 lineto
0.07589 0.52795 lineto
0.07713 0.52929 lineto
0.07837 0.53113 lineto
0.07961 0.53341 lineto
0.08085 0.53605 lineto
0.08333 0.54214 lineto
0.08829 0.55519 lineto
0.09077 0.56093 lineto
0.09325 0.56544 lineto
0.09449 0.56712 lineto
0.09573 0.56838 lineto
0.09697 0.5692 lineto
0.09821 0.56956 lineto
0.09945 0.56948 lineto
0.10069 0.56897 lineto
0.10193 0.56805 lineto
0.10317 0.56675 lineto
0.10813 0.55865 lineto
0.1131 0.54865 lineto
0.11558 0.54413 lineto
0.11682 0.54219 lineto
0.11806 0.54051 lineto
0.1193 0.53913 lineto
0.12054 0.53808 lineto
0.12178 0.53738 lineto
0.12302 0.53705 lineto
0.12426 0.53707 lineto
0.1255 0.53746 lineto
0.12674 0.53819 lineto
0.12798 0.53923 lineto
0.13294 0.54596 lineto
0.1379 0.55453 lineto
0.14038 0.55848 lineto
Mistroke
0.14162 0.5602 lineto
0.14286 0.56171 lineto
0.1441 0.56295 lineto
0.14534 0.56391 lineto
0.14658 0.56457 lineto
0.14782 0.5649 lineto
0.14906 0.56491 lineto
0.1503 0.5646 lineto
0.15154 0.56397 lineto
0.15278 0.56305 lineto
0.15526 0.56042 lineto
0.15774 0.55697 lineto
0.1627 0.54901 lineto
0.16518 0.54527 lineto
0.16642 0.54362 lineto
0.16766 0.54217 lineto
0.1689 0.54095 lineto
0.17014 0.54001 lineto
0.17138 0.53935 lineto
0.17262 0.53899 lineto
0.18254 0.54657 lineto
0.1875 0.5545 lineto
0.18998 0.5583 lineto
0.19246 0.56148 lineto
0.1937 0.56275 lineto
0.19494 0.56375 lineto
0.19618 0.56446 lineto
0.19742 0.56486 lineto
0.19866 0.56494 lineto
0.1999 0.56469 lineto
0.20114 0.56412 lineto
0.20238 0.56324 lineto
0.2123 0.54864 lineto
0.21478 0.54451 lineto
0.21726 0.54099 lineto
0.2185 0.53957 lineto
0.21974 0.53844 lineto
0.22098 0.53762 lineto
0.22222 0.53714 lineto
0.22346 0.53702 lineto
0.2247 0.53725 lineto
0.22594 0.53785 lineto
0.22718 0.53881 lineto
0.22842 0.5401 lineto
0.22966 0.5417 lineto
0.23214 0.54569 lineto
0.2371 0.55549 lineto
0.23958 0.56037 lineto
0.24206 0.5646 lineto
0.2433 0.56633 lineto
Mistroke
0.24454 0.56773 lineto
0.24578 0.56876 lineto
0.24702 0.56939 lineto
0.24826 0.56959 lineto
0.2495 0.56934 lineto
0.25074 0.56865 lineto
0.25198 0.56751 lineto
0.2619 0.54632 lineto
0.26438 0.53984 lineto
0.26687 0.5341 lineto
0.26811 0.53171 lineto
0.26935 0.52975 lineto
0.27059 0.52826 lineto
0.27183 0.52733 lineto
0.27307 0.52698 lineto
0.27431 0.52726 lineto
0.27555 0.52819 lineto
0.27679 0.52977 lineto
0.27803 0.532 lineto
0.27927 0.53486 lineto
0.28175 0.54231 lineto
0.28671 0.56204 lineto
0.29167 0.5825 lineto
0.29291 0.58672 lineto
0.29415 0.59029 lineto
0.29539 0.59308 lineto
0.29663 0.59492 lineto
0.29787 0.5957 lineto
0.29911 0.59529 lineto
0.30035 0.59357 lineto
0.30159 0.59044 lineto
0.32143 0.33971 lineto
0.32639 0.24387 lineto
0.33135 0.15622 lineto
0.33631 0.08703 lineto
0.33879 0.06148 lineto
0.34003 0.05115 lineto
0.34127 0.04247 lineto
0.34251 0.03541 lineto
0.34375 0.02994 lineto
0.34499 0.026 lineto
0.34623 0.02352 lineto
0.34747 0.0224 lineto
0.34871 0.02254 lineto
0.34995 0.02382 lineto
0.35119 0.02611 lineto
0.36111 0.06365 lineto
0.36359 0.07334 lineto
0.36607 0.08135 lineto
0.36731 0.08454 lineto
Mistroke
0.36855 0.08712 lineto
0.36979 0.08906 lineto
0.37103 0.09035 lineto
0.37227 0.09098 lineto
0.37351 0.09097 lineto
0.37475 0.09035 lineto
0.37599 0.08917 lineto
0.37847 0.08529 lineto
0.38095 0.07987 lineto
0.38591 0.06691 lineto
0.38839 0.06065 lineto
0.39087 0.05531 lineto
0.39211 0.05313 lineto
0.39335 0.05133 lineto
0.39459 0.04996 lineto
0.39583 0.04902 lineto
0.39707 0.04853 lineto
0.39831 0.04848 lineto
0.39955 0.04888 lineto
0.40079 0.04969 lineto
0.40203 0.0509 lineto
0.40327 0.05245 lineto
0.40575 0.05642 lineto
0.41071 0.06623 lineto
0.41319 0.0711 lineto
0.41567 0.07534 lineto
0.41815 0.07856 lineto
0.41939 0.0797 lineto
0.42063 0.0805 lineto
0.42188 0.08093 lineto
0.42312 0.08101 lineto
0.42436 0.08072 lineto
0.4256 0.08008 lineto
0.42684 0.07912 lineto
0.42808 0.07785 lineto
0.43056 0.07457 lineto
0.43552 0.06624 lineto
0.44048 0.05828 lineto
0.44172 0.05672 lineto
0.44296 0.0554 lineto
0.4442 0.05436 lineto
0.44544 0.05362 lineto
0.44668 0.05319 lineto
0.44792 0.05309 lineto
0.44916 0.05332 lineto
0.4504 0.05386 lineto
0.46032 0.06647 lineto
0.4628 0.07044 lineto
0.46528 0.07398 lineto
0.46652 0.07549 lineto
Mistroke
0.46776 0.07677 lineto
0.469 0.07779 lineto
0.47024 0.07853 lineto
0.47148 0.07897 lineto
0.47272 0.0791 lineto
0.47396 0.07892 lineto
0.4752 0.07843 lineto
0.47644 0.07763 lineto
0.47768 0.07656 lineto
0.47892 0.07524 lineto
0.48016 0.0737 lineto
0.48512 0.06611 lineto
0.4876 0.06211 lineto
0.49008 0.05849 lineto
0.49256 0.05561 lineto
0.4938 0.05453 lineto
0.49504 0.05374 lineto
0.49628 0.05326 lineto
0.49752 0.05309 lineto
0.49876 0.05324 lineto
0.5 0.05372 lineto
0.50124 0.05452 lineto
0.50248 0.05561 lineto
0.50496 0.05858 lineto
0.50992 0.06662 lineto
0.5124 0.07094 lineto
0.51488 0.07489 lineto
0.51612 0.07661 lineto
0.51736 0.0781 lineto
0.5186 0.07931 lineto
0.51984 0.08022 lineto
0.52108 0.08079 lineto
0.52232 0.08102 lineto
0.52356 0.08088 lineto
0.5248 0.08038 lineto
0.52604 0.07952 lineto
0.52728 0.07832 lineto
0.52852 0.0768 lineto
0.52976 0.075 lineto
0.53472 0.06578 lineto
0.5372 0.06073 lineto
0.53968 0.05603 lineto
0.54216 0.05215 lineto
0.5434 0.05066 lineto
0.54464 0.04952 lineto
0.54588 0.04878 lineto
0.54712 0.04846 lineto
0.54836 0.04858 lineto
0.5496 0.04915 lineto
0.55084 0.05017 lineto
Mistroke
0.55208 0.05162 lineto
0.55456 0.05573 lineto
0.55704 0.06117 lineto
0.55952 0.06749 lineto
0.56448 0.0804 lineto
0.56572 0.08322 lineto
0.56696 0.08571 lineto
0.5682 0.0878 lineto
0.56944 0.08942 lineto
0.57068 0.09051 lineto
0.57192 0.09102 lineto
0.57316 0.09092 lineto
0.5744 0.09017 lineto
0.57564 0.08876 lineto
0.57688 0.08671 lineto
0.57937 0.08072 lineto
0.58185 0.07254 lineto
0.58433 0.06273 lineto
0.58929 0.04163 lineto
0.59177 0.03241 lineto
0.59301 0.02865 lineto
0.59425 0.02563 lineto
0.59549 0.02352 lineto
0.59673 0.02243 lineto
0.59797 0.02251 lineto
0.59921 0.02386 lineto
0.60045 0.02659 lineto
0.60169 0.0308 lineto
0.60293 0.03654 lineto
0.60417 0.04389 lineto
0.60665 0.06348 lineto
0.60913 0.08959 lineto
0.61409 0.15977 lineto
0.61905 0.24802 lineto
0.62897 0.43547 lineto
0.63145 0.47598 lineto
0.63393 0.51144 lineto
0.63641 0.54102 lineto
0.63889 0.56421 lineto
0.64013 0.57335 lineto
0.64137 0.58085 lineto
0.64261 0.58675 lineto
0.64385 0.5911 lineto
0.64509 0.59397 lineto
0.64633 0.59545 lineto
0.64757 0.59565 lineto
0.64881 0.59467 lineto
0.65005 0.59265 lineto
0.65129 0.58972 lineto
0.65253 0.58601 lineto
Mistroke
0.65377 0.58169 lineto
0.65873 0.56109 lineto
0.66369 0.54156 lineto
0.66493 0.53766 lineto
0.66617 0.53431 lineto
0.66741 0.53156 lineto
0.66865 0.52944 lineto
0.66989 0.52797 lineto
0.67113 0.52716 lineto
0.67237 0.527 lineto
0.67361 0.52745 lineto
0.67857 0.53456 lineto
0.68353 0.54691 lineto
0.68601 0.55347 lineto
0.68849 0.55946 lineto
0.68973 0.56207 lineto
0.69097 0.56434 lineto
0.69221 0.56625 lineto
0.69345 0.56774 lineto
0.69469 0.5688 lineto
0.69593 0.56942 lineto
0.69717 0.56958 lineto
0.69841 0.56931 lineto
0.69965 0.5686 lineto
0.70089 0.5675 lineto
0.70213 0.56604 lineto
0.70337 0.56427 lineto
0.70833 0.55504 lineto
0.71081 0.54999 lineto
0.71329 0.5453 lineto
0.71577 0.54139 lineto
0.71701 0.53984 lineto
0.71825 0.53861 lineto
0.71949 0.53772 lineto
0.72073 0.53718 lineto
0.72197 0.53701 lineto
0.72321 0.5372 lineto
0.72445 0.53774 lineto
0.72569 0.53862 lineto
0.72817 0.54127 lineto
0.73065 0.54486 lineto
0.73313 0.54902 lineto
0.7381 0.55745 lineto
0.74058 0.56091 lineto
0.74182 0.5623 lineto
0.74306 0.56342 lineto
0.7443 0.56425 lineto
0.74554 0.56476 lineto
0.74678 0.56495 lineto
0.74802 0.56481 lineto
Mistroke
0.74926 0.56435 lineto
0.7505 0.56359 lineto
0.75174 0.56254 lineto
0.75298 0.56124 lineto
0.75794 0.55414 lineto
0.7629 0.54624 lineto
0.76538 0.54293 lineto
0.76662 0.54159 lineto
0.76786 0.54049 lineto
0.7691 0.53967 lineto
0.77034 0.53915 lineto
0.77158 0.53893 lineto
0.77282 0.53903 lineto
0.77406 0.53944 lineto
0.7753 0.54015 lineto
0.77778 0.54241 lineto
0.7877 0.5573 lineto
0.79018 0.56069 lineto
0.79142 0.56209 lineto
0.79266 0.56323 lineto
0.7939 0.56411 lineto
0.79514 0.56468 lineto
0.79638 0.56493 lineto
0.79762 0.56486 lineto
0.80754 0.55415 lineto
0.8125 0.5456 lineto
0.81498 0.54187 lineto
0.81622 0.54032 lineto
0.81746 0.53903 lineto
0.8187 0.53803 lineto
0.81994 0.53736 lineto
0.82118 0.53704 lineto
0.82242 0.53708 lineto
0.82366 0.53748 lineto
0.8249 0.53824 lineto
0.82614 0.53935 lineto
0.82738 0.54078 lineto
0.83234 0.54908 lineto
0.8373 0.55908 lineto
0.83978 0.56353 lineto
0.84102 0.56542 lineto
0.84226 0.567 lineto
0.8435 0.56824 lineto
0.84474 0.56909 lineto
0.84598 0.56953 lineto
0.84722 0.56953 lineto
0.84846 0.56909 lineto
0.8497 0.56819 lineto
0.85094 0.56685 lineto
0.85218 0.5651 lineto
Mistroke
0.85466 0.56046 lineto
0.85714 0.55464 lineto
0.8621 0.54157 lineto
0.86458 0.53556 lineto
0.86582 0.53297 lineto
0.86706 0.53077 lineto
0.8683 0.52901 lineto
0.86954 0.52777 lineto
0.87078 0.52709 lineto
0.87202 0.52703 lineto
0.87326 0.5276 lineto
0.8745 0.52882 lineto
0.87574 0.5307 lineto
0.87698 0.53322 lineto
0.87822 0.53635 lineto
0.87946 0.54005 lineto
0.88194 0.54891 lineto
0.8869 0.56981 lineto
0.88938 0.57996 lineto
0.89187 0.58842 lineto
0.89311 0.59166 lineto
0.89435 0.59403 lineto
0.89559 0.59542 lineto
0.89683 0.59567 lineto
0.89807 0.59468 lineto
0.89931 0.59234 lineto
0.90055 0.58854 lineto
0.90179 0.58322 lineto
0.90427 0.5678 lineto
0.90551 0.55763 lineto
0.90675 0.54582 lineto
0.91667 0.39951 lineto
0.92659 0.21052 lineto
0.93155 0.12855 lineto
0.93403 0.09514 lineto
0.93651 0.06784 lineto
0.93775 0.05661 lineto
0.93899 0.04703 lineto
0.94023 0.03908 lineto
0.94147 0.03275 lineto
0.94271 0.02798 lineto
0.94395 0.02471 lineto
0.94519 0.02285 lineto
0.94643 0.02232 lineto
0.94767 0.02299 lineto
0.94891 0.02473 lineto
0.95015 0.02743 lineto
0.95139 0.03094 lineto
0.95635 0.05011 lineto
0.96131 0.07082 lineto
Mistroke
0.96379 0.07935 lineto
0.96503 0.08286 lineto
0.96627 0.08578 lineto
0.96751 0.08808 lineto
0.96875 0.08972 lineto
0.96999 0.09071 lineto
0.97123 0.09105 lineto
0.97247 0.09077 lineto
0.97371 0.08989 lineto
0.97495 0.08846 lineto
0.97619 0.08653 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02877 0.41842 lineto
0.03373 0.50947 lineto
0.03621 0.54376 lineto
0.03745 0.55766 lineto
0.03869 0.56933 lineto
0.03993 0.57876 lineto
0.04117 0.58601 lineto
0.04241 0.59113 lineto
0.04365 0.59426 lineto
0.04489 0.59553 lineto
0.04613 0.5951 lineto
0.04737 0.59318 lineto
0.04861 0.58998 lineto
0.05109 0.58061 lineto
0.05357 0.56885 lineto
0.05853 0.54511 lineto
0.05977 0.5402 lineto
0.06101 0.53598 lineto
0.06225 0.53254 lineto
0.06349 0.52994 lineto
0.06473 0.52822 lineto
0.06597 0.52738 lineto
0.06721 0.52741 lineto
0.06845 0.52825 lineto
0.07341 0.53813 lineto
0.07837 0.55297 lineto
0.08085 0.55977 lineto
0.08209 0.56264 lineto
0.08333 0.56504 lineto
0.08457 0.56692 lineto
0.08581 0.56822 lineto
0.08705 0.56894 lineto
0.08829 0.56906 lineto
0.08953 0.5686 lineto
0.09077 0.56759 lineto
0.09325 0.56415 lineto
0.09573 0.55928 lineto
0.09821 0.55369 lineto
0.10069 0.54812 lineto
0.10317 0.54329 lineto
0.10441 0.54133 lineto
0.10565 0.53977 lineto
0.10689 0.53864 lineto
0.10813 0.53796 lineto
0.10938 0.53776 lineto
0.11062 0.53802 lineto
0.11186 0.53873 lineto
0.1131 0.53986 lineto
0.11558 0.54318 lineto
Mistroke
0.11806 0.54749 lineto
0.12302 0.55672 lineto
0.1255 0.56045 lineto
0.12674 0.56186 lineto
0.12798 0.56293 lineto
0.12922 0.5636 lineto
0.13046 0.56387 lineto
0.1317 0.56374 lineto
0.13294 0.56321 lineto
0.13418 0.5623 lineto
0.13542 0.56106 lineto
0.1379 0.55773 lineto
0.14286 0.54944 lineto
0.14534 0.54558 lineto
0.14658 0.54395 lineto
0.14782 0.54258 lineto
0.14906 0.54153 lineto
0.1503 0.54083 lineto
0.15154 0.54049 lineto
0.15278 0.54053 lineto
0.15402 0.54093 lineto
0.15526 0.5417 lineto
0.1565 0.54279 lineto
0.15774 0.54418 lineto
0.1627 0.55159 lineto
0.16518 0.55555 lineto
0.16766 0.55898 lineto
0.1689 0.56036 lineto
0.17014 0.56145 lineto
0.17138 0.56221 lineto
0.17262 0.56263 lineto
0.17386 0.56268 lineto
0.1751 0.56236 lineto
0.17634 0.56169 lineto
0.17758 0.56069 lineto
0.17882 0.55939 lineto
0.18006 0.55783 lineto
0.18254 0.55415 lineto
0.18502 0.55012 lineto
0.1875 0.54629 lineto
0.18874 0.5446 lineto
0.18998 0.54314 lineto
0.19122 0.54197 lineto
0.19246 0.54111 lineto
0.1937 0.5406 lineto
0.19494 0.54046 lineto
0.19618 0.5407 lineto
0.19742 0.54131 lineto
0.1999 0.54355 lineto
0.20114 0.54511 lineto
Mistroke
0.20238 0.54691 lineto
0.20734 0.5552 lineto
0.20982 0.55904 lineto
0.21106 0.56066 lineto
0.2123 0.56199 lineto
0.21354 0.563 lineto
0.21478 0.56363 lineto
0.21602 0.56388 lineto
0.21726 0.56372 lineto
0.22222 0.55922 lineto
0.22718 0.55049 lineto
0.22966 0.54585 lineto
0.23214 0.54183 lineto
0.23338 0.54023 lineto
0.23462 0.539 lineto
0.23586 0.53817 lineto
0.2371 0.53778 lineto
0.23834 0.53786 lineto
0.23958 0.53841 lineto
0.24082 0.53942 lineto
0.24206 0.54086 lineto
0.2433 0.54272 lineto
0.24454 0.54491 lineto
0.24702 0.55009 lineto
0.2495 0.55575 lineto
0.25198 0.56117 lineto
0.25322 0.56355 lineto
0.25446 0.56559 lineto
0.2557 0.56722 lineto
0.25694 0.56837 lineto
0.25818 0.56899 lineto
0.25942 0.56903 lineto
0.26066 0.56848 lineto
0.2619 0.56733 lineto
0.26314 0.56561 lineto
0.26438 0.56335 lineto
0.26687 0.55744 lineto
0.27183 0.5427 lineto
0.27431 0.53574 lineto
0.27555 0.5328 lineto
0.27679 0.53039 lineto
0.27803 0.52862 lineto
0.27927 0.52756 lineto
0.28051 0.52731 lineto
0.28175 0.5279 lineto
0.28299 0.52938 lineto
0.28423 0.53174 lineto
0.28547 0.53495 lineto
0.28671 0.53897 lineto
0.29167 0.56093 lineto
Mistroke
0.29415 0.57327 lineto
0.29663 0.58438 lineto
0.29787 0.5889 lineto
0.29911 0.59242 lineto
0.30035 0.59471 lineto
0.30159 0.59557 lineto
0.30283 0.59479 lineto
0.30407 0.59219 lineto
0.30531 0.58762 lineto
0.30655 0.58096 lineto
0.30779 0.57214 lineto
0.30903 0.56109 lineto
0.31151 0.5323 lineto
0.31399 0.495 lineto
0.31647 0.45019 lineto
0.32143 0.3448 lineto
0.32639 0.23329 lineto
0.33135 0.13464 lineto
0.33383 0.09515 lineto
0.33631 0.06396 lineto
0.33755 0.05168 lineto
0.33879 0.04164 lineto
0.34003 0.0338 lineto
0.34127 0.0281 lineto
0.34251 0.02444 lineto
0.34375 0.02268 lineto
0.34499 0.02266 lineto
0.34623 0.02419 lineto
0.34747 0.02706 lineto
0.34871 0.03106 lineto
0.34995 0.03596 lineto
0.35119 0.04151 lineto
0.35615 0.06587 lineto
0.35863 0.07655 lineto
0.35987 0.08097 lineto
0.36111 0.08463 lineto
0.36235 0.08747 lineto
0.36359 0.08943 lineto
0.36483 0.09051 lineto
0.36607 0.09071 lineto
0.36731 0.09009 lineto
0.36855 0.0887 lineto
0.37103 0.08396 lineto
0.37351 0.07735 lineto
0.37599 0.06984 lineto
0.37847 0.06247 lineto
0.38095 0.05614 lineto
0.38219 0.0536 lineto
0.38343 0.05158 lineto
0.38467 0.05011 lineto
Mistroke
0.38591 0.04923 lineto
0.38715 0.04895 lineto
0.38839 0.04925 lineto
0.38963 0.05012 lineto
0.39087 0.05149 lineto
0.39335 0.05552 lineto
0.39583 0.06074 lineto
0.40079 0.07179 lineto
0.40203 0.07415 lineto
0.40327 0.0762 lineto
0.40451 0.07788 lineto
0.40575 0.07913 lineto
0.40699 0.07993 lineto
0.40823 0.08027 lineto
0.40947 0.08013 lineto
0.41071 0.07954 lineto
0.41195 0.07852 lineto
0.41319 0.07712 lineto
0.41567 0.07338 lineto
0.42063 0.06413 lineto
0.42312 0.05984 lineto
0.42436 0.05803 lineto
0.4256 0.05652 lineto
0.42684 0.05536 lineto
0.42808 0.05458 lineto
0.42932 0.05419 lineto
0.43056 0.05422 lineto
0.4318 0.05464 lineto
0.43304 0.05545 lineto
0.43428 0.0566 lineto
0.43552 0.05807 lineto
0.44048 0.0659 lineto
0.44296 0.07006 lineto
0.44544 0.07366 lineto
0.44668 0.0751 lineto
0.44792 0.07624 lineto
0.44916 0.07705 lineto
0.4504 0.07749 lineto
0.45164 0.07755 lineto
0.45288 0.07725 lineto
0.45412 0.07658 lineto
0.45536 0.07557 lineto
0.4566 0.07426 lineto
0.45784 0.0727 lineto
0.46032 0.069 lineto
0.4628 0.06498 lineto
0.46528 0.06115 lineto
0.46652 0.05947 lineto
0.46776 0.05802 lineto
0.469 0.05685 lineto
Mistroke
0.47024 0.056 lineto
0.47148 0.05549 lineto
0.47272 0.05534 lineto
0.47396 0.05555 lineto
0.4752 0.05612 lineto
0.47768 0.05826 lineto
0.47892 0.05976 lineto
0.48016 0.06147 lineto
0.48512 0.06935 lineto
0.4876 0.07299 lineto
0.48884 0.07452 lineto
0.49008 0.07577 lineto
0.49132 0.07672 lineto
0.49256 0.07733 lineto
0.4938 0.07757 lineto
0.49504 0.07744 lineto
0.5 0.07338 lineto
0.50496 0.06552 lineto
0.50744 0.06137 lineto
0.50868 0.05948 lineto
0.50992 0.05779 lineto
0.51116 0.05638 lineto
0.5124 0.05528 lineto
0.51364 0.05454 lineto
0.51488 0.05418 lineto
0.51612 0.05423 lineto
0.51736 0.05469 lineto
0.5186 0.05554 lineto
0.51984 0.05677 lineto
0.52108 0.05833 lineto
0.52232 0.06019 lineto
0.5248 0.06454 lineto
0.52728 0.06926 lineto
0.52976 0.07375 lineto
0.531 0.07571 lineto
0.53224 0.0774 lineto
0.53348 0.07873 lineto
0.53472 0.07968 lineto
0.53596 0.08019 lineto
0.5372 0.08024 lineto
0.53844 0.07983 lineto
0.53968 0.07894 lineto
0.54216 0.07586 lineto
0.5434 0.07375 lineto
0.54464 0.07134 lineto
0.5496 0.06025 lineto
0.55208 0.05511 lineto
0.55332 0.05296 lineto
0.55456 0.05121 lineto
0.5558 0.04992 lineto
Mistroke
0.55704 0.04916 lineto
0.55828 0.04896 lineto
0.55952 0.04934 lineto
0.56944 0.07052 lineto
0.57192 0.07798 lineto
0.57316 0.08141 lineto
0.5744 0.08447 lineto
0.57564 0.08704 lineto
0.57688 0.089 lineto
0.57813 0.09026 lineto
0.57937 0.09074 lineto
0.58061 0.09038 lineto
0.58185 0.08915 lineto
0.58309 0.08703 lineto
0.58433 0.08405 lineto
0.58557 0.08024 lineto
0.58681 0.0757 lineto
0.58929 0.06483 lineto
0.59177 0.05259 lineto
0.59425 0.04049 lineto
0.59549 0.03504 lineto
0.59673 0.03028 lineto
0.59797 0.02647 lineto
0.59921 0.02381 lineto
0.60045 0.02254 lineto
0.60169 0.02286 lineto
0.60293 0.02495 lineto
0.60417 0.02896 lineto
0.60541 0.03503 lineto
0.60665 0.04326 lineto
0.60789 0.05369 lineto
0.60913 0.06637 lineto
0.61905 0.23808 lineto
0.62897 0.45442 lineto
0.63145 0.49862 lineto
0.63393 0.5352 lineto
0.63641 0.56321 lineto
0.63765 0.57386 lineto
0.63889 0.5823 lineto
0.64013 0.58858 lineto
0.64137 0.59278 lineto
0.64261 0.59505 lineto
0.64385 0.59553 lineto
0.64509 0.59441 lineto
0.64633 0.59188 lineto
0.64881 0.58349 lineto
0.65377 0.55984 lineto
0.65625 0.54805 lineto
0.65873 0.5382 lineto
0.65997 0.53432 lineto
Mistroke
0.66121 0.53126 lineto
0.66245 0.52905 lineto
0.66369 0.52773 lineto
0.66493 0.52729 lineto
0.66617 0.52769 lineto
0.66741 0.52888 lineto
0.66865 0.53078 lineto
0.67113 0.53631 lineto
0.67361 0.54336 lineto
0.67857 0.55802 lineto
0.67981 0.56112 lineto
0.68105 0.56378 lineto
0.68229 0.56595 lineto
0.68353 0.56758 lineto
0.68477 0.56862 lineto
0.68601 0.56907 lineto
0.68725 0.56892 lineto
0.68849 0.56821 lineto
0.68973 0.56697 lineto
0.69097 0.56526 lineto
0.69345 0.56072 lineto
0.69593 0.55525 lineto
0.69841 0.5496 lineto
0.70089 0.5445 lineto
0.70213 0.54236 lineto
0.70337 0.54058 lineto
0.70461 0.5392 lineto
0.70585 0.53827 lineto
0.70709 0.53781 lineto
0.70833 0.53782 lineto
0.70957 0.53829 lineto
0.71081 0.53919 lineto
0.71329 0.54214 lineto
0.71577 0.54624 lineto
0.71825 0.55091 lineto
0.72073 0.55554 lineto
0.72321 0.55953 lineto
0.72445 0.56113 lineto
0.72569 0.56239 lineto
0.72693 0.56328 lineto
0.72817 0.56377 lineto
0.72941 0.56386 lineto
0.73065 0.56355 lineto
0.73189 0.56284 lineto
0.73313 0.56178 lineto
0.7381 0.55483 lineto
0.74306 0.54657 lineto
0.7443 0.54481 lineto
0.74554 0.5433 lineto
0.74678 0.54207 lineto
Mistroke
0.74802 0.54117 lineto
0.74926 0.54063 lineto
0.7505 0.54046 lineto
0.75174 0.54067 lineto
0.75298 0.54124 lineto
0.75794 0.54661 lineto
0.7629 0.55449 lineto
0.76538 0.55812 lineto
0.76662 0.55964 lineto
0.76786 0.56089 lineto
0.7691 0.56184 lineto
0.77034 0.56244 lineto
0.77158 0.56269 lineto
0.77282 0.56258 lineto
0.77406 0.5621 lineto
0.7753 0.56128 lineto
0.77778 0.55871 lineto
0.78274 0.55123 lineto
0.78522 0.54729 lineto
0.7877 0.54391 lineto
0.78894 0.54258 lineto
0.79018 0.54154 lineto
0.79142 0.54084 lineto
0.79266 0.54049 lineto
0.7939 0.54052 lineto
0.79514 0.54093 lineto
0.79638 0.5417 lineto
0.79762 0.5428 lineto
0.80258 0.54981 lineto
0.80506 0.55405 lineto
0.80754 0.55806 lineto
0.81002 0.5613 lineto
0.81126 0.56249 lineto
0.8125 0.56333 lineto
0.81374 0.56379 lineto
0.81498 0.56386 lineto
0.81622 0.56351 lineto
0.81746 0.56277 lineto
0.8187 0.56164 lineto
0.81994 0.56016 lineto
0.82242 0.55635 lineto
0.82738 0.54708 lineto
0.82986 0.54283 lineto
0.8311 0.54107 lineto
0.83234 0.53963 lineto
0.83358 0.53857 lineto
0.83482 0.53794 lineto
0.83606 0.53776 lineto
0.8373 0.53805 lineto
0.83854 0.53881 lineto
Mistroke
0.83978 0.54002 lineto
0.84102 0.54165 lineto
0.84226 0.54367 lineto
0.84722 0.55419 lineto
0.8497 0.55975 lineto
0.85094 0.56228 lineto
0.85218 0.56452 lineto
0.85342 0.56638 lineto
0.85466 0.56781 lineto
0.8559 0.56872 lineto
0.85714 0.56908 lineto
0.85838 0.56886 lineto
0.85962 0.56803 lineto
0.86086 0.56662 lineto
0.8621 0.56465 lineto
0.86334 0.56216 lineto
0.86458 0.55922 lineto
0.86706 0.55231 lineto
0.86954 0.54476 lineto
0.87202 0.53753 lineto
0.87326 0.53436 lineto
0.8745 0.53164 lineto
0.87574 0.52951 lineto
0.87698 0.52805 lineto
0.87822 0.52734 lineto
0.87946 0.52747 lineto
0.8807 0.52846 lineto
0.88194 0.53034 lineto
0.88442 0.53667 lineto
0.88566 0.54102 lineto
0.8869 0.54604 lineto
0.89187 0.56994 lineto
0.89435 0.58156 lineto
0.89559 0.58653 lineto
0.89683 0.59063 lineto
0.89807 0.59362 lineto
0.89931 0.59529 lineto
0.90055 0.59543 lineto
0.90179 0.59385 lineto
0.90303 0.59038 lineto
0.90427 0.58488 lineto
0.90551 0.57725 lineto
0.90675 0.56743 lineto
0.91667 0.41384 lineto
0.92659 0.19507 lineto
0.92907 0.14678 lineto
0.93155 0.10519 lineto
0.93403 0.07165 lineto
0.93527 0.05814 lineto
0.93651 0.04687 lineto
Mistroke
0.93775 0.03783 lineto
0.93899 0.03097 lineto
0.94023 0.0262 lineto
0.94147 0.02342 lineto
0.94271 0.02247 lineto
0.94395 0.02317 lineto
0.94519 0.02533 lineto
0.94643 0.02874 lineto
0.94891 0.0384 lineto
0.95139 0.05028 lineto
0.95635 0.07384 lineto
0.95759 0.07864 lineto
0.95883 0.08272 lineto
0.96007 0.08602 lineto
0.96131 0.08846 lineto
0.96255 0.09003 lineto
0.96379 0.09071 lineto
0.96503 0.09053 lineto
0.96627 0.08955 lineto
0.96751 0.08784 lineto
0.96875 0.08549 lineto
0.97123 0.07929 lineto
0.97371 0.07193 lineto
0.97619 0.06442 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02877 0.43293 lineto
0.03125 0.48621 lineto
0.03373 0.53007 lineto
0.03621 0.56288 lineto
0.03745 0.57492 lineto
0.03869 0.58408 lineto
0.03993 0.59044 lineto
0.04117 0.59416 lineto
0.04241 0.59547 lineto
0.04365 0.5946 lineto
0.04489 0.59186 lineto
0.04613 0.58757 lineto
0.04861 0.57571 lineto
0.05109 0.56176 lineto
0.05357 0.54825 lineto
0.05481 0.54233 lineto
0.05605 0.53724 lineto
0.05729 0.53314 lineto
0.05853 0.53012 lineto
0.05977 0.52824 lineto
0.06101 0.52751 lineto
0.06225 0.52787 lineto
0.06349 0.52926 lineto
0.06597 0.53459 lineto
0.06721 0.53823 lineto
0.06845 0.54226 lineto
0.07093 0.55079 lineto
0.07341 0.55871 lineto
0.07465 0.56205 lineto
0.07589 0.56479 lineto
0.07713 0.56685 lineto
0.07837 0.56818 lineto
0.07961 0.56875 lineto
0.08085 0.56855 lineto
0.08333 0.56606 lineto
0.08829 0.5553 lineto
0.09077 0.54903 lineto
0.09325 0.54358 lineto
0.09449 0.54144 lineto
0.09573 0.53981 lineto
0.09697 0.53873 lineto
0.09821 0.53824 lineto
0.09945 0.53835 lineto
0.10069 0.53903 lineto
0.10193 0.54024 lineto
0.10317 0.54192 lineto
0.10813 0.55147 lineto
0.11062 0.55643 lineto
0.11186 0.55858 lineto
Mistroke
0.1131 0.5604 lineto
0.11434 0.56181 lineto
0.11558 0.56276 lineto
0.11682 0.56321 lineto
0.11806 0.56316 lineto
0.1193 0.56262 lineto
0.12054 0.56161 lineto
0.12302 0.55843 lineto
0.1255 0.55421 lineto
0.12798 0.54968 lineto
0.13046 0.54562 lineto
0.1317 0.54398 lineto
0.13294 0.54269 lineto
0.13418 0.54181 lineto
0.13542 0.54137 lineto
0.13666 0.54138 lineto
0.1379 0.54184 lineto
0.13914 0.54272 lineto
0.14038 0.54398 lineto
0.14162 0.54556 lineto
0.14286 0.5474 lineto
0.18254 0.55142 lineto
0.18502 0.55538 lineto
0.18626 0.55717 lineto
0.1875 0.55873 lineto
0.18874 0.55999 lineto
0.18998 0.5609 lineto
0.19122 0.56141 lineto
0.19246 0.56151 lineto
0.1937 0.56117 lineto
0.19494 0.56043 lineto
0.19742 0.55783 lineto
0.1999 0.55414 lineto
0.20238 0.54997 lineto
0.20486 0.54604 lineto
0.2061 0.54438 lineto
0.20734 0.54303 lineto
0.20858 0.54204 lineto
0.20982 0.54146 lineto
0.21106 0.54133 lineto
0.2123 0.54165 lineto
0.21354 0.54241 lineto
0.21478 0.54359 lineto
0.21602 0.54514 lineto
0.21726 0.54699 lineto
0.22222 0.55582 lineto
0.22346 0.5579 lineto
0.2247 0.55974 lineto
0.22594 0.56126 lineto
0.22718 0.56238 lineto
Mistroke
0.22842 0.56306 lineto
0.22966 0.56325 lineto
0.2309 0.56293 lineto
0.23214 0.56212 lineto
0.23462 0.55912 lineto
0.23586 0.55705 lineto
0.2371 0.5547 lineto
0.24206 0.5446 lineto
0.2433 0.54245 lineto
0.24454 0.54066 lineto
0.24578 0.53931 lineto
0.24702 0.53848 lineto
0.24826 0.53821 lineto
0.2495 0.53854 lineto
0.25074 0.53945 lineto
0.25198 0.54094 lineto
0.25694 0.55126 lineto
0.25942 0.55757 lineto
0.2619 0.56326 lineto
0.26314 0.56553 lineto
0.26438 0.56727 lineto
0.26563 0.56837 lineto
0.26687 0.56877 lineto
0.26811 0.56841 lineto
0.26935 0.56729 lineto
0.27059 0.56543 lineto
0.27183 0.56286 lineto
0.27679 0.5477 lineto
0.27927 0.5393 lineto
0.28051 0.53554 lineto
0.28175 0.53231 lineto
0.28299 0.5298 lineto
0.28423 0.52815 lineto
0.28547 0.5275 lineto
0.28671 0.52793 lineto
0.28795 0.52949 lineto
0.28919 0.5322 lineto
0.29167 0.54084 lineto
0.29415 0.55296 lineto
0.29663 0.5669 lineto
0.29911 0.5804 lineto
0.30035 0.58617 lineto
0.30159 0.59083 lineto
0.30283 0.59402 lineto
0.30407 0.59543 lineto
0.30531 0.59475 lineto
0.30655 0.59171 lineto
0.30779 0.58609 lineto
0.30903 0.57772 lineto
0.31027 0.56647 lineto
Mistroke
0.31151 0.55231 lineto
0.31399 0.51537 lineto
0.31647 0.46785 lineto
0.32143 0.34988 lineto
0.32639 0.22283 lineto
0.32887 0.16483 lineto
0.33135 0.11472 lineto
0.33383 0.07473 lineto
0.33507 0.05897 lineto
0.33631 0.04613 lineto
0.33755 0.03619 lineto
0.33879 0.02907 lineto
0.34003 0.02464 lineto
0.34127 0.0227 lineto
0.34251 0.023 lineto
0.34375 0.02525 lineto
0.34499 0.02915 lineto
0.34623 0.03435 lineto
0.34871 0.04728 lineto
0.35119 0.06135 lineto
0.35367 0.07415 lineto
0.35491 0.07949 lineto
0.35615 0.08387 lineto
0.35739 0.0872 lineto
0.35863 0.08939 lineto
0.35987 0.09044 lineto
0.36111 0.09037 lineto
0.36235 0.08925 lineto
0.36359 0.0872 lineto
0.36483 0.08434 lineto
0.36607 0.08085 lineto
0.37103 0.06422 lineto
0.37227 0.06032 lineto
0.37351 0.05685 lineto
0.37475 0.05393 lineto
0.37599 0.05167 lineto
0.37723 0.05014 lineto
0.37847 0.04937 lineto
0.37971 0.04936 lineto
0.38095 0.05008 lineto
0.38591 0.05879 lineto
0.38839 0.06504 lineto
0.39087 0.07113 lineto
0.39335 0.07605 lineto
0.39459 0.07783 lineto
0.39583 0.07907 lineto
0.39707 0.07972 lineto
0.39831 0.07977 lineto
0.39955 0.07925 lineto
0.40079 0.07817 lineto
Mistroke
0.40203 0.07662 lineto
0.40327 0.07465 lineto
0.40575 0.06987 lineto
0.40823 0.0647 lineto
0.41071 0.06001 lineto
0.41195 0.05809 lineto
0.41319 0.05657 lineto
0.41443 0.05549 lineto
0.41567 0.0549 lineto
0.41691 0.05481 lineto
0.41815 0.05522 lineto
0.41939 0.05611 lineto
0.42063 0.05742 lineto
0.46032 0.06165 lineto
0.5 0.06539 lineto
0.50248 0.06955 lineto
0.50496 0.07322 lineto
0.5062 0.07467 lineto
0.50744 0.07576 lineto
0.50868 0.07646 lineto
0.50992 0.07671 lineto
0.51116 0.07652 lineto
0.5124 0.07588 lineto
0.51364 0.07481 lineto
0.51488 0.07335 lineto
0.51984 0.06507 lineto
0.52232 0.06069 lineto
0.52356 0.05877 lineto
0.5248 0.05715 lineto
0.52604 0.05592 lineto
0.52728 0.05511 lineto
0.52852 0.05479 lineto
0.52976 0.05497 lineto
0.531 0.05564 lineto
0.53224 0.05681 lineto
0.53472 0.06038 lineto
0.5372 0.06515 lineto
0.53968 0.07033 lineto
0.54216 0.07502 lineto
0.5434 0.07692 lineto
0.54464 0.0784 lineto
0.54588 0.07938 lineto
0.54712 0.07981 lineto
0.54836 0.07965 lineto
0.5496 0.07889 lineto
0.55084 0.07756 lineto
0.55208 0.07569 lineto
0.55456 0.07062 lineto
0.55704 0.06448 lineto
0.55952 0.05827 lineto
Mistroke
0.56076 0.05548 lineto
0.562 0.05308 lineto
0.56324 0.05118 lineto
0.56448 0.0499 lineto
0.56572 0.0493 lineto
0.56696 0.04945 lineto
0.5682 0.05036 lineto
0.56944 0.05202 lineto
0.57192 0.05743 lineto
0.5744 0.06495 lineto
0.57937 0.08151 lineto
0.58061 0.0849 lineto
0.58185 0.08762 lineto
0.58309 0.08952 lineto
0.58433 0.09046 lineto
0.58557 0.09034 lineto
0.58681 0.08909 lineto
0.58805 0.08669 lineto
0.58929 0.08317 lineto
0.59177 0.07312 lineto
0.59425 0.06012 lineto
0.59673 0.04605 lineto
0.59921 0.03335 lineto
0.60045 0.02835 lineto
0.60169 0.02472 lineto
0.60293 0.02279 lineto
0.60417 0.02287 lineto
0.60541 0.02524 lineto
0.60665 0.03013 lineto
0.60789 0.03774 lineto
0.60913 0.04819 lineto
0.61905 0.22825 lineto
0.62401 0.3555 lineto
0.62897 0.47244 lineto
0.63145 0.51909 lineto
0.63269 0.53847 lineto
0.63393 0.55503 lineto
0.63517 0.56867 lineto
0.63641 0.57941 lineto
0.63765 0.58728 lineto
0.63889 0.59243 lineto
0.64881 0.56564 lineto
0.65129 0.55178 lineto
0.65253 0.54549 lineto
0.65377 0.53992 lineto
0.65501 0.53526 lineto
0.65625 0.53164 lineto
0.65749 0.52913 lineto
0.65873 0.52777 lineto
0.65997 0.52754 lineto
Mistroke
0.66121 0.52838 lineto
0.66245 0.53019 lineto
0.66369 0.53284 lineto
0.66493 0.53617 lineto
0.66617 0.54001 lineto
0.66865 0.54846 lineto
0.67113 0.55668 lineto
0.67237 0.56028 lineto
0.67361 0.56336 lineto
0.67485 0.56581 lineto
0.67609 0.56755 lineto
0.67733 0.56853 lineto
0.67857 0.56875 lineto
0.67981 0.56822 lineto
0.68105 0.567 lineto
0.68353 0.56281 lineto
0.68601 0.55702 lineto
0.68849 0.55071 lineto
0.69097 0.54494 lineto
0.69221 0.54256 lineto
0.69345 0.54064 lineto
0.69469 0.53925 lineto
0.69593 0.53844 lineto
0.69717 0.53822 lineto
0.69841 0.53859 lineto
0.69965 0.53951 lineto
0.70089 0.54095 lineto
0.70213 0.54281 lineto
0.70337 0.54502 lineto
0.70833 0.55513 lineto
0.70957 0.55744 lineto
0.71081 0.55945 lineto
0.71205 0.56109 lineto
0.71329 0.5623 lineto
0.71453 0.56302 lineto
0.71577 0.56325 lineto
0.71701 0.56297 lineto
0.71825 0.56222 lineto
0.72321 0.55543 lineto
0.72569 0.55091 lineto
0.72817 0.54665 lineto
0.72941 0.54484 lineto
0.73065 0.54335 lineto
0.73189 0.54224 lineto
0.73313 0.54156 lineto
0.73437 0.54132 lineto
0.73562 0.54153 lineto
0.73686 0.54218 lineto
0.7381 0.54324 lineto
0.74058 0.54636 lineto
Mistroke
0.74306 0.55034 lineto
0.74554 0.55449 lineto
0.74678 0.55641 lineto
0.74802 0.55811 lineto
0.74926 0.55952 lineto
0.7505 0.56059 lineto
0.75174 0.56126 lineto
0.75298 0.56152 lineto
0.75794 0.55848 lineto
0.7629 0.55106 lineto
0.76538 0.54721 lineto
0.76662 0.54555 lineto
0.76786 0.54415 lineto
0.7691 0.54308 lineto
0.77034 0.54239 lineto
0.77158 0.54211 lineto
0.77282 0.54224 lineto
0.77406 0.54278 lineto
0.7753 0.54371 lineto
0.77778 0.54657 lineto
0.78274 0.55433 lineto
0.78522 0.55791 lineto
0.78646 0.55934 lineto
0.7877 0.56045 lineto
0.78894 0.56118 lineto
0.79018 0.56151 lineto
0.79142 0.56141 lineto
0.79266 0.56089 lineto
0.7939 0.55996 lineto
0.79514 0.55867 lineto
0.79638 0.55707 lineto
0.79762 0.55522 lineto
0.80258 0.54706 lineto
0.80382 0.54526 lineto
0.80506 0.54373 lineto
0.8063 0.54253 lineto
0.80754 0.54173 lineto
0.80878 0.54135 lineto
0.81002 0.54142 lineto
0.81126 0.54194 lineto
0.8125 0.54289 lineto
0.81746 0.55007 lineto
0.81994 0.55461 lineto
0.82242 0.55876 lineto
0.82366 0.56047 lineto
0.8249 0.56182 lineto
0.82614 0.56275 lineto
0.82738 0.5632 lineto
0.8373 0.55101 lineto
0.83978 0.5459 lineto
Mistroke
0.84102 0.54359 lineto
0.84226 0.54159 lineto
0.8435 0.53999 lineto
0.84474 0.53887 lineto
0.84598 0.53829 lineto
0.84722 0.53828 lineto
0.84846 0.53888 lineto
0.8497 0.54006 lineto
0.85218 0.544 lineto
0.85466 0.54956 lineto
0.85714 0.55586 lineto
0.85962 0.56182 lineto
0.86086 0.56434 lineto
0.8621 0.56639 lineto
0.86334 0.56785 lineto
0.86458 0.56864 lineto
0.86582 0.5687 lineto
0.86706 0.568 lineto
0.8683 0.56654 lineto
0.86954 0.56435 lineto
0.87078 0.5615 lineto
0.87202 0.55807 lineto
0.87698 0.54153 lineto
0.87822 0.53755 lineto
0.87946 0.53401 lineto
0.8807 0.53108 lineto
0.88194 0.52894 lineto
0.88318 0.52773 lineto
0.88442 0.52755 lineto
0.88566 0.52849 lineto
0.8869 0.53057 lineto
0.88814 0.53379 lineto
0.88938 0.53808 lineto
0.89187 0.54937 lineto
0.89435 0.56301 lineto
0.89683 0.57689 lineto
0.89807 0.58312 lineto
0.89931 0.58843 lineto
0.90055 0.59247 lineto
0.90179 0.5949 lineto
0.90303 0.5954 lineto
0.90427 0.59369 lineto
0.90551 0.58951 lineto
0.90675 0.58266 lineto
0.91667 0.42784 lineto
0.92659 0.18007 lineto
0.92907 0.12753 lineto
0.93155 0.0846 lineto
0.93403 0.05281 lineto
0.93527 0.04128 lineto
Mistroke
0.93651 0.03263 lineto
0.93775 0.02675 lineto
0.93899 0.02347 lineto
0.94023 0.02257 lineto
0.94147 0.02379 lineto
0.94271 0.02683 lineto
0.94395 0.03135 lineto
0.94643 0.04351 lineto
0.94891 0.05752 lineto
0.95139 0.07088 lineto
0.95263 0.07667 lineto
0.95387 0.08159 lineto
0.95511 0.08551 lineto
0.95635 0.08833 lineto
0.95759 0.09 lineto
0.95883 0.09054 lineto
0.96007 0.08999 lineto
0.96131 0.08843 lineto
0.96379 0.08284 lineto
0.96627 0.07503 lineto
0.97619 0.0497 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02877 0.447 lineto
0.03125 0.50385 lineto
0.03249 0.52761 lineto
0.03373 0.54788 lineto
0.03497 0.5645 lineto
0.03621 0.57743 lineto
0.03745 0.58672 lineto
0.03869 0.59256 lineto
0.03993 0.59518 lineto
0.04117 0.59494 lineto
0.04241 0.59224 lineto
0.04365 0.58752 lineto
0.04861 0.55827 lineto
0.05109 0.54381 lineto
0.05233 0.53792 lineto
0.05357 0.53325 lineto
0.05481 0.52995 lineto
0.05605 0.52809 lineto
0.05729 0.52765 lineto
0.05853 0.52857 lineto
0.05977 0.53071 lineto
0.06101 0.53387 lineto
0.06349 0.5423 lineto
0.06597 0.5518 lineto
0.06721 0.5563 lineto
0.06845 0.56032 lineto
0.06969 0.56368 lineto
0.07093 0.56622 lineto
0.07217 0.56785 lineto
0.07341 0.56853 lineto
0.07465 0.56827 lineto
0.07589 0.56711 lineto
0.07837 0.56255 lineto
0.07961 0.55946 lineto
0.08085 0.55606 lineto
0.08333 0.54912 lineto
0.08581 0.54321 lineto
0.08705 0.54101 lineto
0.08829 0.53948 lineto
0.08953 0.53865 lineto
0.09077 0.53857 lineto
0.09201 0.5392 lineto
0.09325 0.54049 lineto
0.09449 0.54236 lineto
0.09573 0.54469 lineto
0.09821 0.55016 lineto
0.10069 0.55568 lineto
0.10193 0.55809 lineto
0.10317 0.56009 lineto
Mistroke
0.10441 0.56159 lineto
0.10565 0.56252 lineto
0.10689 0.56284 lineto
0.10813 0.56255 lineto
0.10938 0.56168 lineto
0.11062 0.56028 lineto
0.1131 0.55627 lineto
0.11558 0.55144 lineto
0.11806 0.54684 lineto
0.1193 0.54494 lineto
0.12054 0.54343 lineto
0.12178 0.54241 lineto
0.12302 0.54191 lineto
0.12426 0.54195 lineto
0.1255 0.54252 lineto
0.12674 0.54359 lineto
0.12798 0.54508 lineto
0.13294 0.5534 lineto
0.13418 0.55548 lineto
0.13542 0.55734 lineto
0.13666 0.55886 lineto
0.1379 0.55999 lineto
0.13914 0.56065 lineto
0.14038 0.56081 lineto
0.14162 0.56048 lineto
0.14286 0.55967 lineto
0.18254 0.55035 lineto
0.18502 0.54664 lineto
0.18626 0.54514 lineto
0.1875 0.54401 lineto
0.18874 0.54329 lineto
0.18998 0.54303 lineto
0.19122 0.54325 lineto
0.19246 0.54394 lineto
0.1937 0.54505 lineto
0.19494 0.54654 lineto
0.19742 0.55031 lineto
0.1999 0.55443 lineto
0.20114 0.55635 lineto
0.20238 0.55803 lineto
0.20362 0.55937 lineto
0.20486 0.5603 lineto
0.2061 0.56077 lineto
0.20734 0.56074 lineto
0.20858 0.56022 lineto
0.20982 0.55922 lineto
0.2123 0.55602 lineto
0.21478 0.5518 lineto
0.21726 0.54747 lineto
0.2185 0.54556 lineto
Mistroke
0.21974 0.54396 lineto
0.22098 0.54276 lineto
0.22222 0.54205 lineto
0.22346 0.54186 lineto
0.2247 0.54222 lineto
0.22594 0.5431 lineto
0.22718 0.54448 lineto
0.22842 0.54628 lineto
0.22966 0.54841 lineto
0.23214 0.55322 lineto
0.23462 0.55787 lineto
0.23586 0.55981 lineto
0.2371 0.56134 lineto
0.23834 0.56237 lineto
0.23958 0.56282 lineto
0.24082 0.56267 lineto
0.24206 0.56191 lineto
0.2433 0.56056 lineto
0.24454 0.55868 lineto
0.24702 0.55374 lineto
0.2495 0.5481 lineto
0.25074 0.54539 lineto
0.25198 0.54296 lineto
0.25322 0.54095 lineto
0.25446 0.53949 lineto
0.2557 0.53867 lineto
0.25694 0.53856 lineto
0.25818 0.53918 lineto
0.25942 0.54052 lineto
0.2619 0.54515 lineto
0.26687 0.55855 lineto
0.26935 0.5645 lineto
0.27059 0.56665 lineto
0.27183 0.56803 lineto
0.27307 0.56855 lineto
0.27431 0.56813 lineto
0.27555 0.56676 lineto
0.27679 0.56446 lineto
0.27803 0.56132 lineto
0.27927 0.55746 lineto
0.28175 0.54836 lineto
0.28423 0.539 lineto
0.28547 0.53488 lineto
0.28671 0.53148 lineto
0.28795 0.52905 lineto
0.28919 0.52778 lineto
0.29043 0.52783 lineto
0.29167 0.52929 lineto
0.29291 0.5322 lineto
0.29415 0.53651 lineto
Mistroke
0.29663 0.54872 lineto
0.29911 0.564 lineto
0.30159 0.57937 lineto
0.30283 0.58594 lineto
0.30407 0.59112 lineto
0.30531 0.59442 lineto
0.30655 0.59538 lineto
0.30779 0.59358 lineto
0.30903 0.58866 lineto
0.31027 0.58033 lineto
0.31151 0.56841 lineto
0.31399 0.53353 lineto
0.31647 0.48457 lineto
0.32143 0.35494 lineto
0.32639 0.21252 lineto
0.32887 0.1491 lineto
0.33135 0.0966 lineto
0.33259 0.07535 lineto
0.33383 0.05772 lineto
0.33507 0.04379 lineto
0.33631 0.03351 lineto
0.33755 0.02675 lineto
0.33879 0.02327 lineto
0.34003 0.02277 lineto
0.34127 0.02484 lineto
0.34251 0.02905 lineto
0.34375 0.03492 lineto
0.34623 0.04968 lineto
0.34871 0.06532 lineto
0.34995 0.07243 lineto
0.35119 0.07861 lineto
0.35243 0.08363 lineto
0.35367 0.08732 lineto
0.35491 0.08958 lineto
0.35615 0.0904 lineto
0.35739 0.08984 lineto
0.35863 0.08802 lineto
0.36111 0.08137 lineto
0.36359 0.0723 lineto
0.36607 0.06293 lineto
0.36731 0.05876 lineto
0.36855 0.0552 lineto
0.36979 0.05242 lineto
0.37103 0.05054 lineto
0.37227 0.04959 lineto
0.37351 0.0496 lineto
0.37475 0.05053 lineto
0.37599 0.05227 lineto
0.37847 0.05769 lineto
0.38095 0.06452 lineto
Mistroke
0.38343 0.07125 lineto
0.38467 0.07412 lineto
0.38591 0.07648 lineto
0.38715 0.07821 lineto
0.38839 0.07923 lineto
0.38963 0.07952 lineto
0.39087 0.07908 lineto
0.39211 0.07796 lineto
0.39335 0.07623 lineto
0.39459 0.07402 lineto
0.39583 0.07144 lineto
0.39831 0.06582 lineto
0.40079 0.06057 lineto
0.40203 0.05845 lineto
0.40327 0.0568 lineto
0.40451 0.05571 lineto
0.40575 0.05522 lineto
0.40699 0.05534 lineto
0.40823 0.05606 lineto
0.41071 0.05906 lineto
0.41567 0.06835 lineto
0.41815 0.07261 lineto
0.41939 0.07423 lineto
0.42063 0.0754 lineto
0.42188 0.07604 lineto
0.42312 0.07615 lineto
0.42436 0.07572 lineto
0.4256 0.07479 lineto
0.42684 0.0734 lineto
0.42808 0.07165 lineto
0.43056 0.06745 lineto
0.43304 0.06311 lineto
0.43428 0.06118 lineto
0.43552 0.05955 lineto
0.43676 0.05831 lineto
0.438 0.05752 lineto
0.43924 0.05722 lineto
0.44048 0.05742 lineto
0.44172 0.0581 lineto
0.44296 0.05922 lineto
0.44544 0.06252 lineto
0.44792 0.06659 lineto
0.4504 0.07054 lineto
0.45164 0.0722 lineto
0.45288 0.07354 lineto
0.45412 0.07446 lineto
0.45536 0.07494 lineto
0.4566 0.07495 lineto
0.45784 0.07448 lineto
0.45908 0.07356 lineto
Mistroke
0.46032 0.07226 lineto
0.4628 0.06877 lineto
0.46528 0.06477 lineto
0.46652 0.06285 lineto
0.46776 0.06112 lineto
0.469 0.05968 lineto
0.47024 0.05861 lineto
0.47148 0.05795 lineto
0.47272 0.05776 lineto
0.47396 0.05804 lineto
0.4752 0.05877 lineto
0.47768 0.06141 lineto
0.48016 0.06512 lineto
0.48264 0.06911 lineto
0.48512 0.07251 lineto
0.48636 0.07376 lineto
0.4876 0.07459 lineto
0.48884 0.07498 lineto
0.49008 0.07489 lineto
0.49132 0.07433 lineto
0.49256 0.07333 lineto
0.4938 0.07193 lineto
0.49504 0.07022 lineto
0.49752 0.06622 lineto
0.5 0.06219 lineto
0.50124 0.06044 lineto
0.50248 0.059 lineto
0.50372 0.05794 lineto
0.50496 0.05735 lineto
0.5062 0.05724 lineto
0.50744 0.05763 lineto
0.50868 0.0585 lineto
0.50992 0.05981 lineto
0.5124 0.06347 lineto
0.51488 0.06784 lineto
0.51736 0.07198 lineto
0.5186 0.07368 lineto
0.51984 0.07499 lineto
0.52108 0.07584 lineto
0.52232 0.07617 lineto
0.52356 0.07597 lineto
0.5248 0.07523 lineto
0.52728 0.07228 lineto
0.52852 0.07023 lineto
0.52976 0.06793 lineto
0.53224 0.06305 lineto
0.53472 0.05872 lineto
0.53596 0.05707 lineto
0.5372 0.05589 lineto
0.53844 0.05528 lineto
Mistroke
0.53968 0.05526 lineto
0.54092 0.05586 lineto
0.54216 0.05705 lineto
0.5434 0.05879 lineto
0.54464 0.06099 lineto
0.5496 0.07192 lineto
0.55084 0.07444 lineto
0.55208 0.07658 lineto
0.55332 0.0782 lineto
0.55456 0.07921 lineto
0.5558 0.07952 lineto
0.55704 0.0791 lineto
0.55828 0.07795 lineto
0.55952 0.07611 lineto
0.57937 0.06372 lineto
0.58185 0.07314 lineto
0.58433 0.08208 lineto
0.58557 0.08571 lineto
0.58681 0.08843 lineto
0.58805 0.09004 lineto
0.58929 0.09036 lineto
0.59053 0.08929 lineto
0.59177 0.08677 lineto
0.59301 0.08284 lineto
0.59425 0.0776 lineto
0.59921 0.04828 lineto
0.60045 0.04065 lineto
0.60169 0.03378 lineto
0.60293 0.02817 lineto
0.60417 0.0243 lineto
0.60541 0.02266 lineto
0.60665 0.02366 lineto
0.60789 0.0277 lineto
0.60913 0.03506 lineto
0.61905 0.21853 lineto
0.62401 0.36124 lineto
0.62897 0.48942 lineto
0.63021 0.515 lineto
0.63145 0.53721 lineto
0.63269 0.55584 lineto
0.63393 0.57079 lineto
0.63517 0.58207 lineto
0.63641 0.58977 lineto
0.63765 0.59412 lineto
0.63889 0.5954 lineto
0.64013 0.594 lineto
0.64137 0.59033 lineto
0.64385 0.57809 lineto
0.64633 0.5626 lineto
0.64881 0.54748 lineto
Mistroke
0.65005 0.54101 lineto
0.65129 0.53565 lineto
0.65253 0.53158 lineto
0.65377 0.52893 lineto
0.65501 0.52772 lineto
0.65625 0.52791 lineto
0.65749 0.5294 lineto
0.65873 0.53202 lineto
0.66121 0.53979 lineto
0.66369 0.54921 lineto
0.66617 0.55819 lineto
0.66741 0.56193 lineto
0.66865 0.56493 lineto
0.66989 0.56707 lineto
0.67113 0.56828 lineto
0.67237 0.56853 lineto
0.67361 0.56785 lineto
0.67857 0.55795 lineto
0.68105 0.55098 lineto
0.68229 0.54765 lineto
0.68353 0.54465 lineto
0.68477 0.54214 lineto
0.68601 0.54023 lineto
0.68725 0.53901 lineto
0.68849 0.53852 lineto
0.68973 0.53877 lineto
0.69097 0.53971 lineto
0.69345 0.54337 lineto
0.69469 0.54586 lineto
0.69593 0.5486 lineto
0.69841 0.55423 lineto
0.70089 0.55905 lineto
0.70213 0.56084 lineto
0.70337 0.56209 lineto
0.70461 0.56274 lineto
0.70585 0.56279 lineto
0.70709 0.56223 lineto
0.70833 0.5611 lineto
0.70957 0.55949 lineto
0.71081 0.55749 lineto
0.71329 0.55278 lineto
0.71577 0.54802 lineto
0.71701 0.54594 lineto
0.71825 0.5442 lineto
0.71949 0.54291 lineto
0.72073 0.54211 lineto
0.72197 0.54186 lineto
0.72321 0.54214 lineto
0.72445 0.54294 lineto
0.72569 0.54421 lineto
Mistroke
0.72817 0.54783 lineto
0.73065 0.5522 lineto
0.73313 0.55635 lineto
0.73437 0.55807 lineto
0.73562 0.55943 lineto
0.73686 0.56034 lineto
0.7381 0.56078 lineto
0.73934 0.56072 lineto
0.74058 0.56017 lineto
0.74182 0.55916 lineto
0.74306 0.55775 lineto
0.7443 0.55603 lineto
0.74554 0.55408 lineto
0.74802 0.54995 lineto
0.7505 0.54626 lineto
0.75174 0.54483 lineto
0.75298 0.54378 lineto
0.75422 0.54318 lineto
0.75546 0.54304 lineto
0.7567 0.54338 lineto
0.75794 0.54418 lineto
0.75918 0.54538 lineto
0.76042 0.54693 lineto
0.7629 0.5507 lineto
0.76538 0.55467 lineto
0.76662 0.55646 lineto
0.76786 0.55799 lineto
0.7691 0.55917 lineto
0.77034 0.55995 lineto
0.77158 0.56027 lineto
0.77282 0.56012 lineto
0.77406 0.55951 lineto
0.7753 0.55848 lineto
0.77778 0.55536 lineto
0.78026 0.55145 lineto
0.78274 0.54758 lineto
0.78398 0.54592 lineto
0.78522 0.54458 lineto
0.78646 0.54363 lineto
0.7877 0.54311 lineto
0.78894 0.54307 lineto
0.79018 0.5435 lineto
0.79142 0.54439 lineto
0.79266 0.54568 lineto
0.79514 0.5492 lineto
0.79762 0.55332 lineto
0.8001 0.55714 lineto
0.80134 0.55868 lineto
0.80258 0.55984 lineto
0.80382 0.56057 lineto
Mistroke
0.80506 0.56082 lineto
0.8063 0.56056 lineto
0.80754 0.55982 lineto
0.81002 0.55703 lineto
0.81126 0.55513 lineto
0.8125 0.55301 lineto
0.81498 0.54862 lineto
0.81746 0.54479 lineto
0.8187 0.54336 lineto
0.81994 0.54238 lineto
0.82118 0.5419 lineto
0.82242 0.54195 lineto
0.82366 0.54255 lineto
0.8249 0.54367 lineto
0.82614 0.54525 lineto
0.82738 0.54721 lineto
0.83234 0.55667 lineto
0.83358 0.55879 lineto
0.83482 0.56056 lineto
0.83606 0.56187 lineto
0.8373 0.56265 lineto
0.83854 0.56283 lineto
0.83978 0.5624 lineto
0.84102 0.56137 lineto
0.84226 0.55977 lineto
0.84722 0.54965 lineto
0.8497 0.54425 lineto
0.85094 0.542 lineto
0.85218 0.54022 lineto
0.85342 0.53904 lineto
0.85466 0.53853 lineto
0.8559 0.53874 lineto
0.85714 0.5397 lineto
0.8621 0.54971 lineto
0.86458 0.55668 lineto
0.86582 0.56003 lineto
0.86706 0.56306 lineto
0.8683 0.56556 lineto
0.86954 0.56737 lineto
0.87078 0.56838 lineto
0.87202 0.56848 lineto
0.87326 0.56763 lineto
0.8745 0.56583 lineto
0.87698 0.55965 lineto
0.87946 0.55097 lineto
0.88194 0.54148 lineto
0.88442 0.53324 lineto
0.88566 0.53025 lineto
0.8869 0.52832 lineto
0.89683 0.55966 lineto
Mistroke
0.89931 0.57535 lineto
0.90055 0.58247 lineto
0.90179 0.58848 lineto
0.90303 0.59287 lineto
0.90427 0.59517 lineto
0.90551 0.59494 lineto
0.90675 0.59177 lineto
0.91667 0.44145 lineto
0.92659 0.16556 lineto
0.92907 0.10973 lineto
0.93031 0.08657 lineto
0.93155 0.06694 lineto
0.93279 0.05097 lineto
0.93403 0.0387 lineto
0.93527 0.03003 lineto
0.93651 0.02479 lineto
0.94643 0.06114 lineto
0.94891 0.07535 lineto
0.95015 0.08104 lineto
0.95139 0.08547 lineto
0.95263 0.08852 lineto
0.95387 0.09013 lineto
0.95511 0.09031 lineto
0.95635 0.08917 lineto
0.95759 0.08683 lineto
0.95883 0.08352 lineto
0.96131 0.07491 lineto
0.96379 0.06541 lineto
0.96503 0.06098 lineto
0.96627 0.05706 lineto
0.96751 0.05384 lineto
0.96875 0.05146 lineto
0.96999 0.04999 lineto
0.97123 0.04948 lineto
0.97247 0.04991 lineto
0.97371 0.05122 lineto
0.97495 0.05329 lineto
0.97619 0.056 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.309017 [
[(2)] 0.21429 0.30902 0 2 Msboxa
[(4)] 0.40476 0.30902 0 2 Msboxa
[(6)] 0.59524 0.30902 0 2 Msboxa
[(8)] 0.78571 0.30902 0 2 Msboxa
[(10)] 0.97619 0.30902 0 2 Msboxa
[(-1)] 0.01131 0 1 0 Msboxa
[(-0.75)] 0.01131 0.07725 1 0 Msboxa
[(-0.5)] 0.01131 0.15451 1 0 Msboxa
[(-0.25)] 0.01131 0.23176 1 0 Msboxa
[(0.25)] 0.01131 0.38627 1 0 Msboxa
[(0.5)] 0.01131 0.46353 1 0 Msboxa
[(0.75)] 0.01131 0.54078 1 0 Msboxa
[(1)] 0.01131 0.61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0.21429 0.30902 moveto
0.21429 0.31527 lineto
stroke
grestore
[(2)] 0.21429 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.40476 0.30902 moveto
0.40476 0.31527 lineto
stroke
grestore
[(4)] 0.40476 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.59524 0.30902 moveto
0.59524 0.31527 lineto
stroke
grestore
[(6)] 0.59524 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.78571 0.30902 moveto
0.78571 0.31527 lineto
stroke
grestore
[(8)] 0.78571 0.30902 0 2 Mshowa
gsave
0.002 setlinewidth
0.97619 0.30902 moveto
0.97619 0.31527 lineto
stroke
grestore
[(10)] 0.97619 0.30902 0 2 Mshowa
gsave
0.001 setlinewidth
0.0619 0.30902 moveto
0.0619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1 0.30902 moveto
0.1 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.1381 0.30902 moveto
0.1381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.17619 0.30902 moveto
0.17619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.25238 0.30902 moveto
0.25238 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.29048 0.30902 moveto
0.29048 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.32857 0.30902 moveto
0.32857 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.36667 0.30902 moveto
0.36667 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.44286 0.30902 moveto
0.44286 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.48095 0.30902 moveto
0.48095 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.51905 0.30902 moveto
0.51905 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.55714 0.30902 moveto
0.55714 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.63333 0.30902 moveto
0.63333 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.67143 0.30902 moveto
0.67143 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.70952 0.30902 moveto
0.70952 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.74762 0.30902 moveto
0.74762 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.82381 0.30902 moveto
0.82381 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.8619 0.30902 moveto
0.8619 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9 0.30902 moveto
0.9 0.31277 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.9381 0.30902 moveto
0.9381 0.31277 lineto
stroke
grestore
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.03006 0 lineto
stroke
grestore
[(-1)] 0.01131 0 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.07725 moveto
0.03006 0.07725 lineto
stroke
grestore
[(-0.75)] 0.01131 0.07725 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.15451 moveto
0.03006 0.15451 lineto
stroke
grestore
[(-0.5)] 0.01131 0.15451 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.23176 moveto
0.03006 0.23176 lineto
stroke
grestore
[(-0.25)] 0.01131 0.23176 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.38627 moveto
0.03006 0.38627 lineto
stroke
grestore
[(0.25)] 0.01131 0.38627 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.46353 moveto
0.03006 0.46353 lineto
stroke
grestore
[(0.5)] 0.01131 0.46353 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.54078 moveto
0.03006 0.54078 lineto
stroke
grestore
[(0.75)] 0.01131 0.54078 1 0 Mshowa
gsave
0.002 setlinewidth
0.02381 0.61803 moveto
0.03006 0.61803 lineto
stroke
grestore
[(1)] 0.01131 0.61803 1 0 Mshowa
gsave
0.001 setlinewidth
0.02381 0.01545 moveto
0.02756 0.01545 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0309 moveto
0.02756 0.0309 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.04635 moveto
0.02756 0.04635 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.0618 moveto
0.02756 0.0618 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.09271 moveto
0.02756 0.09271 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.10816 moveto
0.02756 0.10816 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.12361 moveto
0.02756 0.12361 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.13906 moveto
0.02756 0.13906 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.16996 moveto
0.02756 0.16996 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.18541 moveto
0.02756 0.18541 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.20086 moveto
0.02756 0.20086 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.21631 moveto
0.02756 0.21631 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.24721 moveto
0.02756 0.24721 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.26266 moveto
0.02756 0.26266 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.27812 moveto
0.02756 0.27812 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.29357 moveto
0.02756 0.29357 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.32447 moveto
0.02756 0.32447 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.33992 moveto
0.02756 0.33992 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.35537 moveto
0.02756 0.35537 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.37082 moveto
0.02756 0.37082 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.40172 moveto
0.02756 0.40172 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.41717 moveto
0.02756 0.41717 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.43262 moveto
0.02756 0.43262 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.44807 moveto
0.02756 0.44807 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.47898 moveto
0.02756 0.47898 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.49443 moveto
0.02756 0.49443 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.50988 moveto
0.02756 0.50988 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.52533 moveto
0.02756 0.52533 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.55623 moveto
0.02756 0.55623 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.57168 moveto
0.02756 0.57168 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.58713 moveto
0.02756 0.58713 lineto
stroke
grestore
gsave
0.001 setlinewidth
0.02381 0.60258 moveto
0.02756 0.60258 lineto
stroke
grestore
gsave
0.002 setlinewidth
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
grestore
grestore
0 0 moveto
1 0 lineto
1 0.61803 lineto
0 0.61803 lineto
closepath
clip
newpath
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02629 0.38829 lineto
0.02877 0.46059 lineto
0.03125 0.52006 lineto
0.03249 0.54367 lineto
0.03373 0.56281 lineto
0.03497 0.57739 lineto
0.03621 0.5875 lineto
0.03745 0.59336 lineto
0.03869 0.59535 lineto
0.04365 0.57567 lineto
0.04613 0.55828 lineto
0.04737 0.54992 lineto
0.04861 0.54246 lineto
0.04985 0.53629 lineto
0.05109 0.53169 lineto
0.05233 0.52883 lineto
0.05357 0.52774 lineto
0.05481 0.52835 lineto
0.05605 0.5305 lineto
0.05853 0.53834 lineto
0.06101 0.54863 lineto
0.06349 0.55853 lineto
0.06473 0.56254 lineto
0.06597 0.5656 lineto
0.06721 0.56757 lineto
0.06845 0.56838 lineto
0.06969 0.56803 lineto
0.07093 0.56661 lineto
0.07341 0.56115 lineto
0.07837 0.54639 lineto
0.07961 0.54335 lineto
0.08085 0.54099 lineto
0.08209 0.53943 lineto
0.08333 0.53875 lineto
0.08457 0.53897 lineto
0.08581 0.54003 lineto
0.08705 0.54184 lineto
0.08829 0.54425 lineto
0.09325 0.55611 lineto
0.09449 0.55862 lineto
0.09573 0.56059 lineto
0.09697 0.56192 lineto
0.09821 0.56253 lineto
0.09945 0.56239 lineto
0.10069 0.56155 lineto
0.10193 0.56006 lineto
0.10317 0.55806 lineto
0.10813 0.54795 lineto
0.10938 0.54576 lineto
Mistroke
0.11062 0.54402 lineto
0.11186 0.54283 lineto
0.1131 0.54226 lineto
0.11434 0.54234 lineto
0.11558 0.54304 lineto
0.11682 0.54432 lineto
0.11806 0.54607 lineto
0.12302 0.55506 lineto
0.12426 0.55704 lineto
0.1255 0.55864 lineto
0.12674 0.55975 lineto
0.12798 0.5603 lineto
0.12922 0.56027 lineto
0.13046 0.55966 lineto
0.13294 0.55695 lineto
0.13418 0.55504 lineto
0.13542 0.55293 lineto
0.1379 0.54867 lineto
0.13914 0.54682 lineto
0.14038 0.54531 lineto
0.14162 0.54424 lineto
0.14286 0.54369 lineto
0.1441 0.54369 lineto
0.14534 0.54422 lineto
0.14658 0.54526 lineto
0.14782 0.54672 lineto
0.14906 0.54851 lineto
0.1503 0.55051 lineto
0.15278 0.55456 lineto
0.15402 0.55635 lineto
0.15526 0.55782 lineto
0.1565 0.55887 lineto
0.15774 0.55943 lineto
0.15898 0.55947 lineto
0.16022 0.55899 lineto
0.16146 0.55801 lineto
0.1627 0.55662 lineto
0.16394 0.5549 lineto
0.16518 0.55297 lineto
0.16766 0.549 lineto
0.1689 0.54723 lineto
0.17014 0.54576 lineto
0.17138 0.5447 lineto
0.17262 0.54412 lineto
0.17386 0.54405 lineto
0.1751 0.54449 lineto
0.17634 0.54543 lineto
0.17758 0.54679 lineto
0.17882 0.54849 lineto
0.18006 0.55041 lineto
Mistroke
0.18254 0.55438 lineto
0.18378 0.55617 lineto
0.18502 0.55767 lineto
0.18626 0.55877 lineto
0.1875 0.55939 lineto
0.18874 0.5595 lineto
0.18998 0.55908 lineto
0.19122 0.55815 lineto
0.19246 0.55679 lineto
0.1937 0.55508 lineto
0.19494 0.55313 lineto
0.19742 0.54904 lineto
0.19866 0.54719 lineto
0.1999 0.54562 lineto
0.20114 0.54446 lineto
0.20238 0.54378 lineto
0.20362 0.54363 lineto
0.20486 0.54404 lineto
0.2061 0.54497 lineto
0.20734 0.54636 lineto
0.20858 0.54814 lineto
0.20982 0.55017 lineto
0.2123 0.55448 lineto
0.21354 0.55646 lineto
0.21478 0.55814 lineto
0.21602 0.5594 lineto
0.21726 0.56016 lineto
0.2185 0.56035 lineto
0.21974 0.55995 lineto
0.22098 0.55899 lineto
0.22222 0.55752 lineto
0.22718 0.54878 lineto
0.22842 0.54661 lineto
0.22966 0.54475 lineto
0.2309 0.54334 lineto
0.23214 0.54247 lineto
0.23338 0.54222 lineto
0.23462 0.54261 lineto
0.23586 0.54364 lineto
0.2371 0.54524 lineto
0.24206 0.55497 lineto
0.2433 0.55743 lineto
0.24454 0.55956 lineto
0.24578 0.5612 lineto
0.24702 0.56223 lineto
0.24826 0.56256 lineto
0.2495 0.56216 lineto
0.25074 0.56103 lineto
0.25198 0.55922 lineto
0.25694 0.54792 lineto
Mistroke
0.25818 0.545 lineto
0.25942 0.54245 lineto
0.26066 0.54046 lineto
0.2619 0.53918 lineto
0.26314 0.53872 lineto
0.26438 0.53915 lineto
0.26563 0.54047 lineto
0.26687 0.54263 lineto
0.26935 0.54892 lineto
0.27183 0.55652 lineto
0.27307 0.56021 lineto
0.27431 0.56346 lineto
0.27555 0.56604 lineto
0.27679 0.56774 lineto
0.27803 0.5684 lineto
0.27927 0.56791 lineto
0.28051 0.56626 lineto
0.28175 0.56348 lineto
0.28423 0.55516 lineto
0.28671 0.5448 lineto
0.28795 0.53967 lineto
0.28919 0.53506 lineto
0.29043 0.53133 lineto
0.29167 0.5288 lineto
0.29291 0.52774 lineto
0.29415 0.52835 lineto
0.29539 0.53073 lineto
0.29663 0.53486 lineto
0.29911 0.54776 lineto
0.30159 0.56464 lineto
0.30283 0.57336 lineto
0.30407 0.58145 lineto
0.30531 0.58824 lineto
0.30655 0.59308 lineto
0.30779 0.59529 lineto
0.30903 0.59427 lineto
0.31027 0.58951 lineto
0.31151 0.5806 lineto
0.31275 0.56726 lineto
0.31399 0.54937 lineto
0.31523 0.52697 lineto
0.31647 0.50026 lineto
0.32143 0.35998 lineto
0.32639 0.20236 lineto
0.32887 0.13413 lineto
0.33011 0.10521 lineto
0.33135 0.08041 lineto
0.33259 0.06002 lineto
0.33383 0.04419 lineto
0.33507 0.03287 lineto
Mistroke
0.33631 0.02588 lineto
0.33755 0.02287 lineto
0.33879 0.02338 lineto
0.34003 0.02685 lineto
0.34127 0.03266 lineto
0.34375 0.04857 lineto
0.34623 0.06589 lineto
0.34871 0.0802 lineto
0.34995 0.08525 lineto
0.35119 0.0886 lineto
0.35243 0.09017 lineto
0.35367 0.09001 lineto
0.35491 0.08826 lineto
0.35615 0.08515 lineto
0.35739 0.08098 lineto
0.35863 0.07609 lineto
0.36111 0.06562 lineto
0.36359 0.05651 lineto
0.36483 0.05317 lineto
0.36607 0.05089 lineto
0.36731 0.04976 lineto
0.36855 0.04979 lineto
0.36979 0.05094 lineto
0.37103 0.05306 lineto
0.37227 0.05597 lineto
0.37351 0.05945 lineto
0.37599 0.06708 lineto
0.37847 0.07391 lineto
0.37971 0.07648 lineto
0.38095 0.07826 lineto
0.38219 0.07919 lineto
0.38343 0.07921 lineto
0.38467 0.07838 lineto
0.38591 0.07676 lineto
0.38715 0.07449 lineto
0.38839 0.07175 lineto
0.39087 0.06564 lineto
0.39335 0.06006 lineto
0.39459 0.05792 lineto
0.39583 0.05641 lineto
0.39707 0.0556 lineto
0.39831 0.05553 lineto
0.39955 0.05619 lineto
0.40079 0.0575 lineto
0.40203 0.05938 lineto
0.40327 0.06168 lineto
0.40575 0.06688 lineto
0.40699 0.06943 lineto
0.40823 0.07171 lineto
0.40947 0.07358 lineto
Mistroke
0.41071 0.07493 lineto
0.41195 0.07568 lineto
0.41319 0.07578 lineto
0.41443 0.07524 lineto
0.41567 0.07412 lineto
0.41815 0.07047 lineto
0.42063 0.06586 lineto
0.42188 0.06357 lineto
0.42312 0.0615 lineto
0.42436 0.05979 lineto
0.4256 0.05854 lineto
0.42684 0.05783 lineto
0.42808 0.0577 lineto
0.42932 0.05815 lineto
0.43056 0.05915 lineto
0.43304 0.06244 lineto
0.43552 0.06668 lineto
0.43676 0.06881 lineto
0.438 0.07074 lineto
0.43924 0.07235 lineto
0.44048 0.07355 lineto
0.44172 0.07425 lineto
0.44296 0.0744 lineto
0.4442 0.07401 lineto
0.44544 0.07311 lineto
0.44792 0.07004 lineto
0.4504 0.06603 lineto
0.45288 0.06214 lineto
0.45412 0.06058 lineto
0.45536 0.0594 lineto
0.4566 0.0587 lineto
0.45784 0.05852 lineto
0.46032 0.05971 lineto
0.48016 0.06617 lineto
0.48264 0.06233 lineto
0.48388 0.06074 lineto
0.48512 0.05952 lineto
0.48636 0.05876 lineto
0.4876 0.05851 lineto
0.48884 0.05879 lineto
0.49008 0.05958 lineto
0.49256 0.06246 lineto
0.49504 0.0664 lineto
0.49752 0.07036 lineto
0.49876 0.07202 lineto
0.5 0.0733 lineto
0.50124 0.07412 lineto
0.50248 0.07441 lineto
0.50372 0.07416 lineto
0.50496 0.07337 lineto
Mistroke
0.5062 0.0721 lineto
0.50744 0.07042 lineto
0.50992 0.0663 lineto
0.5124 0.0621 lineto
0.51364 0.06032 lineto
0.51488 0.05893 lineto
0.51612 0.05803 lineto
0.51736 0.05768 lineto
0.51984 0.05872 lineto
0.53968 0.06641 lineto
0.54216 0.06125 lineto
0.5434 0.05901 lineto
0.54464 0.05723 lineto
0.54588 0.05602 lineto
0.54712 0.05549 lineto
0.54836 0.05569 lineto
0.5496 0.05663 lineto
0.55084 0.05826 lineto
0.55208 0.06049 lineto
0.55456 0.06618 lineto
0.55704 0.07226 lineto
0.55828 0.07493 lineto
0.55952 0.0771 lineto
0.56076 0.07858 lineto
0.562 0.07927 lineto
0.56324 0.07909 lineto
0.56448 0.07801 lineto
0.56572 0.07608 lineto
0.56696 0.07339 lineto
0.56944 0.06641 lineto
0.57192 0.05881 lineto
0.57316 0.05541 lineto
0.5744 0.05262 lineto
0.57564 0.05066 lineto
0.57688 0.0497 lineto
0.57937 0.05121 lineto
0.58433 0.06653 lineto
0.58681 0.07699 lineto
0.58805 0.08178 lineto
0.58929 0.08579 lineto
0.59053 0.08868 lineto
0.59177 0.09016 lineto
0.59301 0.09002 lineto
0.59425 0.08813 lineto
0.59921 0.06442 lineto
0.60169 0.04703 lineto
0.60293 0.03871 lineto
0.60417 0.03149 lineto
0.60541 0.02605 lineto
0.60665 0.02306 lineto
Mistroke
0.60789 0.02313 lineto
0.60913 0.02682 lineto
0.61905 0.20894 lineto
0.62401 0.36695 lineto
0.62649 0.44182 lineto
0.62897 0.50529 lineto
0.63021 0.53126 lineto
0.63145 0.55287 lineto
0.63269 0.56995 lineto
0.63393 0.5825 lineto
0.63517 0.59065 lineto
0.63641 0.59471 lineto
0.63765 0.59511 lineto
0.63889 0.59239 lineto
0.64385 0.56308 lineto
0.64633 0.54641 lineto
0.64757 0.53949 lineto
0.64881 0.53401 lineto
0.65005 0.53018 lineto
0.65129 0.52812 lineto
0.65253 0.52781 lineto
0.65377 0.52915 lineto
0.65873 0.54573 lineto
0.66121 0.55601 lineto
0.66245 0.56044 lineto
0.66369 0.56405 lineto
0.66493 0.56663 lineto
0.66617 0.56808 lineto
0.66741 0.56836 lineto
0.66865 0.56751 lineto
0.66989 0.56564 lineto
0.67113 0.56293 lineto
0.67237 0.55958 lineto
0.67361 0.55585 lineto
0.67609 0.54828 lineto
0.67733 0.54494 lineto
0.67857 0.54219 lineto
0.67981 0.54018 lineto
0.68105 0.53901 lineto
0.68229 0.53874 lineto
0.68353 0.53935 lineto
0.68477 0.54076 lineto
0.68601 0.54287 lineto
0.68725 0.54549 lineto
0.68849 0.54846 lineto
0.69097 0.55456 lineto
0.69221 0.5573 lineto
0.69345 0.55958 lineto
0.69469 0.56128 lineto
0.69593 0.56229 lineto
Mistroke
0.69717 0.56256 lineto
0.69841 0.5621 lineto
0.69965 0.56095 lineto
0.70089 0.55922 lineto
0.70213 0.55702 lineto
0.70337 0.55451 lineto
0.70585 0.54929 lineto
0.70709 0.54692 lineto
0.70833 0.54492 lineto
0.70957 0.54341 lineto
0.71081 0.5425 lineto
0.71205 0.54222 lineto
0.71329 0.54258 lineto
0.71453 0.54355 lineto
0.71577 0.54505 lineto
0.71701 0.54698 lineto
0.71825 0.54919 lineto
0.72073 0.55385 lineto
0.72197 0.55599 lineto
0.72321 0.55782 lineto
0.72445 0.5592 lineto
0.72569 0.56007 lineto
0.72693 0.56036 lineto
0.72817 0.56006 lineto
0.72941 0.55921 lineto
0.73065 0.55787 lineto
0.73189 0.55612 lineto
0.73313 0.5541 lineto
0.73562 0.5498 lineto
0.73686 0.5478 lineto
0.7381 0.54608 lineto
0.73934 0.54477 lineto
0.74058 0.54393 lineto
0.74182 0.54362 lineto
0.74306 0.54386 lineto
0.7443 0.54463 lineto
0.74554 0.54587 lineto
0.74802 0.54939 lineto
0.7505 0.55349 lineto
0.75174 0.5554 lineto
0.75298 0.55706 lineto
0.75422 0.55835 lineto
0.75546 0.55919 lineto
0.7567 0.55952 lineto
0.75794 0.55932 lineto
0.75918 0.55861 lineto
0.76042 0.55743 lineto
0.7629 0.55404 lineto
0.76538 0.55006 lineto
0.76662 0.54817 lineto
Mistroke
0.76786 0.54652 lineto
0.7691 0.54523 lineto
0.77034 0.54438 lineto
0.77158 0.54402 lineto
0.77282 0.54419 lineto
0.77406 0.54486 lineto
0.7753 0.546 lineto
0.77778 0.54933 lineto
0.78026 0.55332 lineto
0.7815 0.55522 lineto
0.78274 0.55689 lineto
0.78398 0.55822 lineto
0.78522 0.55911 lineto
0.78646 0.5595 lineto
0.7877 0.55937 lineto
0.78894 0.55872 lineto
0.79018 0.55759 lineto
0.79266 0.55422 lineto
0.79514 0.55014 lineto
0.79638 0.54818 lineto
0.79762 0.54644 lineto
0.79886 0.54504 lineto
0.8001 0.54409 lineto
0.80134 0.54365 lineto
0.80258 0.54375 lineto
0.80382 0.54439 lineto
0.80506 0.54554 lineto
0.80754 0.54903 lineto
0.81002 0.55331 lineto
0.81126 0.5554 lineto
0.8125 0.55726 lineto
0.81374 0.55876 lineto
0.81498 0.55981 lineto
0.81622 0.56031 lineto
0.81746 0.56024 lineto
0.8187 0.55959 lineto
0.81994 0.55839 lineto
0.82242 0.55468 lineto
0.8249 0.55005 lineto
0.82614 0.54777 lineto
0.82738 0.54573 lineto
0.82862 0.54405 lineto
0.82986 0.54288 lineto
0.8311 0.54228 lineto
0.83234 0.54232 lineto
0.83358 0.543 lineto
0.83482 0.54429 lineto
0.8373 0.54837 lineto
0.83978 0.55354 lineto
0.84102 0.55611 lineto
Mistroke
0.84226 0.55844 lineto
0.8435 0.56037 lineto
0.84474 0.56175 lineto
0.84598 0.56247 lineto
0.84722 0.56247 lineto
0.84846 0.56174 lineto
0.8497 0.56029 lineto
0.85218 0.55562 lineto
0.85466 0.5496 lineto
0.8559 0.54657 lineto
0.85714 0.54379 lineto
0.85838 0.54147 lineto
0.85962 0.53978 lineto
0.86086 0.53886 lineto
0.8621 0.53881 lineto
0.86334 0.53964 lineto
0.86458 0.54135 lineto
0.86706 0.54698 lineto
0.86954 0.55441 lineto
0.87202 0.56174 lineto
0.87326 0.56472 lineto
0.8745 0.56693 lineto
0.87574 0.56818 lineto
0.87698 0.56832 lineto
0.87822 0.56731 lineto
0.87946 0.56514 lineto
0.88194 0.55774 lineto
0.88442 0.5477 lineto
0.8869 0.5375 lineto
0.88814 0.53325 lineto
0.88938 0.53002 lineto
0.89062 0.52813 lineto
0.89187 0.5278 lineto
0.89311 0.52921 lineto
0.89435 0.53238 lineto
0.89683 0.54369 lineto
0.89931 0.55982 lineto
0.90179 0.57713 lineto
0.90303 0.58471 lineto
0.90427 0.59071 lineto
0.90551 0.59444 lineto
0.90675 0.59526 lineto
0.90799 0.59262 lineto
0.90923 0.58603 lineto
0.91047 0.57514 lineto
0.91171 0.55975 lineto
0.91295 0.53981 lineto
0.91419 0.51543 lineto
0.91667 0.45464 lineto
0.92163 0.30189 lineto
Mistroke
0.92659 0.15159 lineto
0.92907 0.09348 lineto
0.93031 0.07065 lineto
0.93155 0.05231 lineto
0.93279 0.03853 lineto
0.93403 0.0292 lineto
0.93527 0.02405 lineto
0.93651 0.0227 lineto
0.93775 0.02462 lineto
0.93899 0.02922 lineto
0.94147 0.04385 lineto
0.94395 0.06128 lineto
0.94519 0.06952 lineto
0.94643 0.07677 lineto
0.94767 0.08268 lineto
0.94891 0.08698 lineto
0.95015 0.08953 lineto
0.95139 0.09031 lineto
0.95635 0.07884 lineto
0.95883 0.06847 lineto
0.96007 0.06335 lineto
0.96131 0.05873 lineto
0.96255 0.05488 lineto
0.96379 0.052 lineto
0.96503 0.05023 lineto
0.96627 0.04963 lineto
0.96751 0.05018 lineto
0.96875 0.05178 lineto
0.97123 0.05749 lineto
0.97371 0.06499 lineto
0.97619 0.07223 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
gsave
0.01 setlinewidth
0.02381 0.43037 moveto
0.02505 0.55172 lineto
0.02629 0.55172 lineto
0.02877 0.55172 lineto
0.03373 0.55172 lineto
0.04365 0.55172 lineto
0.06349 0.55172 lineto
0.10317 0.55172 lineto
0.14286 0.55172 lineto
0.18254 0.55172 lineto
0.22222 0.55172 lineto
0.2619 0.55172 lineto
0.28175 0.55172 lineto
0.30159 0.55172 lineto
0.31151 0.55172 lineto
0.31647 0.55172 lineto
0.31895 0.55172 lineto
0.32143 0.55172 lineto
0.32267 0.55172 lineto
0.32391 0.06632 lineto
0.32639 0.06632 lineto
0.33135 0.06632 lineto
0.34127 0.06632 lineto
0.38095 0.06632 lineto
0.42063 0.06632 lineto
0.46032 0.06632 lineto
0.5 0.06632 lineto
0.53968 0.06632 lineto
0.57937 0.06632 lineto
0.59921 0.06632 lineto
0.60913 0.06632 lineto
0.61409 0.06632 lineto
0.61657 0.06632 lineto
0.61905 0.06632 lineto
0.62029 0.06632 lineto
0.62153 0.06632 lineto
0.62277 0.55172 lineto
0.62401 0.55172 lineto
0.62897 0.55172 lineto
0.63889 0.55172 lineto
0.65873 0.55172 lineto
0.69841 0.55172 lineto
0.7381 0.55172 lineto
0.77778 0.55172 lineto
0.81746 0.55172 lineto
0.85714 0.55172 lineto
0.87698 0.55172 lineto
0.89683 0.55172 lineto
0.90675 0.55172 lineto
0.91171 0.55172 lineto
Mistroke
0.91419 0.55172 lineto
0.91667 0.55172 lineto
0.91915 0.55172 lineto
0.92039 0.55172 lineto
0.92163 0.30902 lineto
0.92659 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = special3; inactive; startGroup; Cclosed; preserveAspect; ]
Code to generate the animation
:[font = input; endGroup; preserveAspect; ]
sig = 0;
threewave = ( CPulse[Pi, t] -
			  CPulse[Pi, t - Pi] +
			  CPulse[Pi, t - 2 Pi] )  (Pi/4);
squarewaveplot =
	Plot[ threewave, {t, 0, 10},
		    PlotRange -> {-1, 1},
			PlotStyle -> Thickness[0.01],			
		    DisplayFunction -> Identity ];
For [ i = 1, i < 20, i += 2,
		sig += Sin[ t * i ] / i;
		sigplot = Plot[ sig, {t, 0, 10},
						DisplayFunction -> Identity ];
		Show[ sigplot, squarewaveplot,
			  PlotRange -> {-1, 1},
			  DisplayFunction :> $DisplayFunction ] ];
:[font = text; inactive; endGroup; endGroup; ]
The Fourier series effectively replicates the original function over all time.  The square wave here is defined for t in [0, 3 Pi].  Notice what happens at t = 3 Pi (which is approximately 9.4).  The Fourier series matches the periodic extension of the square wave on t in [9.5, 10].
:[font = subsection; inactive; startGroup; Cclosed; ]
Computing Fourier Series in Mathematica
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example 1
:[font = text; inactive; ]
	Consider the function x(t) defined in Mathematica  terms as
:[font = input; ]
x = 1 + 1/2 Cos[2 Pi t] + Cos[4 Pi t];
:[font = text; inactive; ]
Now, the Fourier Series terms could be computed using the definition, but it easier to obtain them from inspection because the frequencies in the cosine functions are already harmonically related.  The key is to remember that cos(t) can be rewritten as [ exp(-j t) + exp(j t) ] / 2.   Therefore, x(t) becomes
:[font = input; ]
xexp = 1 + 1/4 ( Exp[-2 Pi t] - Exp[2 Pi t] ) +
           1/2 ( Exp[-4 Pi t] - Exp[4 Pi t] );
:[font = text; inactive; ]
From inspection, the Fourier coefficients are
:[font = input; endGroup; ]
a[0] = 1;
a[1] = a[-1] = 1/4;
a[2] = a[-2] = 1/2;
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example 2
:[font = text; inactive; ]
	Now, consider the Fourier Series of y(t) = t for t in [0, T].  The Fourier coefficients can be generated directly from the formula:
:[font = input; startGroup; ]
ak = Integrate[t Exp[-I k w0 t], {t,0,T}] / T
:[font = output; inactive; output; endGroup; ]
(E^(-I*T*k*w0)*(1/(k^2*w0^2) + 
       (I*T)/(k*w0)) - 1/(k^2*w0^2))/T
;[o]
 -I T k w0    1      I T       1
E          (------ + ----) - ------
             2   2   k w0     2   2
            k  w0            k  w0
-----------------------------------
                 T
:[font = text; inactive; ]
Using a fundamental frequency of w0 = Pi rad/sec and setting the endpoint of the interval to be T = 2 sec,
:[font = input; startGroup; ]
unitak = ak /. { w0 -> Pi, T -> 2 }
:[font = output; inactive; output; endGroup; ]
(E^(-2*I*Pi*k)*(1/(Pi^2*k^2) + 
       (2*I)/(Pi*k)) - 1/(Pi^2*k^2))/2
;[o]
 -2 I Pi k    1      2 I       1
E          (------ + ----) - ------
              2  2   Pi k      2  2
            Pi  k            Pi  k
-----------------------------------
                 2
:[font = text; inactive; ]
The first 10 Fourier coefficients for these values of w0 and T are:
:[font = input; startGroup; ]
Table[ unitak, {k, 1, 10} ] 
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
{I/Pi, I/2/Pi, I/3/Pi, I/4/Pi, I/5/Pi, 
  I/6/Pi, I/7/Pi, I/8/Pi, I/9/Pi, I/10/Pi}
;[o]
     I   I   I   I   I   I   I   I   I
     -   -   -   -   -   -   -   -   --
 I   2   3   4   5   6   7   8   9   10
{--, --, --, --, --, --, --, --, --, --}
 Pi  Pi  Pi  Pi  Pi  Pi  Pi  Pi  Pi  Pi
:[font = section; inactive; startGroup; Cclosed; ]
The Discrete-Time Fourier Transform (DTFT)
:[font = text; inactive; ]
		Signals defined at equispaced time intervals are called sequences.  Many sequences can be represented by a Fourier integral of the form [Oppenheim & Schafer, 1989]
:[font = postscript; inactive; PostScript; output; pictureLeft = 98; pictureWidth = 203; pictureHeight = 44; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.216749 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.216749 scale
1 string
203 44 1 [203 0 0 44 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1F8E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000FFFFC0FFF03FFFFFFF
FFFE3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00001FFFC01F8007FC0000
FFFE07E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF1FFFFF03F038FFFFFF
FFFFC0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFF03F1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFC7E3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFC7E3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFE38FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFE000001FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF800003FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFE3FFC01FFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFC0000FFFFFFFFFFFFFFFFC7
1FFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFFFFFF
1FFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
E07FC0FC7FFFE07FC01FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFC000700003FE3FFFF000FFFFFFFFFFFFFFFFC7FF8007FFFFFFFFFFFF
FFFFFFFFFFFF03F03FFF81FF03FFFFFF80
FC0E001C7FFFE07FC0E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFF03FFC01FF03FFF803F1FFFFFFFFFFFFFFFC0FC01F8FFFFFFFFFFFF
FFFFFFFFFFC01C01C7FC0E38E07FFFFF80
FF8E07FC7FFFE07FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFE3FFC0FFF03FFF81FFE3FFFFFFFFFFFFFFC0FC0FFF1FFFFFFFFFFF
FFFFFFFFFFC0FF81FFFC0FF8FF81FFFF80
FF803FFC7FFFE07FC0FFF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFC7FC0FFF03FFF8007FFFFFFFFFFFFFFFFC0FC003FFFFFFFFFFFFF
FFFFFFFFFFC0FF81FFFC0FF8FF81FFFF80
FFF03FFC7FFFFC0FF81FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFF8E07FFF03FFF81F81FFFFFFFFFFFFFFFC0FC0FC0FFFFFFFFFFFF
FFFFFFFFFFC0FFF1FFFF81FF1FF03FFF80
FF8007FC7FFFFC01F81FF1FFFFFFFFFFFFFFE00000000000000007FFFFFF
1FFFFFFF8007FFF03FFFF1FF000FFFFFFFFFFFFFC0FF8FF8007FFFFFFFFF
FFFFFFFFFFF8FFF03FFF81FF1FF03FFF80
FF81C0FC7FFFFC0E001FF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFFF03FFFF03FFFF03F0071FFFFFFFFFFFFC0FF81F8038FFFFFFFFF
FFFFFFFFFFF81F803FFFFE3FFFFE3FFF80
FC01F81C7FFFE00FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFFF03FFFFE3FFFFFC01FF1FFFFFFFFFFFFC7FFFE00FF8FFFFFFFFF
FFFFFFFFFFFFE00E3FFFFE07FFF03FFF80
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFF8007FFFE3FFFFFFFFFFE3FFC0E07FFFFC7FFFFFFFFF1FFFFFE07
03FFF8FC0FFFFFFE3FFFFFFF1FF1FFFF80
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFF81F8FFFFC7FFFFFFFFFE3FE3F1F8FFFE3FFFFFFFFFF1FFFFF1F8
FC7FF8FC71FFFFFE07FFFFFFFFFFFFFF80
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFC01F81FFFC7FFFFFFFFFE3FFC7E3F1FFE3FFFFFFFFFF1FFFFFE3F
1F8FF8FC7FFFFFFE07FFFFFFFFFFFFFF80
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFC0FFF03FFF8FFFFFFFFFFC7FC7E3F1FF1FFFFFFFFFFFE3FFFFE3F
1F8FFF1F8FFFFFFE07FFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00003FFFFFFFFFFFFF
1FFFFF000038000FFFFFFFFFFFFFC7FF8FC7E3FFFFFFFFFFFFFE3FFFFFC7
E3F1FF1F8FFFFFF007FFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
1C7FFFFFFFFFFFFFFFFFFFFFFFFE07FFF1FF1FFFFFFFFFFFFFF03FFFFFF8
FF8FF8E07FFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
E07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFE3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
1F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
1F8E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFFFFFFFFF
E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFF
E07E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FC0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
where X( e^(jw) ) is given by
:[font = postscript; inactive; PostScript; output; pictureLeft = 113; pictureWidth = 167; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.281437 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.281437 scale
1 string
167 47 1 [167 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F03FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1C7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1F8000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E3FFFF
FFFFFFFFF0381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E38000
1F80001F8FC7E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE381FFFFF
FFFFFFFFF0381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000
000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00
000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFC7
FFFFFFE07FFFFFFFFF000FFFFFFFF8007FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFC7FFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFF
1FFFFFFC7FFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
E3FFFFFFFFFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
0001C0000FF8FFFFC003FFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
FC7FFFFFFFF81FF03F1FFFF81FF007FC7FF8007FFFFFFFFFFFFFFFFFFFFF
FFFFF8
FC0FFF007FC0FFFE00FC7FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FF8FFFFFFFFF0380071FFFF81FF038FC7FC01F8FFFFFFFFFFFFFFFFFFFFF
FFFFF8
FF8FFF03FFC0FFFE07FF8FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFF1FFFFFFFFE381FF1FFFF81FF03FFC7FC0FFF1FFFFFFFFFFFFFFFFFFFF
FFFFF8
FFF1FF03FFC0FFFE001FFFFFFFFFFFFFFFFF03FFF8000000FFFFFFFFFFFF
FFFE3FFFFFFFE00FFF1FFFF81FF03FFC7FC003FFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFE381FFFC0FFFE07E07FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFFE07FFFFFFFC0FFF1FFFFF03FE07FC7FC0FC0FFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFE001FFFC0FFFFC7FC003FFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFE001FF1FFFFF007E07FC7FF8FF8007FFFFFFFFFFFFFFFFFF
FFFFF8
FFFFC0FFFFC0FFFFC0FC01C7FFFFFFFFFFFF03FFF8000000FFFFFFFFFFFF
FF81FFFFFFFFE0703F1FFFFF038007FC7FF81F8038FFFFFFFFFFFFFFFFFF
FFFFF8
FFFFC0FFFFF8FFFFFF007FC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
FC0FFFFFFFFF007E071FFFF803F03FFC7FFFE00FF8FFFFFFFFFFFFFFFFFF
FFFFF8
FFFE001FFFF8FFFFFFFFFFF8FFF0381FFFFF1FFFFFFFFFFFFFFFFFFFFFFF
E07FFFFFFFFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFF1FFFFFE0703FFFFFC7
E07FF8
FFFE07E3FFFF1FFFFFFFFFF8FF8FC7E3FFF8FFFFFFFFFFFFFFFFFFFFFFFF
03FFFFFFFFFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFF1FFFFF1F8FC7FFFFC7
E38FF8
FFF007E07FFF1FFFFFFFFFF8FFF1F8FC7FF8FFFFFFFFFFFFFFFFFFFFFFF8
1FFFFFFC7FFFFFFFFF1FFFFFFFFFFFFC7FFFFFFFFF1FFFFFE3F1F8FFFFC7
E3FFF8
FFF03FFC0FFFE3FFFFFFFFFF1FF1F8FC7FC7FFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFC7FFFFFFFFF000FFFFFFFF8007FFFFFFFFFE3FFFFE3F1F8FFFFF8
FC7FF8
FC0000E0003FFFFFFFFFFFFF1FFE3F1F8FFFFFFFFFFFFFFFFFFFFFFFFE07
FFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFC7E3F1FFFF8
FC7FF8
FFFFFFFFFFFFFFFFFFFFFFF81FFFC7FC7FFFFFFFFFFFFFFFFFFFFFFFF000
000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF8FF8FFFFC7
03FFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1F8FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
These two equations form a Fourier representation for a certain class of sequences.  The first equation the inverse discrete-time Fourier transform (DTFT), so the second is the forward  DTFT.  The digital frequency domain is continuous and periodic with period 2 Pi.  In the inverse formula, then, the integration can actually be carried out over any interval of length 2 Pi.
:[font = text; inactive; ]
		Like its continuous-time counterpart, the DTFT is a complex-valued function of a real variable.  Such a function can be represented as a sum of real and imaginary components or as a product of a magnitude and a phase.  In polar form, the phase is not unique because adding any multiple of 2 Pi to it does not change the result of complex exponentiation.
:[font = text; inactive; ]
		Also like its continuous-time counterpart, the DTFT is a useful tool in analyzing linear time-invariant systems.  By representing inputs to such systems as a weighted sum of delayed impulses, the output can be represented as a weighted sum of delayed responses.  In fact, the output at any given time is simply a weighted sum of previous input and output samples.
:[font = subsection; inactive; startGroup; Cclosed; ]
Derivation of the DTFT from the CTFT
:[font = text; inactive; ]
		For the code in the following subsections to work, the following statement must be evaluated:
:[font = input; ]
Needs [ "SignalProcessing`Analog`" ]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Continuous Delta Train
:[font = info; inactive; startGroup; Cclosed; ]
-- Time Response of a Delta Train
:[font = input; startGroup; ]
T = 0.5;
x = Summation[m,-Infinity,Infinity,1][Delta[t-m(T)]];
SignalPlot[x, {t, -2, 5}]

:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.30159 0.13228 0.01472 0.5886 [
[(-2)] 0.03704 0.00222 0 1 Msboxa
[(-1)] 0.16931 0.00222 0 1 Msboxa
[(1)] 0.43386 0.00222 0 1 Msboxa
[(2)] 0.56614 0.00222 0 1 Msboxa
[(3)] 0.69841 0.00222 0 1 Msboxa
[(4)] 0.83069 0.00222 0 1 Msboxa
[(5)] 0.96296 0.00222 0 1 Msboxa
[(t)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.28909 0.13244 1 0 Msboxa
[(0.4)] 0.28909 0.25016 1 0 Msboxa
[(0.6)] 0.28909 0.36788 1 0 Msboxa
[(0.8)] 0.28909 0.4856 1 0 Msboxa
[(1)] 0.28909 0.60332 1 0 Msboxa
[( )] 0.30159 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.03704 0.00847 moveto
0.03704 0.02097 lineto
stroke
0 setgray
[(-2)] 0.03704 0.00222 0 1 Mshowa
0.16931 0.00847 moveto
0.16931 0.02097 lineto
stroke
0 setgray
[(-1)] 0.16931 0.00222 0 1 Mshowa
0.43386 0.00847 moveto
0.43386 0.02097 lineto
stroke
0 setgray
[(1)] 0.43386 0.00222 0 1 Mshowa
0.56614 0.00847 moveto
0.56614 0.02097 lineto
stroke
0 setgray
[(2)] 0.56614 0.00222 0 1 Mshowa
0.69841 0.00847 moveto
0.69841 0.02097 lineto
stroke
0 setgray
[(3)] 0.69841 0.00222 0 1 Mshowa
0.83069 0.00847 moveto
0.83069 0.02097 lineto
stroke
0 setgray
[(4)] 0.83069 0.00222 0 1 Mshowa
0.96296 0.00847 moveto
0.96296 0.02097 lineto
stroke
0 setgray
[(5)] 0.96296 0.00222 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.01472 -1 0 Mshowa
0.30159 0 moveto
0.30159 0.61803 lineto
stroke
0.29534 0.13244 moveto
0.30784 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.28909 0.13244 1 0 Mshowa
0.29534 0.25016 moveto
0.30784 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.28909 0.25016 1 0 Mshowa
0.29534 0.36788 moveto
0.30784 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.28909 0.36788 1 0 Mshowa
0.29534 0.4856 moveto
0.30784 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.28909 0.4856 1 0 Mshowa
0.29534 0.60332 moveto
0.30784 0.60332 lineto
stroke
0 setgray
[(1)] 0.28909 0.60332 1 0 Mshowa
0 setgray
[( )] 0.30159 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.03704 0.01472 moveto
0.07562 0.01472 lineto
0.1142 0.01472 lineto
0.15278 0.01472 lineto
0.19136 0.01472 lineto
0.22994 0.01472 lineto
0.26852 0.01472 lineto
0.3071 0.01472 lineto
0.34568 0.01472 lineto
0.38426 0.01472 lineto
0.42284 0.01472 lineto
0.46142 0.01472 lineto
0.5 0.01472 lineto
0.53858 0.01472 lineto
0.57716 0.01472 lineto
0.61574 0.01472 lineto
0.65432 0.01472 lineto
0.6929 0.01472 lineto
0.73148 0.01472 lineto
0.77006 0.01472 lineto
0.80864 0.01472 lineto
0.84722 0.01472 lineto
0.8858 0.01472 lineto
0.92438 0.01472 lineto
0.96296 0.01472 lineto
stroke
grestore
grestore
grestore
gsave
0.004 setlinewidth
0.96296 0.01472 moveto
0.96296 0.60332 lineto
0.94974 0.42674 lineto
0.97619 0.42674 lineto
0.96296 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.89683 0.01472 moveto
0.89683 0.60332 lineto
0.8836 0.42674 lineto
0.91005 0.42674 lineto
0.89683 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.83069 0.01472 moveto
0.83069 0.60332 lineto
0.81746 0.42674 lineto
0.84392 0.42674 lineto
0.83069 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.76455 0.01472 moveto
0.76455 0.60332 lineto
0.75132 0.42674 lineto
0.77778 0.42674 lineto
0.76455 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.69841 0.01472 moveto
0.69841 0.60332 lineto
0.68519 0.42674 lineto
0.71164 0.42674 lineto
0.69841 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.63228 0.01472 moveto
0.63228 0.60332 lineto
0.61905 0.42674 lineto
0.6455 0.42674 lineto
0.63228 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.56614 0.01472 moveto
0.56614 0.60332 lineto
0.55291 0.42674 lineto
0.57937 0.42674 lineto
0.56614 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
0.48677 0.42674 lineto
0.51323 0.42674 lineto
0.5 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.43386 0.01472 moveto
0.43386 0.60332 lineto
0.42063 0.42674 lineto
0.44709 0.42674 lineto
0.43386 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.36772 0.01472 moveto
0.36772 0.60332 lineto
0.3545 0.42674 lineto
0.38095 0.42674 lineto
0.36772 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.30159 0.01472 moveto
0.30159 0.60332 lineto
0.28836 0.42674 lineto
0.31481 0.42674 lineto
0.30159 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.23545 0.01472 moveto
0.23545 0.60332 lineto
0.22222 0.42674 lineto
0.24868 0.42674 lineto
0.23545 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.16931 0.01472 moveto
0.16931 0.60332 lineto
0.15608 0.42674 lineto
0.18254 0.42674 lineto
0.16931 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.10317 0.01472 moveto
0.10317 0.60332 lineto
0.08995 0.42674 lineto
0.1164 0.42674 lineto
0.10317 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.03704 0.01472 moveto
0.03704 0.60332 lineto
0.02381 0.42674 lineto
0.05026 0.42674 lineto
0.03704 0.60332 lineto
stroke
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.03704 0.01472 moveto
0.07562 0.01472 lineto
0.1142 0.01472 lineto
0.15278 0.01472 lineto
0.19136 0.01472 lineto
0.22994 0.01472 lineto
0.26852 0.01472 lineto
0.3071 0.01472 lineto
0.34568 0.01472 lineto
0.38426 0.01472 lineto
0.42284 0.01472 lineto
0.46142 0.01472 lineto
0.5 0.01472 lineto
0.53858 0.01472 lineto
0.57716 0.01472 lineto
0.61574 0.01472 lineto
0.65432 0.01472 lineto
0.6929 0.01472 lineto
0.73148 0.01472 lineto
0.77006 0.01472 lineto
0.80864 0.01472 lineto
0.84722 0.01472 lineto
0.8858 0.01472 lineto
0.92438 0.01472 lineto
0.96296 0.01472 lineto
stroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = info; inactive; startGroup; Cclosed; ]
-- Frequency Response of Delta Train 
:[font = text; inactive; ]
		Note that the transform of an "Train" of Delta Functions is the same Delta train scaled in both magnitude and frequency.  The Delta functions are now spaced a distance of 2Pi/T or 2Pi/0.5 = 12.57 radians.  The magnitude is scaled by 1/T or 1/0.5, which equals two.  (Note this is a scaling factor and will not be reflected in the plot of the Deltas.)
:[font = input; startGroup; ]
T = 0.5;
x = Summation[m,-Infinity,Infinity,1][Delta[t-m(T)]];
 SignalPlot[ TheFunction[CTFTransform[x, t, w]],
		           {w, -30 Pi, 30 Pi}] 

:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.00505 0.01472 0.5886 [
[(Signal Plot)] 0.5 0.62428 0 -1 Msboxa
[(-75)] 0.12106 0.00222 0 1 Msboxa
[(-50)] 0.24737 0.00222 0 1 Msboxa
[(-25)] 0.37369 0.00222 0 1 Msboxa
[(25)] 0.62631 0.00222 0 1 Msboxa
[(50)] 0.75263 0.00222 0 1 Msboxa
[(75)] 0.87894 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.4875 0.13244 1 0 Msboxa
[(0.4)] 0.4875 0.25016 1 0 Msboxa
[(0.6)] 0.4875 0.36788 1 0 Msboxa
[(0.8)] 0.4875 0.4856 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Signal Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.12106 0.00847 moveto
0.12106 0.02097 lineto
stroke
0 setgray
[(-75)] 0.12106 0.00222 0 1 Mshowa
0.24737 0.00847 moveto
0.24737 0.02097 lineto
stroke
0 setgray
[(-50)] 0.24737 0.00222 0 1 Mshowa
0.37369 0.00847 moveto
0.37369 0.02097 lineto
stroke
0 setgray
[(-25)] 0.37369 0.00222 0 1 Mshowa
0.62631 0.00847 moveto
0.62631 0.02097 lineto
stroke
0 setgray
[(25)] 0.62631 0.00222 0 1 Mshowa
0.75263 0.00847 moveto
0.75263 0.02097 lineto
stroke
0 setgray
[(50)] 0.75263 0.00222 0 1 Mshowa
0.87894 0.00847 moveto
0.87894 0.02097 lineto
stroke
0 setgray
[(75)] 0.87894 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
gsave
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
0.49949 0.42674 lineto
0.50051 0.42674 lineto
0.5 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.94444 0.01472 moveto
0.94444 0.60332 lineto
0.94394 0.42674 lineto
0.94495 0.42674 lineto
0.94444 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.88095 0.01472 moveto
0.88095 0.60332 lineto
0.88045 0.42674 lineto
0.88146 0.42674 lineto
0.88095 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.81746 0.01472 moveto
0.81746 0.60332 lineto
0.81696 0.42674 lineto
0.81797 0.42674 lineto
0.81746 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.75397 0.01472 moveto
0.75397 0.60332 lineto
0.75346 0.42674 lineto
0.75447 0.42674 lineto
0.75397 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.69048 0.01472 moveto
0.69048 0.60332 lineto
0.68997 0.42674 lineto
0.69098 0.42674 lineto
0.69048 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.62698 0.01472 moveto
0.62698 0.60332 lineto
0.62648 0.42674 lineto
0.62749 0.42674 lineto
0.62698 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.56349 0.01472 moveto
0.56349 0.60332 lineto
0.56299 0.42674 lineto
0.564 0.42674 lineto
0.56349 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.43651 0.01472 moveto
0.43651 0.60332 lineto
0.436 0.42674 lineto
0.43701 0.42674 lineto
0.43651 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.37302 0.01472 moveto
0.37302 0.60332 lineto
0.37251 0.42674 lineto
0.37352 0.42674 lineto
0.37302 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.30952 0.01472 moveto
0.30952 0.60332 lineto
0.30902 0.42674 lineto
0.31003 0.42674 lineto
0.30952 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.24603 0.01472 moveto
0.24603 0.60332 lineto
0.24553 0.42674 lineto
0.24654 0.42674 lineto
0.24603 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.18254 0.01472 moveto
0.18254 0.60332 lineto
0.18203 0.42674 lineto
0.18304 0.42674 lineto
0.18254 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.11905 0.01472 moveto
0.11905 0.60332 lineto
0.11854 0.42674 lineto
0.11955 0.42674 lineto
0.11905 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.05556 0.01472 moveto
0.05556 0.60332 lineto
0.05505 0.42674 lineto
0.05606 0.42674 lineto
0.05556 0.60332 lineto
stroke
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Explanation and Relationship to CTFT
:[font = text; inactive; ]
		The last section showed that the transform of a train of Delta functions is the same train of Delta functions scaled in magnitude and frequency.  Combining this fact with the convolution property, we will illustrate the relationship between the CTFT and the DTFT using the example of the continuous time pulse.
:[font = text; inactive; ]
		Since the DTFT operates on discrete-time functions, we can convert a continuous-time function to discrete-time by sampling it with an impulse train.   Since multiplication in the time domain is analogous to convolution in the frequency domain, the Fourier Transform of the continuous pulse is convolved with the transformed Delta Function Train.
:[font = text; inactive; ]
		Convolution of any function with a single shifted Delta Function simply results in the original function shifted.  Therefore, a function convolved with a train of Delta Functions (such that each Delta is shifted by 2Pi/T) yields the original function replicated every 2Pi/T.  Therefore, the transform of any sampled function is merely the transform of the original function, scaled by 1/T, and repeated every 2Pi/T.
:[font = text; inactive; endGroup; ]
		How does the DTFT relate to this?  It just has  frequency scale normalized to 2Pi.  If w/T is substituted for W (the continuous FT frequency variable), the original transform will be repeated every 2 Pi. 
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Time Response of Continuous Pulse
:[font = input; startGroup; ]
x = CPulse[3,t+1.5];
SignalPlot[x,{t,-5,5}]
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.09524 0.01472 0.5886 [
[(Signal Plot)] 0.5 0.62428 0 -1 Msboxa
[(-4)] 0.11905 0.00222 0 1 Msboxa
[(-2)] 0.30952 0.00222 0 1 Msboxa
[(2)] 0.69048 0.00222 0 1 Msboxa
[(4)] 0.88095 0.00222 0 1 Msboxa
[(t)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.4875 0.13244 1 0 Msboxa
[(0.4)] 0.4875 0.25016 1 0 Msboxa
[(0.6)] 0.4875 0.36788 1 0 Msboxa
[(0.8)] 0.4875 0.4856 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Signal Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.11905 0.00847 moveto
0.11905 0.02097 lineto
stroke
0 setgray
[(-4)] 0.11905 0.00222 0 1 Mshowa
0.30952 0.00847 moveto
0.30952 0.02097 lineto
stroke
0 setgray
[(-2)] 0.30952 0.00222 0 1 Mshowa
0.69048 0.00847 moveto
0.69048 0.02097 lineto
stroke
0 setgray
[(2)] 0.69048 0.00222 0 1 Mshowa
0.88095 0.00847 moveto
0.88095 0.02097 lineto
stroke
0 setgray
[(4)] 0.88095 0.00222 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.32143 0.01472 lineto
0.33135 0.01472 lineto
0.34127 0.01472 lineto
0.35119 0.01472 lineto
0.35367 0.01472 lineto
0.35491 0.01472 lineto
0.35615 0.01472 lineto
0.35739 0.60332 lineto
0.35863 0.60332 lineto
0.35987 0.60332 lineto
0.36111 0.60332 lineto
0.38095 0.60332 lineto
0.42063 0.60332 lineto
0.46032 0.60332 lineto
0.5 0.60332 lineto
0.53968 0.60332 lineto
0.57937 0.60332 lineto
0.59921 0.60332 lineto
0.61905 0.60332 lineto
0.62897 0.60332 lineto
0.63393 0.60332 lineto
0.63641 0.60332 lineto
0.63889 0.60332 lineto
0.64013 0.60332 lineto
0.64137 0.60332 lineto
0.64261 0.60332 lineto
0.64385 0.01472 lineto
0.64509 0.01472 lineto
0.64633 0.01472 lineto
0.64881 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Frequency Response of Continuous Pulse
:[font = input; startGroup; ]
x = CPulse[3,t+1.5];
 SignalPlot[ TheFunction[CTFTransform[x, t, w]],
		           {w, -4Pi, 4Pi}] 
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.03789 0.11974 0.16119 [
[(Signal Plot)] 0.5 0.62428 0 -1 Msboxa
[(-10)] 0.12106 0.10724 0 1 Msboxa
[(-5)] 0.31053 0.10724 0 1 Msboxa
[(5)] 0.68947 0.10724 0 1 Msboxa
[(10)] 0.87894 0.10724 0 1 Msboxa
[(w)] 1.00625 0.11974 -1 0 Msboxa
[(-0.5)] 0.4875 0.03914 1 0 Msboxa
[(0.5)] 0.4875 0.20034 1 0 Msboxa
[(1)] 0.4875 0.28093 1 0 Msboxa
[(1.5)] 0.4875 0.36153 1 0 Msboxa
[(2)] 0.4875 0.44213 1 0 Msboxa
[(2.5)] 0.4875 0.52272 1 0 Msboxa
[(3)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Signal Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.11974 moveto
1 0.11974 lineto
stroke
0.12106 0.11349 moveto
0.12106 0.12599 lineto
stroke
0 setgray
[(-10)] 0.12106 0.10724 0 1 Mshowa
0.31053 0.11349 moveto
0.31053 0.12599 lineto
stroke
0 setgray
[(-5)] 0.31053 0.10724 0 1 Mshowa
0.68947 0.11349 moveto
0.68947 0.12599 lineto
stroke
0 setgray
[(5)] 0.68947 0.10724 0 1 Mshowa
0.87894 0.11349 moveto
0.87894 0.12599 lineto
stroke
0 setgray
[(10)] 0.87894 0.10724 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.11974 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.03914 moveto
0.50625 0.03914 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.03914 1 0 Mshowa
0.49375 0.20034 moveto
0.50625 0.20034 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.20034 1 0 Mshowa
0.49375 0.28093 moveto
0.50625 0.28093 lineto
stroke
0 setgray
[(1)] 0.4875 0.28093 1 0 Mshowa
0.49375 0.36153 moveto
0.50625 0.36153 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.36153 1 0 Mshowa
0.49375 0.44213 moveto
0.50625 0.44213 lineto
stroke
0 setgray
[(2)] 0.4875 0.44213 1 0 Mshowa
0.49375 0.52272 moveto
0.50625 0.52272 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.52272 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(3)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.11974 moveto
0.03373 0.10971 lineto
0.04365 0.10081 lineto
0.04861 0.09724 lineto
0.05109 0.09574 lineto
0.05357 0.09446 lineto
0.05605 0.09341 lineto
0.05729 0.09297 lineto
0.05853 0.0926 lineto
0.05977 0.09229 lineto
0.06101 0.09204 lineto
0.06225 0.09186 lineto
0.06349 0.09175 lineto
0.10317 0.11974 lineto
0.1131 0.13182 lineto
0.12302 0.14265 lineto
0.12798 0.14704 lineto
0.13046 0.14889 lineto
0.13294 0.15049 lineto
0.13542 0.1518 lineto
0.13666 0.15235 lineto
0.1379 0.15283 lineto
0.13914 0.15323 lineto
0.14038 0.15355 lineto
0.14162 0.15379 lineto
0.14286 0.15394 lineto
0.18254 0.11974 lineto
0.19246 0.10454 lineto
0.20238 0.09071 lineto
0.20734 0.08503 lineto
0.20982 0.08261 lineto
0.2123 0.08051 lineto
0.21478 0.07875 lineto
0.21726 0.07736 lineto
0.2185 0.07681 lineto
0.21974 0.07636 lineto
0.22098 0.07601 lineto
0.22222 0.07576 lineto
0.22346 0.07561 lineto
0.2247 0.07558 lineto
0.22594 0.07564 lineto
0.22718 0.07582 lineto
0.22842 0.0761 lineto
0.22966 0.07649 lineto
0.23214 0.0776 lineto
0.23462 0.07914 lineto
0.2371 0.0811 lineto
0.24206 0.08625 lineto
0.24702 0.09291 lineto
0.25198 0.10089 lineto
Mistroke
0.2619 0.11974 lineto
0.27183 0.14023 lineto
0.28175 0.15932 lineto
0.28671 0.16736 lineto
0.29167 0.17391 lineto
0.29415 0.17653 lineto
0.29663 0.17865 lineto
0.29787 0.17952 lineto
0.29911 0.18026 lineto
0.30035 0.18085 lineto
0.30159 0.18131 lineto
0.30283 0.18162 lineto
0.30407 0.18179 lineto
0.30531 0.18181 lineto
0.30655 0.18168 lineto
0.30779 0.18139 lineto
0.30903 0.18095 lineto
0.31027 0.18036 lineto
0.31151 0.17962 lineto
0.31399 0.17766 lineto
0.31647 0.17508 lineto
0.32143 0.16811 lineto
0.32639 0.15883 lineto
0.33135 0.14746 lineto
0.34127 0.11974 lineto
0.36111 0.05754 lineto
0.37103 0.03222 lineto
0.37599 0.02312 lineto
0.37847 0.0197 lineto
0.37971 0.0183 lineto
0.38095 0.01712 lineto
0.38219 0.01616 lineto
0.38343 0.01544 lineto
0.38467 0.01496 lineto
0.38591 0.01472 lineto
0.38715 0.01473 lineto
0.38839 0.01499 lineto
0.38963 0.01552 lineto
0.39087 0.01631 lineto
0.39211 0.01738 lineto
0.39335 0.01871 lineto
0.39583 0.02222 lineto
0.39831 0.02687 lineto
0.40079 0.03266 lineto
0.40575 0.04772 lineto
0.41071 0.06738 lineto
0.42063 0.11974 lineto
0.44048 0.26486 lineto
0.46032 0.4276 lineto
0.47024 0.49897 lineto
Mistroke
0.4752 0.5293 lineto
0.48016 0.55511 lineto
0.48512 0.57583 lineto
0.4876 0.58413 lineto
0.49008 0.59099 lineto
0.49256 0.59636 lineto
0.4938 0.59848 lineto
0.49504 0.60022 lineto
0.49628 0.60157 lineto
0.49752 0.60254 lineto
0.49876 0.60312 lineto
0.5 0.60332 lineto
0.50124 0.60312 lineto
0.50248 0.60254 lineto
0.50372 0.60157 lineto
0.50496 0.60022 lineto
0.50744 0.59636 lineto
0.50992 0.59099 lineto
0.51488 0.57583 lineto
0.51984 0.55511 lineto
0.52976 0.49897 lineto
0.53968 0.4276 lineto
0.55952 0.26486 lineto
0.56944 0.18706 lineto
0.57937 0.11974 lineto
0.58433 0.09147 lineto
0.58929 0.06738 lineto
0.59425 0.04772 lineto
0.59673 0.03961 lineto
0.59921 0.03266 lineto
0.60169 0.02687 lineto
0.60417 0.02222 lineto
0.60541 0.02033 lineto
0.60665 0.01871 lineto
0.60789 0.01738 lineto
0.60913 0.01631 lineto
0.61037 0.01552 lineto
0.61161 0.01499 lineto
0.61285 0.01473 lineto
0.61409 0.01472 lineto
0.61533 0.01496 lineto
0.61657 0.01544 lineto
0.61781 0.01616 lineto
0.61905 0.01712 lineto
0.62153 0.0197 lineto
0.62401 0.02312 lineto
0.62897 0.03222 lineto
0.63889 0.05754 lineto
0.65873 0.11974 lineto
0.66865 0.14746 lineto
Mistroke
0.67361 0.15883 lineto
0.67857 0.16811 lineto
0.68105 0.1719 lineto
0.68353 0.17508 lineto
0.68601 0.17766 lineto
0.68725 0.17872 lineto
0.68849 0.17962 lineto
0.68973 0.18036 lineto
0.69097 0.18095 lineto
0.69221 0.18139 lineto
0.69345 0.18168 lineto
0.69469 0.18181 lineto
0.69593 0.18179 lineto
0.69717 0.18162 lineto
0.69841 0.18131 lineto
0.70089 0.18026 lineto
0.70213 0.17952 lineto
0.70337 0.17865 lineto
0.70833 0.17391 lineto
0.71329 0.16736 lineto
0.71825 0.15932 lineto
0.7381 0.11974 lineto
0.74802 0.10089 lineto
0.75298 0.09291 lineto
0.75794 0.08625 lineto
0.76042 0.08348 lineto
0.7629 0.0811 lineto
0.76538 0.07914 lineto
0.76786 0.0776 lineto
0.77034 0.07649 lineto
0.77158 0.0761 lineto
0.77282 0.07582 lineto
0.77406 0.07564 lineto
0.7753 0.07558 lineto
0.77654 0.07561 lineto
0.77778 0.07576 lineto
0.77902 0.07601 lineto
0.78026 0.07636 lineto
0.7815 0.07681 lineto
0.78274 0.07736 lineto
0.78522 0.07875 lineto
0.7877 0.08051 lineto
0.79266 0.08503 lineto
0.79762 0.09071 lineto
0.81746 0.11974 lineto
0.82738 0.13402 lineto
0.83234 0.14016 lineto
0.8373 0.14535 lineto
0.83978 0.14753 lineto
0.84226 0.14942 lineto
Mistroke
0.84474 0.15099 lineto
0.84722 0.15224 lineto
0.84846 0.15275 lineto
0.8497 0.15317 lineto
0.85094 0.15351 lineto
0.85218 0.15376 lineto
0.85342 0.15393 lineto
0.85466 0.15402 lineto
0.8559 0.15402 lineto
0.85714 0.15394 lineto
0.89683 0.11974 lineto
0.90675 0.10824 lineto
0.91171 0.10325 lineto
0.91667 0.09901 lineto
0.92163 0.09565 lineto
0.92411 0.09433 lineto
0.92659 0.09328 lineto
0.92783 0.09285 lineto
0.92907 0.09249 lineto
0.93031 0.0922 lineto
0.93155 0.09197 lineto
0.93279 0.09182 lineto
0.93403 0.09173 lineto
0.93527 0.09171 lineto
0.93651 0.09175 lineto
0.97619 0.11974 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.02381 0.11974 moveto
0.06349 0.11974 lineto
0.10317 0.11974 lineto
0.14286 0.11974 lineto
0.18254 0.11974 lineto
0.22222 0.11974 lineto
0.2619 0.11974 lineto
0.30159 0.11974 lineto
0.34127 0.11974 lineto
0.38095 0.11974 lineto
0.42063 0.11974 lineto
0.46032 0.11974 lineto
0.5 0.11974 lineto
0.53968 0.11974 lineto
0.57937 0.11974 lineto
0.61905 0.11974 lineto
0.65873 0.11974 lineto
0.69841 0.11974 lineto
0.7381 0.11974 lineto
0.77778 0.11974 lineto
0.81746 0.11974 lineto
0.85714 0.11974 lineto
0.89683 0.11974 lineto
0.93651 0.11974 lineto
0.97619 0.11974 lineto
stroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Time Response of Continuous Pulse Times the Delta Train
:[font = input; startGroup; ]
T = 0.5;
x = Summation[m,-Infinity,Infinity,1][Delta[t-m(T)] *
                      CPulse[3,t+1.5] ];
 SignalPlot[x,{t, -5,5}] 

:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.09524 0.01472 0.5886 [
[(Signal Plot)] 0.5 0.62428 0 -1 Msboxa
[(-4)] 0.11905 0.00222 0 1 Msboxa
[(-2)] 0.30952 0.00222 0 1 Msboxa
[(2)] 0.69048 0.00222 0 1 Msboxa
[(4)] 0.88095 0.00222 0 1 Msboxa
[(t)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.4875 0.13244 1 0 Msboxa
[(0.4)] 0.4875 0.25016 1 0 Msboxa
[(0.6)] 0.4875 0.36788 1 0 Msboxa
[(0.8)] 0.4875 0.4856 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Signal Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.11905 0.00847 moveto
0.11905 0.02097 lineto
stroke
0 setgray
[(-4)] 0.11905 0.00222 0 1 Mshowa
0.30952 0.00847 moveto
0.30952 0.02097 lineto
stroke
0 setgray
[(-2)] 0.30952 0.00222 0 1 Mshowa
0.69048 0.00847 moveto
0.69048 0.02097 lineto
stroke
0 setgray
[(2)] 0.69048 0.00222 0 1 Mshowa
0.88095 0.00847 moveto
0.88095 0.02097 lineto
stroke
0 setgray
[(4)] 0.88095 0.00222 0 1 Mshowa
0 setgray
[(t)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
gsave
0.004 setlinewidth
0.64286 0.01472 moveto
0.64286 0.60332 lineto
0.63333 0.42674 lineto
0.65238 0.42674 lineto
0.64286 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.59524 0.01472 moveto
0.59524 0.60332 lineto
0.58571 0.42674 lineto
0.60476 0.42674 lineto
0.59524 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.54762 0.01472 moveto
0.54762 0.60332 lineto
0.5381 0.42674 lineto
0.55714 0.42674 lineto
0.54762 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
0.49048 0.42674 lineto
0.50952 0.42674 lineto
0.5 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.45238 0.01472 moveto
0.45238 0.60332 lineto
0.44286 0.42674 lineto
0.4619 0.42674 lineto
0.45238 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.40476 0.01472 moveto
0.40476 0.60332 lineto
0.39524 0.42674 lineto
0.41429 0.42674 lineto
0.40476 0.60332 lineto
stroke
grestore
gsave
0.004 setlinewidth
0.35714 0.01472 moveto
0.35714 0.60332 lineto
0.34762 0.42674 lineto
0.36667 0.42674 lineto
0.35714 0.60332 lineto
stroke
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Frequency Response of Pulse Convolved with the Delta Train
:[font = message; inactive; ]
Note: This is not Working
:[font = input; startGroup; ]
T = 0.5;
x = CPulse[3, t+1.5] *
    Summation[m,-Infinity,Infinity,1]
             [Delta[t - m T]];
SignalPlot[ TheFunction[CTFTransform[x, t, w]],
		     {w, -10 Pi, 10 Pi}]
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
$Interrupted
;[o]
$Interrupted
:[font = subsection; inactive; startGroup; Cclosed; ]
The DTFT of Sinusoids
:[font = text; inactive; startGroup; ]
		This section gives two examples of the computing the DTFT of sinusoids.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example #1:  Increasing Frequencies
:[font = text; inactive; ]
		In this example, the DTFT will be computed for input signals of increasing frequencies.  Sinc functions will be used. It should be observed that the higher the frequency, the more spread-out the signal becomes in the frequency domain:
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.11936 0.48396 [
[(Sequence Plot \(frequency = Pi/10 rad\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.10686 0 1 Msboxa
[(40)] 0.40476 0.10686 0 1 Msboxa
[(60)] 0.59524 0.10686 0 1 Msboxa
[(80)] 0.78571 0.10686 0 1 Msboxa
[(100)] 0.97619 0.10686 0 1 Msboxa
[(n)] 1.00625 0.11936 -1 0 Msboxa
[(-0.2)] 0.01131 0.02257 1 0 Msboxa
[(0.2)] 0.01131 0.21615 1 0 Msboxa
[(0.4)] 0.01131 0.31295 1 0 Msboxa
[(0.6)] 0.01131 0.40974 1 0 Msboxa
[(0.8)] 0.01131 0.50653 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot \(frequency = Pi/10 rad\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.11936 moveto
1 0.11936 lineto
stroke
0.21429 0.11311 moveto
0.21429 0.12561 lineto
stroke
0 setgray
[(20)] 0.21429 0.10686 0 1 Mshowa
0.40476 0.11311 moveto
0.40476 0.12561 lineto
stroke
0 setgray
[(40)] 0.40476 0.10686 0 1 Mshowa
0.59524 0.11311 moveto
0.59524 0.12561 lineto
stroke
0 setgray
[(60)] 0.59524 0.10686 0 1 Mshowa
0.78571 0.11311 moveto
0.78571 0.12561 lineto
stroke
0 setgray
[(80)] 0.78571 0.10686 0 1 Mshowa
0.97619 0.11311 moveto
0.97619 0.12561 lineto
stroke
0 setgray
[(100)] 0.97619 0.10686 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.11936 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.02257 moveto
0.03006 0.02257 lineto
stroke
0 setgray
[(-0.2)] 0.01131 0.02257 1 0 Mshowa
0.01756 0.21615 moveto
0.03006 0.21615 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.21615 1 0 Mshowa
0.01756 0.31295 moveto
0.03006 0.31295 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.31295 1 0 Mshowa
0.01756 0.40974 moveto
0.03006 0.40974 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.40974 1 0 Mshowa
0.01756 0.50653 moveto
0.03006 0.50653 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.50653 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.11936 moveto
0.02381 0.60332 lineto
stroke
0.008 setlinewidth
0.02381 0.60332 Mdot
0.004 setlinewidth
0.03333 0.11936 moveto
0.03333 0.5954 lineto
stroke
0.008 setlinewidth
0.03333 0.5954 Mdot
0.004 setlinewidth
0.04286 0.11936 moveto
0.04286 0.5721 lineto
stroke
0.008 setlinewidth
0.04286 0.5721 Mdot
0.004 setlinewidth
0.05238 0.11936 moveto
0.05238 0.53479 lineto
stroke
0.008 setlinewidth
0.05238 0.53479 Mdot
0.004 setlinewidth
0.0619 0.11936 moveto
0.0619 0.48563 lineto
stroke
0.008 setlinewidth
0.0619 0.48563 Mdot
0.004 setlinewidth
0.07143 0.11936 moveto
0.07143 0.42746 lineto
stroke
0.008 setlinewidth
0.07143 0.42746 Mdot
0.004 setlinewidth
0.08095 0.11936 moveto
0.08095 0.36354 lineto
stroke
0.008 setlinewidth
0.08095 0.36354 Mdot
0.004 setlinewidth
0.09048 0.11936 moveto
0.09048 0.2974 lineto
stroke
0.008 setlinewidth
0.09048 0.2974 Mdot
0.004 setlinewidth
0.1 0.11936 moveto
0.1 0.23255 lineto
stroke
0.008 setlinewidth
0.1 0.23255 Mdot
0.004 setlinewidth
0.10952 0.11936 moveto
0.10952 0.17226 lineto
stroke
0.008 setlinewidth
0.10952 0.17226 Mdot
0.004 setlinewidth
0.11905 0.11936 moveto
0.11905 0.11936 lineto
stroke
0.008 setlinewidth
0.11905 0.11936 Mdot
0.004 setlinewidth
0.12857 0.11936 moveto
0.12857 0.07609 lineto
stroke
0.008 setlinewidth
0.12857 0.07609 Mdot
0.004 setlinewidth
0.1381 0.11936 moveto
0.1381 0.04391 lineto
stroke
0.008 setlinewidth
0.1381 0.04391 Mdot
0.004 setlinewidth
0.14762 0.11936 moveto
0.14762 0.0235 lineto
stroke
0.008 setlinewidth
0.14762 0.0235 Mdot
0.004 setlinewidth
0.15714 0.11936 moveto
0.15714 0.01472 lineto
stroke
0.008 setlinewidth
0.15714 0.01472 Mdot
0.004 setlinewidth
0.16667 0.11936 moveto
0.16667 0.01667 lineto
stroke
0.008 setlinewidth
0.16667 0.01667 Mdot
0.004 setlinewidth
0.17619 0.11936 moveto
0.17619 0.0278 lineto
stroke
0.008 setlinewidth
0.17619 0.0278 Mdot
0.004 setlinewidth
0.18571 0.11936 moveto
0.18571 0.04605 lineto
stroke
0.008 setlinewidth
0.18571 0.04605 Mdot
0.004 setlinewidth
0.19524 0.11936 moveto
0.19524 0.06906 lineto
stroke
0.008 setlinewidth
0.19524 0.06906 Mdot
0.004 setlinewidth
0.20476 0.11936 moveto
0.20476 0.09431 lineto
stroke
0.008 setlinewidth
0.20476 0.09431 Mdot
0.004 setlinewidth
0.21429 0.11936 moveto
0.21429 0.11936 lineto
stroke
0.008 setlinewidth
0.21429 0.11936 Mdot
0.004 setlinewidth
0.22381 0.11936 moveto
0.22381 0.14203 lineto
stroke
0.008 setlinewidth
0.22381 0.14203 Mdot
0.004 setlinewidth
0.23333 0.11936 moveto
0.23333 0.16052 lineto
stroke
0.008 setlinewidth
0.23333 0.16052 Mdot
0.004 setlinewidth
0.24286 0.11936 moveto
0.24286 0.17355 lineto
stroke
0.008 setlinewidth
0.24286 0.17355 Mdot
0.004 setlinewidth
0.25238 0.11936 moveto
0.25238 0.18041 lineto
stroke
0.008 setlinewidth
0.25238 0.18041 Mdot
0.004 setlinewidth
0.2619 0.11936 moveto
0.2619 0.18098 lineto
stroke
0.008 setlinewidth
0.2619 0.18098 Mdot
0.004 setlinewidth
0.27143 0.11936 moveto
0.27143 0.17571 lineto
stroke
0.008 setlinewidth
0.27143 0.17571 Mdot
0.004 setlinewidth
0.28095 0.11936 moveto
0.28095 0.16552 lineto
stroke
0.008 setlinewidth
0.28095 0.16552 Mdot
0.004 setlinewidth
0.29048 0.11936 moveto
0.29048 0.1517 lineto
stroke
0.008 setlinewidth
0.29048 0.1517 Mdot
0.004 setlinewidth
0.3 0.11936 moveto
0.3 0.13578 lineto
stroke
0.008 setlinewidth
0.3 0.13578 Mdot
0.004 setlinewidth
0.30952 0.11936 moveto
0.30952 0.11936 lineto
stroke
0.008 setlinewidth
0.30952 0.11936 Mdot
0.004 setlinewidth
0.31905 0.11936 moveto
0.31905 0.10401 lineto
stroke
0.008 setlinewidth
0.31905 0.10401 Mdot
0.004 setlinewidth
0.32857 0.11936 moveto
0.32857 0.09107 lineto
stroke
0.008 setlinewidth
0.32857 0.09107 Mdot
0.004 setlinewidth
0.3381 0.11936 moveto
0.3381 0.0816 lineto
stroke
0.008 setlinewidth
0.3381 0.0816 Mdot
0.004 setlinewidth
0.34762 0.11936 moveto
0.34762 0.07627 lineto
stroke
0.008 setlinewidth
0.34762 0.07627 Mdot
0.004 setlinewidth
0.35714 0.11936 moveto
0.35714 0.07535 lineto
stroke
0.008 setlinewidth
0.35714 0.07535 Mdot
0.004 setlinewidth
0.36667 0.11936 moveto
0.36667 0.07867 lineto
stroke
0.008 setlinewidth
0.36667 0.07867 Mdot
0.004 setlinewidth
0.37619 0.11936 moveto
0.37619 0.08568 lineto
stroke
0.008 setlinewidth
0.37619 0.08568 Mdot
0.004 setlinewidth
0.38571 0.11936 moveto
0.38571 0.09554 lineto
stroke
0.008 setlinewidth
0.38571 0.09554 Mdot
0.004 setlinewidth
0.39524 0.11936 moveto
0.39524 0.10716 lineto
stroke
0.008 setlinewidth
0.39524 0.10716 Mdot
0.004 setlinewidth
0.40476 0.11936 moveto
0.40476 0.11936 lineto
stroke
0.008 setlinewidth
0.40476 0.11936 Mdot
0.004 setlinewidth
0.41429 0.11936 moveto
0.41429 0.13097 lineto
stroke
0.008 setlinewidth
0.41429 0.13097 Mdot
0.004 setlinewidth
0.42381 0.11936 moveto
0.42381 0.14092 lineto
stroke
0.008 setlinewidth
0.42381 0.14092 Mdot
0.004 setlinewidth
0.43333 0.11936 moveto
0.43333 0.14835 lineto
stroke
0.008 setlinewidth
0.43333 0.14835 Mdot
0.004 setlinewidth
0.44286 0.11936 moveto
0.44286 0.15266 lineto
stroke
0.008 setlinewidth
0.44286 0.15266 Mdot
0.004 setlinewidth
0.45238 0.11936 moveto
0.45238 0.1536 lineto
stroke
0.008 setlinewidth
0.45238 0.1536 Mdot
0.004 setlinewidth
0.4619 0.11936 moveto
0.4619 0.15121 lineto
stroke
0.008 setlinewidth
0.4619 0.15121 Mdot
0.004 setlinewidth
0.47143 0.11936 moveto
0.47143 0.14588 lineto
stroke
0.008 setlinewidth
0.47143 0.14588 Mdot
0.004 setlinewidth
0.48095 0.11936 moveto
0.48095 0.13823 lineto
stroke
0.008 setlinewidth
0.48095 0.13823 Mdot
0.004 setlinewidth
0.49048 0.11936 moveto
0.49048 0.12908 lineto
stroke
0.008 setlinewidth
0.49048 0.12908 Mdot
0.004 setlinewidth
0.5 0.11936 moveto
0.5 0.11936 lineto
stroke
0.008 setlinewidth
0.5 0.11936 Mdot
0.004 setlinewidth
0.50952 0.11936 moveto
0.50952 0.11003 lineto
stroke
0.008 setlinewidth
0.50952 0.11003 Mdot
0.004 setlinewidth
0.51905 0.11936 moveto
0.51905 0.10195 lineto
stroke
0.008 setlinewidth
0.51905 0.10195 Mdot
0.004 setlinewidth
0.52857 0.11936 moveto
0.52857 0.09585 lineto
stroke
0.008 setlinewidth
0.52857 0.09585 Mdot
0.004 setlinewidth
0.5381 0.11936 moveto
0.5381 0.09223 lineto
stroke
0.008 setlinewidth
0.5381 0.09223 Mdot
0.004 setlinewidth
0.54762 0.11936 moveto
0.54762 0.09136 lineto
stroke
0.008 setlinewidth
0.54762 0.09136 Mdot
0.004 setlinewidth
0.55714 0.11936 moveto
0.55714 0.0932 lineto
stroke
0.008 setlinewidth
0.55714 0.0932 Mdot
0.004 setlinewidth
0.56667 0.11936 moveto
0.56667 0.0975 lineto
stroke
0.008 setlinewidth
0.56667 0.0975 Mdot
0.004 setlinewidth
0.57619 0.11936 moveto
0.57619 0.10375 lineto
stroke
0.008 setlinewidth
0.57619 0.10375 Mdot
0.004 setlinewidth
0.58571 0.11936 moveto
0.58571 0.1113 lineto
stroke
0.008 setlinewidth
0.58571 0.1113 Mdot
0.004 setlinewidth
0.59524 0.11936 moveto
0.59524 0.11936 lineto
stroke
0.008 setlinewidth
0.59524 0.11936 Mdot
0.004 setlinewidth
0.60476 0.11936 moveto
0.60476 0.12717 lineto
stroke
0.008 setlinewidth
0.60476 0.12717 Mdot
0.004 setlinewidth
0.61429 0.11936 moveto
0.61429 0.13397 lineto
stroke
0.008 setlinewidth
0.61429 0.13397 Mdot
0.004 setlinewidth
0.62381 0.11936 moveto
0.62381 0.13915 lineto
stroke
0.008 setlinewidth
0.62381 0.13915 Mdot
0.004 setlinewidth
0.63333 0.11936 moveto
0.63333 0.14226 lineto
stroke
0.008 setlinewidth
0.63333 0.14226 Mdot
0.004 setlinewidth
0.64286 0.11936 moveto
0.64286 0.14306 lineto
stroke
0.008 setlinewidth
0.64286 0.14306 Mdot
0.004 setlinewidth
0.65238 0.11936 moveto
0.65238 0.14156 lineto
stroke
0.008 setlinewidth
0.65238 0.14156 Mdot
0.004 setlinewidth
0.6619 0.11936 moveto
0.6619 0.13796 lineto
stroke
0.008 setlinewidth
0.6619 0.13796 Mdot
0.004 setlinewidth
0.67143 0.11936 moveto
0.67143 0.13268 lineto
stroke
0.008 setlinewidth
0.67143 0.13268 Mdot
0.004 setlinewidth
0.68095 0.11936 moveto
0.68095 0.12626 lineto
stroke
0.008 setlinewidth
0.68095 0.12626 Mdot
0.004 setlinewidth
0.69048 0.11936 moveto
0.69048 0.11936 lineto
stroke
0.008 setlinewidth
0.69048 0.11936 Mdot
0.004 setlinewidth
0.7 0.11936 moveto
0.7 0.11266 lineto
stroke
0.008 setlinewidth
0.7 0.11266 Mdot
0.004 setlinewidth
0.70952 0.11936 moveto
0.70952 0.10679 lineto
stroke
0.008 setlinewidth
0.70952 0.10679 Mdot
0.004 setlinewidth
0.71905 0.11936 moveto
0.71905 0.10229 lineto
stroke
0.008 setlinewidth
0.71905 0.10229 Mdot
0.004 setlinewidth
0.72857 0.11936 moveto
0.72857 0.09957 lineto
stroke
0.008 setlinewidth
0.72857 0.09957 Mdot
0.004 setlinewidth
0.7381 0.11936 moveto
0.7381 0.09882 lineto
stroke
0.008 setlinewidth
0.7381 0.09882 Mdot
0.004 setlinewidth
0.74762 0.11936 moveto
0.74762 0.10009 lineto
stroke
0.008 setlinewidth
0.74762 0.10009 Mdot
0.004 setlinewidth
0.75714 0.11936 moveto
0.75714 0.10318 lineto
stroke
0.008 setlinewidth
0.75714 0.10318 Mdot
0.004 setlinewidth
0.76667 0.11936 moveto
0.76667 0.10776 lineto
stroke
0.008 setlinewidth
0.76667 0.10776 Mdot
0.004 setlinewidth
0.77619 0.11936 moveto
0.77619 0.11334 lineto
stroke
0.008 setlinewidth
0.77619 0.11334 Mdot
0.004 setlinewidth
0.78571 0.11936 moveto
0.78571 0.11936 lineto
stroke
0.008 setlinewidth
0.78571 0.11936 Mdot
0.004 setlinewidth
0.79524 0.11936 moveto
0.79524 0.12524 lineto
stroke
0.008 setlinewidth
0.79524 0.12524 Mdot
0.004 setlinewidth
0.80476 0.11936 moveto
0.80476 0.13041 lineto
stroke
0.008 setlinewidth
0.80476 0.13041 Mdot
0.004 setlinewidth
0.81429 0.11936 moveto
0.81429 0.13438 lineto
stroke
0.008 setlinewidth
0.81429 0.13438 Mdot
0.004 setlinewidth
0.82381 0.11936 moveto
0.82381 0.13681 lineto
stroke
0.008 setlinewidth
0.82381 0.13681 Mdot
0.004 setlinewidth
0.83333 0.11936 moveto
0.83333 0.13749 lineto
stroke
0.008 setlinewidth
0.83333 0.13749 Mdot
0.004 setlinewidth
0.84286 0.11936 moveto
0.84286 0.1364 lineto
stroke
0.008 setlinewidth
0.84286 0.1364 Mdot
0.004 setlinewidth
0.85238 0.11936 moveto
0.85238 0.13369 lineto
stroke
0.008 setlinewidth
0.85238 0.13369 Mdot
0.004 setlinewidth
0.8619 0.11936 moveto
0.8619 0.12965 lineto
stroke
0.008 setlinewidth
0.8619 0.12965 Mdot
0.004 setlinewidth
0.87143 0.11936 moveto
0.87143 0.12471 lineto
stroke
0.008 setlinewidth
0.87143 0.12471 Mdot
0.004 setlinewidth
0.88095 0.11936 moveto
0.88095 0.11936 lineto
stroke
0.008 setlinewidth
0.88095 0.11936 Mdot
0.004 setlinewidth
0.89048 0.11936 moveto
0.89048 0.11413 lineto
stroke
0.008 setlinewidth
0.89048 0.11413 Mdot
0.004 setlinewidth
0.9 0.11936 moveto
0.9 0.10952 lineto
stroke
0.008 setlinewidth
0.9 0.10952 Mdot
0.004 setlinewidth
0.90952 0.11936 moveto
0.90952 0.10596 lineto
stroke
0.008 setlinewidth
0.90952 0.10596 Mdot
0.004 setlinewidth
0.91905 0.11936 moveto
0.91905 0.10378 lineto
stroke
0.008 setlinewidth
0.91905 0.10378 Mdot
0.004 setlinewidth
0.92857 0.11936 moveto
0.92857 0.10315 lineto
stroke
0.008 setlinewidth
0.92857 0.10315 Mdot
0.004 setlinewidth
0.9381 0.11936 moveto
0.9381 0.1041 lineto
stroke
0.008 setlinewidth
0.9381 0.1041 Mdot
0.004 setlinewidth
0.94762 0.11936 moveto
0.94762 0.10652 lineto
stroke
0.008 setlinewidth
0.94762 0.10652 Mdot
0.004 setlinewidth
0.95714 0.11936 moveto
0.95714 0.11012 lineto
stroke
0.008 setlinewidth
0.95714 0.11012 Mdot
0.004 setlinewidth
0.96667 0.11936 moveto
0.96667 0.11456 lineto
stroke
0.008 setlinewidth
0.96667 0.11456 Mdot
0.004 setlinewidth
0.97619 0.11936 moveto
0.97619 0.11936 lineto
stroke
0.008 setlinewidth
0.97619 0.11936 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.05886 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(2)] 0.4875 0.13244 1 0 Msboxa
[(4)] 0.4875 0.25016 1 0 Msboxa
[(6)] 0.4875 0.36788 1 0 Msboxa
[(8)] 0.4875 0.4856 1 0 Msboxa
[(10)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(10)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.44048 0.01472 lineto
0.4504 0.01472 lineto
0.46032 0.01472 lineto
0.47024 0.01472 lineto
0.47272 0.01472 lineto
0.47396 0.01472 lineto
0.4752 0.01472 lineto
0.47644 0.60332 lineto
0.47768 0.60332 lineto
0.47892 0.60332 lineto
0.48016 0.60332 lineto
0.5 0.60332 lineto
0.50992 0.60332 lineto
0.51488 0.60332 lineto
0.51736 0.60332 lineto
0.51984 0.60332 lineto
0.52108 0.60332 lineto
0.52232 0.60332 lineto
0.52356 0.60332 lineto
0.5248 0.01472 lineto
0.52604 0.01472 lineto
0.52728 0.01472 lineto
0.52976 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.11936 0.48396 [
[(Sequence Plot \(frequency = Pi/5 rad\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.10686 0 1 Msboxa
[(40)] 0.40476 0.10686 0 1 Msboxa
[(60)] 0.59524 0.10686 0 1 Msboxa
[(80)] 0.78571 0.10686 0 1 Msboxa
[(100)] 0.97619 0.10686 0 1 Msboxa
[(n)] 1.00625 0.11936 -1 0 Msboxa
[(-0.2)] 0.01131 0.02257 1 0 Msboxa
[(0.2)] 0.01131 0.21615 1 0 Msboxa
[(0.4)] 0.01131 0.31295 1 0 Msboxa
[(0.6)] 0.01131 0.40974 1 0 Msboxa
[(0.8)] 0.01131 0.50653 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot \(frequency = Pi/5 rad\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.11936 moveto
1 0.11936 lineto
stroke
0.21429 0.11311 moveto
0.21429 0.12561 lineto
stroke
0 setgray
[(20)] 0.21429 0.10686 0 1 Mshowa
0.40476 0.11311 moveto
0.40476 0.12561 lineto
stroke
0 setgray
[(40)] 0.40476 0.10686 0 1 Mshowa
0.59524 0.11311 moveto
0.59524 0.12561 lineto
stroke
0 setgray
[(60)] 0.59524 0.10686 0 1 Mshowa
0.78571 0.11311 moveto
0.78571 0.12561 lineto
stroke
0 setgray
[(80)] 0.78571 0.10686 0 1 Mshowa
0.97619 0.11311 moveto
0.97619 0.12561 lineto
stroke
0 setgray
[(100)] 0.97619 0.10686 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.11936 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.02257 moveto
0.03006 0.02257 lineto
stroke
0 setgray
[(-0.2)] 0.01131 0.02257 1 0 Mshowa
0.01756 0.21615 moveto
0.03006 0.21615 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.21615 1 0 Mshowa
0.01756 0.31295 moveto
0.03006 0.31295 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.31295 1 0 Mshowa
0.01756 0.40974 moveto
0.03006 0.40974 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.40974 1 0 Mshowa
0.01756 0.50653 moveto
0.03006 0.50653 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.50653 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.11936 moveto
0.02381 0.60332 lineto
stroke
0.008 setlinewidth
0.02381 0.60332 Mdot
0.004 setlinewidth
0.03333 0.11936 moveto
0.03333 0.5721 lineto
stroke
0.008 setlinewidth
0.03333 0.5721 Mdot
0.004 setlinewidth
0.04286 0.11936 moveto
0.04286 0.48563 lineto
stroke
0.008 setlinewidth
0.04286 0.48563 Mdot
0.004 setlinewidth
0.05238 0.11936 moveto
0.05238 0.36354 lineto
stroke
0.008 setlinewidth
0.05238 0.36354 Mdot
0.004 setlinewidth
0.0619 0.11936 moveto
0.0619 0.23255 lineto
stroke
0.008 setlinewidth
0.0619 0.23255 Mdot
0.004 setlinewidth
0.07143 0.11936 moveto
0.07143 0.11936 lineto
stroke
0.008 setlinewidth
0.07143 0.11936 Mdot
0.004 setlinewidth
0.08095 0.11936 moveto
0.08095 0.04391 lineto
stroke
0.008 setlinewidth
0.08095 0.04391 Mdot
0.004 setlinewidth
0.09048 0.11936 moveto
0.09048 0.01472 lineto
stroke
0.008 setlinewidth
0.09048 0.01472 Mdot
0.004 setlinewidth
0.1 0.11936 moveto
0.1 0.0278 lineto
stroke
0.008 setlinewidth
0.1 0.0278 Mdot
0.004 setlinewidth
0.10952 0.11936 moveto
0.10952 0.06906 lineto
stroke
0.008 setlinewidth
0.10952 0.06906 Mdot
0.004 setlinewidth
0.11905 0.11936 moveto
0.11905 0.11936 lineto
stroke
0.008 setlinewidth
0.11905 0.11936 Mdot
0.004 setlinewidth
0.12857 0.11936 moveto
0.12857 0.16052 lineto
stroke
0.008 setlinewidth
0.12857 0.16052 Mdot
0.004 setlinewidth
0.1381 0.11936 moveto
0.1381 0.18041 lineto
stroke
0.008 setlinewidth
0.1381 0.18041 Mdot
0.004 setlinewidth
0.14762 0.11936 moveto
0.14762 0.17571 lineto
stroke
0.008 setlinewidth
0.14762 0.17571 Mdot
0.004 setlinewidth
0.15714 0.11936 moveto
0.15714 0.1517 lineto
stroke
0.008 setlinewidth
0.15714 0.1517 Mdot
0.004 setlinewidth
0.16667 0.11936 moveto
0.16667 0.11936 lineto
stroke
0.008 setlinewidth
0.16667 0.11936 Mdot
0.004 setlinewidth
0.17619 0.11936 moveto
0.17619 0.09107 lineto
stroke
0.008 setlinewidth
0.17619 0.09107 Mdot
0.004 setlinewidth
0.18571 0.11936 moveto
0.18571 0.07627 lineto
stroke
0.008 setlinewidth
0.18571 0.07627 Mdot
0.004 setlinewidth
0.19524 0.11936 moveto
0.19524 0.07867 lineto
stroke
0.008 setlinewidth
0.19524 0.07867 Mdot
0.004 setlinewidth
0.20476 0.11936 moveto
0.20476 0.09554 lineto
stroke
0.008 setlinewidth
0.20476 0.09554 Mdot
0.004 setlinewidth
0.21429 0.11936 moveto
0.21429 0.11936 lineto
stroke
0.008 setlinewidth
0.21429 0.11936 Mdot
0.004 setlinewidth
0.22381 0.11936 moveto
0.22381 0.14092 lineto
stroke
0.008 setlinewidth
0.22381 0.14092 Mdot
0.004 setlinewidth
0.23333 0.11936 moveto
0.23333 0.15266 lineto
stroke
0.008 setlinewidth
0.23333 0.15266 Mdot
0.004 setlinewidth
0.24286 0.11936 moveto
0.24286 0.15121 lineto
stroke
0.008 setlinewidth
0.24286 0.15121 Mdot
0.004 setlinewidth
0.25238 0.11936 moveto
0.25238 0.13823 lineto
stroke
0.008 setlinewidth
0.25238 0.13823 Mdot
0.004 setlinewidth
0.2619 0.11936 moveto
0.2619 0.11936 lineto
stroke
0.008 setlinewidth
0.2619 0.11936 Mdot
0.004 setlinewidth
0.27143 0.11936 moveto
0.27143 0.10195 lineto
stroke
0.008 setlinewidth
0.27143 0.10195 Mdot
0.004 setlinewidth
0.28095 0.11936 moveto
0.28095 0.09223 lineto
stroke
0.008 setlinewidth
0.28095 0.09223 Mdot
0.004 setlinewidth
0.29048 0.11936 moveto
0.29048 0.0932 lineto
stroke
0.008 setlinewidth
0.29048 0.0932 Mdot
0.004 setlinewidth
0.3 0.11936 moveto
0.3 0.10375 lineto
stroke
0.008 setlinewidth
0.3 0.10375 Mdot
0.004 setlinewidth
0.30952 0.11936 moveto
0.30952 0.11936 lineto
stroke
0.008 setlinewidth
0.30952 0.11936 Mdot
0.004 setlinewidth
0.31905 0.11936 moveto
0.31905 0.13397 lineto
stroke
0.008 setlinewidth
0.31905 0.13397 Mdot
0.004 setlinewidth
0.32857 0.11936 moveto
0.32857 0.14226 lineto
stroke
0.008 setlinewidth
0.32857 0.14226 Mdot
0.004 setlinewidth
0.3381 0.11936 moveto
0.3381 0.14156 lineto
stroke
0.008 setlinewidth
0.3381 0.14156 Mdot
0.004 setlinewidth
0.34762 0.11936 moveto
0.34762 0.13268 lineto
stroke
0.008 setlinewidth
0.34762 0.13268 Mdot
0.004 setlinewidth
0.35714 0.11936 moveto
0.35714 0.11936 lineto
stroke
0.008 setlinewidth
0.35714 0.11936 Mdot
0.004 setlinewidth
0.36667 0.11936 moveto
0.36667 0.10679 lineto
stroke
0.008 setlinewidth
0.36667 0.10679 Mdot
0.004 setlinewidth
0.37619 0.11936 moveto
0.37619 0.09957 lineto
stroke
0.008 setlinewidth
0.37619 0.09957 Mdot
0.004 setlinewidth
0.38571 0.11936 moveto
0.38571 0.10009 lineto
stroke
0.008 setlinewidth
0.38571 0.10009 Mdot
0.004 setlinewidth
0.39524 0.11936 moveto
0.39524 0.10776 lineto
stroke
0.008 setlinewidth
0.39524 0.10776 Mdot
0.004 setlinewidth
0.40476 0.11936 moveto
0.40476 0.11936 lineto
stroke
0.008 setlinewidth
0.40476 0.11936 Mdot
0.004 setlinewidth
0.41429 0.11936 moveto
0.41429 0.13041 lineto
stroke
0.008 setlinewidth
0.41429 0.13041 Mdot
0.004 setlinewidth
0.42381 0.11936 moveto
0.42381 0.13681 lineto
stroke
0.008 setlinewidth
0.42381 0.13681 Mdot
0.004 setlinewidth
0.43333 0.11936 moveto
0.43333 0.1364 lineto
stroke
0.008 setlinewidth
0.43333 0.1364 Mdot
0.004 setlinewidth
0.44286 0.11936 moveto
0.44286 0.12965 lineto
stroke
0.008 setlinewidth
0.44286 0.12965 Mdot
0.004 setlinewidth
0.45238 0.11936 moveto
0.45238 0.11936 lineto
stroke
0.008 setlinewidth
0.45238 0.11936 Mdot
0.004 setlinewidth
0.4619 0.11936 moveto
0.4619 0.10952 lineto
stroke
0.008 setlinewidth
0.4619 0.10952 Mdot
0.004 setlinewidth
0.47143 0.11936 moveto
0.47143 0.10378 lineto
stroke
0.008 setlinewidth
0.47143 0.10378 Mdot
0.004 setlinewidth
0.48095 0.11936 moveto
0.48095 0.1041 lineto
stroke
0.008 setlinewidth
0.48095 0.1041 Mdot
0.004 setlinewidth
0.49048 0.11936 moveto
0.49048 0.11012 lineto
stroke
0.008 setlinewidth
0.49048 0.11012 Mdot
0.004 setlinewidth
0.5 0.11936 moveto
0.5 0.11936 lineto
stroke
0.008 setlinewidth
0.5 0.11936 Mdot
0.004 setlinewidth
0.50952 0.11936 moveto
0.50952 0.12824 lineto
stroke
0.008 setlinewidth
0.50952 0.12824 Mdot
0.004 setlinewidth
0.51905 0.11936 moveto
0.51905 0.13345 lineto
stroke
0.008 setlinewidth
0.51905 0.13345 Mdot
0.004 setlinewidth
0.52857 0.11936 moveto
0.52857 0.13319 lineto
stroke
0.008 setlinewidth
0.52857 0.13319 Mdot
0.004 setlinewidth
0.5381 0.11936 moveto
0.5381 0.12775 lineto
stroke
0.008 setlinewidth
0.5381 0.12775 Mdot
0.004 setlinewidth
0.54762 0.11936 moveto
0.54762 0.11936 lineto
stroke
0.008 setlinewidth
0.54762 0.11936 Mdot
0.004 setlinewidth
0.55714 0.11936 moveto
0.55714 0.11128 lineto
stroke
0.008 setlinewidth
0.55714 0.11128 Mdot
0.004 setlinewidth
0.56667 0.11936 moveto
0.56667 0.10651 lineto
stroke
0.008 setlinewidth
0.56667 0.10651 Mdot
0.004 setlinewidth
0.57619 0.11936 moveto
0.57619 0.10673 lineto
stroke
0.008 setlinewidth
0.57619 0.10673 Mdot
0.004 setlinewidth
0.58571 0.11936 moveto
0.58571 0.11169 lineto
stroke
0.008 setlinewidth
0.58571 0.11169 Mdot
0.004 setlinewidth
0.59524 0.11936 moveto
0.59524 0.11936 lineto
stroke
0.008 setlinewidth
0.59524 0.11936 Mdot
0.004 setlinewidth
0.60476 0.11936 moveto
0.60476 0.12679 lineto
stroke
0.008 setlinewidth
0.60476 0.12679 Mdot
0.004 setlinewidth
0.61429 0.11936 moveto
0.61429 0.13118 lineto
stroke
0.008 setlinewidth
0.61429 0.13118 Mdot
0.004 setlinewidth
0.62381 0.11936 moveto
0.62381 0.13099 lineto
stroke
0.008 setlinewidth
0.62381 0.13099 Mdot
0.004 setlinewidth
0.63333 0.11936 moveto
0.63333 0.12644 lineto
stroke
0.008 setlinewidth
0.63333 0.12644 Mdot
0.004 setlinewidth
0.64286 0.11936 moveto
0.64286 0.11936 lineto
stroke
0.008 setlinewidth
0.64286 0.11936 Mdot
0.004 setlinewidth
0.65238 0.11936 moveto
0.65238 0.1125 lineto
stroke
0.008 setlinewidth
0.65238 0.1125 Mdot
0.004 setlinewidth
0.6619 0.11936 moveto
0.6619 0.10843 lineto
stroke
0.008 setlinewidth
0.6619 0.10843 Mdot
0.004 setlinewidth
0.67143 0.11936 moveto
0.67143 0.10859 lineto
stroke
0.008 setlinewidth
0.67143 0.10859 Mdot
0.004 setlinewidth
0.68095 0.11936 moveto
0.68095 0.1128 lineto
stroke
0.008 setlinewidth
0.68095 0.1128 Mdot
0.004 setlinewidth
0.69048 0.11936 moveto
0.69048 0.11936 lineto
stroke
0.008 setlinewidth
0.69048 0.11936 Mdot
0.004 setlinewidth
0.7 0.11936 moveto
0.7 0.12574 lineto
stroke
0.008 setlinewidth
0.7 0.12574 Mdot
0.004 setlinewidth
0.70952 0.11936 moveto
0.70952 0.12954 lineto
stroke
0.008 setlinewidth
0.70952 0.12954 Mdot
0.004 setlinewidth
0.71905 0.11936 moveto
0.71905 0.1294 lineto
stroke
0.008 setlinewidth
0.71905 0.1294 Mdot
0.004 setlinewidth
0.72857 0.11936 moveto
0.72857 0.12548 lineto
stroke
0.008 setlinewidth
0.72857 0.12548 Mdot
0.004 setlinewidth
0.7381 0.11936 moveto
0.7381 0.11936 lineto
stroke
0.008 setlinewidth
0.7381 0.11936 Mdot
0.004 setlinewidth
0.74762 0.11936 moveto
0.74762 0.11341 lineto
stroke
0.008 setlinewidth
0.74762 0.11341 Mdot
0.004 setlinewidth
0.75714 0.11936 moveto
0.75714 0.10985 lineto
stroke
0.008 setlinewidth
0.75714 0.10985 Mdot
0.004 setlinewidth
0.76667 0.11936 moveto
0.76667 0.10997 lineto
stroke
0.008 setlinewidth
0.76667 0.10997 Mdot
0.004 setlinewidth
0.77619 0.11936 moveto
0.77619 0.11363 lineto
stroke
0.008 setlinewidth
0.77619 0.11363 Mdot
0.004 setlinewidth
0.78571 0.11936 moveto
0.78571 0.11936 lineto
stroke
0.008 setlinewidth
0.78571 0.11936 Mdot
0.004 setlinewidth
0.79524 0.11936 moveto
0.79524 0.12495 lineto
stroke
0.008 setlinewidth
0.79524 0.12495 Mdot
0.004 setlinewidth
0.80476 0.11936 moveto
0.80476 0.1283 lineto
stroke
0.008 setlinewidth
0.80476 0.1283 Mdot
0.004 setlinewidth
0.81429 0.11936 moveto
0.81429 0.12819 lineto
stroke
0.008 setlinewidth
0.81429 0.12819 Mdot
0.004 setlinewidth
0.82381 0.11936 moveto
0.82381 0.12475 lineto
stroke
0.008 setlinewidth
0.82381 0.12475 Mdot
0.004 setlinewidth
0.83333 0.11936 moveto
0.83333 0.11936 lineto
stroke
0.008 setlinewidth
0.83333 0.11936 Mdot
0.004 setlinewidth
0.84286 0.11936 moveto
0.84286 0.1141 lineto
stroke
0.008 setlinewidth
0.84286 0.1141 Mdot
0.004 setlinewidth
0.85238 0.11936 moveto
0.85238 0.11094 lineto
stroke
0.008 setlinewidth
0.85238 0.11094 Mdot
0.004 setlinewidth
0.8619 0.11936 moveto
0.8619 0.11104 lineto
stroke
0.008 setlinewidth
0.8619 0.11104 Mdot
0.004 setlinewidth
0.87143 0.11936 moveto
0.87143 0.11428 lineto
stroke
0.008 setlinewidth
0.87143 0.11428 Mdot
0.004 setlinewidth
0.88095 0.11936 moveto
0.88095 0.11936 lineto
stroke
0.008 setlinewidth
0.88095 0.11936 Mdot
0.004 setlinewidth
0.89048 0.11936 moveto
0.89048 0.12434 lineto
stroke
0.008 setlinewidth
0.89048 0.12434 Mdot
0.004 setlinewidth
0.9 0.11936 moveto
0.9 0.12733 lineto
stroke
0.008 setlinewidth
0.9 0.12733 Mdot
0.004 setlinewidth
0.90952 0.11936 moveto
0.90952 0.12724 lineto
stroke
0.008 setlinewidth
0.90952 0.12724 Mdot
0.004 setlinewidth
0.91905 0.11936 moveto
0.91905 0.12418 lineto
stroke
0.008 setlinewidth
0.91905 0.12418 Mdot
0.004 setlinewidth
0.92857 0.11936 moveto
0.92857 0.11936 lineto
stroke
0.008 setlinewidth
0.92857 0.11936 Mdot
0.004 setlinewidth
0.9381 0.11936 moveto
0.9381 0.11465 lineto
stroke
0.008 setlinewidth
0.9381 0.11465 Mdot
0.004 setlinewidth
0.94762 0.11936 moveto
0.94762 0.11181 lineto
stroke
0.008 setlinewidth
0.94762 0.11181 Mdot
0.004 setlinewidth
0.95714 0.11936 moveto
0.95714 0.11189 lineto
stroke
0.008 setlinewidth
0.95714 0.11189 Mdot
0.004 setlinewidth
0.96667 0.11936 moveto
0.96667 0.11479 lineto
stroke
0.008 setlinewidth
0.96667 0.11479 Mdot
0.004 setlinewidth
0.97619 0.11936 moveto
0.97619 0.11936 lineto
stroke
0.008 setlinewidth
0.97619 0.11936 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.11772 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(1)] 0.4875 0.13244 1 0 Msboxa
[(2)] 0.4875 0.25016 1 0 Msboxa
[(3)] 0.4875 0.36788 1 0 Msboxa
[(4)] 0.4875 0.4856 1 0 Msboxa
[(5)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(1)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(2)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(3)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(4)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(5)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.40079 0.01472 lineto
0.42063 0.01472 lineto
0.44048 0.01472 lineto
0.44544 0.01472 lineto
0.44792 0.01472 lineto
0.44916 0.01472 lineto
0.4504 0.01472 lineto
0.45164 0.01472 lineto
0.45288 0.60332 lineto
0.45536 0.60332 lineto
0.46032 0.60332 lineto
0.5 0.60332 lineto
0.51984 0.60332 lineto
0.52976 0.60332 lineto
0.53472 0.60332 lineto
0.53968 0.60332 lineto
0.54216 0.60332 lineto
0.54464 0.60332 lineto
0.54588 0.60332 lineto
0.54712 0.60332 lineto
0.54836 0.01472 lineto
0.5496 0.01472 lineto
0.55208 0.01472 lineto
0.55456 0.01472 lineto
0.55952 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.11775 0.48556 [
[(Sequence Plot \(frequency = \(3*Pi\)/10 rad\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.10525 0 1 Msboxa
[(40)] 0.40476 0.10525 0 1 Msboxa
[(60)] 0.59524 0.10525 0 1 Msboxa
[(80)] 0.78571 0.10525 0 1 Msboxa
[(100)] 0.97619 0.10525 0 1 Msboxa
[(n)] 1.00625 0.11775 -1 0 Msboxa
[(-0.2)] 0.01131 0.02064 1 0 Msboxa
[(0.2)] 0.01131 0.21487 1 0 Msboxa
[(0.4)] 0.01131 0.31198 1 0 Msboxa
[(0.6)] 0.01131 0.40909 1 0 Msboxa
[(0.8)] 0.01131 0.50621 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot \(frequency = \(3*Pi\)/10 rad\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.11775 moveto
1 0.11775 lineto
stroke
0.21429 0.1115 moveto
0.21429 0.124 lineto
stroke
0 setgray
[(20)] 0.21429 0.10525 0 1 Mshowa
0.40476 0.1115 moveto
0.40476 0.124 lineto
stroke
0 setgray
[(40)] 0.40476 0.10525 0 1 Mshowa
0.59524 0.1115 moveto
0.59524 0.124 lineto
stroke
0 setgray
[(60)] 0.59524 0.10525 0 1 Mshowa
0.78571 0.1115 moveto
0.78571 0.124 lineto
stroke
0 setgray
[(80)] 0.78571 0.10525 0 1 Mshowa
0.97619 0.1115 moveto
0.97619 0.124 lineto
stroke
0 setgray
[(100)] 0.97619 0.10525 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.11775 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.02064 moveto
0.03006 0.02064 lineto
stroke
0 setgray
[(-0.2)] 0.01131 0.02064 1 0 Mshowa
0.01756 0.21487 moveto
0.03006 0.21487 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.21487 1 0 Mshowa
0.01756 0.31198 moveto
0.03006 0.31198 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.31198 1 0 Mshowa
0.01756 0.40909 moveto
0.03006 0.40909 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.40909 1 0 Mshowa
0.01756 0.50621 moveto
0.03006 0.50621 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.50621 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.11775 moveto
0.02381 0.60332 lineto
stroke
0.008 setlinewidth
0.02381 0.60332 Mdot
0.004 setlinewidth
0.03333 0.11775 moveto
0.03333 0.53456 lineto
stroke
0.008 setlinewidth
0.03333 0.53456 Mdot
0.004 setlinewidth
0.04286 0.11775 moveto
0.04286 0.36275 lineto
stroke
0.008 setlinewidth
0.04286 0.36275 Mdot
0.004 setlinewidth
0.05238 0.11775 moveto
0.05238 0.17082 lineto
stroke
0.008 setlinewidth
0.05238 0.17082 Mdot
0.004 setlinewidth
0.0619 0.11775 moveto
0.0619 0.04205 lineto
stroke
0.008 setlinewidth
0.0619 0.04205 Mdot
0.004 setlinewidth
0.07143 0.11775 moveto
0.07143 0.01472 lineto
stroke
0.008 setlinewidth
0.07143 0.01472 Mdot
0.004 setlinewidth
0.08095 0.11775 moveto
0.08095 0.06728 lineto
stroke
0.008 setlinewidth
0.08095 0.06728 Mdot
0.004 setlinewidth
0.09048 0.11775 moveto
0.09048 0.1405 lineto
stroke
0.008 setlinewidth
0.09048 0.1405 Mdot
0.004 setlinewidth
0.1 0.11775 moveto
0.1 0.179 lineto
stroke
0.008 setlinewidth
0.1 0.179 Mdot
0.004 setlinewidth
0.10952 0.11775 moveto
0.10952 0.16407 lineto
stroke
0.008 setlinewidth
0.10952 0.16407 Mdot
0.004 setlinewidth
0.11905 0.11775 moveto
0.11905 0.11775 lineto
stroke
0.008 setlinewidth
0.11905 0.11775 Mdot
0.004 setlinewidth
0.12857 0.11775 moveto
0.12857 0.07986 lineto
stroke
0.008 setlinewidth
0.12857 0.07986 Mdot
0.004 setlinewidth
0.1381 0.11775 moveto
0.1381 0.07692 lineto
stroke
0.008 setlinewidth
0.1381 0.07692 Mdot
0.004 setlinewidth
0.14762 0.11775 moveto
0.14762 0.10551 lineto
stroke
0.008 setlinewidth
0.14762 0.10551 Mdot
0.004 setlinewidth
0.15714 0.11775 moveto
0.15714 0.13939 lineto
stroke
0.008 setlinewidth
0.15714 0.13939 Mdot
0.004 setlinewidth
0.16667 0.11775 moveto
0.16667 0.1521 lineto
stroke
0.008 setlinewidth
0.16667 0.1521 Mdot
0.004 setlinewidth
0.17619 0.11775 moveto
0.17619 0.13668 lineto
stroke
0.008 setlinewidth
0.17619 0.13668 Mdot
0.004 setlinewidth
0.18571 0.11775 moveto
0.18571 0.10839 lineto
stroke
0.008 setlinewidth
0.18571 0.10839 Mdot
0.004 setlinewidth
0.19524 0.11775 moveto
0.19524 0.09053 lineto
stroke
0.008 setlinewidth
0.19524 0.09053 Mdot
0.004 setlinewidth
0.20476 0.11775 moveto
0.20476 0.09582 lineto
stroke
0.008 setlinewidth
0.20476 0.09582 Mdot
0.004 setlinewidth
0.21429 0.11775 moveto
0.21429 0.11775 lineto
stroke
0.008 setlinewidth
0.21429 0.11775 Mdot
0.004 setlinewidth
0.22381 0.11775 moveto
0.22381 0.1376 lineto
stroke
0.008 setlinewidth
0.22381 0.1376 Mdot
0.004 setlinewidth
0.23333 0.11775 moveto
0.23333 0.14003 lineto
stroke
0.008 setlinewidth
0.23333 0.14003 Mdot
0.004 setlinewidth
0.24286 0.11775 moveto
0.24286 0.12468 lineto
stroke
0.008 setlinewidth
0.24286 0.12468 Mdot
0.004 setlinewidth
0.25238 0.11775 moveto
0.25238 0.10514 lineto
stroke
0.008 setlinewidth
0.25238 0.10514 Mdot
0.004 setlinewidth
0.2619 0.11775 moveto
0.2619 0.09715 lineto
stroke
0.008 setlinewidth
0.2619 0.09715 Mdot
0.004 setlinewidth
0.27143 0.11775 moveto
0.27143 0.10611 lineto
stroke
0.008 setlinewidth
0.27143 0.10611 Mdot
0.004 setlinewidth
0.28095 0.11775 moveto
0.28095 0.12365 lineto
stroke
0.008 setlinewidth
0.28095 0.12365 Mdot
0.004 setlinewidth
0.29048 0.11775 moveto
0.29048 0.13525 lineto
stroke
0.008 setlinewidth
0.29048 0.13525 Mdot
0.004 setlinewidth
0.3 0.11775 moveto
0.3 0.13213 lineto
stroke
0.008 setlinewidth
0.3 0.13213 Mdot
0.004 setlinewidth
0.30952 0.11775 moveto
0.30952 0.11775 lineto
stroke
0.008 setlinewidth
0.30952 0.11775 Mdot
0.004 setlinewidth
0.31905 0.11775 moveto
0.31905 0.10431 lineto
stroke
0.008 setlinewidth
0.31905 0.10431 Mdot
0.004 setlinewidth
0.32857 0.11775 moveto
0.32857 0.10244 lineto
stroke
0.008 setlinewidth
0.32857 0.10244 Mdot
0.004 setlinewidth
0.3381 0.11775 moveto
0.3381 0.11293 lineto
stroke
0.008 setlinewidth
0.3381 0.11293 Mdot
0.004 setlinewidth
0.34762 0.11775 moveto
0.34762 0.12666 lineto
stroke
0.008 setlinewidth
0.34762 0.12666 Mdot
0.004 setlinewidth
0.35714 0.11775 moveto
0.35714 0.13247 lineto
stroke
0.008 setlinewidth
0.35714 0.13247 Mdot
0.004 setlinewidth
0.36667 0.11775 moveto
0.36667 0.12617 lineto
stroke
0.008 setlinewidth
0.36667 0.12617 Mdot
0.004 setlinewidth
0.37619 0.11775 moveto
0.37619 0.11345 lineto
stroke
0.008 setlinewidth
0.37619 0.11345 Mdot
0.004 setlinewidth
0.38571 0.11775 moveto
0.38571 0.10486 lineto
stroke
0.008 setlinewidth
0.38571 0.10486 Mdot
0.004 setlinewidth
0.39524 0.11775 moveto
0.39524 0.10707 lineto
stroke
0.008 setlinewidth
0.39524 0.10707 Mdot
0.004 setlinewidth
0.40476 0.11775 moveto
0.40476 0.11775 lineto
stroke
0.008 setlinewidth
0.40476 0.11775 Mdot
0.004 setlinewidth
0.41429 0.11775 moveto
0.41429 0.12792 lineto
stroke
0.008 setlinewidth
0.41429 0.12792 Mdot
0.004 setlinewidth
0.42381 0.11775 moveto
0.42381 0.12942 lineto
stroke
0.008 setlinewidth
0.42381 0.12942 Mdot
0.004 setlinewidth
0.43333 0.11775 moveto
0.43333 0.12146 lineto
stroke
0.008 setlinewidth
0.43333 0.12146 Mdot
0.004 setlinewidth
0.44286 0.11775 moveto
0.44286 0.11087 lineto
stroke
0.008 setlinewidth
0.44286 0.11087 Mdot
0.004 setlinewidth
0.45238 0.11775 moveto
0.45238 0.10631 lineto
stroke
0.008 setlinewidth
0.45238 0.10631 Mdot
0.004 setlinewidth
0.4619 0.11775 moveto
0.4619 0.11117 lineto
stroke
0.008 setlinewidth
0.4619 0.11117 Mdot
0.004 setlinewidth
0.47143 0.11775 moveto
0.47143 0.12114 lineto
stroke
0.008 setlinewidth
0.47143 0.12114 Mdot
0.004 setlinewidth
0.48095 0.11775 moveto
0.48095 0.12796 lineto
stroke
0.008 setlinewidth
0.48095 0.12796 Mdot
0.004 setlinewidth
0.49048 0.11775 moveto
0.49048 0.12626 lineto
stroke
0.008 setlinewidth
0.49048 0.12626 Mdot
0.004 setlinewidth
0.5 0.11775 moveto
0.5 0.11775 lineto
stroke
0.008 setlinewidth
0.5 0.11775 Mdot
0.004 setlinewidth
0.50952 0.11775 moveto
0.50952 0.10958 lineto
stroke
0.008 setlinewidth
0.50952 0.10958 Mdot
0.004 setlinewidth
0.51905 0.11775 moveto
0.51905 0.10833 lineto
stroke
0.008 setlinewidth
0.51905 0.10833 Mdot
0.004 setlinewidth
0.52857 0.11775 moveto
0.52857 0.11475 lineto
stroke
0.008 setlinewidth
0.52857 0.11475 Mdot
0.004 setlinewidth
0.5381 0.11775 moveto
0.5381 0.12336 lineto
stroke
0.008 setlinewidth
0.5381 0.12336 Mdot
0.004 setlinewidth
0.54762 0.11775 moveto
0.54762 0.12712 lineto
stroke
0.008 setlinewidth
0.54762 0.12712 Mdot
0.004 setlinewidth
0.55714 0.11775 moveto
0.55714 0.12316 lineto
stroke
0.008 setlinewidth
0.55714 0.12316 Mdot
0.004 setlinewidth
0.56667 0.11775 moveto
0.56667 0.11496 lineto
stroke
0.008 setlinewidth
0.56667 0.11496 Mdot
0.004 setlinewidth
0.57619 0.11775 moveto
0.57619 0.10931 lineto
stroke
0.008 setlinewidth
0.57619 0.10931 Mdot
0.004 setlinewidth
0.58571 0.11775 moveto
0.58571 0.11069 lineto
stroke
0.008 setlinewidth
0.58571 0.11069 Mdot
0.004 setlinewidth
0.59524 0.11775 moveto
0.59524 0.11775 lineto
stroke
0.008 setlinewidth
0.59524 0.11775 Mdot
0.004 setlinewidth
0.60476 0.11775 moveto
0.60476 0.12459 lineto
stroke
0.008 setlinewidth
0.60476 0.12459 Mdot
0.004 setlinewidth
0.61429 0.11775 moveto
0.61429 0.12566 lineto
stroke
0.008 setlinewidth
0.61429 0.12566 Mdot
0.004 setlinewidth
0.62381 0.11775 moveto
0.62381 0.12028 lineto
stroke
0.008 setlinewidth
0.62381 0.12028 Mdot
0.004 setlinewidth
0.63333 0.11775 moveto
0.63333 0.11302 lineto
stroke
0.008 setlinewidth
0.63333 0.11302 Mdot
0.004 setlinewidth
0.64286 0.11775 moveto
0.64286 0.10983 lineto
stroke
0.008 setlinewidth
0.64286 0.10983 Mdot
0.004 setlinewidth
0.65238 0.11775 moveto
0.65238 0.11317 lineto
stroke
0.008 setlinewidth
0.65238 0.11317 Mdot
0.004 setlinewidth
0.6619 0.11775 moveto
0.6619 0.12013 lineto
stroke
0.008 setlinewidth
0.6619 0.12013 Mdot
0.004 setlinewidth
0.67143 0.11775 moveto
0.67143 0.12496 lineto
stroke
0.008 setlinewidth
0.67143 0.12496 Mdot
0.004 setlinewidth
0.68095 0.11775 moveto
0.68095 0.1238 lineto
stroke
0.008 setlinewidth
0.68095 0.1238 Mdot
0.004 setlinewidth
0.69048 0.11775 moveto
0.69048 0.11775 lineto
stroke
0.008 setlinewidth
0.69048 0.11775 Mdot
0.004 setlinewidth
0.7 0.11775 moveto
0.7 0.11188 lineto
stroke
0.008 setlinewidth
0.7 0.11188 Mdot
0.004 setlinewidth
0.70952 0.11775 moveto
0.70952 0.11095 lineto
stroke
0.008 setlinewidth
0.70952 0.11095 Mdot
0.004 setlinewidth
0.71905 0.11775 moveto
0.71905 0.11557 lineto
stroke
0.008 setlinewidth
0.71905 0.11557 Mdot
0.004 setlinewidth
0.72857 0.11775 moveto
0.72857 0.12185 lineto
stroke
0.008 setlinewidth
0.72857 0.12185 Mdot
0.004 setlinewidth
0.7381 0.11775 moveto
0.7381 0.12462 lineto
stroke
0.008 setlinewidth
0.7381 0.12462 Mdot
0.004 setlinewidth
0.74762 0.11775 moveto
0.74762 0.12174 lineto
stroke
0.008 setlinewidth
0.74762 0.12174 Mdot
0.004 setlinewidth
0.75714 0.11775 moveto
0.75714 0.11569 lineto
stroke
0.008 setlinewidth
0.75714 0.11569 Mdot
0.004 setlinewidth
0.76667 0.11775 moveto
0.76667 0.11147 lineto
stroke
0.008 setlinewidth
0.76667 0.11147 Mdot
0.004 setlinewidth
0.77619 0.11775 moveto
0.77619 0.11248 lineto
stroke
0.008 setlinewidth
0.77619 0.11248 Mdot
0.004 setlinewidth
0.78571 0.11775 moveto
0.78571 0.11775 lineto
stroke
0.008 setlinewidth
0.78571 0.11775 Mdot
0.004 setlinewidth
0.79524 0.11775 moveto
0.79524 0.1229 lineto
stroke
0.008 setlinewidth
0.79524 0.1229 Mdot
0.004 setlinewidth
0.80476 0.11775 moveto
0.80476 0.12373 lineto
stroke
0.008 setlinewidth
0.80476 0.12373 Mdot
0.004 setlinewidth
0.81429 0.11775 moveto
0.81429 0.11967 lineto
stroke
0.008 setlinewidth
0.81429 0.11967 Mdot
0.004 setlinewidth
0.82381 0.11775 moveto
0.82381 0.11415 lineto
stroke
0.008 setlinewidth
0.82381 0.11415 Mdot
0.004 setlinewidth
0.83333 0.11775 moveto
0.83333 0.11169 lineto
stroke
0.008 setlinewidth
0.83333 0.11169 Mdot
0.004 setlinewidth
0.84286 0.11775 moveto
0.84286 0.11423 lineto
stroke
0.008 setlinewidth
0.84286 0.11423 Mdot
0.004 setlinewidth
0.85238 0.11775 moveto
0.85238 0.11958 lineto
stroke
0.008 setlinewidth
0.85238 0.11958 Mdot
0.004 setlinewidth
0.8619 0.11775 moveto
0.8619 0.12332 lineto
stroke
0.008 setlinewidth
0.8619 0.12332 Mdot
0.004 setlinewidth
0.87143 0.11775 moveto
0.87143 0.12244 lineto
stroke
0.008 setlinewidth
0.87143 0.12244 Mdot
0.004 setlinewidth
0.88095 0.11775 moveto
0.88095 0.11775 lineto
stroke
0.008 setlinewidth
0.88095 0.11775 Mdot
0.004 setlinewidth
0.89048 0.11775 moveto
0.89048 0.11317 lineto
stroke
0.008 setlinewidth
0.89048 0.11317 Mdot
0.004 setlinewidth
0.9 0.11775 moveto
0.9 0.11243 lineto
stroke
0.008 setlinewidth
0.9 0.11243 Mdot
0.004 setlinewidth
0.90952 0.11775 moveto
0.90952 0.11604 lineto
stroke
0.008 setlinewidth
0.90952 0.11604 Mdot
0.004 setlinewidth
0.91905 0.11775 moveto
0.91905 0.12098 lineto
stroke
0.008 setlinewidth
0.91905 0.12098 Mdot
0.004 setlinewidth
0.92857 0.11775 moveto
0.92857 0.12318 lineto
stroke
0.008 setlinewidth
0.92857 0.12318 Mdot
0.004 setlinewidth
0.9381 0.11775 moveto
0.9381 0.12091 lineto
stroke
0.008 setlinewidth
0.9381 0.12091 Mdot
0.004 setlinewidth
0.94762 0.11775 moveto
0.94762 0.11611 lineto
stroke
0.008 setlinewidth
0.94762 0.11611 Mdot
0.004 setlinewidth
0.95714 0.11775 moveto
0.95714 0.11276 lineto
stroke
0.008 setlinewidth
0.95714 0.11276 Mdot
0.004 setlinewidth
0.96667 0.11775 moveto
0.96667 0.11354 lineto
stroke
0.008 setlinewidth
0.96667 0.11354 Mdot
0.004 setlinewidth
0.97619 0.11775 moveto
0.97619 0.11775 lineto
stroke
0.008 setlinewidth
0.97619 0.11775 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.17658 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(0.5)] 0.4875 0.10301 1 0 Msboxa
[(1)] 0.4875 0.1913 1 0 Msboxa
[(1.5)] 0.4875 0.27959 1 0 Msboxa
[(2)] 0.4875 0.36788 1 0 Msboxa
[(2.5)] 0.4875 0.45617 1 0 Msboxa
[(3)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(1)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.27959 moveto
0.50625 0.27959 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.27959 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(2)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.45617 moveto
0.50625 0.45617 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.45617 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(3)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.40079 0.01472 lineto
0.41071 0.01472 lineto
0.41567 0.01472 lineto
0.42063 0.01472 lineto
0.4256 0.01472 lineto
0.42684 0.01472 lineto
0.42808 0.01472 lineto
0.42932 0.60332 lineto
0.43056 0.60332 lineto
0.44048 0.60332 lineto
0.46032 0.60332 lineto
0.5 0.60332 lineto
0.51984 0.60332 lineto
0.53968 0.60332 lineto
0.5496 0.60332 lineto
0.55952 0.60332 lineto
0.56448 0.60332 lineto
0.56696 0.60332 lineto
0.5682 0.60332 lineto
0.56944 0.60332 lineto
0.57068 0.60332 lineto
0.57192 0.01472 lineto
0.5744 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.10836 0.49496 [
[(Sequence Plot \(frequency = \(2*Pi\)/5 rad\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.09586 0 1 Msboxa
[(40)] 0.40476 0.09586 0 1 Msboxa
[(60)] 0.59524 0.09586 0 1 Msboxa
[(80)] 0.78571 0.09586 0 1 Msboxa
[(100)] 0.97619 0.09586 0 1 Msboxa
[(n)] 1.00625 0.10836 -1 0 Msboxa
[(-0.2)] 0.01131 0.00937 1 0 Msboxa
[(0.2)] 0.01131 0.20735 1 0 Msboxa
[(0.4)] 0.01131 0.30635 1 0 Msboxa
[(0.6)] 0.01131 0.40534 1 0 Msboxa
[(0.8)] 0.01131 0.50433 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot \(frequency = \(2*Pi\)/5 rad\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.10836 moveto
1 0.10836 lineto
stroke
0.21429 0.10211 moveto
0.21429 0.11461 lineto
stroke
0 setgray
[(20)] 0.21429 0.09586 0 1 Mshowa
0.40476 0.10211 moveto
0.40476 0.11461 lineto
stroke
0 setgray
[(40)] 0.40476 0.09586 0 1 Mshowa
0.59524 0.10211 moveto
0.59524 0.11461 lineto
stroke
0 setgray
[(60)] 0.59524 0.09586 0 1 Mshowa
0.78571 0.10211 moveto
0.78571 0.11461 lineto
stroke
0 setgray
[(80)] 0.78571 0.09586 0 1 Mshowa
0.97619 0.10211 moveto
0.97619 0.11461 lineto
stroke
0 setgray
[(100)] 0.97619 0.09586 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.10836 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.00937 moveto
0.03006 0.00937 lineto
stroke
0 setgray
[(-0.2)] 0.01131 0.00937 1 0 Mshowa
0.01756 0.20735 moveto
0.03006 0.20735 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.20735 1 0 Mshowa
0.01756 0.30635 moveto
0.03006 0.30635 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.30635 1 0 Mshowa
0.01756 0.40534 moveto
0.03006 0.40534 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.40534 1 0 Mshowa
0.01756 0.50433 moveto
0.03006 0.50433 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.50433 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.10836 moveto
0.02381 0.60332 lineto
stroke
0.008 setlinewidth
0.02381 0.60332 Mdot
0.004 setlinewidth
0.03333 0.10836 moveto
0.03333 0.48296 lineto
stroke
0.008 setlinewidth
0.03333 0.48296 Mdot
0.004 setlinewidth
0.04286 0.10836 moveto
0.04286 0.22412 lineto
stroke
0.008 setlinewidth
0.04286 0.22412 Mdot
0.004 setlinewidth
0.05238 0.10836 moveto
0.05238 0.03119 lineto
stroke
0.008 setlinewidth
0.05238 0.03119 Mdot
0.004 setlinewidth
0.0619 0.10836 moveto
0.0619 0.01472 lineto
stroke
0.008 setlinewidth
0.0619 0.01472 Mdot
0.004 setlinewidth
0.07143 0.10836 moveto
0.07143 0.10836 lineto
stroke
0.008 setlinewidth
0.07143 0.10836 Mdot
0.004 setlinewidth
0.08095 0.10836 moveto
0.08095 0.1708 lineto
stroke
0.008 setlinewidth
0.08095 0.1708 Mdot
0.004 setlinewidth
0.09048 0.10836 moveto
0.09048 0.14144 lineto
stroke
0.008 setlinewidth
0.09048 0.14144 Mdot
0.004 setlinewidth
0.1 0.10836 moveto
0.1 0.07942 lineto
stroke
0.008 setlinewidth
0.1 0.07942 Mdot
0.004 setlinewidth
0.10952 0.10836 moveto
0.10952 0.06674 lineto
stroke
0.008 setlinewidth
0.10952 0.06674 Mdot
0.004 setlinewidth
0.11905 0.10836 moveto
0.11905 0.10836 lineto
stroke
0.008 setlinewidth
0.11905 0.10836 Mdot
0.004 setlinewidth
0.12857 0.10836 moveto
0.12857 0.14242 lineto
stroke
0.008 setlinewidth
0.12857 0.14242 Mdot
0.004 setlinewidth
0.1381 0.10836 moveto
0.1381 0.12766 lineto
stroke
0.008 setlinewidth
0.1381 0.12766 Mdot
0.004 setlinewidth
0.14762 0.10836 moveto
0.14762 0.09056 lineto
stroke
0.008 setlinewidth
0.14762 0.09056 Mdot
0.004 setlinewidth
0.15714 0.10836 moveto
0.15714 0.08161 lineto
stroke
0.008 setlinewidth
0.15714 0.08161 Mdot
0.004 setlinewidth
0.16667 0.10836 moveto
0.16667 0.10836 lineto
stroke
0.008 setlinewidth
0.16667 0.10836 Mdot
0.004 setlinewidth
0.17619 0.10836 moveto
0.17619 0.13178 lineto
stroke
0.008 setlinewidth
0.17619 0.13178 Mdot
0.004 setlinewidth
0.18571 0.10836 moveto
0.18571 0.12198 lineto
stroke
0.008 setlinewidth
0.18571 0.12198 Mdot
0.004 setlinewidth
0.19524 0.10836 moveto
0.19524 0.0955 lineto
stroke
0.008 setlinewidth
0.19524 0.0955 Mdot
0.004 setlinewidth
0.20476 0.10836 moveto
0.20476 0.08865 lineto
stroke
0.008 setlinewidth
0.20476 0.08865 Mdot
0.004 setlinewidth
0.21429 0.10836 moveto
0.21429 0.10836 lineto
stroke
0.008 setlinewidth
0.21429 0.10836 Mdot
0.004 setlinewidth
0.22381 0.10836 moveto
0.22381 0.1262 lineto
stroke
0.008 setlinewidth
0.22381 0.1262 Mdot
0.004 setlinewidth
0.23333 0.10836 moveto
0.23333 0.11889 lineto
stroke
0.008 setlinewidth
0.23333 0.11889 Mdot
0.004 setlinewidth
0.24286 0.10836 moveto
0.24286 0.0983 lineto
stroke
0.008 setlinewidth
0.24286 0.0983 Mdot
0.004 setlinewidth
0.25238 0.10836 moveto
0.25238 0.09276 lineto
stroke
0.008 setlinewidth
0.25238 0.09276 Mdot
0.004 setlinewidth
0.2619 0.10836 moveto
0.2619 0.10836 lineto
stroke
0.008 setlinewidth
0.2619 0.10836 Mdot
0.004 setlinewidth
0.27143 0.10836 moveto
0.27143 0.12277 lineto
stroke
0.008 setlinewidth
0.27143 0.12277 Mdot
0.004 setlinewidth
0.28095 0.10836 moveto
0.28095 0.11694 lineto
stroke
0.008 setlinewidth
0.28095 0.11694 Mdot
0.004 setlinewidth
0.29048 0.10836 moveto
0.29048 0.1001 lineto
stroke
0.008 setlinewidth
0.29048 0.1001 Mdot
0.004 setlinewidth
0.3 0.10836 moveto
0.3 0.09545 lineto
stroke
0.008 setlinewidth
0.3 0.09545 Mdot
0.004 setlinewidth
0.30952 0.10836 moveto
0.30952 0.10836 lineto
stroke
0.008 setlinewidth
0.30952 0.10836 Mdot
0.004 setlinewidth
0.31905 0.10836 moveto
0.31905 0.12045 lineto
stroke
0.008 setlinewidth
0.31905 0.12045 Mdot
0.004 setlinewidth
0.32857 0.10836 moveto
0.32857 0.1156 lineto
stroke
0.008 setlinewidth
0.32857 0.1156 Mdot
0.004 setlinewidth
0.3381 0.10836 moveto
0.3381 0.10135 lineto
stroke
0.008 setlinewidth
0.3381 0.10135 Mdot
0.004 setlinewidth
0.34762 0.10836 moveto
0.34762 0.09735 lineto
stroke
0.008 setlinewidth
0.34762 0.09735 Mdot
0.004 setlinewidth
0.35714 0.10836 moveto
0.35714 0.10836 lineto
stroke
0.008 setlinewidth
0.35714 0.10836 Mdot
0.004 setlinewidth
0.36667 0.10836 moveto
0.36667 0.11877 lineto
stroke
0.008 setlinewidth
0.36667 0.11877 Mdot
0.004 setlinewidth
0.37619 0.10836 moveto
0.37619 0.11462 lineto
stroke
0.008 setlinewidth
0.37619 0.11462 Mdot
0.004 setlinewidth
0.38571 0.10836 moveto
0.38571 0.10227 lineto
stroke
0.008 setlinewidth
0.38571 0.10227 Mdot
0.004 setlinewidth
0.39524 0.10836 moveto
0.39524 0.09876 lineto
stroke
0.008 setlinewidth
0.39524 0.09876 Mdot
0.004 setlinewidth
0.40476 0.10836 moveto
0.40476 0.10836 lineto
stroke
0.008 setlinewidth
0.40476 0.10836 Mdot
0.004 setlinewidth
0.41429 0.10836 moveto
0.41429 0.1175 lineto
stroke
0.008 setlinewidth
0.41429 0.1175 Mdot
0.004 setlinewidth
0.42381 0.10836 moveto
0.42381 0.11388 lineto
stroke
0.008 setlinewidth
0.42381 0.11388 Mdot
0.004 setlinewidth
0.43333 0.10836 moveto
0.43333 0.10298 lineto
stroke
0.008 setlinewidth
0.43333 0.10298 Mdot
0.004 setlinewidth
0.44286 0.10836 moveto
0.44286 0.09985 lineto
stroke
0.008 setlinewidth
0.44286 0.09985 Mdot
0.004 setlinewidth
0.45238 0.10836 moveto
0.45238 0.10836 lineto
stroke
0.008 setlinewidth
0.45238 0.10836 Mdot
0.004 setlinewidth
0.4619 0.10836 moveto
0.4619 0.11651 lineto
stroke
0.008 setlinewidth
0.4619 0.11651 Mdot
0.004 setlinewidth
0.47143 0.10836 moveto
0.47143 0.11329 lineto
stroke
0.008 setlinewidth
0.47143 0.11329 Mdot
0.004 setlinewidth
0.48095 0.10836 moveto
0.48095 0.10354 lineto
stroke
0.008 setlinewidth
0.48095 0.10354 Mdot
0.004 setlinewidth
0.49048 0.10836 moveto
0.49048 0.10072 lineto
stroke
0.008 setlinewidth
0.49048 0.10072 Mdot
0.004 setlinewidth
0.5 0.10836 moveto
0.5 0.10836 lineto
stroke
0.008 setlinewidth
0.5 0.10836 Mdot
0.004 setlinewidth
0.50952 0.10836 moveto
0.50952 0.11571 lineto
stroke
0.008 setlinewidth
0.50952 0.11571 Mdot
0.004 setlinewidth
0.51905 0.10836 moveto
0.51905 0.11282 lineto
stroke
0.008 setlinewidth
0.51905 0.11282 Mdot
0.004 setlinewidth
0.52857 0.10836 moveto
0.52857 0.104 lineto
stroke
0.008 setlinewidth
0.52857 0.104 Mdot
0.004 setlinewidth
0.5381 0.10836 moveto
0.5381 0.10143 lineto
stroke
0.008 setlinewidth
0.5381 0.10143 Mdot
0.004 setlinewidth
0.54762 0.10836 moveto
0.54762 0.10836 lineto
stroke
0.008 setlinewidth
0.54762 0.10836 Mdot
0.004 setlinewidth
0.55714 0.10836 moveto
0.55714 0.11505 lineto
stroke
0.008 setlinewidth
0.55714 0.11505 Mdot
0.004 setlinewidth
0.56667 0.10836 moveto
0.56667 0.11243 lineto
stroke
0.008 setlinewidth
0.56667 0.11243 Mdot
0.004 setlinewidth
0.57619 0.10836 moveto
0.57619 0.10437 lineto
stroke
0.008 setlinewidth
0.57619 0.10437 Mdot
0.004 setlinewidth
0.58571 0.10836 moveto
0.58571 0.10201 lineto
stroke
0.008 setlinewidth
0.58571 0.10201 Mdot
0.004 setlinewidth
0.59524 0.10836 moveto
0.59524 0.10836 lineto
stroke
0.008 setlinewidth
0.59524 0.10836 Mdot
0.004 setlinewidth
0.60476 0.10836 moveto
0.60476 0.1145 lineto
stroke
0.008 setlinewidth
0.60476 0.1145 Mdot
0.004 setlinewidth
0.61429 0.10836 moveto
0.61429 0.1121 lineto
stroke
0.008 setlinewidth
0.61429 0.1121 Mdot
0.004 setlinewidth
0.62381 0.10836 moveto
0.62381 0.10469 lineto
stroke
0.008 setlinewidth
0.62381 0.10469 Mdot
0.004 setlinewidth
0.63333 0.10836 moveto
0.63333 0.10251 lineto
stroke
0.008 setlinewidth
0.63333 0.10251 Mdot
0.004 setlinewidth
0.64286 0.10836 moveto
0.64286 0.10836 lineto
stroke
0.008 setlinewidth
0.64286 0.10836 Mdot
0.004 setlinewidth
0.65238 0.10836 moveto
0.65238 0.11404 lineto
stroke
0.008 setlinewidth
0.65238 0.11404 Mdot
0.004 setlinewidth
0.6619 0.10836 moveto
0.6619 0.11182 lineto
stroke
0.008 setlinewidth
0.6619 0.11182 Mdot
0.004 setlinewidth
0.67143 0.10836 moveto
0.67143 0.10496 lineto
stroke
0.008 setlinewidth
0.67143 0.10496 Mdot
0.004 setlinewidth
0.68095 0.10836 moveto
0.68095 0.10293 lineto
stroke
0.008 setlinewidth
0.68095 0.10293 Mdot
0.004 setlinewidth
0.69048 0.10836 moveto
0.69048 0.10836 lineto
stroke
0.008 setlinewidth
0.69048 0.10836 Mdot
0.004 setlinewidth
0.7 0.10836 moveto
0.7 0.11364 lineto
stroke
0.008 setlinewidth
0.7 0.11364 Mdot
0.004 setlinewidth
0.70952 0.10836 moveto
0.70952 0.11158 lineto
stroke
0.008 setlinewidth
0.70952 0.11158 Mdot
0.004 setlinewidth
0.71905 0.10836 moveto
0.71905 0.10519 lineto
stroke
0.008 setlinewidth
0.71905 0.10519 Mdot
0.004 setlinewidth
0.72857 0.10836 moveto
0.72857 0.1033 lineto
stroke
0.008 setlinewidth
0.72857 0.1033 Mdot
0.004 setlinewidth
0.7381 0.10836 moveto
0.7381 0.10836 lineto
stroke
0.008 setlinewidth
0.7381 0.10836 Mdot
0.004 setlinewidth
0.74762 0.10836 moveto
0.74762 0.11329 lineto
stroke
0.008 setlinewidth
0.74762 0.11329 Mdot
0.004 setlinewidth
0.75714 0.10836 moveto
0.75714 0.11137 lineto
stroke
0.008 setlinewidth
0.75714 0.11137 Mdot
0.004 setlinewidth
0.76667 0.10836 moveto
0.76667 0.1054 lineto
stroke
0.008 setlinewidth
0.76667 0.1054 Mdot
0.004 setlinewidth
0.77619 0.10836 moveto
0.77619 0.10362 lineto
stroke
0.008 setlinewidth
0.77619 0.10362 Mdot
0.004 setlinewidth
0.78571 0.10836 moveto
0.78571 0.10836 lineto
stroke
0.008 setlinewidth
0.78571 0.10836 Mdot
0.004 setlinewidth
0.79524 0.10836 moveto
0.79524 0.11299 lineto
stroke
0.008 setlinewidth
0.79524 0.11299 Mdot
0.004 setlinewidth
0.80476 0.10836 moveto
0.80476 0.11119 lineto
stroke
0.008 setlinewidth
0.80476 0.11119 Mdot
0.004 setlinewidth
0.81429 0.10836 moveto
0.81429 0.10557 lineto
stroke
0.008 setlinewidth
0.81429 0.10557 Mdot
0.004 setlinewidth
0.82381 0.10836 moveto
0.82381 0.1039 lineto
stroke
0.008 setlinewidth
0.82381 0.1039 Mdot
0.004 setlinewidth
0.83333 0.10836 moveto
0.83333 0.10836 lineto
stroke
0.008 setlinewidth
0.83333 0.10836 Mdot
0.004 setlinewidth
0.84286 0.10836 moveto
0.84286 0.11272 lineto
stroke
0.008 setlinewidth
0.84286 0.11272 Mdot
0.004 setlinewidth
0.85238 0.10836 moveto
0.85238 0.11102 lineto
stroke
0.008 setlinewidth
0.85238 0.11102 Mdot
0.004 setlinewidth
0.8619 0.10836 moveto
0.8619 0.10573 lineto
stroke
0.008 setlinewidth
0.8619 0.10573 Mdot
0.004 setlinewidth
0.87143 0.10836 moveto
0.87143 0.10415 lineto
stroke
0.008 setlinewidth
0.87143 0.10415 Mdot
0.004 setlinewidth
0.88095 0.10836 moveto
0.88095 0.10836 lineto
stroke
0.008 setlinewidth
0.88095 0.10836 Mdot
0.004 setlinewidth
0.89048 0.10836 moveto
0.89048 0.11248 lineto
stroke
0.008 setlinewidth
0.89048 0.11248 Mdot
0.004 setlinewidth
0.9 0.10836 moveto
0.9 0.11088 lineto
stroke
0.008 setlinewidth
0.9 0.11088 Mdot
0.004 setlinewidth
0.90952 0.10836 moveto
0.90952 0.10587 lineto
stroke
0.008 setlinewidth
0.90952 0.10587 Mdot
0.004 setlinewidth
0.91905 0.10836 moveto
0.91905 0.10438 lineto
stroke
0.008 setlinewidth
0.91905 0.10438 Mdot
0.004 setlinewidth
0.92857 0.10836 moveto
0.92857 0.10836 lineto
stroke
0.008 setlinewidth
0.92857 0.10836 Mdot
0.004 setlinewidth
0.9381 0.10836 moveto
0.9381 0.11227 lineto
stroke
0.008 setlinewidth
0.9381 0.11227 Mdot
0.004 setlinewidth
0.94762 0.10836 moveto
0.94762 0.11075 lineto
stroke
0.008 setlinewidth
0.94762 0.11075 Mdot
0.004 setlinewidth
0.95714 0.10836 moveto
0.95714 0.106 lineto
stroke
0.008 setlinewidth
0.95714 0.106 Mdot
0.004 setlinewidth
0.96667 0.10836 moveto
0.96667 0.10458 lineto
stroke
0.008 setlinewidth
0.96667 0.10458 Mdot
0.004 setlinewidth
0.97619 0.10836 moveto
0.97619 0.10836 lineto
stroke
0.008 setlinewidth
0.97619 0.10836 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.23544 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(0.5)] 0.4875 0.13244 1 0 Msboxa
[(1)] 0.4875 0.25016 1 0 Msboxa
[(1.5)] 0.4875 0.36788 1 0 Msboxa
[(2)] 0.4875 0.4856 1 0 Msboxa
[(2.5)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(1)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(2)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.39087 0.01472 lineto
0.39583 0.01472 lineto
0.39831 0.01472 lineto
0.40079 0.01472 lineto
0.40203 0.01472 lineto
0.40327 0.01472 lineto
0.40451 0.01472 lineto
0.40575 0.60332 lineto
0.40823 0.60332 lineto
0.41071 0.60332 lineto
0.42063 0.60332 lineto
0.46032 0.60332 lineto
0.5 0.60332 lineto
0.53968 0.60332 lineto
0.55952 0.60332 lineto
0.56944 0.60332 lineto
0.57937 0.60332 lineto
0.58433 0.60332 lineto
0.58929 0.60332 lineto
0.59177 0.60332 lineto
0.59301 0.60332 lineto
0.59425 0.60332 lineto
0.59549 0.01472 lineto
0.59673 0.01472 lineto
0.59921 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.02381 0.00952 0.11775 0.48556 [
[(Sequence Plot \(frequency = Pi/2 rad\))] 0.5 0.62428 0 -1 Msboxa
[(20)] 0.21429 0.10525 0 1 Msboxa
[(40)] 0.40476 0.10525 0 1 Msboxa
[(60)] 0.59524 0.10525 0 1 Msboxa
[(80)] 0.78571 0.10525 0 1 Msboxa
[(100)] 0.97619 0.10525 0 1 Msboxa
[(n)] 1.00625 0.11775 -1 0 Msboxa
[(-0.2)] 0.01131 0.02064 1 0 Msboxa
[(0.2)] 0.01131 0.21487 1 0 Msboxa
[(0.4)] 0.01131 0.31198 1 0 Msboxa
[(0.6)] 0.01131 0.40909 1 0 Msboxa
[(0.8)] 0.01131 0.50621 1 0 Msboxa
[(1)] 0.01131 0.60332 1 0 Msboxa
[( )] 0.02381 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot \(frequency = Pi/2 rad\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.11775 moveto
1 0.11775 lineto
stroke
0.21429 0.1115 moveto
0.21429 0.124 lineto
stroke
0 setgray
[(20)] 0.21429 0.10525 0 1 Mshowa
0.40476 0.1115 moveto
0.40476 0.124 lineto
stroke
0 setgray
[(40)] 0.40476 0.10525 0 1 Mshowa
0.59524 0.1115 moveto
0.59524 0.124 lineto
stroke
0 setgray
[(60)] 0.59524 0.10525 0 1 Mshowa
0.78571 0.1115 moveto
0.78571 0.124 lineto
stroke
0 setgray
[(80)] 0.78571 0.10525 0 1 Mshowa
0.97619 0.1115 moveto
0.97619 0.124 lineto
stroke
0 setgray
[(100)] 0.97619 0.10525 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.11775 -1 0 Mshowa
0.02381 0 moveto
0.02381 0.61803 lineto
stroke
0.01756 0.02064 moveto
0.03006 0.02064 lineto
stroke
0 setgray
[(-0.2)] 0.01131 0.02064 1 0 Mshowa
0.01756 0.21487 moveto
0.03006 0.21487 lineto
stroke
0 setgray
[(0.2)] 0.01131 0.21487 1 0 Mshowa
0.01756 0.31198 moveto
0.03006 0.31198 lineto
stroke
0 setgray
[(0.4)] 0.01131 0.31198 1 0 Mshowa
0.01756 0.40909 moveto
0.03006 0.40909 lineto
stroke
0 setgray
[(0.6)] 0.01131 0.40909 1 0 Mshowa
0.01756 0.50621 moveto
0.03006 0.50621 lineto
stroke
0 setgray
[(0.8)] 0.01131 0.50621 1 0 Mshowa
0.01756 0.60332 moveto
0.03006 0.60332 lineto
stroke
0 setgray
[(1)] 0.01131 0.60332 1 0 Mshowa
0 setgray
[( )] 0.02381 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.11775 moveto
0.02381 0.60332 lineto
stroke
0.008 setlinewidth
0.02381 0.60332 Mdot
0.004 setlinewidth
0.03333 0.11775 moveto
0.03333 0.42687 lineto
stroke
0.008 setlinewidth
0.03333 0.42687 Mdot
0.004 setlinewidth
0.04286 0.11775 moveto
0.04286 0.11775 lineto
stroke
0.008 setlinewidth
0.04286 0.11775 Mdot
0.004 setlinewidth
0.05238 0.11775 moveto
0.05238 0.01472 lineto
stroke
0.008 setlinewidth
0.05238 0.01472 Mdot
0.004 setlinewidth
0.0619 0.11775 moveto
0.0619 0.11775 lineto
stroke
0.008 setlinewidth
0.0619 0.11775 Mdot
0.004 setlinewidth
0.07143 0.11775 moveto
0.07143 0.17958 lineto
stroke
0.008 setlinewidth
0.07143 0.17958 Mdot
0.004 setlinewidth
0.08095 0.11775 moveto
0.08095 0.11775 lineto
stroke
0.008 setlinewidth
0.08095 0.11775 Mdot
0.004 setlinewidth
0.09048 0.11775 moveto
0.09048 0.0736 lineto
stroke
0.008 setlinewidth
0.09048 0.0736 Mdot
0.004 setlinewidth
0.1 0.11775 moveto
0.1 0.11775 lineto
stroke
0.008 setlinewidth
0.1 0.11775 Mdot
0.004 setlinewidth
0.10952 0.11775 moveto
0.10952 0.1521 lineto
stroke
0.008 setlinewidth
0.10952 0.1521 Mdot
0.004 setlinewidth
0.11905 0.11775 moveto
0.11905 0.11775 lineto
stroke
0.008 setlinewidth
0.11905 0.11775 Mdot
0.004 setlinewidth
0.12857 0.11775 moveto
0.12857 0.08965 lineto
stroke
0.008 setlinewidth
0.12857 0.08965 Mdot
0.004 setlinewidth
0.1381 0.11775 moveto
0.1381 0.11775 lineto
stroke
0.008 setlinewidth
0.1381 0.11775 Mdot
0.004 setlinewidth
0.14762 0.11775 moveto
0.14762 0.14153 lineto
stroke
0.008 setlinewidth
0.14762 0.14153 Mdot
0.004 setlinewidth
0.15714 0.11775 moveto
0.15714 0.11775 lineto
stroke
0.008 setlinewidth
0.15714 0.11775 Mdot
0.004 setlinewidth
0.16667 0.11775 moveto
0.16667 0.09715 lineto
stroke
0.008 setlinewidth
0.16667 0.09715 Mdot
0.004 setlinewidth
0.17619 0.11775 moveto
0.17619 0.11775 lineto
stroke
0.008 setlinewidth
0.17619 0.11775 Mdot
0.004 setlinewidth
0.18571 0.11775 moveto
0.18571 0.13594 lineto
stroke
0.008 setlinewidth
0.18571 0.13594 Mdot
0.004 setlinewidth
0.19524 0.11775 moveto
0.19524 0.11775 lineto
stroke
0.008 setlinewidth
0.19524 0.11775 Mdot
0.004 setlinewidth
0.20476 0.11775 moveto
0.20476 0.10149 lineto
stroke
0.008 setlinewidth
0.20476 0.10149 Mdot
0.004 setlinewidth
0.21429 0.11775 moveto
0.21429 0.11775 lineto
stroke
0.008 setlinewidth
0.21429 0.11775 Mdot
0.004 setlinewidth
0.22381 0.11775 moveto
0.22381 0.13247 lineto
stroke
0.008 setlinewidth
0.22381 0.13247 Mdot
0.004 setlinewidth
0.23333 0.11775 moveto
0.23333 0.11775 lineto
stroke
0.008 setlinewidth
0.23333 0.11775 Mdot
0.004 setlinewidth
0.24286 0.11775 moveto
0.24286 0.10431 lineto
stroke
0.008 setlinewidth
0.24286 0.10431 Mdot
0.004 setlinewidth
0.25238 0.11775 moveto
0.25238 0.11775 lineto
stroke
0.008 setlinewidth
0.25238 0.11775 Mdot
0.004 setlinewidth
0.2619 0.11775 moveto
0.2619 0.13012 lineto
stroke
0.008 setlinewidth
0.2619 0.13012 Mdot
0.004 setlinewidth
0.27143 0.11775 moveto
0.27143 0.11775 lineto
stroke
0.008 setlinewidth
0.27143 0.11775 Mdot
0.004 setlinewidth
0.28095 0.11775 moveto
0.28095 0.10631 lineto
stroke
0.008 setlinewidth
0.28095 0.10631 Mdot
0.004 setlinewidth
0.29048 0.11775 moveto
0.29048 0.11775 lineto
stroke
0.008 setlinewidth
0.29048 0.11775 Mdot
0.004 setlinewidth
0.3 0.11775 moveto
0.3 0.12841 lineto
stroke
0.008 setlinewidth
0.3 0.12841 Mdot
0.004 setlinewidth
0.30952 0.11775 moveto
0.30952 0.11775 lineto
stroke
0.008 setlinewidth
0.30952 0.11775 Mdot
0.004 setlinewidth
0.31905 0.11775 moveto
0.31905 0.10778 lineto
stroke
0.008 setlinewidth
0.31905 0.10778 Mdot
0.004 setlinewidth
0.32857 0.11775 moveto
0.32857 0.11775 lineto
stroke
0.008 setlinewidth
0.32857 0.11775 Mdot
0.004 setlinewidth
0.3381 0.11775 moveto
0.3381 0.12712 lineto
stroke
0.008 setlinewidth
0.3381 0.12712 Mdot
0.004 setlinewidth
0.34762 0.11775 moveto
0.34762 0.11775 lineto
stroke
0.008 setlinewidth
0.34762 0.11775 Mdot
0.004 setlinewidth
0.35714 0.11775 moveto
0.35714 0.10892 lineto
stroke
0.008 setlinewidth
0.35714 0.10892 Mdot
0.004 setlinewidth
0.36667 0.11775 moveto
0.36667 0.11775 lineto
stroke
0.008 setlinewidth
0.36667 0.11775 Mdot
0.004 setlinewidth
0.37619 0.11775 moveto
0.37619 0.12611 lineto
stroke
0.008 setlinewidth
0.37619 0.12611 Mdot
0.004 setlinewidth
0.38571 0.11775 moveto
0.38571 0.11775 lineto
stroke
0.008 setlinewidth
0.38571 0.11775 Mdot
0.004 setlinewidth
0.39524 0.11775 moveto
0.39524 0.10983 lineto
stroke
0.008 setlinewidth
0.39524 0.10983 Mdot
0.004 setlinewidth
0.40476 0.11775 moveto
0.40476 0.11775 lineto
stroke
0.008 setlinewidth
0.40476 0.11775 Mdot
0.004 setlinewidth
0.41429 0.11775 moveto
0.41429 0.12529 lineto
stroke
0.008 setlinewidth
0.41429 0.12529 Mdot
0.004 setlinewidth
0.42381 0.11775 moveto
0.42381 0.11775 lineto
stroke
0.008 setlinewidth
0.42381 0.11775 Mdot
0.004 setlinewidth
0.43333 0.11775 moveto
0.43333 0.11057 lineto
stroke
0.008 setlinewidth
0.43333 0.11057 Mdot
0.004 setlinewidth
0.44286 0.11775 moveto
0.44286 0.11775 lineto
stroke
0.008 setlinewidth
0.44286 0.11775 Mdot
0.004 setlinewidth
0.45238 0.11775 moveto
0.45238 0.12462 lineto
stroke
0.008 setlinewidth
0.45238 0.12462 Mdot
0.004 setlinewidth
0.4619 0.11775 moveto
0.4619 0.11775 lineto
stroke
0.008 setlinewidth
0.4619 0.11775 Mdot
0.004 setlinewidth
0.47143 0.11775 moveto
0.47143 0.11118 lineto
stroke
0.008 setlinewidth
0.47143 0.11118 Mdot
0.004 setlinewidth
0.48095 0.11775 moveto
0.48095 0.11775 lineto
stroke
0.008 setlinewidth
0.48095 0.11775 Mdot
0.004 setlinewidth
0.49048 0.11775 moveto
0.49048 0.12406 lineto
stroke
0.008 setlinewidth
0.49048 0.12406 Mdot
0.004 setlinewidth
0.5 0.11775 moveto
0.5 0.11775 lineto
stroke
0.008 setlinewidth
0.5 0.11775 Mdot
0.004 setlinewidth
0.50952 0.11775 moveto
0.50952 0.11169 lineto
stroke
0.008 setlinewidth
0.50952 0.11169 Mdot
0.004 setlinewidth
0.51905 0.11775 moveto
0.51905 0.11775 lineto
stroke
0.008 setlinewidth
0.51905 0.11775 Mdot
0.004 setlinewidth
0.52857 0.11775 moveto
0.52857 0.12359 lineto
stroke
0.008 setlinewidth
0.52857 0.12359 Mdot
0.004 setlinewidth
0.5381 0.11775 moveto
0.5381 0.11775 lineto
stroke
0.008 setlinewidth
0.5381 0.11775 Mdot
0.004 setlinewidth
0.54762 0.11775 moveto
0.54762 0.11213 lineto
stroke
0.008 setlinewidth
0.54762 0.11213 Mdot
0.004 setlinewidth
0.55714 0.11775 moveto
0.55714 0.11775 lineto
stroke
0.008 setlinewidth
0.55714 0.11775 Mdot
0.004 setlinewidth
0.56667 0.11775 moveto
0.56667 0.12318 lineto
stroke
0.008 setlinewidth
0.56667 0.12318 Mdot
0.004 setlinewidth
0.57619 0.11775 moveto
0.57619 0.11775 lineto
stroke
0.008 setlinewidth
0.57619 0.11775 Mdot
0.004 setlinewidth
0.58571 0.11775 moveto
0.58571 0.11252 lineto
stroke
0.008 setlinewidth
0.58571 0.11252 Mdot
0.004 setlinewidth
0.59524 0.11775 moveto
0.59524 0.11775 lineto
stroke
0.008 setlinewidth
0.59524 0.11775 Mdot
0.004 setlinewidth
0.60476 0.11775 moveto
0.60476 0.12282 lineto
stroke
0.008 setlinewidth
0.60476 0.12282 Mdot
0.004 setlinewidth
0.61429 0.11775 moveto
0.61429 0.11775 lineto
stroke
0.008 setlinewidth
0.61429 0.11775 Mdot
0.004 setlinewidth
0.62381 0.11775 moveto
0.62381 0.11285 lineto
stroke
0.008 setlinewidth
0.62381 0.11285 Mdot
0.004 setlinewidth
0.63333 0.11775 moveto
0.63333 0.11775 lineto
stroke
0.008 setlinewidth
0.63333 0.11775 Mdot
0.004 setlinewidth
0.64286 0.11775 moveto
0.64286 0.12251 lineto
stroke
0.008 setlinewidth
0.64286 0.12251 Mdot
0.004 setlinewidth
0.65238 0.11775 moveto
0.65238 0.11775 lineto
stroke
0.008 setlinewidth
0.65238 0.11775 Mdot
0.004 setlinewidth
0.6619 0.11775 moveto
0.6619 0.11314 lineto
stroke
0.008 setlinewidth
0.6619 0.11314 Mdot
0.004 setlinewidth
0.67143 0.11775 moveto
0.67143 0.11775 lineto
stroke
0.008 setlinewidth
0.67143 0.11775 Mdot
0.004 setlinewidth
0.68095 0.11775 moveto
0.68095 0.12223 lineto
stroke
0.008 setlinewidth
0.68095 0.12223 Mdot
0.004 setlinewidth
0.69048 0.11775 moveto
0.69048 0.11775 lineto
stroke
0.008 setlinewidth
0.69048 0.11775 Mdot
0.004 setlinewidth
0.7 0.11775 moveto
0.7 0.1134 lineto
stroke
0.008 setlinewidth
0.7 0.1134 Mdot
0.004 setlinewidth
0.70952 0.11775 moveto
0.70952 0.11775 lineto
stroke
0.008 setlinewidth
0.70952 0.11775 Mdot
0.004 setlinewidth
0.71905 0.11775 moveto
0.71905 0.12199 lineto
stroke
0.008 setlinewidth
0.71905 0.12199 Mdot
0.004 setlinewidth
0.72857 0.11775 moveto
0.72857 0.11775 lineto
stroke
0.008 setlinewidth
0.72857 0.11775 Mdot
0.004 setlinewidth
0.7381 0.11775 moveto
0.7381 0.11363 lineto
stroke
0.008 setlinewidth
0.7381 0.11363 Mdot
0.004 setlinewidth
0.74762 0.11775 moveto
0.74762 0.11775 lineto
stroke
0.008 setlinewidth
0.74762 0.11775 Mdot
0.004 setlinewidth
0.75714 0.11775 moveto
0.75714 0.12177 lineto
stroke
0.008 setlinewidth
0.75714 0.12177 Mdot
0.004 setlinewidth
0.76667 0.11775 moveto
0.76667 0.11775 lineto
stroke
0.008 setlinewidth
0.76667 0.11775 Mdot
0.004 setlinewidth
0.77619 0.11775 moveto
0.77619 0.11384 lineto
stroke
0.008 setlinewidth
0.77619 0.11384 Mdot
0.004 setlinewidth
0.78571 0.11775 moveto
0.78571 0.11775 lineto
stroke
0.008 setlinewidth
0.78571 0.11775 Mdot
0.004 setlinewidth
0.79524 0.11775 moveto
0.79524 0.12157 lineto
stroke
0.008 setlinewidth
0.79524 0.12157 Mdot
0.004 setlinewidth
0.80476 0.11775 moveto
0.80476 0.11775 lineto
stroke
0.008 setlinewidth
0.80476 0.11775 Mdot
0.004 setlinewidth
0.81429 0.11775 moveto
0.81429 0.11403 lineto
stroke
0.008 setlinewidth
0.81429 0.11403 Mdot
0.004 setlinewidth
0.82381 0.11775 moveto
0.82381 0.11775 lineto
stroke
0.008 setlinewidth
0.82381 0.11775 Mdot
0.004 setlinewidth
0.83333 0.11775 moveto
0.83333 0.12139 lineto
stroke
0.008 setlinewidth
0.83333 0.12139 Mdot
0.004 setlinewidth
0.84286 0.11775 moveto
0.84286 0.11775 lineto
stroke
0.008 setlinewidth
0.84286 0.11775 Mdot
0.004 setlinewidth
0.85238 0.11775 moveto
0.85238 0.1142 lineto
stroke
0.008 setlinewidth
0.85238 0.1142 Mdot
0.004 setlinewidth
0.8619 0.11775 moveto
0.8619 0.11775 lineto
stroke
0.008 setlinewidth
0.8619 0.11775 Mdot
0.004 setlinewidth
0.87143 0.11775 moveto
0.87143 0.12123 lineto
stroke
0.008 setlinewidth
0.87143 0.12123 Mdot
0.004 setlinewidth
0.88095 0.11775 moveto
0.88095 0.11775 lineto
stroke
0.008 setlinewidth
0.88095 0.11775 Mdot
0.004 setlinewidth
0.89048 0.11775 moveto
0.89048 0.11436 lineto
stroke
0.008 setlinewidth
0.89048 0.11436 Mdot
0.004 setlinewidth
0.9 0.11775 moveto
0.9 0.11775 lineto
stroke
0.008 setlinewidth
0.9 0.11775 Mdot
0.004 setlinewidth
0.90952 0.11775 moveto
0.90952 0.12108 lineto
stroke
0.008 setlinewidth
0.90952 0.12108 Mdot
0.004 setlinewidth
0.91905 0.11775 moveto
0.91905 0.11775 lineto
stroke
0.008 setlinewidth
0.91905 0.11775 Mdot
0.004 setlinewidth
0.92857 0.11775 moveto
0.92857 0.1145 lineto
stroke
0.008 setlinewidth
0.92857 0.1145 Mdot
0.004 setlinewidth
0.9381 0.11775 moveto
0.9381 0.11775 lineto
stroke
0.008 setlinewidth
0.9381 0.11775 Mdot
0.004 setlinewidth
0.94762 0.11775 moveto
0.94762 0.12094 lineto
stroke
0.008 setlinewidth
0.94762 0.12094 Mdot
0.004 setlinewidth
0.95714 0.11775 moveto
0.95714 0.11775 lineto
stroke
0.008 setlinewidth
0.95714 0.11775 Mdot
0.004 setlinewidth
0.96667 0.11775 moveto
0.96667 0.11463 lineto
stroke
0.008 setlinewidth
0.96667 0.11463 Mdot
0.004 setlinewidth
0.97619 0.11775 moveto
0.97619 0.11775 lineto
stroke
0.008 setlinewidth
0.97619 0.11775 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.2943 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(0.5)] 0.4875 0.16187 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.5)] 0.4875 0.45617 1 0 Msboxa
[(2)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.16187 moveto
0.50625 0.16187 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.16187 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.45617 moveto
0.50625 0.45617 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.45617 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(2)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.36111 0.01472 lineto
0.37103 0.01472 lineto
0.37599 0.01472 lineto
0.37847 0.01472 lineto
0.37971 0.01472 lineto
0.38095 0.01472 lineto
0.38219 0.60332 lineto
0.38343 0.60332 lineto
0.38591 0.60332 lineto
0.39087 0.60332 lineto
0.40079 0.60332 lineto
0.42063 0.60332 lineto
0.46032 0.60332 lineto
0.5 0.60332 lineto
0.53968 0.60332 lineto
0.57937 0.60332 lineto
0.59921 0.60332 lineto
0.60913 0.60332 lineto
0.61409 0.60332 lineto
0.61657 0.60332 lineto
0.61781 0.60332 lineto
0.61905 0.60332 lineto
0.62029 0.01472 lineto
0.62153 0.01472 lineto
0.62401 0.01472 lineto
0.62897 0.01472 lineto
0.63889 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Code for the plots
:[font = input; endGroup; endGroup; ]
Block[ {formatstr, i, n, magplot, seqplot, splabel, w},
       formatstr = "Sequence Plot (freq = `` rad)";
       dtft = DTFTransform[Sinc[2 Pi i n / 20], n, w];
       For [ i = 1, i <= 5, i++,
             splabel = ToString[StringForm[formatstr,
                              InputForm[2 Pi i / 20]] ]; 
             seqplot = SequencePlot[Sinc[2 Pi i n / 20],
                                {n, 0, 100},
      			                DisplayFunction -> Identity,
      			                PlotLabel -> splabel];
             magplot = MagPhasePlot[dtft, {w, -2 Pi, 2 Pi},
             					DisplayFunction -> Identity,
             					PhaseRangeScale -> Null ];
		     If [ TrueQ[ $VersionNumber >= 2.0 ],
		          Show[ GraphicsArray[ {seqplot, magplot[[1]] } ],
		                DisplayFunction :> $DisplayFunction ],
		          Show[ seqplot,
		                DisplayFunction :> $DisplayFunction ];
		          Show[ magplot[[1]],
		                DisplayFunction :> $DisplayFunction ] ] ] ]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example #2:  Changing the Sampling Rate
:[font = text; inactive; ]
		A very important property of the Fourier Transform is that if the signal is compressed  (or decimated) by some factor (i.e., the sequence is sampled at "factor*n" positions and the rest of the signal is thrown away) the spectrum will expand by that same factor. This property imposes a limit in the achievable compression of a signal if the information must not be corrupted. 
:[font = text; inactive; ]
		In the following example, the input signal will be compressed by a factor of two. The compressed function is f2 [n]= f1[2*n].  Phase information remains unchanged.  Because of this property of the expansion in the frequency domain, an arbitrary signal must be low-pass filtered before the decimation is performed. For example, for a decimation of factor of two, a low-pass filter of cutoff frequency (Pi/2) should be used. This prevents aliasing from happening.  Aliasing is the phenomenon that occurs when high frequency information of the signal appears in the low frequency spectrum. 

:[font = input; startGroup; Cclosed; ]
f1 = Sinc [2 Pi n / 20];
f2 = Sinc [2 Pi 2 n /20];
MagPhasePlot[DTFTransform[f1, n, w],
             {w, -2 Pi, 2 Pi},
             PhaseRangeScale -> Null];
MagPhasePlot[DTFTransform[f2, n, w],
             {w, -2 Pi, 2 Pi},
             PhaseRangeScale -> Null]
:[font = postscript; inactive; PostScript; output; startGroup; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.05886 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(2)] 0.4875 0.13244 1 0 Msboxa
[(4)] 0.4875 0.25016 1 0 Msboxa
[(6)] 0.4875 0.36788 1 0 Msboxa
[(8)] 0.4875 0.4856 1 0 Msboxa
[(10)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(2)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(4)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(6)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(8)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(10)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.44048 0.01472 lineto
0.4504 0.01472 lineto
0.46032 0.01472 lineto
0.47024 0.01472 lineto
0.47272 0.01472 lineto
0.47396 0.01472 lineto
0.4752 0.01472 lineto
0.47644 0.60332 lineto
0.47768 0.60332 lineto
0.47892 0.60332 lineto
0.48016 0.60332 lineto
0.5 0.60332 lineto
0.50992 0.60332 lineto
0.51488 0.60332 lineto
0.51736 0.60332 lineto
0.51984 0.60332 lineto
0.52108 0.60332 lineto
0.52232 0.60332 lineto
0.52356 0.60332 lineto
0.5248 0.01472 lineto
0.52604 0.01472 lineto
0.52728 0.01472 lineto
0.52976 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0.11772 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(1)] 0.4875 0.13244 1 0 Msboxa
[(2)] 0.4875 0.25016 1 0 Msboxa
[(3)] 0.4875 0.36788 1 0 Msboxa
[(4)] 0.4875 0.4856 1 0 Msboxa
[(5)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13244 moveto
0.50625 0.13244 lineto
stroke
0 setgray
[(1)] 0.4875 0.13244 1 0 Mshowa
0.49375 0.25016 moveto
0.50625 0.25016 lineto
stroke
0 setgray
[(2)] 0.4875 0.25016 1 0 Mshowa
0.49375 0.36788 moveto
0.50625 0.36788 lineto
stroke
0 setgray
[(3)] 0.4875 0.36788 1 0 Mshowa
0.49375 0.4856 moveto
0.50625 0.4856 lineto
stroke
0 setgray
[(4)] 0.4875 0.4856 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(5)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.22222 0.01472 lineto
0.2619 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.40079 0.01472 lineto
0.42063 0.01472 lineto
0.44048 0.01472 lineto
0.44544 0.01472 lineto
0.44792 0.01472 lineto
0.44916 0.01472 lineto
0.4504 0.01472 lineto
0.45164 0.01472 lineto
0.45288 0.60332 lineto
0.45536 0.60332 lineto
0.46032 0.60332 lineto
0.5 0.60332 lineto
0.51984 0.60332 lineto
0.52976 0.60332 lineto
0.53472 0.60332 lineto
0.53968 0.60332 lineto
0.54216 0.60332 lineto
0.54464 0.60332 lineto
0.54588 0.60332 lineto
0.54712 0.60332 lineto
0.54836 0.01472 lineto
0.5496 0.01472 lineto
0.55208 0.01472 lineto
0.55456 0.01472 lineto
0.55952 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; endGroup; endGroup; pictureLeft = 38; pictureWidth = 283; pictureHeight = 175; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; startGroup; Cclosed; ]
Library of Other DTFT Relationships
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Impulse
:[font = info; inactive; startGroup; Cclosed; ]
-- Time Response
:[font = input; startGroup; ]
signal = Impulse[n-1];
SequencePlot[signal, {n,-2,5}]
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.29592 0.13605 0.01472 0.5886 [
[(Sequence Plot)] 0.5 0.62428 0 -1 Msboxa
[(-2)] 0.02381 0.00222 0 1 Msboxa
[(-1)] 0.15986 0.00222 0 1 Msboxa
[(1)] 0.43197 0.00222 0 1 Msboxa
[(2)] 0.56803 0.00222 0 1 Msboxa
[(3)] 0.70408 0.00222 0 1 Msboxa
[(4)] 0.84014 0.00222 0 1 Msboxa
[(5)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.28342 0.13244 1 0 Msboxa
[(0.4)] 0.28342 0.25016 1 0 Msboxa
[(0.6)] 0.28342 0.36788 1 0 Msboxa
[(0.8)] 0.28342 0.4856 1 0 Msboxa
[(1)] 0.28342 0.60332 1 0 Msboxa
[( )] 0.29592 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-2)] 0.02381 0.00222 0 1 Mshowa
0.15986 0.00847 moveto
0.15986 0.02097 lineto
stroke
0 setgray
[(-1)] 0.15986 0.00222 0 1 Mshowa
0.43197 0.00847 moveto
0.43197 0.02097 lineto
stroke
0 setgray
[(1)] 0.43197 0.00222 0 1 Mshowa
0.56803 0.00847 moveto
0.56803 0.02097 lineto
stroke
0 setgray
[(2)] 0.56803 0.00222 0 1 Mshowa
0.70408 0.00847 moveto
0.70408 0.02097 lineto
stroke
0 setgray
[(3)] 0.70408 0.00222 0 1 Mshowa
0.84014 0.00847 moveto
0.84014 0.02097 lineto
stroke
0 setgray
[(4)] 0.84014 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(5)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.29592 0 moveto
0.29592 0.61803 lineto
stroke
0.28967 0.13244 moveto
0.30217 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.28342 0.13244 1 0 Mshowa
0.28967 0.25016 moveto
0.30217 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.28342 0.25016 1 0 Mshowa
0.28967 0.36788 moveto
0.30217 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.28342 0.36788 1 0 Mshowa
0.28967 0.4856 moveto
0.30217 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.28342 0.4856 1 0 Mshowa
0.28967 0.60332 moveto
0.30217 0.60332 lineto
stroke
0 setgray
[(1)] 0.28342 0.60332 1 0 Mshowa
0 setgray
[( )] 0.29592 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.008 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.024 setlinewidth
0.02381 0.01472 Mdot
0.008 setlinewidth
0.15986 0.01472 moveto
0.15986 0.01472 lineto
stroke
0.024 setlinewidth
0.15986 0.01472 Mdot
0.008 setlinewidth
0.29592 0.01472 moveto
0.29592 0.01472 lineto
stroke
0.024 setlinewidth
0.29592 0.01472 Mdot
0.008 setlinewidth
0.43197 0.01472 moveto
0.43197 0.60332 lineto
stroke
0.024 setlinewidth
0.43197 0.60332 Mdot
0.008 setlinewidth
0.56803 0.01472 moveto
0.56803 0.01472 lineto
stroke
0.024 setlinewidth
0.56803 0.01472 Mdot
0.008 setlinewidth
0.70408 0.01472 moveto
0.70408 0.01472 lineto
stroke
0.024 setlinewidth
0.70408 0.01472 Mdot
0.008 setlinewidth
0.84014 0.01472 moveto
0.84014 0.01472 lineto
stroke
0.024 setlinewidth
0.84014 0.01472 Mdot
0.008 setlinewidth
0.97619 0.01472 moveto
0.97619 0.01472 lineto
stroke
0.024 setlinewidth
0.97619 0.01472 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = info; inactive; startGroup; Cclosed; ]
-- DTFT
:[font = input; startGroup; ]
MagPhasePlot[ DTFTransform[ Impulse[n], n, w ],
                     {w, -2Pi, 2Pi} ]
:[font = message; inactive; ]
Set::raw: Cannot assign to raw object 1..
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 -0.27959 0.5886 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(0.6)] 0.4875 0.07358 1 0 Msboxa
[(0.8)] 0.4875 0.1913 1 0 Msboxa
[(1.2)] 0.4875 0.42674 1 0 Msboxa
[(1.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(1.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(1.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.5886 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-0.4)] 0.4875 0.07358 1 0 Msboxa
[(-0.2)] 0.4875 0.1913 1 0 Msboxa
[(0.2)] 0.4875 0.42674 1 0 Msboxa
[(0.4)] 0.4875 0.54446 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07358 moveto
0.50625 0.07358 lineto
stroke
0 setgray
[(-0.4)] 0.4875 0.07358 1 0 Mshowa
0.49375 0.1913 moveto
0.50625 0.1913 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.1913 1 0 Mshowa
0.49375 0.42674 moveto
0.50625 0.42674 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.42674 1 0 Mshowa
0.49375 0.54446 moveto
0.50625 0.54446 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.54446 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.30902 lineto
0.10317 0.30902 lineto
0.14286 0.30902 lineto
0.18254 0.30902 lineto
0.22222 0.30902 lineto
0.2619 0.30902 lineto
0.30159 0.30902 lineto
0.34127 0.30902 lineto
0.38095 0.30902 lineto
0.42063 0.30902 lineto
0.46032 0.30902 lineto
0.5 0.30902 lineto
0.53968 0.30902 lineto
0.57937 0.30902 lineto
0.61905 0.30902 lineto
0.65873 0.30902 lineto
0.69841 0.30902 lineto
0.7381 0.30902 lineto
0.77778 0.30902 lineto
0.81746 0.30902 lineto
0.85714 0.30902 lineto
0.89683 0.30902 lineto
0.93651 0.30902 lineto
0.97619 0.30902 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{Graphics[{{Line[{{-6.283185307179586476, 1.}, 
       {-5.759586531581287603, 1.}, 
       {-5.23598775598298873, 1.}, 
       {-4.712388980384689857, 1.}, 
       {-4.188790204786390984, 1.}, 
       {-3.665191429188092112, 1.}, 
       {-3.141592653589793239, 1.}, 
       {-2.617993877991494366, 1.}, 
       {-2.094395102393195493, 1.}, 
       {-1.57079632679489662, 1.}, 
       {-1.047197551196597747, 1.}, 
       {-0.5235987755982988739, 1.}, 
       {-(8.673617379884035472*10^-19), 1.}, 
       {0.5235987755982988721, 1.}, 
       {1.047197551196597745, 1.}, 
       {1.570796326794896618, 1.}, 
       {2.094395102393195491, 1.}, 
       {2.617993877991494364, 1.}, 
       {3.141592653589793237, 1.}, 
       {3.66519142918809211, 1.}, 
       {4.188790204786390983, 1.}, 
       {4.712388980384689856, 1.}, 
       {5.235987755982988729, 1.}, 
       {5.759586531581287601, 1.}, 
       {6.283185307179586474, 1.}}]}}, 
   {PlotRange -> Automatic, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[{{Line[{{-6.283185307179586476, 0.}, 
       {-5.759586531581287603, 0.}, 
       {-5.23598775598298873, 0.}, 
       {-4.712388980384689857, 0.}, 
       {-4.188790204786390984, 0.}, 
       {-3.665191429188092112, 0.}, 
       {-3.141592653589793239, 0.}, 
       {-2.617993877991494366, 0.}, 
       {-2.094395102393195493, 0.}, 
       {-1.57079632679489662, 0.}, 
       {-1.047197551196597747, 0.}, 
       {-0.5235987755982988739, 0.}, 
       {-(8.673617379884035472*10^-19), 0.}, 
       {0.5235987755982988721, 0.}, 
       {1.047197551196597745, 0.}, 
       {1.570796326794896618, 0.}, 
       {2.094395102393195491, 0.}, 
       {2.617993877991494364, 0.}, 
       {3.141592653589793237, 0.}, 
       {3.66519142918809211, 0.}, 
       {4.188790204786390983, 0.}, 
       {4.712388980384689856, 0.}, 
       {5.235987755982988729, 0.}, 
       {5.759586531581287601, 0.}, 
       {6.283185307179586474, 0.}}]}}, 
   {PlotRange -> All, 
    AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = info; inactive; startGroup; Cclosed; ]
-- DTFT of Delayed Impulse
:[font = input; startGroup; ]
MagPhasePlot[ DTFTransform[ Impulse[n - 1], n, w ],
                     {w,-2Pi,2Pi}, MagRangeScale -> Null]
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30979 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29729 0 1 Msboxa
[(-4)] 0.19685 0.29729 0 1 Msboxa
[(-2)] 0.34842 0.29729 0 1 Msboxa
[(2)] 0.65158 0.29729 0 1 Msboxa
[(4)] 0.80315 0.29729 0 1 Msboxa
[(6)] 0.95473 0.29729 0 1 Msboxa
[(w)] 1.00625 0.30979 -1 0 Msboxa
[(-150)] 0.4875 0.06389 1 0 Msboxa
[(-100)] 0.4875 0.14586 1 0 Msboxa
[(-50)] 0.4875 0.22782 1 0 Msboxa
[(50)] 0.4875 0.39175 1 0 Msboxa
[(100)] 0.4875 0.47371 1 0 Msboxa
[(150)] 0.4875 0.55568 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30979 moveto
1 0.30979 lineto
stroke
0.04527 0.30354 moveto
0.04527 0.31604 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29729 0 1 Mshowa
0.19685 0.30354 moveto
0.19685 0.31604 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29729 0 1 Mshowa
0.34842 0.30354 moveto
0.34842 0.31604 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29729 0 1 Mshowa
0.65158 0.30354 moveto
0.65158 0.31604 lineto
stroke
0 setgray
[(2)] 0.65158 0.29729 0 1 Mshowa
0.80315 0.30354 moveto
0.80315 0.31604 lineto
stroke
0 setgray
[(4)] 0.80315 0.29729 0 1 Mshowa
0.95473 0.30354 moveto
0.95473 0.31604 lineto
stroke
0 setgray
[(6)] 0.95473 0.29729 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30979 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06389 moveto
0.50625 0.06389 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06389 1 0 Mshowa
0.49375 0.14586 moveto
0.50625 0.14586 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14586 1 0 Mshowa
0.49375 0.22782 moveto
0.50625 0.22782 lineto
stroke
0 setgray
[(-50)] 0.4875 0.22782 1 0 Mshowa
0.49375 0.39175 moveto
0.50625 0.39175 lineto
stroke
0 setgray
[(50)] 0.4875 0.39175 1 0 Mshowa
0.49375 0.47371 moveto
0.50625 0.47371 lineto
stroke
0 setgray
[(100)] 0.4875 0.47371 1 0 Mshowa
0.49375 0.55568 moveto
0.50625 0.55568 lineto
stroke
0 setgray
[(150)] 0.4875 0.55568 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30979 moveto
0.06349 0.26061 lineto
0.10317 0.21143 lineto
0.14286 0.16225 lineto
0.18254 0.11307 lineto
0.22222 0.06389 lineto
0.24206 0.0393 lineto
0.25198 0.02701 lineto
0.25694 0.02086 lineto
0.25942 0.01779 lineto
0.26066 0.01625 lineto
0.2619 0.01472 lineto
0.26314 0.60332 lineto
0.26438 0.60178 lineto
0.26562 0.60025 lineto
0.26687 0.59871 lineto
0.27183 0.59256 lineto
0.28175 0.58027 lineto
0.30159 0.55568 lineto
0.34127 0.5065 lineto
0.38095 0.45732 lineto
0.42063 0.40814 lineto
0.46032 0.35896 lineto
0.5 0.30979 lineto
0.53968 0.26061 lineto
0.57937 0.21143 lineto
0.61905 0.16225 lineto
0.65873 0.11307 lineto
0.69841 0.06389 lineto
0.71825 0.0393 lineto
0.72817 0.02701 lineto
0.73313 0.02086 lineto
0.73562 0.01779 lineto
0.73686 0.01625 lineto
0.7381 0.01472 lineto
0.73934 0.60332 lineto
0.74058 0.60178 lineto
0.74182 0.60025 lineto
0.74306 0.59871 lineto
0.74802 0.59256 lineto
0.75794 0.58027 lineto
0.77778 0.55568 lineto
0.81746 0.5065 lineto
0.85714 0.45732 lineto
0.89683 0.40814 lineto
0.93651 0.35896 lineto
0.97619 0.30979 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
{Graphics[Point[{0, 0}], DisplayFunction -> Identity], 
  Graphics[{{Line[{{-6.283185307179586476, 0.}, 
       {-5.759586531581287603, -29.99999999999999979}, 
       {-5.23598775598298873, -59.99999999999999985}, 
       {-4.712388980384689857, -89.99999999999999993}, 
       {-4.188790204786390984, -119.9999999999999998}, 
       {-3.665191429188092112, -149.9999999999999999}, 
       {-3.403392041388942675, -165.}, 
       {-3.272492347489367957, -172.5}, 
       {-3.207042500539580598, -176.25}, 
       {-3.174317577064686918, -178.125}, 
       {-3.157955115327240078, -179.0625}, 
       {-3.141592653589793239, -180.}, 
       {-3.125230191852346399, 179.0625000000000002}, 
       {-3.108867730114899559, 178.1250000000000002}, 
       {-3.092505268377452719, 177.1875000000000002}, 
       {-3.07614280664000588, 176.2500000000000002}, 
       {-3.01069295969021852, 172.5000000000000002}, 
       {-2.879793265790643802, 165.0000000000000002}, 
       {-2.617993877991494366, 150.0000000000000003}, 
       {-2.094395102393195493, 120.0000000000000002}, 
       {-1.57079632679489662, 90.00000000000000013}, 
       {-1.047197551196597747, 60.00000000000000025}, 
       {-0.5235987755982988739, 30.00000000000000019}, 
       {-(8.673617379884035472*10^-19), 0.}, 
       {0.5235987755982988721, -29.99999999999999979}, 
       {1.047197551196597745, -59.99999999999999985}, 
       {1.570796326794896618, -90.00000000000000002}, 
       {2.094395102393195491, -120.0000000000000002}, 
       {2.617993877991494364, -149.9999999999999999}, 
       {2.8797932657906438, -165.0000000000000002}, 
       {3.010692959690218519, -172.5000000000000001}, 
       {3.076142806640005878, -176.2500000000000001}, 
       {3.108867730114899557, -178.1250000000000001}, 
       {3.125230191852346397, -179.0625000000000001}, 
       {3.141592653589793237, -180.0000000000000001}, 
       {3.157955115327240077, 179.0625000000000001}, 
       {3.174317577064686916, 178.1250000000000001}, 
       {3.190680038802133756, 177.1875000000000001}, 
       {3.207042500539580596, 176.2500000000000001}, 
       {3.272492347489367955, 172.5000000000000001}, 
       {3.403392041388942673, 165.0000000000000002}, 
       {3.66519142918809211, 149.9999999999999999}, 
       {4.188790204786390983, 120.0000000000000002}, 
       {4.712388980384689856, 90.00000000000000004}, 
       {5.235987755982988729, 59.99999999999999985}, 
       {5.759586531581287601, 30.00000000000000019}, 
       {6.283185307179586474, 0.}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Step
:[font = info; inactive; startGroup; Cclosed; ]
-- Time Response
:[font = input; startGroup; ]
del = 2;
signal = Step[n - del];
SequencePlot[signal, {n,-2,10}]
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.18254 0.07937 0.01472 0.5886 [
[(Sequence Plot)] 0.5 0.62428 0 -1 Msboxa
[(-2)] 0.02381 0.00222 0 1 Msboxa
[(2)] 0.34127 0.00222 0 1 Msboxa
[(4)] 0.5 0.00222 0 1 Msboxa
[(6)] 0.65873 0.00222 0 1 Msboxa
[(8)] 0.81746 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.17004 0.13244 1 0 Msboxa
[(0.4)] 0.17004 0.25016 1 0 Msboxa
[(0.6)] 0.17004 0.36788 1 0 Msboxa
[(0.8)] 0.17004 0.4856 1 0 Msboxa
[(1)] 0.17004 0.60332 1 0 Msboxa
[( )] 0.18254 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-2)] 0.02381 0.00222 0 1 Mshowa
0.34127 0.00847 moveto
0.34127 0.02097 lineto
stroke
0 setgray
[(2)] 0.34127 0.00222 0 1 Mshowa
0.5 0.00847 moveto
0.5 0.02097 lineto
stroke
0 setgray
[(4)] 0.5 0.00222 0 1 Mshowa
0.65873 0.00847 moveto
0.65873 0.02097 lineto
stroke
0 setgray
[(6)] 0.65873 0.00222 0 1 Mshowa
0.81746 0.00847 moveto
0.81746 0.02097 lineto
stroke
0 setgray
[(8)] 0.81746 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.18254 0 moveto
0.18254 0.61803 lineto
stroke
0.17629 0.13244 moveto
0.18879 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.17004 0.13244 1 0 Mshowa
0.17629 0.25016 moveto
0.18879 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.17004 0.25016 1 0 Mshowa
0.17629 0.36788 moveto
0.18879 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.17004 0.36788 1 0 Mshowa
0.17629 0.4856 moveto
0.18879 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.17004 0.4856 1 0 Mshowa
0.17629 0.60332 moveto
0.18879 0.60332 lineto
stroke
0 setgray
[(1)] 0.17004 0.60332 1 0 Mshowa
0 setgray
[( )] 0.18254 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.0068 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.02041 setlinewidth
0.02381 0.01472 Mdot
0.0068 setlinewidth
0.10317 0.01472 moveto
0.10317 0.01472 lineto
stroke
0.02041 setlinewidth
0.10317 0.01472 Mdot
0.0068 setlinewidth
0.18254 0.01472 moveto
0.18254 0.01472 lineto
stroke
0.02041 setlinewidth
0.18254 0.01472 Mdot
0.0068 setlinewidth
0.2619 0.01472 moveto
0.2619 0.01472 lineto
stroke
0.02041 setlinewidth
0.2619 0.01472 Mdot
0.0068 setlinewidth
0.34127 0.01472 moveto
0.34127 0.60332 lineto
stroke
0.02041 setlinewidth
0.34127 0.60332 Mdot
0.0068 setlinewidth
0.42063 0.01472 moveto
0.42063 0.60332 lineto
stroke
0.02041 setlinewidth
0.42063 0.60332 Mdot
0.0068 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
stroke
0.02041 setlinewidth
0.5 0.60332 Mdot
0.0068 setlinewidth
0.57937 0.01472 moveto
0.57937 0.60332 lineto
stroke
0.02041 setlinewidth
0.57937 0.60332 Mdot
0.0068 setlinewidth
0.65873 0.01472 moveto
0.65873 0.60332 lineto
stroke
0.02041 setlinewidth
0.65873 0.60332 Mdot
0.0068 setlinewidth
0.7381 0.01472 moveto
0.7381 0.60332 lineto
stroke
0.02041 setlinewidth
0.7381 0.60332 Mdot
0.0068 setlinewidth
0.81746 0.01472 moveto
0.81746 0.60332 lineto
stroke
0.02041 setlinewidth
0.81746 0.60332 Mdot
0.0068 setlinewidth
0.89683 0.01472 moveto
0.89683 0.60332 lineto
stroke
0.02041 setlinewidth
0.89683 0.60332 Mdot
0.0068 setlinewidth
0.97619 0.01472 moveto
0.97619 0.60332 lineto
stroke
0.02041 setlinewidth
0.97619 0.60332 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = info; inactive; startGroup; Cclosed; ]
-- Frequency Response
:[font = text; startGroup; ]
del = 2;
sig = Step[n-del];
DTFTransform[sig, n, w]
:[font = output; inactive; output; ]
DTFTData[E^(-I*w)/(-1 + E^(I*w)) + 
   E^(-2*I*w)*Pi*Summation[l2, DirectedInfinity[-1], 
      DirectedInfinity[1], 1][Delta[2*Pi*l2 + w]], FVariables[w]]
;[o]
            -I w
           E          -2 I w
DTFTData[--------- + E       Pi 
               I w
         -1 + E
 
    Summation[l2, -Infinity, Infinity, 1][Delta[2 Pi l2 + w]], 
 
  FVariables[w]]
:[font = text; ]
MagPhasePlot[ DTFTransform[sig, n, w],
		                    {w, -2 Pi, 2 Pi} ] 
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01472 0 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00222 0 1 Msboxa
[(-4)] 0.19685 0.00222 0 1 Msboxa
[(-2)] 0.34842 0.00222 0 1 Msboxa
[(2)] 0.65158 0.00222 0 1 Msboxa
[(4)] 0.80315 0.00222 0 1 Msboxa
[(6)] 0.95473 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(     17)(2. 10)] 0.4875 0.11682 1 0 Msboxa
[(     17)(4. 10)] 0.4875 0.21893 1 0 Msboxa
[(     17)(6. 10)] 0.4875 0.32103 1 0 Msboxa
[(     17)(8. 10)] 0.4875 0.42314 1 0 Msboxa
[(     18)(1. 10)] 0.4875 0.52525 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.04527 0.00847 moveto
0.04527 0.02097 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00222 0 1 Mshowa
0.19685 0.00847 moveto
0.19685 0.02097 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00222 0 1 Mshowa
0.34842 0.00847 moveto
0.34842 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00222 0 1 Mshowa
0.65158 0.00847 moveto
0.65158 0.02097 lineto
stroke
0 setgray
[(2)] 0.65158 0.00222 0 1 Mshowa
0.80315 0.00847 moveto
0.80315 0.02097 lineto
stroke
0 setgray
[(4)] 0.80315 0.00222 0 1 Mshowa
0.95473 0.00847 moveto
0.95473 0.02097 lineto
stroke
0 setgray
[(6)] 0.95473 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.11682 moveto
0.50625 0.11682 lineto
stroke
0 setgray
[(     17)(2. 10)] 0.4875 0.11682 1 0 Mshowa
0.49375 0.21893 moveto
0.50625 0.21893 lineto
stroke
0 setgray
[(     17)(4. 10)] 0.4875 0.21893 1 0 Mshowa
0.49375 0.32103 moveto
0.50625 0.32103 lineto
stroke
0 setgray
[(     17)(6. 10)] 0.4875 0.32103 1 0 Mshowa
0.49375 0.42314 moveto
0.50625 0.42314 lineto
stroke
0 setgray
[(     17)(8. 10)] 0.4875 0.42314 1 0 Mshowa
0.49375 0.52525 moveto
0.50625 0.52525 lineto
stroke
0 setgray
[(     18)(1. 10)] 0.4875 0.52525 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.12956 moveto
0.02505 0.01472 lineto
0.02629 0.01472 lineto
0.02753 0.01472 lineto
0.02877 0.01472 lineto
0.03001 0.01472 lineto
0.03125 0.01472 lineto
0.03249 0.01472 lineto
0.03373 0.01472 lineto
0.03497 0.01472 lineto
0.03621 0.01472 lineto
0.03869 0.01472 lineto
0.04117 0.01472 lineto
0.04365 0.01472 lineto
0.04613 0.01472 lineto
0.04861 0.01472 lineto
0.05357 0.01472 lineto
0.05853 0.01472 lineto
0.06349 0.01472 lineto
0.06845 0.01472 lineto
0.07341 0.01472 lineto
0.08333 0.01472 lineto
0.09325 0.01472 lineto
0.10317 0.01472 lineto
0.1131 0.01472 lineto
0.12302 0.01472 lineto
0.13294 0.01472 lineto
0.14286 0.01472 lineto
0.15278 0.01472 lineto
0.1627 0.01472 lineto
0.17262 0.01472 lineto
0.18254 0.01472 lineto
0.19246 0.01472 lineto
0.20238 0.01472 lineto
0.2123 0.01472 lineto
0.22222 0.01472 lineto
0.22718 0.01472 lineto
0.23214 0.01472 lineto
0.2371 0.01472 lineto
0.24206 0.01472 lineto
0.24702 0.01472 lineto
0.2495 0.01472 lineto
0.25198 0.01472 lineto
0.25446 0.01472 lineto
0.2557 0.01472 lineto
0.25694 0.01472 lineto
0.25818 0.01472 lineto
0.25942 0.01472 lineto
0.26066 0.01472 lineto
0.2619 0.01472 lineto
Mistroke
0.26314 0.01472 lineto
0.26438 0.01472 lineto
0.26562 0.01472 lineto
0.26687 0.01472 lineto
0.26935 0.01472 lineto
0.27183 0.01472 lineto
0.27431 0.01472 lineto
0.27679 0.01472 lineto
0.28175 0.01472 lineto
0.28671 0.01472 lineto
0.29167 0.01472 lineto
0.30159 0.01472 lineto
0.31151 0.01472 lineto
0.32143 0.01472 lineto
0.33135 0.01472 lineto
0.34127 0.01472 lineto
0.36111 0.01472 lineto
0.37103 0.01472 lineto
0.38095 0.01472 lineto
0.39087 0.01472 lineto
0.40079 0.01472 lineto
0.41071 0.01472 lineto
0.42063 0.01472 lineto
0.43056 0.01472 lineto
0.44048 0.01472 lineto
0.44544 0.01472 lineto
0.4504 0.01472 lineto
0.45536 0.01472 lineto
0.46032 0.01472 lineto
0.46528 0.01472 lineto
0.47024 0.01472 lineto
0.47272 0.01472 lineto
0.4752 0.01472 lineto
0.47768 0.01472 lineto
0.48016 0.01472 lineto
0.48264 0.01472 lineto
0.48512 0.01472 lineto
0.48636 0.01472 lineto
0.4876 0.01472 lineto
0.48884 0.01472 lineto
0.49008 0.01472 lineto
0.49132 0.01472 lineto
0.49256 0.01472 lineto
0.4938 0.01472 lineto
0.49504 0.01472 lineto
0.49628 0.01472 lineto
0.49752 0.01472 lineto
0.49876 0.01472 lineto
0.5 0.60332 lineto
0.50124 0.01472 lineto
Mistroke
0.50248 0.01472 lineto
0.50372 0.01472 lineto
0.50496 0.01472 lineto
0.5062 0.01472 lineto
0.50744 0.01472 lineto
0.50868 0.01472 lineto
0.50992 0.01472 lineto
0.5124 0.01472 lineto
0.51364 0.01472 lineto
0.51488 0.01472 lineto
0.51736 0.01472 lineto
0.51984 0.01472 lineto
0.52232 0.01472 lineto
0.5248 0.01472 lineto
0.52976 0.01472 lineto
0.53472 0.01472 lineto
0.53968 0.01472 lineto
0.54464 0.01472 lineto
0.5496 0.01472 lineto
0.55952 0.01472 lineto
0.56944 0.01472 lineto
0.57937 0.01472 lineto
0.58929 0.01472 lineto
0.59921 0.01472 lineto
0.60913 0.01472 lineto
0.61905 0.01472 lineto
0.62897 0.01472 lineto
0.63889 0.01472 lineto
0.64881 0.01472 lineto
0.65873 0.01472 lineto
0.66865 0.01472 lineto
0.67857 0.01472 lineto
0.68849 0.01472 lineto
0.69841 0.01472 lineto
0.70337 0.01472 lineto
0.70833 0.01472 lineto
0.71329 0.01472 lineto
0.71825 0.01472 lineto
0.72321 0.01472 lineto
0.72569 0.01472 lineto
0.72817 0.01472 lineto
0.73065 0.01472 lineto
0.73189 0.01472 lineto
0.73313 0.01472 lineto
0.73438 0.01472 lineto
0.73562 0.01472 lineto
0.73686 0.01472 lineto
0.7381 0.01472 lineto
0.73934 0.01472 lineto
0.74058 0.01472 lineto
Mistroke
0.74182 0.01472 lineto
0.74306 0.01472 lineto
0.74554 0.01472 lineto
0.74802 0.01472 lineto
0.7505 0.01472 lineto
0.75298 0.01472 lineto
0.75794 0.01472 lineto
0.7629 0.01472 lineto
0.76786 0.01472 lineto
0.77778 0.01472 lineto
0.7877 0.01472 lineto
0.79762 0.01472 lineto
0.80754 0.01472 lineto
0.81746 0.01472 lineto
0.82738 0.01472 lineto
0.8373 0.01472 lineto
0.84722 0.01472 lineto
0.85714 0.01472 lineto
0.86706 0.01472 lineto
0.87698 0.01472 lineto
0.8869 0.01472 lineto
0.89683 0.01472 lineto
0.90675 0.01472 lineto
0.91667 0.01472 lineto
0.92163 0.01472 lineto
0.92659 0.01472 lineto
0.93155 0.01472 lineto
0.93651 0.01472 lineto
0.94147 0.01472 lineto
0.94643 0.01472 lineto
0.95139 0.01472 lineto
0.95387 0.01472 lineto
0.95635 0.01472 lineto
0.95883 0.01472 lineto
0.96131 0.01472 lineto
0.96255 0.01472 lineto
0.96379 0.01472 lineto
0.96503 0.01472 lineto
0.96627 0.01472 lineto
0.96751 0.01472 lineto
0.96875 0.01472 lineto
0.96999 0.01472 lineto
0.97123 0.01472 lineto
0.97247 0.01472 lineto
0.97371 0.01472 lineto
0.97495 0.01472 lineto
0.97619 0.20307 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-150)] 0.4875 0.06377 1 0 Msboxa
[(-100)] 0.4875 0.14552 1 0 Msboxa
[(-50)] 0.4875 0.22727 1 0 Msboxa
[(50)] 0.4875 0.39077 1 0 Msboxa
[(100)] 0.4875 0.47252 1 0 Msboxa
[(150)] 0.4875 0.55427 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06377 moveto
0.50625 0.06377 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06377 1 0 Mshowa
0.49375 0.14552 moveto
0.50625 0.14552 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14552 1 0 Mshowa
0.49375 0.22727 moveto
0.50625 0.22727 lineto
stroke
0 setgray
[(-50)] 0.4875 0.22727 1 0 Mshowa
0.49375 0.39077 moveto
0.50625 0.39077 lineto
stroke
0 setgray
[(50)] 0.4875 0.39077 1 0 Mshowa
0.49375 0.47252 moveto
0.50625 0.47252 lineto
stroke
0 setgray
[(100)] 0.4875 0.47252 1 0 Mshowa
0.49375 0.55427 moveto
0.50625 0.55427 lineto
stroke
0 setgray
[(150)] 0.4875 0.55427 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.45617 moveto
0.02505 0.15957 lineto
0.02629 0.15727 lineto
0.02877 0.15267 lineto
0.03373 0.14347 lineto
0.04365 0.12508 lineto
0.06349 0.08829 lineto
0.08333 0.0515 lineto
0.09325 0.03311 lineto
0.09821 0.02391 lineto
0.10069 0.01931 lineto
0.10193 0.01701 lineto
0.10317 0.01472 lineto
0.10441 0.60102 lineto
0.10565 0.59872 lineto
0.10813 0.59412 lineto
0.1131 0.58493 lineto
0.12302 0.56653 lineto
0.14286 0.52974 lineto
0.18254 0.45617 lineto
0.22222 0.38259 lineto
0.2619 0.30902 lineto
0.30159 0.23544 lineto
0.34127 0.16187 lineto
0.38095 0.08829 lineto
0.40079 0.0515 lineto
0.41071 0.03311 lineto
0.41567 0.02391 lineto
0.41815 0.01931 lineto
0.41939 0.01701 lineto
0.42063 0.01472 lineto
0.42187 0.60102 lineto
0.42312 0.59872 lineto
0.4256 0.59412 lineto
0.43056 0.58493 lineto
0.44048 0.56653 lineto
0.46032 0.52974 lineto
0.48016 0.49296 lineto
0.49008 0.47456 lineto
0.49504 0.46536 lineto
0.49752 0.46077 lineto
0.49876 0.45847 lineto
0.5 0.45617 lineto
0.50124 0.15957 lineto
0.50248 0.15727 lineto
0.50496 0.15267 lineto
0.50992 0.14347 lineto
0.51984 0.12508 lineto
0.53968 0.08829 lineto
0.55952 0.0515 lineto
Mistroke
0.56944 0.03311 lineto
0.5744 0.02391 lineto
0.57688 0.01931 lineto
0.57813 0.01701 lineto
0.57937 0.01472 lineto
0.58061 0.60102 lineto
0.58185 0.59872 lineto
0.58433 0.59412 lineto
0.58929 0.58493 lineto
0.59921 0.56653 lineto
0.61905 0.52974 lineto
0.65873 0.45617 lineto
0.69841 0.38259 lineto
0.7381 0.30902 lineto
0.77778 0.23544 lineto
0.81746 0.16187 lineto
0.8373 0.12508 lineto
0.85714 0.08829 lineto
0.86706 0.0699 lineto
0.87698 0.0515 lineto
0.88194 0.04231 lineto
0.8869 0.03311 lineto
0.89187 0.02391 lineto
0.89435 0.01931 lineto
0.89559 0.01701 lineto
0.89683 0.60332 lineto
0.91667 0.56653 lineto
0.93651 0.52974 lineto
0.94643 0.51135 lineto
0.95635 0.49296 lineto
0.96131 0.48376 lineto
0.96627 0.47456 lineto
0.97123 0.46536 lineto
0.97371 0.46077 lineto
0.97495 0.45847 lineto
0.97619 0.16187 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
{Graphics[{{Line[{{-6.283185307179586476, 224960293581823800.2}, 
       {-6.266822845442139636, 61.11617992185071873}, 
       {-6.250460383704692796, 30.55911265471360721}, 
       {-6.234097921967245956, 20.37387816723143577}, 
       {-6.217735460229799117, 15.28160195453968221}, 
       {-6.201372998492352277, 12.22650914124492605}, 
       {-6.185010536754905437, 10.19000812354805724}, 
       {-6.168648075017458598, 8.735559660980040936}, 
       {-6.152285613280011758, 7.644894149339256066}, 
       {-6.135923151542564918, 6.796750711673635952}, 
       {-6.119560689805118078, 6.118372834676254781}, 
       {-6.086835766330224399, 5.101148618689163971}, 
       {-6.05411084285533072, 4.374952122886852677}, 
       {-6.02138591938043704, 3.830648787770194407}, 
       {-5.98866099590554336, 3.407608418468718826}, 
       {-5.95593607243064968, 3.069453003085165014}, 
       {-5.890486225480862321, 2.562915447741506204}, 
       {-5.825036378531074963, 2.201903419224023093}, 
       {-5.759586531581287603, 1.931851652578136588}, 
       {-5.694136684631500244, 1.722447098238333949}, 
       {-5.628686837681712885, 1.555502836368991915}, 
       {-5.497787143782138167, 1.306562964876376529}, 
       {-5.366887449882563449, 1.130483349579711611}, 
       {-5.23598775598298873, 1.000000000000000003}, 
       {-5.105088062083414012, 0.8999762231364157066}, 
       {-4.974188368183839294, 0.8213398158522907887}, 
       {-4.843288674284264576, 0.7583274035403031044}, 
       {-4.712388980384689857, 0.7071067811865475258}, 
       {-4.581489286485115139, 0.6650352841472560283}, 
       {-4.450589592585540421, 0.6302362070051322346}, 
       {-4.319689898685965703, 0.6013448869350452813}, 
       {-4.188790204786390984, 0.5773502691896257651}, 
       {-4.057890510886816266, 0.5574926930497825926}, 
       {-3.926990816987241548, 0.5411961001461969845}, 
       {-3.79609112308766683, 0.5280220624795150924}, 
       {-3.665191429188092112, 0.5176380902050415249}, 
       {-3.599741582238304752, 0.5134118688902837426}, 
       {-3.534291735288517393, 0.509795579104159169}, 
       {-3.468841888338730034, 0.5067687417939048857}, 
       {-3.403392041388942675, 0.5043144802900763604}, 
       {-3.337942194439155316, 0.5024192861881557056}, 
       {-3.305217270964261636, 0.5016779928298666529}, 
       {-3.272492347489367957, 0.5010728354036498047}, 
       {-3.239767424014474277, 0.5006029982351963013}, 
       {-3.223404962277027438, 0.5004186202287720864}, 
       {-3.207042500539580598, 0.5002678496718859569}, 
       {-3.190680038802133758, 0.5001506360206509883}, 
       {-3.174317577064686918, 0.5000669400059482388}, 
       {-3.157955115327240078, 0.5000167336013075317}, 
       {-3.141592653589793239, 0.5}, 
       {-3.125230191852346399, 0.5000167336013075317}, 
       {-3.108867730114899559, 0.5000669400059482388}, 
       {-3.092505268377452719, 0.5001506360206509882}, 
       {-3.07614280664000588, 0.5002678496718859568}, 
       {-3.0434178831651122, 0.5006029982351963013}, 
       {-3.01069295969021852, 0.5010728354036498046}, 
       {-2.977968036215324841, 0.5016779928298666528}, 
       {-2.945243112740431161, 0.5024192861881557055}, 
       {-2.879793265790643802, 0.5043144802900763604}, 
       {-2.814343418840856443, 0.5067687417939048854}, 
       {-2.748893571891069084, 0.5097955791041591687}, 
       {-2.617993877991494366, 0.5176380902050415245}, 
       {-2.487094184091919648, 0.5280220624795150917}, 
       {-2.356194490192344929, 0.5411961001461969843}, 
       {-2.225294796292770211, 0.5574926930497825917}, 
       {-2.094395102393195493, 0.577350269189625764}, 
       {-1.832595714594046056, 0.6302362070051322329}, 
       {-1.701696020694471338, 0.6650352841472560268}, 
       {-1.57079632679489662, 0.7071067811865475237}, 
       {-1.439896632895321902, 0.7583274035403031022}, 
       {-1.308996938995747183, 0.821339815852290785}, 
       {-1.178097245096172465, 0.8999762231364157043}, 
       {-1.047197551196597747, 0.9999999999999999967}, 
       {-0.9162978572970230287, 1.130483349579711603}, 
       {-0.7853981633974483104, 1.306562964876376527}, 
       {-0.7199483164476609512, 1.41944622279172777}, 
       {-0.6544984694978735921, 1.555502836368991899}, 
       {-0.589048622548086233, 1.722447098238333929}, 
       {-0.5235987755982988739, 1.931851652578136563}, 
       {-0.4581489286485115148, 2.20190341922402306}, 
       {-0.3926990816987241556, 2.562915447741506182}, 
       {-0.359974158223830476, 2.793032993843835704}, 
       {-0.3272492347489367965, 3.069453003085164983}, 
       {-0.2945243112740431169, 3.407608418468718786}, 
       {-0.2617993877991494374, 3.830648787770194307}, 
       {-0.2290744643242557578, 4.374952122886852579}, 
       {-0.1963495408493620783, 5.101148618689163837}, 
       {-0.1799870791119152385, 5.563460930685811913}, 
       {-0.1636246173744683987, 6.118372834676254586}, 
       {-0.1472621556370215589, 6.796750711673635713}, 
       {-0.1308996938995747191, 7.644894149339255762}, 
       {-0.1145372321621278794, 8.73555966098004054}, 
       {-0.09817477042468103956, 10.1900081235480567}, 
       {-0.08181230868723419977, 12.22650914124492528}, 
       {-0.06544984694978735999, 15.281601954539681}, 
       {-0.04908738521234052021, 20.3738781672314336}, 
       {-0.03272492347489368043, 30.55911265471360276}, 
       {-0.01636246173744684065, 61.11617992185070091}, 
       {-(8.673617379884035472*10^-19), 1152921504606846975.}, 
       {0.01636246173744683891, 61.11617992185070739}, 
       {0.03272492347489367869, 30.55911265471360438}, 
       {0.04908738521234051848, 20.37387816723143433}, 
       {0.06544984694978735825, 15.28160195453968141}, 
       {0.08181230868723419803, 12.22650914124492554}, 
       {0.09817477042468103783, 10.19000812354805688}, 
       {0.1145372321621278776, 8.735559660980040672}, 
       {0.1308996938995747174, 7.644894149339255863}, 
       {0.1636246173744683969, 6.118372834676254652}, 
       {0.1799870791119152367, 5.563460930685811969}, 
       {0.1963495408493620765, 5.101148618689163882}, 
       {0.2290744643242557561, 4.374952122886852612}, 
       {0.2617993877991494356, 3.830648787770194357}, 
       {0.2945243112740431152, 3.407608418468718786}, 
       {0.3272492347489367947, 3.069453003085164983}, 
       {0.3926990816987241539, 2.562915447741506182}, 
       {0.458148928648511513, 2.20190341922402306}, 
       {0.5235987755982988721, 1.931851652578136588}, 
       {0.5890486225480862313, 1.722447098238333929}, 
       {0.6544984694978735903, 1.555502836368991915}, 
       {0.7853981633974483087, 1.306562964876376529}, 
       {0.916297857297023027, 1.130483349579711611}, 
       {1.047197551196597745, 1.000000000000000003}, 
       {1.178097245096172463, 0.8999762231364157043}, 
       {1.308996938995747182, 0.821339815852290785}, 
       {1.4398966328953219, 0.7583274035403031029}, 
       {1.570796326794896618, 0.7071067811865475243}, 
       {1.701696020694471337, 0.6650352841472560273}, 
       {1.832595714594046055, 0.6302362070051322329}, 
       {1.963495408493620773, 0.6013448869350452806}, 
       {2.094395102393195491, 0.577350269189625764}, 
       {2.225294796292770209, 0.5574926930497825917}, 
       {2.356194490192344928, 0.5411961001461969843}, 
       {2.487094184091919646, 0.5280220624795150917}, 
       {2.617993877991494364, 0.5176380902050415245}, 
       {2.683443724941281723, 0.5134118688902837423}, 
       {2.748893571891069082, 0.5097955791041591689}, 
       {2.814343418840856441, 0.5067687417939048856}, 
       {2.8797932657906438, 0.5043144802900763604}, 
       {2.94524311274043116, 0.5024192861881557055}, 
       {2.977968036215324839, 0.5016779928298666528}, 
       {3.010692959690218519, 0.5010728354036498046}, 
       {3.043417883165112198, 0.5006029982351963013}, 
       {3.059780344902559038, 0.5004186202287720864}, 
       {3.076142806640005878, 0.5002678496718859569}, 
       {3.092505268377452718, 0.5001506360206509882}, 
       {3.108867730114899557, 0.5000669400059482387}, 
       {3.125230191852346397, 0.5000167336013075317}, 
       {3.141592653589793237, 0.5}, 
       {3.157955115327240077, 0.5000167336013075317}, 
       {3.174317577064686916, 0.5000669400059482388}, 
       {3.190680038802133756, 0.5001506360206509882}, 
       {3.207042500539580596, 0.5002678496718859569}, 
       {3.239767424014474276, 0.5006029982351963013}, 
       {3.272492347489367955, 0.5010728354036498047}, 
       {3.305217270964261635, 0.5016779928298666528}, 
       {3.337942194439155314, 0.5024192861881557055}, 
       {3.403392041388942673, 0.5043144802900763604}, 
       {3.468841888338730032, 0.5067687417939048857}, 
       {3.534291735288517392, 0.509795579104159169}, 
       {3.66519142918809211, 0.5176380902050415249}, 
       {3.796091123087666828, 0.5280220624795150924}, 
       {3.926990816987241546, 0.5411961001461969845}, 
       {4.057890510886816265, 0.5574926930497825926}, 
       {4.188790204786390983, 0.5773502691896257651}, 
       {4.319689898685965701, 0.6013448869350452806}, 
       {4.450589592585540419, 0.6302362070051322338}, 
       {4.581489286485115137, 0.6650352841472560277}, 
       {4.712388980384689856, 0.7071067811865475252}, 
       {4.843288674284264574, 0.7583274035403031044}, 
       {4.974188368183839292, 0.8213398158522907868}, 
       {5.10508806208341401, 0.8999762231364157066}, 
       {5.235987755982988729, 1.000000000000000003}, 
       {5.366887449882563447, 1.130483349579711611}, 
       {5.497787143782138165, 1.306562964876376529}, 
       {5.563236990731925524, 1.419446222791727783}, 
       {5.628686837681712883, 1.555502836368991915}, 
       {5.694136684631500242, 1.722447098238333929}, 
       {5.759586531581287601, 1.931851652578136588}, 
       {5.825036378531074961, 2.201903419224023076}, 
       {5.89048622548086232, 2.562915447741506204}, 
       {5.955936072430649679, 3.069453003085165014}, 
       {5.988660995905543358, 3.407608418468718826}, 
       {6.021385919380437038, 3.830648787770194357}, 
       {6.054110842855330718, 4.374952122886852644}, 
       {6.086835766330224397, 5.101148618689163926}, 
       {6.103198228067671237, 5.563460930685812022}, 
       {6.119560689805118077, 6.118372834676254716}, 
       {6.135923151542564916, 6.796750711673635871}, 
       {6.152285613280011756, 7.644894149339255963}, 
       {6.168648075017458596, 8.735559660980040804}, 
       {6.185010536754905436, 10.19000812354805706}, 
       {6.201372998492352275, 12.22650914124492579}, 
       {6.217735460229799115, 15.28160195453968181}, 
       {6.234097921967245955, 20.37387816723143504}, 
       {6.250460383704692794, 30.55911265471360559}, 
       {6.266822845442139634, 61.11617992185071225}, 
       {6.283185307179586474, 368934881474191032.3}}]}}, 
   {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[{{Line[{{-6.283185307179586476, 90.00000000000000016}, 
       {-6.266822845442139636, -91.40625}, 
       {-6.250460383704692796, -92.81250000000000002}, 
       {-6.217735460229799117, -95.62499999999999987}, 
       {-6.152285613280011758, -101.2499999999999999}, 
       {-6.02138591938043704, -112.4999999999999999}, 
       {-5.759586531581287603, -134.9999999999999997}, 
       {-5.497787143782138167, -157.5}, 
       {-5.366887449882563449, -168.7499999999999998}, 
       {-5.30143760293277609, -174.3750000000000001}, 
       {-5.26871267945788241, -177.1875000000000001}, 
       {-5.25235021772043557, -178.5937499999999998}, 
       {-5.23598775598298873, -179.9999999999999998}, 
       {-5.21962529424554189, 178.5937500000000002}, 
       {-5.20326283250809505, 177.1875000000000003}, 
       {-5.170537909033201371, 174.3750000000000001}, 
       {-5.105088062083414012, 168.7500000000000003}, 
       {-4.974188368183839294, 157.5000000000000003}, 
       {-4.712388980384689857, 135.0000000000000003}, 
       {-4.188790204786390984, 90.00000000000000039}, 
       {-3.665191429188092112, 45.00000000000000029}, 
       {-3.141592653589793239, 0.}, 
       {-2.617993877991494366, -44.99999999999999969}, 
       {-2.094395102393195493, -89.99999999999999979}, 
       {-1.57079632679489662, -135.}, 
       {-1.308996938995747183, -157.5}, 
       {-1.178097245096172465, -168.75}, 
       {-1.112647398146385106, -174.3750000000000001}, 
       {-1.079922474671491426, -177.1875}, 
       {-1.063560012934044587, -178.5937500000000002}, 
       {-1.047197551196597747, -179.9999999999999998}, 
       {-1.030835089459150907, 178.5937500000000004}, 
       {-1.014472627721704067, 177.1875000000000001}, 
       {-0.9817477042468103878, 174.3750000000000001}, 
       {-0.9162978572970230287, 168.7500000000000004}, 
       {-0.7853981633974483104, 157.5000000000000001}, 
       {-0.5235987755982988739, 135.0000000000000003}, 
       {-0.2617993877991494374, 112.5000000000000002}, 
       {-0.1308996938995747191, 101.2500000000000002}, 
       {-0.06544984694978735999, 95.62500000000000009}, 
       {-0.03272492347489368043, 92.81250000000000027}, 
       {-0.01636246173744684065, 91.40625000000000026}, 
       {-(8.673617379884035472*10^-19), 90.0000000000000001}, 
       {0.01636246173744683891, -91.40625000000000002}, 
       {0.03272492347489367869, -92.81250000000000013}, 
       {0.06544984694978735825, -95.62499999999999994}, 
       {0.1308996938995747174, -101.2500000000000001}, 
       {0.2617993877991494356, -112.4999999999999999}, 
       {0.5235987755982988721, -134.9999999999999997}, 
       {0.7853981633974483087, -157.5}, 
       {0.916297857297023027, -168.7499999999999998}, 
       {0.9817477042468103861, -174.3750000000000001}, 
       {1.014472627721704066, -177.1875000000000001}, 
       {1.030835089459150905, -178.5937499999999998}, 
       {1.047197551196597745, -179.9999999999999998}, 
       {1.063560012934044585, 178.5937500000000002}, 
       {1.079922474671491425, 177.1875000000000003}, 
       {1.112647398146385104, 174.3750000000000001}, 
       {1.178097245096172463, 168.75}, 
       {1.308996938995747182, 157.5000000000000003}, 
       {1.570796326794896618, 135.0000000000000001}, 
       {2.094395102393195491, 89.99999999999999979}, 
       {2.617993877991494364, 45.00000000000000029}, 
       {3.141592653589793237, 0.}, 
       {3.66519142918809211, -45.00000000000000029}, 
       {4.188790204786390983, -89.99999999999999979}, 
       {4.450589592585540419, -112.5000000000000002}, 
       {4.712388980384689856, -135.0000000000000001}, 
       {4.843288674284264574, -146.25}, 
       {4.974188368183839292, -157.5}, 
       {5.039638215133626651, -163.1250000000000001}, 
       {5.10508806208341401, -168.75}, 
       {5.170537909033201369, -174.3750000000000001}, 
       {5.203262832508095049, -177.1875}, 
       {5.219625294245541888, -178.5937500000000002}, 
       {5.235987755982988729, 179.9999999999999998}, 
       {5.497787143782138165, 157.5000000000000001}, 
       {5.759586531581287601, 135.0000000000000003}, 
       {5.89048622548086232, 123.75}, 
       {6.021385919380437038, 112.4999999999999999}, 
       {6.086835766330224397, 106.875}, 
       {6.152285613280011756, 101.2500000000000001}, 
       {6.217735460229799115, 95.62500000000000001}, 
       {6.250460383704692794, 92.81250000000000017}, 
       {6.266822845442139634, 91.40625000000000006}, 
       {6.283185307179586474, -90.00000000000000006}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Pulse
:[font = info; inactive; startGroup; Cclosed; ]
-- Time Response
:[font = text; startGroup; ]
len = 5
del = -1;
signal = Pulse[len, n-del];
SequencePlot[signal, {n, -3, 5}]
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.38095 0.11905 0.01472 0.5886 [
[(Sequence Plot)] 0.5 0.62428 0 -1 Msboxa
[(-2)] 0.14286 0.00222 0 1 Msboxa
[(2)] 0.61905 0.00222 0 1 Msboxa
[(4)] 0.85714 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.36845 0.13244 1 0 Msboxa
[(0.4)] 0.36845 0.25016 1 0 Msboxa
[(0.6)] 0.36845 0.36788 1 0 Msboxa
[(0.8)] 0.36845 0.4856 1 0 Msboxa
[(1)] 0.36845 0.60332 1 0 Msboxa
[( )] 0.38095 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.14286 0.00847 moveto
0.14286 0.02097 lineto
stroke
0 setgray
[(-2)] 0.14286 0.00222 0 1 Mshowa
0.61905 0.00847 moveto
0.61905 0.02097 lineto
stroke
0 setgray
[(2)] 0.61905 0.00222 0 1 Mshowa
0.85714 0.00847 moveto
0.85714 0.02097 lineto
stroke
0 setgray
[(4)] 0.85714 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.38095 0 moveto
0.38095 0.61803 lineto
stroke
0.3747 0.13244 moveto
0.3872 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.36845 0.13244 1 0 Mshowa
0.3747 0.25016 moveto
0.3872 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.36845 0.25016 1 0 Mshowa
0.3747 0.36788 moveto
0.3872 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.36845 0.36788 1 0 Mshowa
0.3747 0.4856 moveto
0.3872 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.36845 0.4856 1 0 Mshowa
0.3747 0.60332 moveto
0.3872 0.60332 lineto
stroke
0 setgray
[(1)] 0.36845 0.60332 1 0 Mshowa
0 setgray
[( )] 0.38095 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.00768 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.02305 setlinewidth
0.02381 0.01472 Mdot
0.00768 setlinewidth
0.14286 0.01472 moveto
0.14286 0.01472 lineto
stroke
0.02305 setlinewidth
0.14286 0.01472 Mdot
0.00768 setlinewidth
0.2619 0.01472 moveto
0.2619 0.60332 lineto
stroke
0.02305 setlinewidth
0.2619 0.60332 Mdot
0.00768 setlinewidth
0.38095 0.01472 moveto
0.38095 0.60332 lineto
stroke
0.02305 setlinewidth
0.38095 0.60332 Mdot
0.00768 setlinewidth
0.5 0.01472 moveto
0.5 0.60332 lineto
stroke
0.02305 setlinewidth
0.5 0.60332 Mdot
0.00768 setlinewidth
0.61905 0.01472 moveto
0.61905 0.60332 lineto
stroke
0.02305 setlinewidth
0.61905 0.60332 Mdot
0.00768 setlinewidth
0.7381 0.01472 moveto
0.7381 0.60332 lineto
stroke
0.02305 setlinewidth
0.7381 0.60332 Mdot
0.00768 setlinewidth
0.85714 0.01472 moveto
0.85714 0.01472 lineto
stroke
0.02305 setlinewidth
0.85714 0.01472 Mdot
0.00768 setlinewidth
0.97619 0.01472 moveto
0.97619 0.01472 lineto
stroke
0.02305 setlinewidth
0.97619 0.01472 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = info; inactive; startGroup; Cclosed; ]
-- Frequency Response
:[font = text; startGroup; ]
MagPhasePlot[ DTFTransform[signal, n, w],
		                      {w, -2 Pi, 2 Pi} ] 
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.01308 0.59024 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.00058 0 1 Msboxa
[(-4)] 0.19685 0.00058 0 1 Msboxa
[(-2)] 0.34842 0.00058 0 1 Msboxa
[(2)] 0.65158 0.00058 0 1 Msboxa
[(4)] 0.80315 0.00058 0 1 Msboxa
[(6)] 0.95473 0.00058 0 1 Msboxa
[(w)] 1.00625 0.01308 -1 0 Msboxa
[(0.2)] 0.4875 0.13112 1 0 Msboxa
[(0.4)] 0.4875 0.24917 1 0 Msboxa
[(0.6)] 0.4875 0.36722 1 0 Msboxa
[(0.8)] 0.4875 0.48527 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01308 moveto
1 0.01308 lineto
stroke
0.04527 0.00683 moveto
0.04527 0.01933 lineto
stroke
0 setgray
[(-6)] 0.04527 0.00058 0 1 Mshowa
0.19685 0.00683 moveto
0.19685 0.01933 lineto
stroke
0 setgray
[(-4)] 0.19685 0.00058 0 1 Mshowa
0.34842 0.00683 moveto
0.34842 0.01933 lineto
stroke
0 setgray
[(-2)] 0.34842 0.00058 0 1 Mshowa
0.65158 0.00683 moveto
0.65158 0.01933 lineto
stroke
0 setgray
[(2)] 0.65158 0.00058 0 1 Mshowa
0.80315 0.00683 moveto
0.80315 0.01933 lineto
stroke
0 setgray
[(4)] 0.80315 0.00058 0 1 Mshowa
0.95473 0.00683 moveto
0.95473 0.01933 lineto
stroke
0 setgray
[(6)] 0.95473 0.00058 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01308 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13112 moveto
0.50625 0.13112 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.13112 1 0 Mshowa
0.49375 0.24917 moveto
0.50625 0.24917 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.24917 1 0 Mshowa
0.49375 0.36722 moveto
0.50625 0.36722 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.36722 1 0 Mshowa
0.49375 0.48527 moveto
0.50625 0.48527 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.48527 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.53586 moveto
0.02505 0.60316 lineto
0.02629 0.60269 lineto
0.02753 0.6019 lineto
0.02877 0.60079 lineto
0.03125 0.59765 lineto
0.03373 0.59325 lineto
0.03869 0.58081 lineto
0.04365 0.56364 lineto
0.05357 0.5162 lineto
0.06349 0.45364 lineto
0.08333 0.29807 lineto
0.09325 0.21374 lineto
0.10317 0.13112 lineto
0.10813 0.09182 lineto
0.1131 0.05453 lineto
0.11558 0.03678 lineto
0.11682 0.02816 lineto
0.11806 0.01971 lineto
0.1193 0.01472 lineto
0.12054 0.0228 lineto
0.12178 0.03069 lineto
0.12302 0.03839 lineto
0.13294 0.09226 lineto
0.1379 0.11366 lineto
0.14286 0.13112 lineto
0.14534 0.13834 lineto
0.14782 0.14455 lineto
0.1503 0.14973 lineto
0.15278 0.1539 lineto
0.15402 0.1556 lineto
0.15526 0.15705 lineto
0.1565 0.15826 lineto
0.15774 0.15921 lineto
0.15898 0.15992 lineto
0.16022 0.16039 lineto
0.16146 0.16061 lineto
0.1627 0.1606 lineto
0.16394 0.16035 lineto
0.16518 0.15987 lineto
0.16642 0.15916 lineto
0.16766 0.15823 lineto
0.17014 0.1557 lineto
0.17262 0.15232 lineto
0.17758 0.14318 lineto
0.18254 0.13112 lineto
0.19246 0.09986 lineto
0.20238 0.06197 lineto
0.20734 0.04172 lineto
0.20982 0.03147 lineto
Mistroke
0.21106 0.02635 lineto
0.2123 0.02123 lineto
0.21354 0.01613 lineto
0.21478 0.0151 lineto
0.21602 0.02015 lineto
0.21726 0.02517 lineto
0.22222 0.04471 lineto
0.23214 0.07994 lineto
0.2371 0.09487 lineto
0.24206 0.10754 lineto
0.24702 0.11769 lineto
0.2495 0.12175 lineto
0.25198 0.1251 lineto
0.25446 0.12772 lineto
0.2557 0.12876 lineto
0.25694 0.12961 lineto
0.25818 0.13027 lineto
0.25942 0.13075 lineto
0.26066 0.13103 lineto
0.2619 0.13112 lineto
0.26314 0.13103 lineto
0.26438 0.13075 lineto
0.26562 0.13027 lineto
0.26687 0.12961 lineto
0.26935 0.12772 lineto
0.27183 0.1251 lineto
0.27679 0.11769 lineto
0.28175 0.10754 lineto
0.29167 0.07994 lineto
0.29663 0.0631 lineto
0.30159 0.04471 lineto
0.30407 0.03505 lineto
0.30655 0.02517 lineto
0.30779 0.02015 lineto
0.30903 0.0151 lineto
0.31027 0.01613 lineto
0.31151 0.02123 lineto
0.31399 0.03147 lineto
0.31647 0.04172 lineto
0.32143 0.06197 lineto
0.33135 0.09986 lineto
0.33631 0.11655 lineto
0.34127 0.13112 lineto
0.34623 0.14318 lineto
0.34871 0.14814 lineto
0.35119 0.15232 lineto
0.35367 0.1557 lineto
0.35491 0.15707 lineto
0.35615 0.15823 lineto
0.35739 0.15916 lineto
Mistroke
0.35863 0.15987 lineto
0.35987 0.16035 lineto
0.36111 0.1606 lineto
0.36235 0.16061 lineto
0.36359 0.16039 lineto
0.36483 0.15992 lineto
0.36607 0.15921 lineto
0.36731 0.15826 lineto
0.36855 0.15705 lineto
0.37103 0.1539 lineto
0.37351 0.14973 lineto
0.37599 0.14455 lineto
0.38095 0.13112 lineto
0.38591 0.11366 lineto
0.39087 0.09226 lineto
0.39583 0.06709 lineto
0.39831 0.05316 lineto
0.40079 0.03839 lineto
0.40203 0.03069 lineto
0.40327 0.0228 lineto
0.40451 0.01472 lineto
0.40575 0.01971 lineto
0.40823 0.03678 lineto
0.41071 0.05453 lineto
0.42063 0.13112 lineto
0.44048 0.29807 lineto
0.46032 0.45364 lineto
0.47024 0.5162 lineto
0.4752 0.542 lineto
0.48016 0.56364 lineto
0.48512 0.58081 lineto
0.4876 0.58764 lineto
0.49008 0.59325 lineto
0.49256 0.59765 lineto
0.4938 0.59938 lineto
0.49504 0.60079 lineto
0.49628 0.6019 lineto
0.49752 0.60269 lineto
0.49876 0.60316 lineto
0.5 0.60332 lineto
0.50124 0.60316 lineto
0.50248 0.60269 lineto
0.50372 0.6019 lineto
0.50496 0.60079 lineto
0.50744 0.59765 lineto
0.50992 0.59325 lineto
0.51488 0.58081 lineto
0.51984 0.56364 lineto
0.52976 0.5162 lineto
0.53968 0.45364 lineto
Mistroke
0.55952 0.29807 lineto
0.56944 0.21374 lineto
0.57937 0.13112 lineto
0.58433 0.09182 lineto
0.58929 0.05453 lineto
0.59177 0.03678 lineto
0.59301 0.02816 lineto
0.59425 0.01971 lineto
0.59549 0.01472 lineto
0.59673 0.0228 lineto
0.59921 0.03839 lineto
0.60913 0.09226 lineto
0.61409 0.11366 lineto
0.61905 0.13112 lineto
0.62153 0.13834 lineto
0.62401 0.14455 lineto
0.62649 0.14973 lineto
0.62897 0.1539 lineto
0.63021 0.1556 lineto
0.63145 0.15705 lineto
0.63269 0.15826 lineto
0.63393 0.15921 lineto
0.63517 0.15992 lineto
0.63641 0.16039 lineto
0.63765 0.16061 lineto
0.63889 0.1606 lineto
0.64013 0.16035 lineto
0.64137 0.15987 lineto
0.64261 0.15916 lineto
0.64385 0.15823 lineto
0.64633 0.1557 lineto
0.64881 0.15232 lineto
0.65377 0.14318 lineto
0.65873 0.13112 lineto
0.66865 0.09986 lineto
0.67857 0.06197 lineto
0.68353 0.04172 lineto
0.68601 0.03147 lineto
0.68725 0.02635 lineto
0.68849 0.02123 lineto
0.68973 0.01613 lineto
0.69097 0.0151 lineto
0.69221 0.02015 lineto
0.69345 0.02517 lineto
0.69841 0.04471 lineto
0.70833 0.07994 lineto
0.71329 0.09487 lineto
0.71825 0.10754 lineto
0.72321 0.11769 lineto
0.72569 0.12175 lineto
Mistroke
0.72817 0.1251 lineto
0.73065 0.12772 lineto
0.73189 0.12876 lineto
0.73313 0.12961 lineto
0.73438 0.13027 lineto
0.73562 0.13075 lineto
0.73686 0.13103 lineto
0.7381 0.13112 lineto
0.73934 0.13103 lineto
0.74058 0.13075 lineto
0.74182 0.13027 lineto
0.74306 0.12961 lineto
0.74554 0.12772 lineto
0.74802 0.1251 lineto
0.75298 0.11769 lineto
0.75794 0.10754 lineto
0.76786 0.07994 lineto
0.77282 0.0631 lineto
0.77778 0.04471 lineto
0.78026 0.03505 lineto
0.78274 0.02517 lineto
0.78398 0.02015 lineto
0.78522 0.0151 lineto
0.78646 0.01613 lineto
0.7877 0.02123 lineto
0.79018 0.03147 lineto
0.79266 0.04172 lineto
0.79762 0.06197 lineto
0.80754 0.09986 lineto
0.8125 0.11655 lineto
0.81746 0.13112 lineto
0.82242 0.14318 lineto
0.8249 0.14814 lineto
0.82738 0.15232 lineto
0.82986 0.1557 lineto
0.8311 0.15707 lineto
0.83234 0.15823 lineto
0.83358 0.15916 lineto
0.83482 0.15987 lineto
0.83606 0.16035 lineto
0.8373 0.1606 lineto
0.83854 0.16061 lineto
0.83978 0.16039 lineto
0.84102 0.15992 lineto
0.84226 0.15921 lineto
0.8435 0.15826 lineto
0.84474 0.15705 lineto
0.84722 0.1539 lineto
0.8497 0.14973 lineto
0.85218 0.14455 lineto
Mistroke
0.85714 0.13112 lineto
0.8621 0.11366 lineto
0.86706 0.09226 lineto
0.87202 0.06709 lineto
0.8745 0.05316 lineto
0.87698 0.03839 lineto
0.87822 0.03069 lineto
0.87946 0.0228 lineto
0.8807 0.01472 lineto
0.88194 0.01971 lineto
0.88442 0.03678 lineto
0.8869 0.05453 lineto
0.89683 0.13112 lineto
0.91667 0.29807 lineto
0.93651 0.45364 lineto
0.94643 0.5162 lineto
0.95139 0.542 lineto
0.95635 0.56364 lineto
0.96131 0.58081 lineto
0.96379 0.58764 lineto
0.96627 0.59325 lineto
0.96875 0.59765 lineto
0.96999 0.59938 lineto
0.97123 0.60079 lineto
0.97247 0.6019 lineto
0.97371 0.60269 lineto
0.97495 0.60316 lineto
0.97619 0.58279 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30979 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29729 0 1 Msboxa
[(-4)] 0.19685 0.29729 0 1 Msboxa
[(-2)] 0.34842 0.29729 0 1 Msboxa
[(2)] 0.65158 0.29729 0 1 Msboxa
[(4)] 0.80315 0.29729 0 1 Msboxa
[(6)] 0.95473 0.29729 0 1 Msboxa
[(w)] 1.00625 0.30979 -1 0 Msboxa
[(-150)] 0.4875 0.06389 1 0 Msboxa
[(-100)] 0.4875 0.14586 1 0 Msboxa
[(-50)] 0.4875 0.22782 1 0 Msboxa
[(50)] 0.4875 0.39175 1 0 Msboxa
[(100)] 0.4875 0.47371 1 0 Msboxa
[(150)] 0.4875 0.55568 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30979 moveto
1 0.30979 lineto
stroke
0.04527 0.30354 moveto
0.04527 0.31604 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29729 0 1 Mshowa
0.19685 0.30354 moveto
0.19685 0.31604 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29729 0 1 Mshowa
0.34842 0.30354 moveto
0.34842 0.31604 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29729 0 1 Mshowa
0.65158 0.30354 moveto
0.65158 0.31604 lineto
stroke
0 setgray
[(2)] 0.65158 0.29729 0 1 Mshowa
0.80315 0.30354 moveto
0.80315 0.31604 lineto
stroke
0 setgray
[(4)] 0.80315 0.29729 0 1 Mshowa
0.95473 0.30354 moveto
0.95473 0.31604 lineto
stroke
0 setgray
[(6)] 0.95473 0.29729 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30979 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06389 moveto
0.50625 0.06389 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06389 1 0 Mshowa
0.49375 0.14586 moveto
0.50625 0.14586 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14586 1 0 Mshowa
0.49375 0.22782 moveto
0.50625 0.22782 lineto
stroke
0 setgray
[(-50)] 0.4875 0.22782 1 0 Mshowa
0.49375 0.39175 moveto
0.50625 0.39175 lineto
stroke
0 setgray
[(50)] 0.4875 0.39175 1 0 Mshowa
0.49375 0.47371 moveto
0.50625 0.47371 lineto
stroke
0 setgray
[(100)] 0.4875 0.47371 1 0 Mshowa
0.49375 0.55568 moveto
0.50625 0.55568 lineto
stroke
0 setgray
[(150)] 0.4875 0.55568 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30979 moveto
0.06349 0.26061 lineto
0.08333 0.23602 lineto
0.09325 0.22372 lineto
0.10317 0.21143 lineto
0.10813 0.20528 lineto
0.1131 0.19913 lineto
0.11558 0.19606 lineto
0.11682 0.19452 lineto
0.11806 0.19299 lineto
0.1193 0.48652 lineto
0.12054 0.48498 lineto
0.12178 0.48345 lineto
0.12302 0.48191 lineto
0.14286 0.45732 lineto
0.1627 0.43273 lineto
0.18254 0.40814 lineto
0.19246 0.39585 lineto
0.20238 0.38355 lineto
0.20734 0.37741 lineto
0.20982 0.37433 lineto
0.21106 0.3728 lineto
0.2123 0.37126 lineto
0.21354 0.36972 lineto
0.21478 0.07311 lineto
0.21602 0.07158 lineto
0.21726 0.07004 lineto
0.22222 0.06389 lineto
0.24206 0.0393 lineto
0.25198 0.02701 lineto
0.25694 0.02086 lineto
0.25942 0.01779 lineto
0.26066 0.01625 lineto
0.2619 0.01472 lineto
0.26314 0.60332 lineto
0.26438 0.60178 lineto
0.26562 0.60025 lineto
0.26687 0.59871 lineto
0.27183 0.59256 lineto
0.28175 0.58027 lineto
0.29167 0.56797 lineto
0.29663 0.56182 lineto
0.30159 0.55568 lineto
0.30407 0.5526 lineto
0.30655 0.54953 lineto
0.30779 0.54799 lineto
0.30903 0.54646 lineto
0.31027 0.24985 lineto
0.31151 0.24831 lineto
0.31399 0.24524 lineto
Mistroke
0.31647 0.24217 lineto
0.32143 0.23602 lineto
0.34127 0.21143 lineto
0.36111 0.18684 lineto
0.38095 0.16225 lineto
0.39087 0.14996 lineto
0.39583 0.14381 lineto
0.39831 0.14073 lineto
0.40079 0.13766 lineto
0.40203 0.13612 lineto
0.40327 0.13459 lineto
0.40451 0.13305 lineto
0.40575 0.42658 lineto
0.40823 0.42351 lineto
0.41071 0.42044 lineto
0.42063 0.40814 lineto
0.46032 0.35896 lineto
0.5 0.30979 lineto
0.53968 0.26061 lineto
0.55952 0.23602 lineto
0.56944 0.22372 lineto
0.57937 0.21143 lineto
0.58433 0.20528 lineto
0.58929 0.19913 lineto
0.59177 0.19606 lineto
0.59301 0.19452 lineto
0.59425 0.19299 lineto
0.59549 0.48652 lineto
0.59673 0.48498 lineto
0.59921 0.48191 lineto
0.61905 0.45732 lineto
0.63889 0.43273 lineto
0.65873 0.40814 lineto
0.66865 0.39585 lineto
0.67857 0.38355 lineto
0.68353 0.37741 lineto
0.68601 0.37433 lineto
0.68725 0.3728 lineto
0.68849 0.37126 lineto
0.68973 0.36972 lineto
0.69097 0.07311 lineto
0.69221 0.07158 lineto
0.69345 0.07004 lineto
0.69841 0.06389 lineto
0.71825 0.0393 lineto
0.72817 0.02701 lineto
0.73313 0.02086 lineto
0.73562 0.01779 lineto
0.73686 0.01625 lineto
0.7381 0.01472 lineto
Mistroke
0.73934 0.60332 lineto
0.74058 0.60178 lineto
0.74182 0.60025 lineto
0.74306 0.59871 lineto
0.74802 0.59256 lineto
0.75794 0.58027 lineto
0.76786 0.56797 lineto
0.77282 0.56182 lineto
0.77778 0.55568 lineto
0.78026 0.5526 lineto
0.78274 0.54953 lineto
0.78398 0.54799 lineto
0.78522 0.54646 lineto
0.78646 0.24985 lineto
0.7877 0.24831 lineto
0.79018 0.24524 lineto
0.79266 0.24217 lineto
0.79762 0.23602 lineto
0.81746 0.21143 lineto
0.8373 0.18684 lineto
0.85714 0.16225 lineto
0.86706 0.14996 lineto
0.87202 0.14381 lineto
0.8745 0.14073 lineto
0.87698 0.13766 lineto
0.87822 0.13612 lineto
0.87946 0.13459 lineto
0.8807 0.13305 lineto
0.88194 0.42658 lineto
0.88442 0.42351 lineto
0.8869 0.42044 lineto
0.89683 0.40814 lineto
0.93651 0.35896 lineto
0.97619 0.30979 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
{Graphics[{{Line[{{-6.283185307179586476, 0.8857142857142857143}, 
       {-6.266822845442139636, 0.9997322901543709611}, 
       {-6.250460383704692796, 0.9989294042859876644}, 
       {-6.234097921967245956, 0.9975920731509477074}, 
       {-6.217735460229799117, 0.9957215138449655735}, 
       {-6.185010536754905437, 0.9903880028301709347}, 
       {-6.152285613280011758, 0.9829482750651514888}, 
       {-6.086835766330224399, 0.9618659251658068841}, 
       {-6.02138591938043704, 0.93278049202940278}, 
       {-5.890486225480862321, 0.8523945254791337087}, 
       {-5.759586531581287603, 0.7464101615137754537}, 
       {-5.497787143782138167, 0.4828427124746190098}, 
       {-5.366887449882563449, 0.3399769535624799501}, 
       {-5.23598775598298873, 0.1999999999999999976}, 
       {-5.170537909033201371, 0.1334109044841122559}, 
       {-5.105088062083414012, 0.07023066047141689864}, 
       {-5.072363138608520333, 0.04016409617690244355}, 
       {-5.056000676871073493, 0.02555176001179323579}, 
       {-5.039638215133626653, 0.01123445000477056611}, 
       {-5.023275753396179813, 0.002777465798024701438}, 
       {-5.006913291658732974, 0.01647397401923314795}, 
       {-4.990550829921286134, 0.0298454253366586184}, 
       {-4.974188368183839294, 0.04288254347276715404}, 
       {-4.843288674284264576, 0.134159853627606678}, 
       {-4.777838827334477217, 0.1704166928574669387}, 
       {-4.712388980384689857, 0.2}, 
       {-4.679664056909796177, 0.2122312024241518597}, 
       {-4.646939133434902498, 0.2227391962415813902}, 
       {-4.614214209960008819, 0.2315209682931164212}, 
       {-4.581489286485115139, 0.2385808074036479516}, 
       {-4.565126824747668299, 0.2414683240750282465}, 
       {-4.54876436301022146, 0.2439302411558777619}, 
       {-4.53240190127277462, 0.2459691152135833534}, 
       {-4.51603943953532778, 0.2475879418109660095}, 
       {-4.499676977797880941, 0.248790150912056394}, 
       {-4.483314516060434101, 0.2495796018268246041}, 
       {-4.466952054322987261, 0.2499605777006475679}, 
       {-4.450589592585540421, 0.249937779554783763}, 
       {-4.434227130848093581, 0.2495163198846044913}, 
       {-4.417864669110646741, 0.2487017158228030422}, 
       {-4.401502207373199901, 0.2474998818752674714}, 
       {-4.385139745635753062, 0.2459171222377586985}, 
       {-4.352414822160859382, 0.2416359421600843617}, 
       {-4.319689898685965703, 0.2359160854206549183}, 
       {-4.254240051736178344, 0.2204200476910887685}, 
       {-4.188790204786390984, 0.2}, 
       {-4.057890510886816266, 0.1470321896444965609}, 
       {-3.926990816987241548, 0.08284271247461900964}, 
       {-3.861540970037454189, 0.04852544610357032207}, 
       {-3.828816046562560509, 0.03116805253864347701}, 
       {-3.81245358482511367, 0.02248419447771086304}, 
       {-3.79609112308766683, 0.01381371807548576088}, 
       {-3.77972866135021999, 0.005169141690473016945}, 
       {-3.76336619961277315, 0.003437112284618545538}, 
       {-3.747003737875326311, 0.01199273157258335938}, 
       {-3.730641276137879471, 0.02048552802501781391}, 
       {-3.665191429188092112, 0.05358983848622454098}, 
       {-3.534291735288517393, 0.1132908994701043073}, 
       {-3.468841888338730034, 0.1385692843184517997}, 
       {-3.403392041388942675, 0.1600398309981481436}, 
       {-3.337942194439155316, 0.1772377008432225226}, 
       {-3.305217270964261636, 0.1841147189640906639}, 
       {-3.272492347489367957, 0.1897923859661031503}, 
       {-3.239767424014474277, 0.194240221492413425}, 
       {-3.223404962277027438, 0.1959952371102794719}, 
       {-3.207042500539580598, 0.1974343752540827618}, 
       {-3.190680038802133758, 0.1985557081868097975}, 
       {-3.174317577064686918, 0.1993577343048951449}, 
       {-3.157955115327240078, 0.1998393798267215446}, 
       {-3.141592653589793239, 0.2}, 
       {-3.125230191852346399, 0.1998393798267215446}, 
       {-3.108867730114899559, 0.1993577343048951449}, 
       {-3.092505268377452719, 0.1985557081868097975}, 
       {-3.07614280664000588, 0.1974343752540827618}, 
       {-3.0434178831651122, 0.1942402214924134251}, 
       {-3.01069295969021852, 0.1897923859661031502}, 
       {-2.945243112740431161, 0.1772377008432225229}, 
       {-2.879793265790643802, 0.1600398309981481444}, 
       {-2.748893571891069084, 0.1132908994701043072}, 
       {-2.683443724941281725, 0.08475547499041293442}, 
       {-2.617993877991494366, 0.05358983848622454167}, 
       {-2.585268954516600686, 0.03723460347696895813}, 
       {-2.552544031041707007, 0.02048552802501781409}, 
       {-2.536181569304260167, 0.01199273157258335965}, 
       {-2.519819107566813327, 0.003437112284618545858}, 
       {-2.503456645829366487, 0.005169141690473016625}, 
       {-2.487094184091919648, 0.0138137180754857607}, 
       {-2.454369260617025968, 0.03116805253864347701}, 
       {-2.421644337142132288, 0.04852544610357032172}, 
       {-2.356194490192344929, 0.08284271247461900964}, 
       {-2.225294796292770211, 0.1470321896444965609}, 
       {-2.159844949342982852, 0.1753014661538767986}, 
       {-2.094395102393195493, 0.1999999999999999992}, 
       {-2.028945255443408134, 0.2204200476910887685}, 
       {-1.996220331968514454, 0.2288211379617854423}, 
       {-1.963495408493620775, 0.2359160854206549183}, 
       {-1.930770485018727095, 0.2416359421600843605}, 
       {-1.914408023281280255, 0.243960122701982805}, 
       {-1.898045561543833416, 0.2459171222377586985}, 
       {-1.881683099806386576, 0.2474998818752674714}, 
       {-1.865320638068939736, 0.2487017158228030422}, 
       {-1.848958176331492896, 0.2495163198846044913}, 
       {-1.832595714594046056, 0.2499377795547837631}, 
       {-1.816233252856599217, 0.249960577700647568}, 
       {-1.799870791119152377, 0.2495796018268246042}, 
       {-1.783508329381705537, 0.248790150912056394}, 
       {-1.767145867644258697, 0.2475879418109660095}, 
       {-1.750783405906811858, 0.2459691152135833535}, 
       {-1.734420944169365018, 0.2439302411558777622}, 
       {-1.701696020694471338, 0.2385808074036479519}, 
       {-1.668971097219577659, 0.2315209682931164212}, 
       {-1.636246173744683979, 0.2227391962415813913}, 
       {-1.57079632679489662, 0.2}, 
       {-1.505346479845109261, 0.1704166928574669387}, 
       {-1.439896632895321902, 0.134159853627606678}, 
       {-1.374446785945534543, 0.09151568419806339535}, 
       {-1.341721862470640863, 0.06791859139932603923}, 
       {-1.308996938995747183, 0.04288254347276715404}, 
       {-1.292634477258300344, 0.02984542533665861926}, 
       {-1.276272015520853504, 0.01647397401923314824}, 
       {-1.259909553783406664, 0.002777465798024702063}, 
       {-1.243547092045959824, 0.01123445000477056581}, 
       {-1.210822168571066145, 0.04016409617690244325}, 
       {-1.178097245096172465, 0.07023066047141689804}, 
       {-1.047197551196597747, 0.1999999999999999976}, 
       {-0.7853981633974483104, 0.4828427124746190098}, 
       {-0.5235987755982988739, 0.7464101615137754537}, 
       {-0.3926990816987241556, 0.8523945254791337087}, 
       {-0.3272492347489367965, 0.8961133879145363272}, 
       {-0.2617993877991494374, 0.93278049202940278}, 
       {-0.1963495408493620783, 0.9618659251658068842}, 
       {-0.1636246173744683987, 0.9734293846319938665}, 
       {-0.1308996938995747191, 0.9829482750651514759}, 
       {-0.09817477042468103956, 0.9903880028301709277}, 
       {-0.08181230868723419977, 0.9933194285576237347}, 
       {-0.06544984694978735999, 0.9957215138449655735}, 
       {-0.04908738521234052021, 0.9975920731509477162}, 
       {-0.03272492347489368043, 0.9989294042859876674}, 
       {-0.01636246173744684065, 0.9997322901543709639}, 
       {-(8.673617379884035472*10^-19), 1.}, 
       {0.01636246173744683891, 0.9997322901543709641}, 
       {0.03272492347489367869, 0.9989294042859876675}, 
       {0.04908738521234051848, 0.9975920731509477164}, 
       {0.06544984694978735825, 0.9957215138449655684}, 
       {0.09817477042468103783, 0.9903880028301709316}, 
       {0.1308996938995747174, 0.9829482750651514688}, 
       {0.1963495408493620765, 0.9618659251658068863}, 
       {0.2617993877991494356, 0.9327804920294027714}, 
       {0.3926990816987241539, 0.852394525479133716}, 
       {0.5235987755982988721, 0.7464101615137754627}, 
       {0.7853981633974483087, 0.4828427124746190111}, 
       {0.916297857297023027, 0.3399769535624799501}, 
       {1.047197551196597745, 0.2000000000000000024}, 
       {1.112647398146385104, 0.1334109044841122584}, 
       {1.178097245096172463, 0.07023066047141689988}, 
       {1.210822168571066143, 0.04016409617690244517}, 
       {1.227184630308512983, 0.02555176001179323694}, 
       {1.243547092045959823, 0.0112344500047705673}, 
       {1.259909553783406662, 0.002777465798024700591}, 
       {1.276272015520853502, 0.01647397401923314679}, 
       {1.308996938995747182, 0.04288254347276715331}, 
       {1.4398966328953219, 0.1341598536276066771}, 
       {1.505346479845109259, 0.1704166928574669371}, 
       {1.570796326794896618, 0.2}, 
       {1.603521250269790298, 0.2122312024241518598}, 
       {1.636246173744683977, 0.2227391962415813902}, 
       {1.668971097219577657, 0.2315209682931164202}, 
       {1.701696020694471337, 0.2385808074036479511}, 
       {1.718058482431918176, 0.2414683240750282461}, 
       {1.734420944169365016, 0.2439302411558777615}, 
       {1.750783405906811856, 0.2459691152135833532}, 
       {1.767145867644258696, 0.2475879418109660092}, 
       {1.783508329381705535, 0.2487901509120563938}, 
       {1.799870791119152375, 0.249579601826824604}, 
       {1.816233252856599215, 0.2499605777006475679}, 
       {1.832595714594046055, 0.2499377795547837643}, 
       {1.848958176331492894, 0.2495163198846044912}, 
       {1.865320638068939734, 0.2487017158228030422}, 
       {1.881683099806386574, 0.2474998818752674714}, 
       {1.898045561543833414, 0.2459171222377586985}, 
       {1.930770485018727093, 0.2416359421600843618}, 
       {1.963495408493620773, 0.2359160854206549185}, 
       {2.028945255443408132, 0.2204200476910887688}, 
       {2.094395102393195491, 0.2000000000000000008}, 
       {2.225294796292770209, 0.1470321896444965609}, 
       {2.356194490192344928, 0.08284271247461901035}, 
       {2.421644337142132287, 0.04852544610357032244}, 
       {2.454369260617025966, 0.03116805253864347773}, 
       {2.470731722354472806, 0.0224841944777108638}, 
       {2.487094184091919646, 0.01381371807548576162}, 
       {2.503456645829366486, 0.005169141690473017538}, 
       {2.519819107566813325, 0.003437112284618544946}, 
       {2.536181569304260165, 0.01199273157258335875}, 
       {2.552544031041707005, 0.02048552802501781319}, 
       {2.617993877991494364, 0.05358983848622454102}, 
       {2.748893571891069082, 0.1132908994701043073}, 
       {2.814343418840856441, 0.1385692843184517998}, 
       {2.8797932657906438, 0.1600398309981481436}, 
       {2.94524311274043116, 0.1772377008432225226}, 
       {2.977968036215324839, 0.1841147189640906637}, 
       {3.010692959690218519, 0.1897923859661031501}, 
       {3.043417883165112198, 0.1942402214924134249}, 
       {3.059780344902559038, 0.1959952371102794718}, 
       {3.076142806640005878, 0.1974343752540827617}, 
       {3.092505268377452718, 0.1985557081868097974}, 
       {3.108867730114899557, 0.1993577343048951449}, 
       {3.125230191852346397, 0.1998393798267215446}, 
       {3.141592653589793237, 0.2}, 
       {3.157955115327240077, 0.1998393798267215447}, 
       {3.174317577064686916, 0.199357734304895145}, 
       {3.190680038802133756, 0.1985557081868097976}, 
       {3.207042500539580596, 0.197434375254082762}, 
       {3.239767424014474276, 0.1942402214924134252}, 
       {3.272492347489367955, 0.1897923859661031505}, 
       {3.337942194439155314, 0.1772377008432225232}, 
       {3.403392041388942673, 0.1600398309981481444}, 
       {3.534291735288517392, 0.1132908994701043084}, 
       {3.599741582238304751, 0.08475547499041293502}, 
       {3.66519142918809211, 0.05358983848622454236}, 
       {3.697916352662985789, 0.03723460347696895844}, 
       {3.730641276137879469, 0.02048552802501781481}, 
       {3.747003737875326309, 0.01199273157258336029}, 
       {3.763366199612773149, 0.003437112284618546449}, 
       {3.779728661350219988, 0.005169141690473016031}, 
       {3.796091123087666828, 0.01381371807548575997}, 
       {3.828816046562560508, 0.03116805253864347624}, 
       {3.861540970037454187, 0.04852544610357032099}, 
       {3.926990816987241546, 0.08284271247461900896}, 
       {4.057890510886816265, 0.1470321896444965597}, 
       {4.123340357836603623, 0.1753014661538767976}, 
       {4.188790204786390983, 0.1999999999999999992}, 
       {4.254240051736178342, 0.2204200476910887682}, 
       {4.286964975211072022, 0.2288211379617854421}, 
       {4.319689898685965701, 0.2359160854206549182}, 
       {4.35241482216085938, 0.2416359421600843604}, 
       {4.36877728389830622, 0.2439601227019828038}, 
       {4.38513974563575306, 0.2459171222377586984}, 
       {4.4015022073731999, 0.2474998818752674714}, 
       {4.417864669110646739, 0.2487017158228030423}, 
       {4.434227130848093579, 0.2495163198846044913}, 
       {4.450589592585540419, 0.2499377795547837632}, 
       {4.466952054322987259, 0.2499605777006475681}, 
       {4.483314516060434099, 0.2495796018268246044}, 
       {4.499676977797880939, 0.2487901509120563942}, 
       {4.516039439535327779, 0.2475879418109660097}, 
       {4.532401901272774618, 0.2459691152135833538}, 
       {4.548764363010221458, 0.2439302411558777625}, 
       {4.581489286485115137, 0.2385808074036479524}, 
       {4.614214209960008817, 0.2315209682931164212}, 
       {4.646939133434902496, 0.2227391962415813914}, 
       {4.712388980384689856, 0.2000000000000000014}, 
       {4.777838827334477215, 0.1704166928574669375}, 
       {4.843288674284264574, 0.134159853627606679}, 
       {4.908738521234051933, 0.09151568419806339743}, 
       {4.941463444708945612, 0.06791859139932604027}, 
       {4.974188368183839292, 0.04288254347276715518}, 
       {4.990550829921286132, 0.02984542533665862012}, 
       {5.006913291658732972, 0.01647397401923314912}, 
       {5.023275753396179812, 0.002777465798024703206}, 
       {5.039638215133626651, 0.01123445000477056492}, 
       {5.072363138608520331, 0.04016409617690244235}, 
       {5.10508806208341401, 0.07023066047141689743}, 
       {5.235987755982988729, 0.1999999999999999976}, 
       {5.497787143782138165, 0.4828427124746190091}, 
       {5.759586531581287601, 0.7464101615137754544}, 
       {5.89048622548086232, 0.8523945254791337126}, 
       {5.955936072430649679, 0.896113387914536333}, 
       {6.021385919380437038, 0.9327804920294027676}, 
       {6.086835766330224397, 0.9618659251658068821}, 
       {6.119560689805118077, 0.9734293846319938637}, 
       {6.152285613280011756, 0.9829482750651514858}, 
       {6.185010536754905436, 0.9903880028301709309}, 
       {6.201372998492352275, 0.9933194285576237386}, 
       {6.217735460229799115, 0.9957215138449655679}, 
       {6.234097921967245955, 0.9975920731509477143}, 
       {6.250460383704692794, 0.9989294042859876539}, 
       {6.266822845442139634, 0.9997322901543709823}, 
       {6.283185307179586474, 0.9652173913043478261}}]}}, 
   {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[{{Line[{{-6.283185307179586476, 0.}, 
       {-5.759586531581287603, -29.99999999999999979}, 
       {-5.497787143782138167, -44.99999999999999998}, 
       {-5.366887449882563449, -52.49999999999999982}, 
       {-5.23598775598298873, -59.99999999999999985}, 
       {-5.170537909033201371, -63.75000000000000001}, 
       {-5.105088062083414012, -67.49999999999999987}, 
       {-5.072363138608520333, -69.37499999999999983}, 
       {-5.056000676871073493, -70.31249999999999996}, 
       {-5.039638215133626653, -71.24999999999999985}, 
       {-5.023275753396179813, 107.8125000000000002}, 
       {-5.006913291658732974, 106.8750000000000003}, 
       {-4.990550829921286134, 105.9375000000000001}, 
       {-4.974188368183839294, 105.0000000000000002}, 
       {-4.712388980384689857, 90.00000000000000016}, 
       {-4.450589592585540421, 75.00000000000000013}, 
       {-4.188790204786390984, 60.00000000000000025}, 
       {-4.057890510886816266, 52.50000000000000022}, 
       {-3.926990816987241548, 45.00000000000000006}, 
       {-3.861540970037454189, 41.25000000000000009}, 
       {-3.828816046562560509, 39.37499999999999999}, 
       {-3.81245358482511367, 38.43750000000000027}, 
       {-3.79609112308766683, 37.50000000000000022}, 
       {-3.77972866135021999, 36.5625000000000001}, 
       {-3.76336619961277315, -144.375}, 
       {-3.747003737875326311, -145.3124999999999999}, 
       {-3.730641276137879471, -146.2500000000000001}, 
       {-3.665191429188092112, -149.9999999999999999}, 
       {-3.403392041388942675, -165.}, 
       {-3.272492347489367957, -172.5}, 
       {-3.207042500539580598, -176.25}, 
       {-3.174317577064686918, -178.125}, 
       {-3.157955115327240078, -179.0625}, 
       {-3.141592653589793239, -180.}, 
       {-3.125230191852346399, 179.0625000000000002}, 
       {-3.108867730114899559, 178.1250000000000002}, 
       {-3.092505268377452719, 177.1875000000000002}, 
       {-3.07614280664000588, 176.2500000000000002}, 
       {-3.01069295969021852, 172.5000000000000002}, 
       {-2.879793265790643802, 165.0000000000000002}, 
       {-2.748893571891069084, 157.5000000000000001}, 
       {-2.683443724941281725, 153.7500000000000003}, 
       {-2.617993877991494366, 150.0000000000000003}, 
       {-2.585268954516600686, 148.1250000000000001}, 
       {-2.552544031041707007, 146.2500000000000001}, 
       {-2.536181569304260167, 145.3125000000000003}, 
       {-2.519819107566813327, 144.375}, 
       {-2.503456645829366487, -36.5625000000000001}, 
       {-2.487094184091919648, -37.49999999999999983}, 
       {-2.454369260617025968, -39.37499999999999999}, 
       {-2.421644337142132288, -41.25000000000000009}, 
       {-2.356194490192344929, -44.99999999999999999}, 
       {-2.094395102393195493, -59.99999999999999985}, 
       {-1.832595714594046056, -74.99999999999999992}, 
       {-1.57079632679489662, -89.99999999999999998}, 
       {-1.439896632895321902, -97.49999999999999994}, 
       {-1.374446785945534543, -101.25}, 
       {-1.341721862470640863, -103.125}, 
       {-1.308996938995747183, -105.}, 
       {-1.292634477258300344, -105.9374999999999999}, 
       {-1.276272015520853504, -106.8750000000000001}, 
       {-1.259909553783406664, -107.8125}, 
       {-1.243547092045959824, 71.25000000000000006}, 
       {-1.210822168571066145, 69.37500000000000003}, 
       {-1.178097245096172465, 67.50000000000000007}, 
       {-1.047197551196597747, 60.00000000000000025}, 
       {-0.5235987755982988739, 30.00000000000000019}, 
       {-(8.673617379884035472*10^-19), 0.}, 
       {0.5235987755982988721, -29.9999999999999998}, 
       {0.7853981633974483087, -44.99999999999999999}, 
       {0.916297857297023027, -52.49999999999999982}, 
       {1.047197551196597745, -59.99999999999999985}, 
       {1.112647398146385104, -63.75000000000000001}, 
       {1.178097245096172463, -67.50000000000000006}, 
       {1.210822168571066143, -69.37500000000000003}, 
       {1.227184630308512983, -70.31249999999999996}, 
       {1.243547092045959823, -71.25000000000000006}, 
       {1.259909553783406662, 107.8125}, 
       {1.276272015520853502, 106.8750000000000001}, 
       {1.308996938995747182, 105.0000000000000002}, 
       {1.570796326794896618, 90.00000000000000007}, 
       {1.832595714594046055, 75.00000000000000013}, 
       {2.094395102393195491, 59.99999999999999985}, 
       {2.225294796292770209, 52.50000000000000022}, 
       {2.356194490192344928, 45.00000000000000006}, 
       {2.421644337142132287, 41.25000000000000008}, 
       {2.454369260617025966, 39.375}, 
       {2.470731722354472806, 38.43749999999999988}, 
       {2.487094184091919646, 37.50000000000000022}, 
       {2.503456645829366486, 36.5625000000000001}, 
       {2.519819107566813325, -144.375}, 
       {2.536181569304260165, -145.3124999999999999}, 
       {2.552544031041707005, -146.2500000000000001}, 
       {2.617993877991494364, -149.9999999999999999}, 
       {2.8797932657906438, -165.0000000000000002}, 
       {3.010692959690218519, -172.5000000000000001}, 
       {3.076142806640005878, -176.2500000000000001}, 
       {3.108867730114899557, -178.1250000000000001}, 
       {3.125230191852346397, -179.0625000000000001}, 
       {3.141592653589793237, -180.0000000000000001}, 
       {3.157955115327240077, 179.0625000000000001}, 
       {3.174317577064686916, 178.1250000000000001}, 
       {3.190680038802133756, 177.1875000000000001}, 
       {3.207042500539580596, 176.2500000000000001}, 
       {3.272492347489367955, 172.5000000000000001}, 
       {3.403392041388942673, 165.0000000000000002}, 
       {3.534291735288517392, 157.5000000000000001}, 
       {3.599741582238304751, 153.7500000000000001}, 
       {3.66519142918809211, 149.9999999999999999}, 
       {3.697916352662985789, 148.1250000000000001}, 
       {3.730641276137879469, 146.2500000000000001}, 
       {3.747003737875326309, 145.3124999999999999}, 
       {3.763366199612773149, 144.375}, 
       {3.779728661350219988, -36.5625000000000001}, 
       {3.796091123087666828, -37.49999999999999983}, 
       {3.828816046562560508, -39.37499999999999999}, 
       {3.861540970037454187, -41.25000000000000009}, 
       {3.926990816987241546, -45.00000000000000006}, 
       {4.188790204786390983, -59.99999999999999986}, 
       {4.450589592585540419, -75.00000000000000013}, 
       {4.712388980384689856, -90.00000000000000006}, 
       {4.843288674284264574, -97.50000000000000004}, 
       {4.908738521234051933, -101.25}, 
       {4.941463444708945612, -103.1250000000000001}, 
       {4.974188368183839292, -105.}, 
       {4.990550829921286132, -105.9375000000000001}, 
       {5.006913291658732972, -106.8750000000000001}, 
       {5.023275753396179812, -107.8125}, 
       {5.039638215133626651, 71.25000000000000006}, 
       {5.072363138608520331, 69.37500000000000003}, 
       {5.10508806208341401, 67.50000000000000007}, 
       {5.235987755982988729, 59.99999999999999985}, 
       {5.759586531581287601, 30.00000000000000019}, 
       {6.283185307179586474, 0.}}]}}, 
   {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w", " "}, Ticks -> Automatic, Framed -> False, 
    Prolog -> {}, Epilog -> {}, AxesStyle -> {}, 
    Background -> Automatic, DefaultColor -> Automatic}]}
;[o]
{-Graphics-, -Graphics-}
:[font = subsubsection; inactive; startGroup; Cclosed; ]
2-D Pulse
:[font = text; inactive; ]
		The Fourier transform can be easily extended to multidimensions, as shown in [Dudgeon & Mersereau, 1984].  The 2-D forward DTFT, for example, is simply a double summation over two discrete-time variables, and the inverse DTFT is a double integral over two continuous frequency variables each over the interval (-Pi, Pi).   In 1-D, the DTFT of a discrete pulse is a sinc function.  This is also the case in 2-D, as shown below. 
:[font = info; inactive; startGroup; Cclosed; ]
-- Time Response
:[font = input; ]
len = 3
del = -1;
signal = Pulse[len,n1-del] Pulse[len,n2-del];
SequencePlot[signal,{n1,-5,5},{n2,-5,5}];
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 17; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(-4)] 0.109 0.29162 1 0.971791 Msboxa
[(-2)] 0.21698 0.24912 0.945631 1 Msboxa
[(0)] 0.33027 0.20455 0.862234 1 Msboxa
[(2)] 0.44927 0.15776 0.778837 1 Msboxa
[(4)] 0.57441 0.10858 0.69544 1 Msboxa
[(-4)] 0.68734 0.13508 -1 0.380111 Msboxa
[(-2)] 0.74388 0.22166 -1 0.359096 Msboxa
[(0)] 0.79557 0.30082 -1 0.340282 Msboxa
[(2)] 0.84302 0.37347 -1 0.323342 Msboxa
[(4)] 0.88671 0.44039 -1 0.308008 Msboxa
[(0)] 0.05375 0.32922 1 -0.390596 Msboxa
[(0.25)] 0.04624 0.37629 1 -0.380668 Msboxa
[(0.5)] 0.03847 0.425 1 -0.370357 Msboxa
[(0.75)] 0.03042 0.47544 1 -0.359642 Msboxa
[(1)] 0.02208 0.5277 1 -0.348498 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.11326 0.29577 moveto
0.1218 0.30407 lineto
stroke
0 setgray
[(-4)] 0.109 0.29162 1 0.971791 Mshowa
0.22107 0.25345 moveto
0.22925 0.2621 lineto
stroke
0 setgray
[(-2)] 0.21698 0.24912 0.945631 1 Mshowa
0.33416 0.20906 moveto
0.34194 0.21808 lineto
stroke
0 setgray
[(0)] 0.33027 0.20455 0.862234 1 Mshowa
0.45293 0.16246 moveto
0.46024 0.17185 lineto
stroke
0 setgray
[(2)] 0.44927 0.15776 0.778837 1 Mshowa
0.5778 0.11347 moveto
0.5846 0.12325 lineto
stroke
0 setgray
[(4)] 0.57441 0.10858 0.69544 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.68177 0.13719 moveto
0.67065 0.14142 lineto
stroke
0 setgray
[(-4)] 0.68734 0.13508 -1 0.380111 Mshowa
0.73828 0.22367 moveto
0.72708 0.22769 lineto
stroke
0 setgray
[(-2)] 0.74388 0.22166 -1 0.359096 Mshowa
0.78994 0.30274 moveto
0.77867 0.30657 lineto
stroke
0 setgray
[(0)] 0.79557 0.30082 -1 0.340282 Mshowa
0.83735 0.3753 moveto
0.82603 0.37897 lineto
stroke
0 setgray
[(2)] 0.84302 0.37347 -1 0.323342 Mshowa
0.88102 0.44214 moveto
0.86964 0.44565 lineto
stroke
0 setgray
[(4)] 0.88671 0.44039 -1 0.308008 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.05181 0.37417 moveto
0.06293 0.36993 lineto
stroke
0 setgray
[(0.25)] 0.04624 0.37629 1 -0.380668 Mshowa
0.04405 0.42293 moveto
0.05522 0.41879 lineto
stroke
0 setgray
[(0.5)] 0.03847 0.425 1 -0.370357 Mshowa
0.03602 0.47342 moveto
0.04722 0.46939 lineto
stroke
0 setgray
[(0.75)] 0.03042 0.47544 1 -0.359642 Mshowa
0.0277 0.52574 moveto
0.03894 0.52183 lineto
stroke
0 setgray
[(1)] 0.02208 0.5277 1 -0.348498 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.11905 setgray
0.0015 setlinewidth
0.37373 0.6125 0.39332 0.63074 0.42607 0.62092 0.40676 0.60242 Metetra
0.11905 setgray
0.40676 0.60242 0.42607 0.62092 0.45927 0.61096 0.44025 0.59221 Metetra
0.11905 setgray
0.44025 0.59221 0.45927 0.61096 0.49293 0.60086 0.47421 0.58185 Metetra
0.11905 setgray
0.47421 0.58185 0.49293 0.60086 0.52706 0.59062 0.50866 0.57134 Metetra
0.11905 setgray
0.50866 0.57134 0.52706 0.59062 0.56167 0.58024 0.54359 0.56069 Metetra
0.11905 setgray
0.54359 0.56069 0.56167 0.58024 0.59676 0.56971 0.57902 0.54988 Metetra
0.11905 setgray
0.57902 0.54988 0.59676 0.56971 0.63236 0.55903 0.61496 0.53891 Metetra
0.11905 setgray
0.61496 0.53891 0.63236 0.55903 0.66847 0.5482 0.65143 0.52779 Metetra
0.11905 setgray
0.65143 0.52779 0.66847 0.5482 0.7051 0.53721 0.68843 0.5165 Metetra
0.11905 setgray
0.68843 0.5165 0.7051 0.53721 0.74226 0.52606 0.72598 0.50505 Metetra
0.11905 setgray
0.72598 0.50505 0.74226 0.52606 0.77997 0.51475 0.76409 0.49342 Metetra
0.11905 setgray
0.76409 0.49342 0.77997 0.51475 0.81824 0.50327 0.80276 0.48162 Metetra
0.11905 setgray
0.80276 0.48162 0.81824 0.50327 0.85708 0.49162 0.84202 0.46965 Metetra
0.11905 setgray
0.84202 0.46965 0.85708 0.49162 0.8965 0.47979 0.88188 0.45749 Metetra
0.11905 setgray
0.35364 0.59379 0.37373 0.6125 0.40676 0.60242 0.38695 0.58345 Metetra
0.11905 setgray
0.38695 0.58345 0.40676 0.60242 0.44025 0.59221 0.42074 0.57297 Metetra
0.11905 setgray
0.42074 0.57297 0.44025 0.59221 0.47421 0.58185 0.45501 0.56233 Metetra
0.11905 setgray
0.45501 0.56233 0.47421 0.58185 0.50866 0.57134 0.48977 0.55155 Metetra
0.11905 setgray
0.48977 0.55155 0.50866 0.57134 0.54359 0.56069 0.52503 0.54061 Metetra
0.11905 setgray
0.52503 0.54061 0.54359 0.56069 0.57902 0.54988 0.5608 0.52951 Metetra
0.11905 setgray
0.5608 0.52951 0.57902 0.54988 0.61496 0.53891 0.5971 0.51825 Metetra
0.11905 setgray
0.5971 0.51825 0.61496 0.53891 0.65143 0.52779 0.63393 0.50682 Metetra
0.11905 setgray
0.63393 0.50682 0.65143 0.52779 0.68843 0.5165 0.67131 0.49522 Metetra
0.11905 setgray
0.67131 0.49522 0.68843 0.5165 0.72598 0.50505 0.70925 0.48345 Metetra
0.11905 setgray
0.70925 0.48345 0.72598 0.50505 0.76409 0.49342 0.74776 0.4715 Metetra
0.11905 setgray
0.74776 0.4715 0.76409 0.49342 0.80276 0.48162 0.78685 0.45937 Metetra
0.11905 setgray
0.78685 0.45937 0.80276 0.48162 0.84202 0.46965 0.82655 0.44705 Metetra
0.11905 setgray
0.82655 0.44705 0.84202 0.46965 0.88188 0.45749 0.86685 0.43455 Metetra
0.11905 setgray
0.33302 0.57459 0.35364 0.59379 0.38695 0.58345 0.36662 0.56398 Metetra
0.11905 setgray
0.36662 0.56398 0.38695 0.58345 0.42074 0.57297 0.40071 0.55322 Metetra
0.11905 setgray
0.40071 0.55322 0.42074 0.57297 0.45501 0.56233 0.43529 0.5423 Metetra
0.11905 setgray
0.43529 0.5423 0.45501 0.56233 0.48977 0.55155 0.47037 0.53123 Metetra
0.11905 setgray
0.47037 0.53123 0.48977 0.55155 0.52503 0.54061 0.50597 0.51999 Metetra
0.11905 setgray
0.50597 0.51999 0.52503 0.54061 0.5608 0.52951 0.54209 0.50859 Metetra
0.11905 setgray
0.54209 0.50859 0.5608 0.52951 0.5971 0.51825 0.57874 0.49702 Metetra
0.11905 setgray
0.57874 0.49702 0.5971 0.51825 0.63393 0.50682 0.61594 0.48527 Metetra
0.11905 setgray
0.61594 0.48527 0.63393 0.50682 0.67131 0.49522 0.65371 0.47335 Metetra
0.11905 setgray
0.65371 0.47335 0.67131 0.49522 0.70925 0.48345 0.69204 0.46125 Metetra
0.11905 setgray
0.69204 0.46125 0.70925 0.48345 0.74776 0.4715 0.73097 0.44896 Metetra
0.11905 setgray
0.73097 0.44896 0.74776 0.4715 0.78685 0.45937 0.77049 0.43648 Metetra
0.11905 setgray
0.77049 0.43648 0.78685 0.45937 0.82655 0.44705 0.81062 0.42381 Metetra
0.11905 setgray
0.81062 0.42381 0.82655 0.44705 0.86685 0.43455 0.85139 0.41095 Metetra
0.11905 setgray
0.31185 0.55488 0.33302 0.57459 0.36662 0.56398 0.34575 0.54399 Metetra
0.11905 setgray
0.34575 0.54399 0.36662 0.56398 0.40071 0.55322 0.38015 0.53294 Metetra
0.11905 setgray
0.38015 0.53294 0.40071 0.55322 0.43529 0.5423 0.41504 0.52173 Metetra
0.11905 setgray
0.41504 0.52173 0.43529 0.5423 0.47037 0.53123 0.45045 0.51035 Metetra
0.11905 setgray
0.45045 0.51035 0.47037 0.53123 0.50597 0.51999 0.48639 0.49881 Metetra
0.11905 setgray
0.48639 0.49881 0.50597 0.51999 0.54209 0.50859 0.52286 0.48709 Metetra
0.11905 setgray
0.52286 0.48709 0.54209 0.50859 0.57874 0.49702 0.55988 0.4752 Metetra
0.11905 setgray
0.55988 0.4752 0.57874 0.49702 0.61594 0.48527 0.59746 0.46312 Metetra
0.11905 setgray
0.59746 0.46312 0.61594 0.48527 0.65371 0.47335 0.63561 0.45086 Metetra
0.11905 setgray
0.63561 0.45086 0.65371 0.47335 0.69204 0.46125 0.67435 0.43842 Metetra
0.11905 setgray
0.67435 0.43842 0.69204 0.46125 0.73097 0.44896 0.71369 0.42578 Metetra
0.11905 setgray
0.71369 0.42578 0.73097 0.44896 0.77049 0.43648 0.75365 0.41294 Metetra
0.11905 setgray
0.75365 0.41294 0.77049 0.43648 0.81062 0.42381 0.79424 0.3999 Metetra
0.11905 setgray
0.79424 0.3999 0.81062 0.42381 0.85139 0.41095 0.83547 0.38665 Metetra
0.11905 setgray
0.29012 0.53465 0.31185 0.55488 0.34575 0.54399 0.32432 0.52347 Metetra
0.11905 setgray
0.32432 0.52347 0.34575 0.54399 0.38015 0.53294 0.35903 0.51211 Metetra
0.11905 setgray
0.35903 0.51211 0.38015 0.53294 0.41504 0.52173 0.39424 0.5006 Metetra
0.11905 setgray
0.39424 0.5006 0.41504 0.52173 0.45045 0.51035 0.42998 0.4889 Metetra
0.11905 setgray
0.42998 0.4889 0.45045 0.51035 0.48639 0.49881 0.46405 0.66743 Metetra
0.88095 setgray
0.46405 0.66743 0.48639 0.49881 0.52286 0.48709 0.50329 0.65612 Metetra
0.88095 setgray
0.50329 0.65612 0.52286 0.48709 0.55988 0.4752 0.54318 0.64463 Metetra
0.88095 setgray
0.54318 0.64463 0.55988 0.4752 0.59746 0.46312 0.58372 0.63295 Metetra
0.88095 setgray
0.58372 0.63295 0.59746 0.46312 0.63561 0.45086 0.62494 0.62108 Metetra
0.88095 setgray
0.62494 0.62108 0.63561 0.45086 0.67435 0.43842 0.65615 0.41493 Metetra
0.11905 setgray
0.65615 0.41493 0.67435 0.43842 0.71369 0.42578 0.69592 0.40192 Metetra
0.11905 setgray
0.69592 0.40192 0.71369 0.42578 0.75365 0.41294 0.73632 0.3887 Metetra
0.11905 setgray
0.73632 0.3887 0.75365 0.41294 0.79424 0.3999 0.77737 0.37528 Metetra
0.11905 setgray
0.77737 0.37528 0.79424 0.3999 0.83547 0.38665 0.81908 0.36163 Metetra
0.11905 setgray
0.26781 0.51387 0.29012 0.53465 0.32432 0.52347 0.30231 0.50238 Metetra
0.11905 setgray
0.30231 0.50238 0.32432 0.52347 0.35903 0.51211 0.33732 0.49071 Metetra
0.11905 setgray
0.33732 0.49071 0.35903 0.51211 0.39424 0.5006 0.37286 0.47888 Metetra
0.11905 setgray
0.37286 0.47888 0.39424 0.5006 0.42998 0.4889 0.40894 0.46686 Metetra
0.11905 setgray
0.40894 0.46686 0.42998 0.4889 0.46405 0.66743 0.44194 0.64641 Metetra
0.88095 setgray
0.44194 0.64641 0.46405 0.66743 0.50329 0.65612 0.4816 0.63476 Metetra
0.88095 setgray
0.4816 0.63476 0.50329 0.65612 0.54318 0.64463 0.52192 0.62292 Metetra
0.88095 setgray
0.52192 0.62292 0.54318 0.64463 0.58372 0.63295 0.56291 0.61088 Metetra
0.88095 setgray
0.56291 0.61088 0.58372 0.63295 0.62494 0.62108 0.60459 0.59864 Metetra
0.88095 setgray
0.60459 0.59864 0.62494 0.62108 0.65615 0.41493 0.63742 0.39075 Metetra
0.11905 setgray
0.63742 0.39075 0.65615 0.41493 0.69592 0.40192 0.67762 0.37736 Metetra
0.11905 setgray
0.67762 0.37736 0.69592 0.40192 0.73632 0.3887 0.71848 0.36375 Metetra
0.11905 setgray
0.71848 0.36375 0.73632 0.3887 0.77737 0.37528 0.76 0.34992 Metetra
0.11905 setgray
0.76 0.34992 0.77737 0.37528 0.81908 0.36163 0.80219 0.33586 Metetra
0.11905 setgray
0.24487 0.49252 0.26781 0.51387 0.30231 0.50238 0.27968 0.48071 Metetra
0.11905 setgray
0.27968 0.48071 0.30231 0.50238 0.33732 0.49071 0.31501 0.46872 Metetra
0.11905 setgray
0.31501 0.46872 0.33732 0.49071 0.37286 0.47888 0.35089 0.45654 Metetra
0.11905 setgray
0.35089 0.45654 0.37286 0.47888 0.40894 0.46686 0.38731 0.44419 Metetra
0.11905 setgray
0.38731 0.44419 0.40894 0.46686 0.44194 0.64641 0.41917 0.62475 Metetra
0.88095 setgray
0.41917 0.62475 0.44194 0.64641 0.4816 0.63476 0.45925 0.61274 Metetra
0.88095 setgray
0.45925 0.61274 0.4816 0.63476 0.52192 0.62292 0.5 0.60053 Metetra
0.88095 setgray
0.5 0.60053 0.52192 0.62292 0.56291 0.61088 0.54144 0.58811 Metetra
0.88095 setgray
0.54144 0.58811 0.56291 0.61088 0.60459 0.59864 0.58359 0.57548 Metetra
0.88095 setgray
0.58359 0.57548 0.60459 0.59864 0.63742 0.39075 0.61813 0.36585 Metetra
0.11905 setgray
0.61813 0.36585 0.63742 0.39075 0.67762 0.37736 0.65878 0.35206 Metetra
0.11905 setgray
0.65878 0.35206 0.67762 0.37736 0.71848 0.36375 0.7001 0.33804 Metetra
0.11905 setgray
0.7001 0.33804 0.71848 0.36375 0.76 0.34992 0.74209 0.32379 Metetra
0.11905 setgray
0.74209 0.32379 0.76 0.34992 0.80219 0.33586 0.78479 0.3093 Metetra
0.11905 setgray
0.2213 0.47057 0.24487 0.49252 0.27968 0.48071 0.25642 0.45843 Metetra
0.11905 setgray
0.25642 0.45843 0.27968 0.48071 0.31501 0.46872 0.29208 0.4461 Metetra
0.11905 setgray
0.29208 0.4461 0.31501 0.46872 0.35089 0.45654 0.32828 0.43358 Metetra
0.11905 setgray
0.32828 0.43358 0.35089 0.45654 0.38731 0.44419 0.36505 0.42086 Metetra
0.11905 setgray
0.36505 0.42086 0.38731 0.44419 0.41917 0.62475 0.39568 0.60242 Metetra
0.88095 setgray
0.39568 0.60242 0.41917 0.62475 0.45925 0.61274 0.43619 0.59004 Metetra
0.88095 setgray
0.43619 0.59004 0.45925 0.61274 0.5 0.60053 0.47739 0.57744 Metetra
0.88095 setgray
0.47739 0.57744 0.5 0.60053 0.54144 0.58811 0.5193 0.56463 Metetra
0.88095 setgray
0.5193 0.56463 0.54144 0.58811 0.58359 0.57548 0.56193 0.55159 Metetra
0.88095 setgray
0.56193 0.55159 0.58359 0.57548 0.61813 0.36585 0.59826 0.34021 Metetra
0.11905 setgray
0.59826 0.34021 0.61813 0.36585 0.65878 0.35206 0.63936 0.32599 Metetra
0.11905 setgray
0.63936 0.32599 0.65878 0.35206 0.7001 0.33804 0.68115 0.31154 Metetra
0.11905 setgray
0.68115 0.31154 0.7001 0.33804 0.74209 0.32379 0.72364 0.29685 Metetra
0.11905 setgray
0.72364 0.29685 0.74209 0.32379 0.78479 0.3093 0.76684 0.28191 Metetra
0.11905 setgray
0.19707 0.44801 0.2213 0.47057 0.25642 0.45843 0.2325 0.43552 Metetra
0.11905 setgray
0.2325 0.43552 0.25642 0.45843 0.29208 0.4461 0.26848 0.42283 Metetra
0.11905 setgray
0.26848 0.42283 0.29208 0.4461 0.32828 0.43358 0.30502 0.40995 Metetra
0.11905 setgray
0.30502 0.40995 0.32828 0.43358 0.36505 0.42086 0.34214 0.39686 Metetra
0.11905 setgray
0.34214 0.39686 0.36505 0.42086 0.39568 0.60242 0.37146 0.57939 Metetra
0.88095 setgray
0.37146 0.57939 0.39568 0.60242 0.43619 0.59004 0.41241 0.56661 Metetra
0.88095 setgray
0.41241 0.56661 0.43619 0.59004 0.47739 0.57744 0.45406 0.55361 Metetra
0.88095 setgray
0.45406 0.55361 0.47739 0.57744 0.5193 0.56463 0.49644 0.54039 Metetra
0.88095 setgray
0.49644 0.54039 0.5193 0.56463 0.56193 0.55159 0.53956 0.52692 Metetra
0.88095 setgray
0.53956 0.52692 0.56193 0.55159 0.59826 0.34021 0.57778 0.31378 Metetra
0.11905 setgray
0.57778 0.31378 0.59826 0.34021 0.63936 0.32599 0.61935 0.29913 Metetra
0.11905 setgray
0.61935 0.29913 0.63936 0.32599 0.68115 0.31154 0.66162 0.28422 Metetra
0.11905 setgray
0.66162 0.28422 0.68115 0.31154 0.72364 0.29685 0.70461 0.26907 Metetra
0.11905 setgray
0.70461 0.26907 0.72364 0.29685 0.76684 0.28191 0.74833 0.25365 Metetra
0.11905 setgray
0.17214 0.4248 0.19707 0.44801 0.2325 0.43552 0.20789 0.41194 Metetra
0.11905 setgray
0.20789 0.41194 0.2325 0.43552 0.26848 0.42283 0.24419 0.39889 Metetra
0.11905 setgray
0.24419 0.39889 0.26848 0.42283 0.30502 0.40995 0.28108 0.38562 Metetra
0.11905 setgray
0.28108 0.38562 0.30502 0.40995 0.34214 0.39686 0.31856 0.37215 Metetra
0.11905 setgray
0.31856 0.37215 0.34214 0.39686 0.37146 0.57939 0.35664 0.35845 Metetra
0.11905 setgray
0.35664 0.35845 0.37146 0.57939 0.41241 0.56661 0.39534 0.34454 Metetra
0.11905 setgray
0.39534 0.34454 0.41241 0.56661 0.45406 0.55361 0.43468 0.33039 Metetra
0.11905 setgray
0.43468 0.33039 0.45406 0.55361 0.49644 0.54039 0.47467 0.31601 Metetra
0.11905 setgray
0.47467 0.31601 0.49644 0.54039 0.53956 0.52692 0.51533 0.3014 Metetra
0.11905 setgray
0.51533 0.3014 0.53956 0.52692 0.57778 0.31378 0.55666 0.28653 Metetra
0.11905 setgray
0.55666 0.28653 0.57778 0.31378 0.61935 0.29913 0.59871 0.27141 Metetra
0.11905 setgray
0.59871 0.27141 0.61935 0.29913 0.66162 0.28422 0.64147 0.25604 Metetra
0.11905 setgray
0.64147 0.25604 0.66162 0.28422 0.70461 0.26907 0.68496 0.2404 Metetra
0.11905 setgray
0.68496 0.2404 0.70461 0.26907 0.74833 0.25365 0.72922 0.22449 Metetra
0.11905 setgray
0.14648 0.40091 0.17214 0.4248 0.20789 0.41194 0.18255 0.38768 Metetra
0.11905 setgray
0.18255 0.38768 0.20789 0.41194 0.24419 0.39889 0.21919 0.37423 Metetra
0.11905 setgray
0.21919 0.37423 0.24419 0.39889 0.28108 0.38562 0.25643 0.36058 Metetra
0.11905 setgray
0.25643 0.36058 0.28108 0.38562 0.31856 0.37215 0.29427 0.34669 Metetra
0.11905 setgray
0.29427 0.34669 0.31856 0.37215 0.35664 0.35845 0.33273 0.33258 Metetra
0.11905 setgray
0.33273 0.33258 0.35664 0.35845 0.39534 0.34454 0.37182 0.31824 Metetra
0.11905 setgray
0.37182 0.31824 0.39534 0.34454 0.43468 0.33039 0.41157 0.30366 Metetra
0.11905 setgray
0.41157 0.30366 0.43468 0.33039 0.47467 0.31601 0.45198 0.28883 Metetra
0.11905 setgray
0.45198 0.28883 0.47467 0.31601 0.51533 0.3014 0.49308 0.27376 Metetra
0.11905 setgray
0.49308 0.27376 0.51533 0.3014 0.55666 0.28653 0.53488 0.25842 Metetra
0.11905 setgray
0.53488 0.25842 0.55666 0.28653 0.59871 0.27141 0.57741 0.24282 Metetra
0.11905 setgray
0.57741 0.24282 0.59871 0.27141 0.64147 0.25604 0.62067 0.22695 Metetra
0.11905 setgray
0.62067 0.22695 0.64147 0.25604 0.68496 0.2404 0.66469 0.2108 Metetra
0.11905 setgray
0.66469 0.2108 0.68496 0.2404 0.72922 0.22449 0.70949 0.19437 Metetra
0.11905 setgray
0.12007 0.37632 0.14648 0.40091 0.18255 0.38768 0.15646 0.36269 Metetra
0.11905 setgray
0.15646 0.36269 0.18255 0.38768 0.21919 0.37423 0.19344 0.34884 Metetra
0.11905 setgray
0.19344 0.34884 0.21919 0.37423 0.25643 0.36058 0.23103 0.33477 Metetra
0.11905 setgray
0.23103 0.33477 0.25643 0.36058 0.29427 0.34669 0.26924 0.32046 Metetra
0.11905 setgray
0.26924 0.32046 0.29427 0.34669 0.33273 0.33258 0.30808 0.30592 Metetra
0.11905 setgray
0.30808 0.30592 0.33273 0.33258 0.37182 0.31824 0.34757 0.29113 Metetra
0.11905 setgray
0.34757 0.29113 0.37182 0.31824 0.41157 0.30366 0.38773 0.27609 Metetra
0.11905 setgray
0.38773 0.27609 0.41157 0.30366 0.45198 0.28883 0.42858 0.2608 Metetra
0.11905 setgray
0.42858 0.2608 0.45198 0.28883 0.49308 0.27376 0.47013 0.24524 Metetra
0.11905 setgray
0.47013 0.24524 0.49308 0.27376 0.53488 0.25842 0.51241 0.22941 Metetra
0.11905 setgray
0.51241 0.22941 0.53488 0.25842 0.57741 0.24282 0.55542 0.21331 Metetra
0.11905 setgray
0.55542 0.21331 0.57741 0.24282 0.62067 0.22695 0.59919 0.19691 Metetra
0.11905 setgray
0.59919 0.19691 0.62067 0.22695 0.66469 0.2108 0.64374 0.18023 Metetra
0.11905 setgray
0.64374 0.18023 0.66469 0.2108 0.70949 0.19437 0.6891 0.16325 Metetra
0.11905 setgray
0.09287 0.35099 0.12007 0.37632 0.15646 0.36269 0.12959 0.33695 Metetra
0.11905 setgray
0.12959 0.33695 0.15646 0.36269 0.19344 0.34884 0.16691 0.32268 Metetra
0.11905 setgray
0.16691 0.32268 0.19344 0.34884 0.23103 0.33477 0.20485 0.30817 Metetra
0.11905 setgray
0.20485 0.30817 0.23103 0.33477 0.26924 0.32046 0.24343 0.29342 Metetra
0.11905 setgray
0.24343 0.29342 0.26924 0.32046 0.30808 0.30592 0.28266 0.27842 Metetra
0.11905 setgray
0.28266 0.27842 0.30808 0.30592 0.34757 0.29113 0.32256 0.26317 Metetra
0.11905 setgray
0.32256 0.26317 0.34757 0.29113 0.38773 0.27609 0.36314 0.24765 Metetra
0.11905 setgray
0.36314 0.24765 0.38773 0.27609 0.42858 0.2608 0.40443 0.23186 Metetra
0.11905 setgray
0.40443 0.23186 0.42858 0.2608 0.47013 0.24524 0.44644 0.2158 Metetra
0.11905 setgray
0.44644 0.2158 0.47013 0.24524 0.51241 0.22941 0.48919 0.19946 Metetra
0.11905 setgray
0.48919 0.19946 0.51241 0.22941 0.55542 0.21331 0.53271 0.18282 Metetra
0.11905 setgray
0.53271 0.18282 0.55542 0.21331 0.59919 0.19691 0.577 0.16588 Metetra
0.11905 setgray
0.577 0.16588 0.59919 0.19691 0.64374 0.18023 0.6221 0.14864 Metetra
0.11905 setgray
0.6221 0.14864 0.64374 0.18023 0.6891 0.16325 0.66802 0.13108 Metetra
0.11905 setgray
0.06484 0.32489 0.09287 0.35099 0.12959 0.33695 0.10189 0.31042 Metetra
0.11905 setgray
0.10189 0.31042 0.12959 0.33695 0.16691 0.32268 0.13956 0.29571 Metetra
0.11905 setgray
0.13956 0.29571 0.16691 0.32268 0.20485 0.30817 0.17786 0.28075 Metetra
0.11905 setgray
0.17786 0.28075 0.20485 0.30817 0.24343 0.29342 0.21681 0.26553 Metetra
0.11905 setgray
0.21681 0.26553 0.24343 0.29342 0.28266 0.27842 0.25644 0.25006 Metetra
0.11905 setgray
0.25644 0.25006 0.28266 0.27842 0.32256 0.26317 0.29674 0.23431 Metetra
0.11905 setgray
0.29674 0.23431 0.32256 0.26317 0.36314 0.24765 0.33776 0.21829 Metetra
0.11905 setgray
0.33776 0.21829 0.36314 0.24765 0.40443 0.23186 0.37949 0.20199 Metetra
0.11905 setgray
0.37949 0.20199 0.40443 0.23186 0.44644 0.2158 0.42197 0.1854 Metetra
0.11905 setgray
0.42197 0.1854 0.44644 0.2158 0.48919 0.19946 0.46521 0.16851 Metetra
0.11905 setgray
0.46521 0.16851 0.48919 0.19946 0.53271 0.18282 0.50924 0.15131 Metetra
0.11905 setgray
0.50924 0.15131 0.53271 0.18282 0.577 0.16588 0.55406 0.1338 Metetra
0.11905 setgray
0.55406 0.1338 0.577 0.16588 0.6221 0.14864 0.59972 0.11597 Metetra
0.11905 setgray
0.59972 0.11597 0.6221 0.14864 0.66802 0.13108 0.64622 0.09781 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.11326 0.29577 moveto
0.1218 0.30407 lineto
stroke
0 setgray
[(-4)] 0.109 0.29162 1 0.971791 Mshowa
0.22107 0.25345 moveto
0.22925 0.2621 lineto
stroke
0 setgray
[(-2)] 0.21698 0.24912 0.945631 1 Mshowa
0.33416 0.20906 moveto
0.34194 0.21808 lineto
stroke
0 setgray
[(0)] 0.33027 0.20455 0.862234 1 Mshowa
0.45293 0.16246 moveto
0.46024 0.17185 lineto
stroke
0 setgray
[(2)] 0.44927 0.15776 0.778837 1 Mshowa
0.5778 0.11347 moveto
0.5846 0.12325 lineto
stroke
0 setgray
[(4)] 0.57441 0.10858 0.69544 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.68177 0.13719 moveto
0.67065 0.14142 lineto
stroke
0 setgray
[(-4)] 0.68734 0.13508 -1 0.380111 Mshowa
0.73828 0.22367 moveto
0.72708 0.22769 lineto
stroke
0 setgray
[(-2)] 0.74388 0.22166 -1 0.359096 Mshowa
0.78994 0.30274 moveto
0.77867 0.30657 lineto
stroke
0 setgray
[(0)] 0.79557 0.30082 -1 0.340282 Mshowa
0.83735 0.3753 moveto
0.82603 0.37897 lineto
stroke
0 setgray
[(2)] 0.84302 0.37347 -1 0.323342 Mshowa
0.88102 0.44214 moveto
0.86964 0.44565 lineto
stroke
0 setgray
[(4)] 0.88671 0.44039 -1 0.308008 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.05181 0.37417 moveto
0.06293 0.36993 lineto
stroke
0 setgray
[(0.25)] 0.04624 0.37629 1 -0.380668 Mshowa
0.04405 0.42293 moveto
0.05522 0.41879 lineto
stroke
0 setgray
[(0.5)] 0.03847 0.425 1 -0.370357 Mshowa
0.03602 0.47342 moveto
0.04722 0.46939 lineto
stroke
0 setgray
[(0.75)] 0.03042 0.47544 1 -0.359642 Mshowa
0.0277 0.52574 moveto
0.03894 0.52183 lineto
stroke
0 setgray
[(1)] 0.02208 0.5277 1 -0.348498 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = info; inactive; startGroup; Cclosed; ]
-- Frequency Response
:[font = input; startGroup; ]
len = 3
del = -1;
signal = Pulse[len,n1-del] Pulse[len,n2-del];
 MagPhasePlot[DTFTransform[signal, {n1, n2}, {w1,w2}],
		           {w1, -2 Pi, 2 Pi},{w2,-2 Pi, 2 Pi} ] 
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(Magnitude Response)] 0.5 1.00625 0 -1 Msboxa
[(-5)] 0.11011 0.29118 1 0.972624 Msboxa
[(0)] 0.33027 0.20455 0.862234 1 Msboxa
[(5)] 0.57305 0.10912 0.696321 1 Msboxa
[(w1)] 0.2914 0.15947 0.862234 1 Msboxa
[(-5)] 0.68796 0.13603 -1 0.379876 Msboxa
[(0)] 0.79557 0.30082 -1 0.340282 Msboxa
[(5)] 0.88627 0.43971 -1 0.308163 Msboxa
[(w2)] 0.85193 0.28164 -1 0.340282 Msboxa
[(0)] 0.05448 0.32465 1 -0.391559 Msboxa
[(0.5)] 0.04357 0.39301 1 -0.377133 Msboxa
[(1)] 0.03211 0.46486 1 -0.361892 Msboxa
[( )] -0.01735 0.44567 1 -0.370357 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 1.00625 0 -1 Mshowa
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.11438 0.29533 moveto
0.12291 0.30363 lineto
stroke
0 setgray
[(-5)] 0.11011 0.29118 1 0.972624 Mshowa
0.33416 0.20906 moveto
0.34194 0.21808 lineto
stroke
0 setgray
[(0)] 0.33027 0.20455 0.862234 1 Mshowa
0.57645 0.114 moveto
0.58325 0.12377 lineto
stroke
0 setgray
[(5)] 0.57305 0.10912 0.696321 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.6824 0.13815 moveto
0.67127 0.14237 lineto
stroke
0 setgray
[(-5)] 0.68796 0.13603 -1 0.379876 Mshowa
0.78994 0.30274 moveto
0.77867 0.30657 lineto
stroke
0 setgray
[(0)] 0.79557 0.30082 -1 0.340282 Mshowa
0.88058 0.44146 moveto
0.8692 0.44497 lineto
stroke
0 setgray
[(5)] 0.88627 0.43971 -1 0.308163 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06003 0.32248 moveto
0.07111 0.31814 lineto
stroke
0 setgray
[(0)] 0.05448 0.32465 1 -0.391559 Mshowa
0.04914 0.39091 moveto
0.06028 0.3867 lineto
stroke
0 setgray
[(0.5)] 0.04357 0.39301 1 -0.377133 Mshowa
0.03771 0.46284 moveto
0.0489 0.45879 lineto
stroke
0 setgray
[(1)] 0.03211 0.46486 1 -0.361892 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.59141 setgray
0.0015 setlinewidth
0.36916 0.72241 0.38861 0.76553 0.42408 0.70302 0.4047 0.66927 Metetra
0.40925 setgray
0.4047 0.66927 0.42408 0.70302 0.45905 0.62768 0.43999 0.60526 Metetra
0.17653 setgray
0.43999 0.60526 0.45905 0.62768 0.49287 0.62709 0.47404 0.60275 Metetra
0.21049 setgray
0.47404 0.60275 0.49287 0.62709 0.52729 0.61695 0.50872 0.59232 Metetra
0.21049 setgray
0.50872 0.59232 0.52729 0.61695 0.56201 0.59714 0.54378 0.57388 Metetra
0.17653 setgray
0.54378 0.57388 0.56201 0.59714 0.59947 0.65337 0.58083 0.61797 Metetra
0.40925 setgray
0.58083 0.61797 0.59947 0.65337 0.63746 0.67376 0.6186 0.63241 Metetra
0.51282 setgray
0.6186 0.63241 0.63746 0.67376 0.67325 0.63248 0.65495 0.59638 Metetra
0.40925 setgray
0.65495 0.59638 0.67325 0.63248 0.70629 0.55435 0.68929 0.52988 Metetra
0.17653 setgray
0.68929 0.52988 0.70629 0.55435 0.74447 0.55296 0.72763 0.52647 Metetra
0.21049 setgray
0.72763 0.52647 0.74447 0.55296 0.78255 0.54174 0.76603 0.51492 Metetra
0.21049 setgray
0.76603 0.51492 0.78255 0.54174 0.82013 0.52059 0.80417 0.49515 Metetra
0.17653 setgray
0.80417 0.49515 0.82013 0.52059 0.8676 0.57746 0.85029 0.53948 Metetra
0.40925 setgray
0.85029 0.53948 0.8676 0.57746 0.91105 0.5863 0.89339 0.54421 Metetra
0.22152 setgray
0.3525 0.61713 0.36916 0.72241 0.4047 0.66927 0.38646 0.59655 Metetra
0.17653 setgray
0.38646 0.59655 0.4047 0.66927 0.43999 0.60526 0.42074 0.57297 Metetra
0.11905 setgray
0.42074 0.57297 0.43999 0.60526 0.47404 0.60275 0.45498 0.56425 Metetra
0.12744 setgray
0.45498 0.56425 0.47404 0.60275 0.50872 0.59232 0.48976 0.55347 Metetra
0.12744 setgray
0.48976 0.55347 0.50872 0.59232 0.54378 0.57388 0.52503 0.54061 Metetra
0.11905 setgray
0.52503 0.54061 0.54378 0.57388 0.58083 0.61797 0.56108 0.54284 Metetra
0.17653 setgray
0.56108 0.54284 0.58083 0.61797 0.6186 0.63241 0.59774 0.53762 Metetra
0.2021 setgray
0.59774 0.53762 0.6186 0.63241 0.65495 0.59638 0.63454 0.52024 Metetra
0.17653 setgray
0.63454 0.52024 0.65495 0.59638 0.68929 0.52988 0.67131 0.49522 Metetra
0.11905 setgray
0.67131 0.49522 0.68929 0.52988 0.72763 0.52647 0.70939 0.48541 Metetra
0.12744 setgray
0.70939 0.48541 0.72763 0.52647 0.76603 0.51492 0.74793 0.47347 Metetra
0.12744 setgray
0.74793 0.47347 0.76603 0.51492 0.80417 0.49515 0.78685 0.45937 Metetra
0.11905 setgray
0.78685 0.45937 0.80417 0.49515 0.85029 0.53948 0.8281 0.46071 Metetra
0.17653 setgray
0.8281 0.46071 0.85029 0.53948 0.89339 0.54421 0.86912 0.45221 Metetra
0.27551 setgray
0.33101 0.61062 0.3525 0.61713 0.38646 0.59655 0.36568 0.58501 Metetra
0.21049 setgray
0.36568 0.58501 0.38646 0.59655 0.42074 0.57297 0.40065 0.55514 Metetra
0.12744 setgray
0.40065 0.55514 0.42074 0.57297 0.45498 0.56425 0.43519 0.54703 Metetra
0.13956 setgray
0.43519 0.54703 0.45498 0.56425 0.48976 0.55347 0.47033 0.53597 Metetra
0.13956 setgray
0.47033 0.53597 0.48976 0.55347 0.52503 0.54061 0.50597 0.52193 Metetra
0.12744 setgray
0.50597 0.52193 0.52503 0.54061 0.56108 0.54284 0.54239 0.52999 Metetra
0.21049 setgray
0.54239 0.52999 0.56108 0.54284 0.59774 0.53762 0.57956 0.52726 Metetra
0.24746 setgray
0.57956 0.52726 0.59774 0.53762 0.63454 0.52024 0.6168 0.50682 Metetra
0.21049 setgray
0.6168 0.50682 0.63454 0.52024 0.67131 0.49522 0.65381 0.47532 Metetra
0.12744 setgray
0.65381 0.47532 0.67131 0.49522 0.70939 0.48541 0.69237 0.46609 Metetra
0.13956 setgray
0.69237 0.46609 0.70939 0.48541 0.74793 0.47347 0.73136 0.45382 Metetra
0.13956 setgray
0.73136 0.45382 0.74793 0.47347 0.78685 0.45937 0.77068 0.43848 Metetra
0.12744 setgray
0.77068 0.43848 0.78685 0.45937 0.8281 0.46071 0.81302 0.44573 Metetra
0.21049 setgray
0.81302 0.44573 0.8281 0.46071 0.86912 0.45221 0.85484 0.43874 Metetra
0.27551 setgray
0.30956 0.59115 0.33101 0.61062 0.36568 0.58501 0.34465 0.56516 Metetra
0.21049 setgray
0.34465 0.56516 0.36568 0.58501 0.40065 0.55514 0.38007 0.53488 Metetra
0.12744 setgray
0.38007 0.53488 0.40065 0.55514 0.43519 0.54703 0.41491 0.52648 Metetra
0.13956 setgray
0.41491 0.52648 0.43519 0.54703 0.47033 0.53597 0.45037 0.51512 Metetra
0.13956 setgray
0.45037 0.51512 0.47033 0.53597 0.50597 0.52193 0.48638 0.50076 Metetra
0.12744 setgray
0.48638 0.50076 0.50597 0.52193 0.54239 0.52999 0.52303 0.50863 Metetra
0.21049 setgray
0.52303 0.50863 0.54239 0.52999 0.57956 0.52726 0.56051 0.50564 Metetra
0.24746 setgray
0.56051 0.50564 0.57956 0.52726 0.6168 0.50682 0.59819 0.48481 Metetra
0.21049 setgray
0.59819 0.48481 0.6168 0.50682 0.65381 0.47532 0.6357 0.45285 Metetra
0.12744 setgray
0.6357 0.45285 0.65381 0.47532 0.69237 0.46609 0.67465 0.44329 Metetra
0.13956 setgray
0.67465 0.44329 0.69237 0.46609 0.73136 0.45382 0.71406 0.43066 Metetra
0.13956 setgray
0.71406 0.43066 0.73136 0.45382 0.77068 0.43848 0.75383 0.41494 Metetra
0.12744 setgray
0.75383 0.41494 0.77068 0.43848 0.81302 0.44573 0.79654 0.42195 Metetra
0.21049 setgray
0.79654 0.42195 0.81302 0.44573 0.85484 0.43874 0.83881 0.41461 Metetra
0.22152 setgray
0.28843 0.55846 0.30956 0.59115 0.34465 0.56516 0.32353 0.53682 Metetra
0.17653 setgray
0.32353 0.53682 0.34465 0.56516 0.38007 0.53488 0.35903 0.51211 Metetra
0.11905 setgray
0.35903 0.51211 0.38007 0.53488 0.41491 0.52648 0.39417 0.50255 Metetra
0.12744 setgray
0.39417 0.50255 0.41491 0.52648 0.45037 0.51512 0.42994 0.49087 Metetra
0.12744 setgray
0.42994 0.49087 0.45037 0.51512 0.48638 0.50076 0.46626 0.47704 Metetra
0.11905 setgray
0.46626 0.47704 0.48638 0.50076 0.52303 0.50863 0.5031 0.47858 Metetra
0.17653 setgray
0.5031 0.47858 0.52303 0.50863 0.56051 0.50564 0.54076 0.4725 Metetra
0.2021 setgray
0.54076 0.4725 0.56051 0.50564 0.59819 0.48481 0.57882 0.45402 Metetra
0.17653 setgray
0.57882 0.45402 0.59819 0.48481 0.6357 0.45285 0.617 0.42773 Metetra
0.11905 setgray
0.617 0.42773 0.6357 0.45285 0.67465 0.44329 0.65626 0.41693 Metetra
0.12744 setgray
0.65626 0.41693 0.67465 0.44329 0.71406 0.43066 0.69606 0.40393 Metetra
0.12744 setgray
0.69606 0.40393 0.71406 0.43066 0.75383 0.41494 0.73632 0.3887 Metetra
0.11905 setgray
0.73632 0.3887 0.75383 0.41494 0.79654 0.42195 0.77875 0.38918 Metetra
0.17653 setgray
0.77875 0.38918 0.79654 0.42195 0.83881 0.41461 0.82114 0.37962 Metetra
0.59141 setgray
0.2588 0.62769 0.28843 0.55846 0.32353 0.53682 0.29763 0.57153 Metetra
0.40925 setgray
0.29763 0.57153 0.32353 0.53682 0.35903 0.51211 0.33657 0.5042 Metetra
0.17653 setgray
0.33657 0.5042 0.35903 0.51211 0.39417 0.50255 0.37192 0.50047 Metetra
0.21049 setgray
0.37192 0.50047 0.39417 0.50255 0.42994 0.49087 0.40826 0.48852 Metetra
0.21049 setgray
0.40826 0.48852 0.42994 0.49087 0.46626 0.47704 0.44531 0.46828 Metetra
0.17653 setgray
0.44531 0.46828 0.46626 0.47704 0.5031 0.47858 0.48234 0.51266 Metetra
0.40925 setgray
0.48234 0.51266 0.5031 0.47858 0.54076 0.4725 0.52123 0.52639 Metetra
0.51282 setgray
0.52123 0.52639 0.54076 0.4725 0.57882 0.45402 0.56036 0.48779 Metetra
0.40925 setgray
0.56036 0.48779 0.57882 0.45402 0.617 0.42773 0.59832 0.41774 Metetra
0.17653 setgray
0.59832 0.41774 0.617 0.42773 0.65626 0.41693 0.6385 0.41285 Metetra
0.21049 setgray
0.6385 0.41285 0.65626 0.41693 0.69606 0.40393 0.67903 0.39953 Metetra
0.21049 setgray
0.67903 0.39953 0.69606 0.40393 0.73632 0.3887 0.71957 0.37769 Metetra
0.17653 setgray
0.71957 0.37769 0.73632 0.3887 0.77875 0.38918 0.76676 0.422 Metetra
0.40925 setgray
0.76676 0.422 0.77875 0.38918 0.82114 0.37962 0.81201 0.4254 Metetra
0.75603 setgray
0.23115 0.64922 0.2588 0.62769 0.29763 0.57153 0.27245 0.57597 Metetra
0.51282 setgray
0.27245 0.57597 0.29763 0.57153 0.33657 0.5042 0.31376 0.48837 Metetra
0.2021 setgray
0.31376 0.48837 0.33657 0.5042 0.37192 0.50047 0.3493 0.48715 Metetra
0.24746 setgray
0.3493 0.48715 0.37192 0.50047 0.40826 0.48852 0.3861 0.47489 Metetra
0.24746 setgray
0.3861 0.47489 0.40826 0.48852 0.44531 0.46828 0.42376 0.45149 Metetra
0.2021 setgray
0.42376 0.45149 0.44531 0.46828 0.48234 0.51266 0.46055 0.51588 Metetra
0.51282 setgray
0.46055 0.51588 0.48234 0.51266 0.52123 0.52639 0.5 0.53906 Metetra
0.6511 setgray
0.5 0.53906 0.52123 0.52639 0.56036 0.48779 0.5401 0.49046 Metetra
0.51282 setgray
0.5401 0.49046 0.56036 0.48779 0.59832 0.41774 0.57869 0.39955 Metetra
0.2021 setgray
0.57869 0.39955 0.59832 0.41774 0.6385 0.41285 0.61946 0.39718 Metetra
0.24746 setgray
0.61946 0.39718 0.6385 0.41285 0.67903 0.39953 0.66058 0.38349 Metetra
0.24746 setgray
0.66058 0.38349 0.67903 0.39953 0.71957 0.37769 0.70157 0.35835 Metetra
0.2021 setgray
0.70157 0.35835 0.71957 0.37769 0.76676 0.422 0.75086 0.42313 Metetra
0.51282 setgray
0.75086 0.42313 0.76676 0.422 0.81201 0.4254 0.79765 0.43259 Metetra
0.59141 setgray
0.21018 0.58597 0.23115 0.64922 0.27245 0.57597 0.25049 0.52849 Metetra
0.40925 setgray
0.25049 0.52849 0.27245 0.57597 0.31376 0.48837 0.29109 0.45976 Metetra
0.17653 setgray
0.29109 0.45976 0.31376 0.48837 0.3493 0.48715 0.32697 0.45544 Metetra
0.21049 setgray
0.32697 0.45544 0.3493 0.48715 0.3861 0.47489 0.36401 0.4428 Metetra
0.21049 setgray
0.36401 0.4428 0.3861 0.47489 0.42376 0.45149 0.40192 0.42174 Metetra
0.17653 setgray
0.40192 0.42174 0.42376 0.45149 0.46055 0.51588 0.43882 0.46612 Metetra
0.40925 setgray
0.43882 0.46612 0.46055 0.51588 0.5 0.53906 0.47813 0.47946 Metetra
0.51282 setgray
0.47813 0.47946 0.5 0.53906 0.5401 0.49046 0.51849 0.43973 Metetra
0.40925 setgray
0.51849 0.43973 0.5401 0.49046 0.57869 0.39955 0.55811 0.36817 Metetra
0.17653 setgray
0.55811 0.36817 0.57869 0.39955 0.61946 0.39718 0.59905 0.36258 Metetra
0.21049 setgray
0.59905 0.36258 0.61946 0.39718 0.66058 0.38349 0.6405 0.34843 Metetra
0.21049 setgray
0.6405 0.34843 0.66058 0.38349 0.70157 0.35835 0.68209 0.32564 Metetra
0.17653 setgray
0.68209 0.32564 0.70157 0.35835 0.75086 0.42313 0.72964 0.3698 Metetra
0.40925 setgray
0.72964 0.3698 0.75086 0.42313 0.79765 0.43259 0.77579 0.37252 Metetra
0.22152 setgray
0.19449 0.47244 0.21018 0.58597 0.25049 0.52849 0.23122 0.44921 Metetra
0.17653 setgray
0.23122 0.44921 0.25049 0.52849 0.29109 0.45976 0.26848 0.42283 Metetra
0.11905 setgray
0.26848 0.42283 0.29109 0.45976 0.32697 0.45544 0.30488 0.41195 Metetra
0.12744 setgray
0.30488 0.41195 0.32697 0.45544 0.36401 0.4428 0.34203 0.39887 Metetra
0.12744 setgray
0.34203 0.39887 0.36401 0.4428 0.40192 0.42174 0.37985 0.38356 Metetra
0.11905 setgray
0.37985 0.38356 0.40192 0.42174 0.43882 0.46612 0.41776 0.38398 Metetra
0.17653 setgray
0.41776 0.38398 0.43882 0.46612 0.47813 0.47946 0.45679 0.37655 Metetra
0.2021 setgray
0.45679 0.37655 0.47813 0.47946 0.51849 0.43973 0.49666 0.35639 Metetra
0.17653 setgray
0.49666 0.35639 0.51849 0.43973 0.55811 0.36817 0.53689 0.3282 Metetra
0.11905 setgray
0.53689 0.3282 0.55811 0.36817 0.59905 0.36258 0.57784 0.31583 Metetra
0.12744 setgray
0.57784 0.31583 0.59905 0.36258 0.6405 0.34843 0.61944 0.30118 Metetra
0.12744 setgray
0.61944 0.30118 0.6405 0.34843 0.68209 0.32564 0.66162 0.28422 Metetra
0.11905 setgray
0.66162 0.28422 0.68209 0.32564 0.72964 0.3698 0.70569 0.28329 Metetra
0.17653 setgray
0.70569 0.28329 0.72964 0.3698 0.77579 0.37252 0.75004 0.27204 Metetra
0.27551 setgray
0.1678 0.4625 0.19449 0.47244 0.23122 0.44921 0.20562 0.43393 Metetra
0.21049 setgray
0.20562 0.43393 0.23122 0.44921 0.26848 0.42283 0.24401 0.4009 Metetra
0.12744 setgray
0.24401 0.4009 0.26848 0.42283 0.30488 0.41195 0.2807 0.39056 Metetra
0.13956 setgray
0.2807 0.39056 0.30488 0.41195 0.34203 0.39887 0.31824 0.3771 Metetra
0.13956 setgray
0.31824 0.3771 0.34203 0.39887 0.37985 0.38356 0.35654 0.36048 Metetra
0.12744 setgray
0.35654 0.36048 0.37985 0.38356 0.41776 0.38398 0.3945 0.36688 Metetra
0.21049 setgray
0.3945 0.36688 0.41776 0.38398 0.45679 0.37655 0.43393 0.36197 Metetra
0.24746 setgray
0.43393 0.36197 0.45679 0.37655 0.49666 0.35639 0.47446 0.3385 Metetra
0.21049 setgray
0.47446 0.3385 0.49666 0.35639 0.53689 0.3282 0.51534 0.30345 Metetra
0.12744 setgray
0.51534 0.30345 0.53689 0.3282 0.57784 0.31583 0.55677 0.29157 Metetra
0.13956 setgray
0.55677 0.29157 0.57784 0.31583 0.61944 0.30118 0.59889 0.27647 Metetra
0.13956 setgray
0.59889 0.27647 0.61944 0.30118 0.66162 0.28422 0.64158 0.25811 Metetra
0.12744 setgray
0.64158 0.25811 0.66162 0.28422 0.70569 0.28329 0.68655 0.26321 Metetra
0.21049 setgray
0.68655 0.26321 0.70569 0.28329 0.75004 0.27204 0.73173 0.2534 Metetra
0.27551 setgray
0.14173 0.43884 0.1678 0.4625 0.20562 0.43393 0.18005 0.4098 Metetra
0.21049 setgray
0.18005 0.4098 0.20562 0.43393 0.24401 0.4009 0.21899 0.37626 Metetra
0.12744 setgray
0.21899 0.37626 0.24401 0.4009 0.2807 0.39056 0.25599 0.36554 Metetra
0.13956 setgray
0.25599 0.36554 0.2807 0.39056 0.31824 0.3771 0.2939 0.35167 Metetra
0.13956 setgray
0.2939 0.35167 0.31824 0.3771 0.35654 0.36048 0.3326 0.33462 Metetra
0.12744 setgray
0.3326 0.33462 0.35654 0.36048 0.3945 0.36688 0.37077 0.34072 Metetra
0.21049 setgray
0.37077 0.34072 0.3945 0.36688 0.43393 0.36197 0.41054 0.33542 Metetra
0.24746 setgray
0.41054 0.33542 0.43393 0.36197 0.47446 0.3385 0.45158 0.31144 Metetra
0.21049 setgray
0.45158 0.31144 0.47446 0.3385 0.51534 0.30345 0.49308 0.27582 Metetra
0.12744 setgray
0.49308 0.27582 0.51534 0.30345 0.55677 0.29157 0.53495 0.26349 Metetra
0.13956 setgray
0.53495 0.26349 0.55677 0.29157 0.59889 0.27647 0.57755 0.2479 Metetra
0.13956 setgray
0.57755 0.2479 0.59889 0.27647 0.64158 0.25811 0.62076 0.22903 Metetra
0.12744 setgray
0.62076 0.22903 0.64158 0.25811 0.68655 0.26321 0.66612 0.23373 Metetra
0.21049 setgray
0.66612 0.23373 0.68655 0.26321 0.73173 0.2534 0.71182 0.22343 Metetra
0.22152 setgray
0.11669 0.4012 0.14173 0.43884 0.18005 0.4098 0.15474 0.37664 Metetra
0.17653 setgray
0.15474 0.37664 0.18005 0.4098 0.21899 0.37626 0.19344 0.34884 Metetra
0.11905 setgray
0.19344 0.34884 0.21899 0.37626 0.25599 0.36554 0.23083 0.33681 Metetra
0.12744 setgray
0.23083 0.33681 0.25599 0.36554 0.2939 0.35167 0.26906 0.32251 Metetra
0.12744 setgray
0.26906 0.32251 0.2939 0.35167 0.3326 0.33462 0.30808 0.30592 Metetra
0.11905 setgray
0.30808 0.30592 0.3326 0.33462 0.37077 0.34072 0.34678 0.30529 Metetra
0.17653 setgray
0.34678 0.30529 0.37077 0.34072 0.41054 0.33542 0.38688 0.29666 Metetra
0.2021 setgray
0.38688 0.29666 0.41054 0.33542 0.45158 0.31144 0.4282 0.27504 Metetra
0.17653 setgray
0.4282 0.27504 0.45158 0.31144 0.49308 0.27582 0.47013 0.24524 Metetra
0.11905 setgray
0.47013 0.24524 0.49308 0.27582 0.53495 0.26349 0.51241 0.23149 Metetra
0.12744 setgray
0.51241 0.23149 0.53495 0.26349 0.57755 0.2479 0.55546 0.21539 Metetra
0.12744 setgray
0.55546 0.21539 0.57755 0.2479 0.62076 0.22903 0.59919 0.19691 Metetra
0.11905 setgray
0.59919 0.19691 0.62076 0.22903 0.66612 0.23373 0.64454 0.19467 Metetra
0.17653 setgray
0.64454 0.19467 0.66612 0.23373 0.71182 0.22343 0.69046 0.18191 Metetra
0.59141 setgray
0.07536 0.47024 0.11669 0.4012 0.15474 0.37664 0.11988 0.40926 Metetra
0.40925 setgray
0.11988 0.40926 0.15474 0.37664 0.19344 0.34884 0.1652 0.33675 Metetra
0.17653 setgray
0.1652 0.33675 0.19344 0.34884 0.23083 0.33681 0.20242 0.33069 Metetra
0.21049 setgray
0.20242 0.33069 0.23083 0.33681 0.26906 0.32251 0.24129 0.31601 Metetra
0.21049 setgray
0.24129 0.31601 0.26906 0.32251 0.30808 0.30592 0.28152 0.29262 Metetra
0.17653 setgray
0.28152 0.29262 0.30808 0.30592 0.34678 0.30529 0.3177 0.33662 Metetra
0.40925 setgray
0.3177 0.33662 0.34678 0.30529 0.38688 0.29666 0.35797 0.34861 Metetra
0.51282 setgray
0.35797 0.34861 0.38688 0.29666 0.4282 0.27504 0.40177 0.30575 Metetra
0.40925 setgray
0.40177 0.30575 0.4282 0.27504 0.47013 0.24524 0.44615 0.23015 Metetra
0.17653 setgray
0.44615 0.23015 0.47013 0.24524 0.51241 0.23149 0.4891 0.22243 Metetra
0.21049 setgray
0.4891 0.22243 0.51241 0.23149 0.55546 0.21539 0.533 0.20585 Metetra
0.21049 setgray
0.533 0.20585 0.55546 0.21539 0.59919 0.19691 0.57743 0.18035 Metetra
0.17653 setgray
0.57743 0.18035 0.59919 0.19691 0.64454 0.19467 0.62566 0.22355 Metetra
0.40925 setgray
0.62566 0.22355 0.64454 0.19467 0.69046 0.18191 0.67415 0.22412 Metetra
0.88095 setgray
0.03332 0.52378 0.07536 0.47024 0.11988 0.40926 0.08434 0.43083 Metetra
0.59141 setgray
0.08434 0.43083 0.11988 0.40926 0.1652 0.33675 0.1362 0.32103 Metetra
0.22152 setgray
0.1362 0.32103 0.1652 0.33675 0.20242 0.33069 0.17321 0.31972 Metetra
0.27551 setgray
0.17321 0.31972 0.20242 0.33069 0.24129 0.31601 0.21269 0.30462 Metetra
0.27551 setgray
0.21269 0.30462 0.24129 0.31601 0.28152 0.29262 0.25411 0.2756 Metetra
0.22152 setgray
0.25411 0.2756 0.28152 0.29262 0.3177 0.33662 0.28738 0.35667 Metetra
0.59141 setgray
0.28738 0.35667 0.3177 0.33662 0.35797 0.34861 0.32742 0.38652 Metetra
0.75603 setgray
0.32742 0.38652 0.35797 0.34861 0.40177 0.30575 0.37384 0.32508 Metetra
0.59141 setgray
0.37384 0.32508 0.40177 0.30575 0.44615 0.23015 0.4212 0.21122 Metetra
0.22152 setgray
0.4212 0.21122 0.44615 0.23015 0.4891 0.22243 0.46468 0.20825 Metetra
0.27551 setgray
0.46468 0.20825 0.4891 0.22243 0.533 0.20585 0.50938 0.19115 Metetra
0.27551 setgray
0.50938 0.19115 0.533 0.20585 0.57743 0.18035 0.55461 0.15982 Metetra
0.22152 setgray
0.55461 0.15982 0.57743 0.18035 0.62566 0.22355 0.60462 0.24079 Metetra
0.59141 setgray
0.60462 0.24079 0.62566 0.22355 0.67415 0.22412 0.65522 0.25284 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.11438 0.29533 moveto
0.12291 0.30363 lineto
stroke
0 setgray
[(-5)] 0.11011 0.29118 1 0.972624 Mshowa
0.33416 0.20906 moveto
0.34194 0.21808 lineto
stroke
0 setgray
[(0)] 0.33027 0.20455 0.862234 1 Mshowa
0.57645 0.114 moveto
0.58325 0.12377 lineto
stroke
0 setgray
[(5)] 0.57305 0.10912 0.696321 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.6824 0.13815 moveto
0.67127 0.14237 lineto
stroke
0 setgray
[(-5)] 0.68796 0.13603 -1 0.379876 Mshowa
0.78994 0.30274 moveto
0.77867 0.30657 lineto
stroke
0 setgray
[(0)] 0.79557 0.30082 -1 0.340282 Mshowa
0.88058 0.44146 moveto
0.8692 0.44497 lineto
stroke
0 setgray
[(5)] 0.88627 0.43971 -1 0.308163 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06003 0.32248 moveto
0.07111 0.31814 lineto
stroke
0 setgray
[(0)] 0.05448 0.32465 1 -0.391559 Mshowa
0.04914 0.39091 moveto
0.06028 0.3867 lineto
stroke
0 setgray
[(0.5)] 0.04357 0.39301 1 -0.377133 Mshowa
0.03771 0.46284 moveto
0.0489 0.45879 lineto
stroke
0 setgray
[(1)] 0.03211 0.46486 1 -0.361892 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.02381 0.95238 0.02381 0.95238 [
[(Phase Response \(degrees\))] 0.5 1.00625 0 -1 Msboxa
[(-5)] 0.11011 0.29118 1 0.972624 Msboxa
[(0)] 0.33027 0.20455 0.862234 1 Msboxa
[(5)] 0.57305 0.10912 0.696321 1 Msboxa
[(w1)] 0.2914 0.15947 0.862234 1 Msboxa
[(-5)] 0.68796 0.13603 -1 0.379876 Msboxa
[(0)] 0.79557 0.30082 -1 0.340282 Msboxa
[(5)] 0.88627 0.43971 -1 0.308163 Msboxa
[(w2)] 0.85193 0.28164 -1 0.340282 Msboxa
[(0)] 0.05375 0.32922 1 -0.390596 Msboxa
[(50)] 0.04539 0.38162 1 -0.379542 Msboxa
[(100)] 0.03671 0.43605 1 -0.368012 Msboxa
[(150)] 0.02767 0.49265 1 -0.355977 Msboxa
[( )] -0.01735 0.44567 1 -0.370357 Msboxa
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: SurfaceGraphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 1.00625 0 -1 Mshowa
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.11438 0.29533 moveto
0.12291 0.30363 lineto
stroke
0 setgray
[(-5)] 0.11011 0.29118 1 0.972624 Mshowa
0.33416 0.20906 moveto
0.34194 0.21808 lineto
stroke
0 setgray
[(0)] 0.33027 0.20455 0.862234 1 Mshowa
0.57645 0.114 moveto
0.58325 0.12377 lineto
stroke
0 setgray
[(5)] 0.57305 0.10912 0.696321 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.6824 0.13815 moveto
0.67127 0.14237 lineto
stroke
0 setgray
[(-5)] 0.68796 0.13603 -1 0.379876 Mshowa
0.78994 0.30274 moveto
0.77867 0.30657 lineto
stroke
0 setgray
[(0)] 0.79557 0.30082 -1 0.340282 Mshowa
0.88058 0.44146 moveto
0.8692 0.44497 lineto
stroke
0 setgray
[(5)] 0.88627 0.43971 -1 0.308163 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.05096 0.3795 moveto
0.06209 0.37528 lineto
stroke
0 setgray
[(50)] 0.04539 0.38162 1 -0.379542 Mshowa
0.04229 0.434 moveto
0.05346 0.42989 lineto
stroke
0 setgray
[(100)] 0.03671 0.43605 1 -0.368012 Mshowa
0.03328 0.49065 moveto
0.0445 0.48666 lineto
stroke
0 setgray
[(150)] 0.02767 0.49265 1 -0.355977 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
0.002 setlinewidth
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.03248 0.52913 lineto
stroke
0.38687 0.8155 moveto
0.39347 0.6265 lineto
stroke
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.39347 0.6265 moveto
0.38687 0.8155 lineto
stroke
0.39347 0.6265 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.06558 0.32026 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.39347 0.6265 lineto
stroke
0.89589 0.47534 moveto
0.64594 0.09301 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
grestore
0.11905 setgray
0.0015 setlinewidth
0.37373 0.6125 0.39332 0.63074 0.42607 0.62092 0.40676 0.60242 Metetra
0.11905 setgray
0.40676 0.60242 0.42607 0.62092 0.45927 0.61096 0.44025 0.59221 Metetra
0.11905 setgray
0.44025 0.59221 0.45927 0.61096 0.4925 0.78301 0.47264 0.76534 Metetra
0.88095 setgray
0.47264 0.76534 0.4925 0.78301 0.5287 0.7735 0.50919 0.75556 Metetra
0.88095 setgray
0.50919 0.75556 0.5287 0.7735 0.56167 0.58024 0.54359 0.56069 Metetra
0.11905 setgray
0.54359 0.56069 0.56167 0.58024 0.59676 0.56971 0.57902 0.54988 Metetra
0.11905 setgray
0.57902 0.54988 0.59676 0.56971 0.63236 0.55903 0.61496 0.53891 Metetra
0.11905 setgray
0.61496 0.53891 0.63236 0.55903 0.66847 0.5482 0.65143 0.52779 Metetra
0.11905 setgray
0.65143 0.52779 0.66847 0.5482 0.7051 0.53721 0.68843 0.5165 Metetra
0.11905 setgray
0.68843 0.5165 0.7051 0.53721 0.75766 0.71333 0.74055 0.69368 Metetra
0.88095 setgray
0.74055 0.69368 0.75766 0.71333 0.7979 0.70275 0.78125 0.68279 Metetra
0.88095 setgray
0.78125 0.68279 0.7979 0.70275 0.81824 0.50327 0.80276 0.48162 Metetra
0.11905 setgray
0.80276 0.48162 0.81824 0.50327 0.85708 0.49162 0.84202 0.46965 Metetra
0.11905 setgray
0.84202 0.46965 0.85708 0.49162 0.8965 0.47979 0.88188 0.45749 Metetra
0.11905 setgray
0.35364 0.59379 0.37373 0.6125 0.40676 0.60242 0.38695 0.58345 Metetra
0.11905 setgray
0.38695 0.58345 0.40676 0.60242 0.44025 0.59221 0.42074 0.57297 Metetra
0.11905 setgray
0.42074 0.57297 0.44025 0.59221 0.47264 0.76534 0.45222 0.74717 Metetra
0.88095 setgray
0.45222 0.74717 0.47264 0.76534 0.50919 0.75556 0.48913 0.73712 Metetra
0.88095 setgray
0.48913 0.73712 0.50919 0.75556 0.54359 0.56069 0.52503 0.54061 Metetra
0.11905 setgray
0.52503 0.54061 0.54359 0.56069 0.57902 0.54988 0.5608 0.52951 Metetra
0.11905 setgray
0.5608 0.52951 0.57902 0.54988 0.61496 0.53891 0.5971 0.51825 Metetra
0.11905 setgray
0.5971 0.51825 0.61496 0.53891 0.65143 0.52779 0.63393 0.50682 Metetra
0.11905 setgray
0.63393 0.50682 0.65143 0.52779 0.68843 0.5165 0.67131 0.49522 Metetra
0.11905 setgray
0.67131 0.49522 0.68843 0.5165 0.74055 0.69368 0.72293 0.67344 Metetra
0.88095 setgray
0.72293 0.67344 0.74055 0.69368 0.78125 0.68279 0.76409 0.66223 Metetra
0.88095 setgray
0.76409 0.66223 0.78125 0.68279 0.80276 0.48162 0.78685 0.45937 Metetra
0.11905 setgray
0.78685 0.45937 0.80276 0.48162 0.84202 0.46965 0.82655 0.44705 Metetra
0.11905 setgray
0.82655 0.44705 0.84202 0.46965 0.88188 0.45749 0.86685 0.43455 Metetra
0.88095 setgray
0.32276 0.75859 0.35364 0.59379 0.38695 0.58345 0.35837 0.74871 Metetra
0.88095 setgray
0.35837 0.74871 0.38695 0.58345 0.42074 0.57297 0.39452 0.73868 Metetra
0.88095 setgray
0.39452 0.73868 0.42074 0.57297 0.45222 0.74717 0.43529 0.5423 Metetra
0.11905 setgray
0.43529 0.5423 0.45222 0.74717 0.48913 0.73712 0.47037 0.53123 Metetra
0.11905 setgray
0.47037 0.53123 0.48913 0.73712 0.52503 0.54061 0.50635 0.70766 Metetra
0.88095 setgray
0.50635 0.70766 0.52503 0.54061 0.5608 0.52951 0.54479 0.69699 Metetra
0.88095 setgray
0.54479 0.69699 0.5608 0.52951 0.5971 0.51825 0.58385 0.68616 Metetra
0.88095 setgray
0.58385 0.68616 0.5971 0.51825 0.63393 0.50682 0.62352 0.67515 Metetra
0.88095 setgray
0.62352 0.67515 0.63393 0.50682 0.67131 0.49522 0.66383 0.66397 Metetra
0.88095 setgray
0.66383 0.66397 0.67131 0.49522 0.72293 0.67344 0.69204 0.46125 Metetra
0.11905 setgray
0.69204 0.46125 0.72293 0.67344 0.76409 0.66223 0.73097 0.44896 Metetra
0.11905 setgray
0.73097 0.44896 0.76409 0.66223 0.78685 0.45937 0.78874 0.62932 Metetra
0.88095 setgray
0.78874 0.62932 0.78685 0.45937 0.82655 0.44705 0.83176 0.61739 Metetra
0.88095 setgray
0.83176 0.61739 0.82655 0.44705 0.86685 0.43455 0.8755 0.60525 Metetra
0.88095 setgray
0.30013 0.74023 0.32276 0.75859 0.35837 0.74871 0.33607 0.73007 Metetra
0.88095 setgray
0.33607 0.73007 0.35837 0.74871 0.39452 0.73868 0.37257 0.71976 Metetra
0.88095 setgray
0.37257 0.71976 0.39452 0.73868 0.43529 0.5423 0.41504 0.52173 Metetra
0.11905 setgray
0.41504 0.52173 0.43529 0.5423 0.47037 0.53123 0.45045 0.51035 Metetra
0.11905 setgray
0.45045 0.51035 0.47037 0.53123 0.50635 0.70766 0.48551 0.68784 Metetra
0.88095 setgray
0.48551 0.68784 0.50635 0.70766 0.54479 0.69699 0.52435 0.67686 Metetra
0.88095 setgray
0.52435 0.67686 0.54479 0.69699 0.58385 0.68616 0.56382 0.6657 Metetra
0.88095 setgray
0.56382 0.6657 0.58385 0.68616 0.62352 0.67515 0.60392 0.65437 Metetra
0.88095 setgray
0.60392 0.65437 0.62352 0.67515 0.66383 0.66397 0.64468 0.64285 Metetra
0.88095 setgray
0.64468 0.64285 0.66383 0.66397 0.69204 0.46125 0.67435 0.43842 Metetra
0.11905 setgray
0.67435 0.43842 0.69204 0.46125 0.73097 0.44896 0.71369 0.42578 Metetra
0.11905 setgray
0.71369 0.42578 0.73097 0.44896 0.78874 0.62932 0.77103 0.60713 Metetra
0.88095 setgray
0.77103 0.60713 0.78874 0.62932 0.83176 0.61739 0.81457 0.59483 Metetra
0.88095 setgray
0.81457 0.59483 0.83176 0.61739 0.8755 0.60525 0.85885 0.58231 Metetra
0.11905 setgray
0.29012 0.53465 0.30013 0.74023 0.33607 0.73007 0.32432 0.52347 Metetra
0.11905 setgray
0.32432 0.52347 0.33607 0.73007 0.37257 0.71976 0.35903 0.51211 Metetra
0.11905 setgray
0.35903 0.51211 0.37257 0.71976 0.41504 0.52173 0.3874 0.68951 Metetra
0.88095 setgray
0.3874 0.68951 0.41504 0.52173 0.45045 0.51035 0.42542 0.67856 Metetra
0.88095 setgray
0.42542 0.67856 0.45045 0.51035 0.48551 0.68784 0.46626 0.47704 Metetra
0.11905 setgray
0.46626 0.47704 0.48551 0.68784 0.52435 0.67686 0.50309 0.46499 Metetra
0.11905 setgray
0.50309 0.46499 0.52435 0.67686 0.56382 0.6657 0.54048 0.45276 Metetra
0.11905 setgray
0.54048 0.45276 0.56382 0.6657 0.60392 0.65437 0.57844 0.44034 Metetra
0.11905 setgray
0.57844 0.44034 0.60392 0.65437 0.64468 0.64285 0.617 0.42773 Metetra
0.11905 setgray
0.617 0.42773 0.64468 0.64285 0.67435 0.43842 0.66684 0.60901 Metetra
0.88095 setgray
0.66684 0.60901 0.67435 0.43842 0.71369 0.42578 0.70944 0.59673 Metetra
0.88095 setgray
0.70944 0.59673 0.71369 0.42578 0.77103 0.60713 0.73632 0.3887 Metetra
0.11905 setgray
0.73632 0.3887 0.77103 0.60713 0.81457 0.59483 0.77737 0.37528 Metetra
0.11905 setgray
0.77737 0.37528 0.81457 0.59483 0.85885 0.58231 0.81908 0.36163 Metetra
0.11905 setgray
0.26781 0.51387 0.29012 0.53465 0.32432 0.52347 0.30231 0.50238 Metetra
0.11905 setgray
0.30231 0.50238 0.32432 0.52347 0.35903 0.51211 0.33732 0.49071 Metetra
0.11905 setgray
0.33732 0.49071 0.35903 0.51211 0.3874 0.68951 0.36452 0.66915 Metetra
0.88095 setgray
0.36452 0.66915 0.3874 0.68951 0.42542 0.67856 0.40292 0.65787 Metetra
0.88095 setgray
0.40292 0.65787 0.42542 0.67856 0.46626 0.47704 0.44557 0.45466 Metetra
0.11905 setgray
0.44557 0.45466 0.46626 0.47704 0.50309 0.46499 0.48276 0.44227 Metetra
0.11905 setgray
0.48276 0.44227 0.50309 0.46499 0.54048 0.45276 0.52053 0.42969 Metetra
0.11905 setgray
0.52053 0.42969 0.54048 0.45276 0.57844 0.44034 0.55888 0.41691 Metetra
0.11905 setgray
0.55888 0.41691 0.57844 0.44034 0.617 0.42773 0.59784 0.40393 Metetra
0.11905 setgray
0.59784 0.40393 0.617 0.42773 0.66684 0.60901 0.64697 0.58619 Metetra
0.88095 setgray
0.64697 0.58619 0.66684 0.60901 0.70944 0.59673 0.69008 0.57352 Metetra
0.88095 setgray
0.69008 0.57352 0.70944 0.59673 0.73632 0.3887 0.71848 0.36375 Metetra
0.11905 setgray
0.71848 0.36375 0.73632 0.3887 0.77737 0.37528 0.76 0.34992 Metetra
0.11905 setgray
0.76 0.34992 0.77737 0.37528 0.81908 0.36163 0.80219 0.33586 Metetra
0.11905 setgray
0.24487 0.49252 0.26781 0.51387 0.30231 0.50238 0.27968 0.48071 Metetra
0.11905 setgray
0.27968 0.48071 0.30231 0.50238 0.33732 0.49071 0.31501 0.46872 Metetra
0.11905 setgray
0.31501 0.46872 0.33732 0.49071 0.36452 0.66915 0.34096 0.64819 Metetra
0.88095 setgray
0.34096 0.64819 0.36452 0.66915 0.40292 0.65787 0.37974 0.63657 Metetra
0.88095 setgray
0.37974 0.63657 0.40292 0.65787 0.44557 0.45466 0.42429 0.43163 Metetra
0.11905 setgray
0.42429 0.43163 0.44557 0.45466 0.48276 0.44227 0.46185 0.41889 Metetra
0.11905 setgray
0.46185 0.41889 0.48276 0.44227 0.52053 0.42969 0.5 0.40594 Metetra
0.11905 setgray
0.5 0.40594 0.52053 0.42969 0.55888 0.41691 0.53875 0.39279 Metetra
0.11905 setgray
0.53875 0.39279 0.55888 0.41691 0.59784 0.40393 0.57812 0.37943 Metetra
0.11905 setgray
0.57812 0.37943 0.59784 0.40393 0.64697 0.58619 0.62647 0.56264 Metetra
0.88095 setgray
0.62647 0.56264 0.64697 0.58619 0.69008 0.57352 0.67009 0.54957 Metetra
0.88095 setgray
0.67009 0.54957 0.69008 0.57352 0.71848 0.36375 0.7001 0.33804 Metetra
0.11905 setgray
0.7001 0.33804 0.71848 0.36375 0.76 0.34992 0.74209 0.32379 Metetra
0.11905 setgray
0.74209 0.32379 0.76 0.34992 0.80219 0.33586 0.78479 0.3093 Metetra
0.11905 setgray
0.2213 0.47057 0.24487 0.49252 0.27968 0.48071 0.25642 0.45843 Metetra
0.11905 setgray
0.25642 0.45843 0.27968 0.48071 0.31501 0.46872 0.29208 0.4461 Metetra
0.11905 setgray
0.29208 0.4461 0.31501 0.46872 0.34096 0.64819 0.31667 0.62658 Metetra
0.88095 setgray
0.31667 0.62658 0.34096 0.64819 0.37974 0.63657 0.35585 0.6146 Metetra
0.88095 setgray
0.35585 0.6146 0.37974 0.63657 0.42429 0.43163 0.40239 0.40795 Metetra
0.11905 setgray
0.40239 0.40795 0.42429 0.43163 0.46185 0.41889 0.44033 0.39483 Metetra
0.11905 setgray
0.44033 0.39483 0.46185 0.41889 0.5 0.40594 0.47887 0.3815 Metetra
0.11905 setgray
0.47887 0.3815 0.5 0.40594 0.53875 0.39279 0.51803 0.36796 Metetra
0.11905 setgray
0.51803 0.36796 0.53875 0.39279 0.57812 0.37943 0.55782 0.3542 Metetra
0.11905 setgray
0.55782 0.3542 0.57812 0.37943 0.62647 0.56264 0.60531 0.53833 Metetra
0.88095 setgray
0.60531 0.53833 0.62647 0.56264 0.67009 0.54957 0.64945 0.52483 Metetra
0.88095 setgray
0.64945 0.52483 0.67009 0.54957 0.7001 0.33804 0.68115 0.31154 Metetra
0.11905 setgray
0.68115 0.31154 0.7001 0.33804 0.74209 0.32379 0.72364 0.29685 Metetra
0.11905 setgray
0.72364 0.29685 0.74209 0.32379 0.78479 0.3093 0.76684 0.28191 Metetra
0.11905 setgray
0.19707 0.44801 0.2213 0.47057 0.25642 0.45843 0.2325 0.43552 Metetra
0.11905 setgray
0.2325 0.43552 0.25642 0.45843 0.29208 0.4461 0.26848 0.42283 Metetra
0.11905 setgray
0.26848 0.42283 0.29208 0.4461 0.31667 0.62658 0.29164 0.60431 Metetra
0.88095 setgray
0.29164 0.60431 0.31667 0.62658 0.35585 0.6146 0.33121 0.59196 Metetra
0.88095 setgray
0.33121 0.59196 0.35585 0.6146 0.40239 0.40795 0.37985 0.38356 Metetra
0.11905 setgray
0.37985 0.38356 0.40239 0.40795 0.44033 0.39483 0.41817 0.37006 Metetra
0.11905 setgray
0.41817 0.37006 0.44033 0.39483 0.47887 0.3815 0.4571 0.35633 Metetra
0.11905 setgray
0.4571 0.35633 0.47887 0.3815 0.51803 0.36796 0.49667 0.34238 Metetra
0.11905 setgray
0.49667 0.34238 0.51803 0.36796 0.55782 0.3542 0.53689 0.3282 Metetra
0.11905 setgray
0.53689 0.3282 0.55782 0.3542 0.60531 0.53833 0.58345 0.51322 Metetra
0.88095 setgray
0.58345 0.51322 0.60531 0.53833 0.64945 0.52483 0.62813 0.49928 Metetra
0.88095 setgray
0.62813 0.49928 0.64945 0.52483 0.68115 0.31154 0.66162 0.28422 Metetra
0.11905 setgray
0.66162 0.28422 0.68115 0.31154 0.72364 0.29685 0.70461 0.26907 Metetra
0.11905 setgray
0.70461 0.26907 0.72364 0.29685 0.76684 0.28191 0.74833 0.25365 Metetra
0.88095 setgray
0.14984 0.61831 0.19707 0.44801 0.2325 0.43552 0.18786 0.60619 Metetra
0.88095 setgray
0.18786 0.60619 0.2325 0.43552 0.26848 0.42283 0.22651 0.59387 Metetra
0.88095 setgray
0.22651 0.59387 0.26848 0.42283 0.29164 0.60431 0.28108 0.38562 Metetra
0.11905 setgray
0.28108 0.38562 0.29164 0.60431 0.33121 0.59196 0.31856 0.37215 Metetra
0.11905 setgray
0.31856 0.37215 0.33121 0.59196 0.37985 0.38356 0.34647 0.55563 Metetra
0.88095 setgray
0.34647 0.55563 0.37985 0.38356 0.41817 0.37006 0.38785 0.54244 Metetra
0.88095 setgray
0.38785 0.54244 0.41817 0.37006 0.4571 0.35633 0.42997 0.52901 Metetra
0.88095 setgray
0.42997 0.52901 0.4571 0.35633 0.49667 0.34238 0.47282 0.51535 Metetra
0.88095 setgray
0.47282 0.51535 0.49667 0.34238 0.53689 0.3282 0.51645 0.50144 Metetra
0.88095 setgray
0.51645 0.50144 0.53689 0.3282 0.58345 0.51322 0.55666 0.28653 Metetra
0.11905 setgray
0.55666 0.28653 0.58345 0.51322 0.62813 0.49928 0.59871 0.27141 Metetra
0.11905 setgray
0.59871 0.27141 0.62813 0.49928 0.66162 0.28422 0.65215 0.45818 Metetra
0.88095 setgray
0.65215 0.45818 0.66162 0.28422 0.70461 0.26907 0.69906 0.44323 Metetra
0.88095 setgray
0.69906 0.44323 0.70461 0.26907 0.74833 0.25365 0.74685 0.42799 Metetra
0.88095 setgray
0.12207 0.59578 0.14984 0.61831 0.18786 0.60619 0.16044 0.58328 Metetra
0.88095 setgray
0.16044 0.58328 0.18786 0.60619 0.22651 0.59387 0.19947 0.57057 Metetra
0.88095 setgray
0.19947 0.57057 0.22651 0.59387 0.28108 0.38562 0.25643 0.36058 Metetra
0.11905 setgray
0.25643 0.36058 0.28108 0.38562 0.31856 0.37215 0.29427 0.34669 Metetra
0.11905 setgray
0.29427 0.34669 0.31856 0.37215 0.34647 0.55563 0.32067 0.53109 Metetra
0.88095 setgray
0.32067 0.53109 0.34647 0.55563 0.38785 0.54244 0.3625 0.51747 Metetra
0.88095 setgray
0.3625 0.51747 0.38785 0.54244 0.42997 0.52901 0.40508 0.5036 Metetra
0.88095 setgray
0.40508 0.5036 0.42997 0.52901 0.47282 0.51535 0.44843 0.48948 Metetra
0.88095 setgray
0.44843 0.48948 0.47282 0.51535 0.51645 0.50144 0.49257 0.4751 Metetra
0.88095 setgray
0.49257 0.4751 0.51645 0.50144 0.55666 0.28653 0.53488 0.25842 Metetra
0.11905 setgray
0.53488 0.25842 0.55666 0.28653 0.59871 0.27141 0.57741 0.24282 Metetra
0.11905 setgray
0.57741 0.24282 0.59871 0.27141 0.65215 0.45818 0.62994 0.43035 Metetra
0.88095 setgray
0.62994 0.43035 0.65215 0.45818 0.69906 0.44323 0.67746 0.41487 Metetra
0.88095 setgray
0.67746 0.41487 0.69906 0.44323 0.74685 0.42799 0.72589 0.3991 Metetra
0.11905 setgray
0.12007 0.37632 0.12207 0.59578 0.16044 0.58328 0.15646 0.36269 Metetra
0.11905 setgray
0.15646 0.36269 0.16044 0.58328 0.19947 0.57057 0.19344 0.34884 Metetra
0.11905 setgray
0.19344 0.34884 0.19947 0.57057 0.25643 0.36058 0.21167 0.53317 Metetra
0.88095 setgray
0.21167 0.53317 0.25643 0.36058 0.29427 0.34669 0.25248 0.51958 Metetra
0.88095 setgray
0.25248 0.51958 0.29427 0.34669 0.32067 0.53109 0.30808 0.30592 Metetra
0.11905 setgray
0.30808 0.30592 0.32067 0.53109 0.3625 0.51747 0.34757 0.29113 Metetra
0.11905 setgray
0.34757 0.29113 0.3625 0.51747 0.40508 0.5036 0.38773 0.27609 Metetra
0.11905 setgray
0.38773 0.27609 0.40508 0.5036 0.44843 0.48948 0.42858 0.2608 Metetra
0.11905 setgray
0.42858 0.2608 0.44843 0.48948 0.49257 0.4751 0.47013 0.24524 Metetra
0.11905 setgray
0.47013 0.24524 0.49257 0.4751 0.53488 0.25842 0.51336 0.43271 Metetra
0.88095 setgray
0.51336 0.43271 0.53488 0.25842 0.57741 0.24282 0.55971 0.41727 Metetra
0.88095 setgray
0.55971 0.41727 0.57741 0.24282 0.62994 0.43035 0.59919 0.19691 Metetra
0.11905 setgray
0.59919 0.19691 0.62994 0.43035 0.67746 0.41487 0.64374 0.18023 Metetra
0.11905 setgray
0.64374 0.18023 0.67746 0.41487 0.72589 0.3991 0.6891 0.16325 Metetra
0.11905 setgray
0.09287 0.35099 0.12007 0.37632 0.15646 0.36269 0.12959 0.33695 Metetra
0.11905 setgray
0.12959 0.33695 0.15646 0.36269 0.19344 0.34884 0.16691 0.32268 Metetra
0.11905 setgray
0.16691 0.32268 0.19344 0.34884 0.21167 0.53317 0.18325 0.50789 Metetra
0.88095 setgray
0.18325 0.50789 0.21167 0.53317 0.25248 0.51958 0.22449 0.49385 Metetra
0.88095 setgray
0.22449 0.49385 0.25248 0.51958 0.30808 0.30592 0.28266 0.27842 Metetra
0.11905 setgray
0.28266 0.27842 0.30808 0.30592 0.34757 0.29113 0.32256 0.26317 Metetra
0.11905 setgray
0.32256 0.26317 0.34757 0.29113 0.38773 0.27609 0.36314 0.24765 Metetra
0.11905 setgray
0.36314 0.24765 0.38773 0.27609 0.42858 0.2608 0.40443 0.23186 Metetra
0.11905 setgray
0.40443 0.23186 0.42858 0.2608 0.47013 0.24524 0.44644 0.2158 Metetra
0.11905 setgray
0.44644 0.2158 0.47013 0.24524 0.51336 0.43271 0.48835 0.40399 Metetra
0.88095 setgray
0.48835 0.40399 0.51336 0.43271 0.55971 0.41727 0.53528 0.388 Metetra
0.88095 setgray
0.53528 0.388 0.55971 0.41727 0.59919 0.19691 0.577 0.16588 Metetra
0.11905 setgray
0.577 0.16588 0.59919 0.19691 0.64374 0.18023 0.6221 0.14864 Metetra
0.11905 setgray
0.6221 0.14864 0.64374 0.18023 0.6891 0.16325 0.66802 0.13108 Metetra
0.11905 setgray
0.06484 0.32489 0.09287 0.35099 0.12959 0.33695 0.10189 0.31042 Metetra
0.11905 setgray
0.10189 0.31042 0.12959 0.33695 0.16691 0.32268 0.13956 0.29571 Metetra
0.11905 setgray
0.13956 0.29571 0.16691 0.32268 0.18325 0.50789 0.15389 0.48177 Metetra
0.88095 setgray
0.15389 0.48177 0.18325 0.50789 0.22449 0.49385 0.19555 0.46725 Metetra
0.88095 setgray
0.19555 0.46725 0.22449 0.49385 0.28266 0.27842 0.25644 0.25006 Metetra
0.11905 setgray
0.25644 0.25006 0.28266 0.27842 0.32256 0.26317 0.29674 0.23431 Metetra
0.11905 setgray
0.29674 0.23431 0.32256 0.26317 0.36314 0.24765 0.33776 0.21829 Metetra
0.11905 setgray
0.33776 0.21829 0.36314 0.24765 0.40443 0.23186 0.37949 0.20199 Metetra
0.11905 setgray
0.37949 0.20199 0.40443 0.23186 0.44644 0.2158 0.42197 0.1854 Metetra
0.11905 setgray
0.42197 0.1854 0.44644 0.2158 0.48835 0.40399 0.46245 0.37423 Metetra
0.88095 setgray
0.46245 0.37423 0.48835 0.40399 0.53528 0.388 0.50998 0.35767 Metetra
0.88095 setgray
0.50998 0.35767 0.53528 0.388 0.577 0.16588 0.55406 0.1338 Metetra
0.11905 setgray
0.55406 0.1338 0.577 0.16588 0.6221 0.14864 0.59972 0.11597 Metetra
0.11905 setgray
0.59972 0.11597 0.6221 0.14864 0.66802 0.13108 0.64622 0.09781 Metetra
0 setgray
0.002 setlinewidth
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.64594 0.09301 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
0.92319 0.67509 moveto
0.89589 0.47534 lineto
stroke
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.64594 0.09301 lineto
stroke
0.65863 0.31163 moveto
0.03248 0.52913 lineto
stroke
0.03248 0.52913 moveto
0.65863 0.31163 lineto
stroke
0.03248 0.52913 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.38687 0.8155 lineto
stroke
0.92319 0.67509 moveto
0.65863 0.31163 lineto
stroke
gsave
0.06558 0.32026 moveto
0.64594 0.09301 lineto
stroke
0.11438 0.29533 moveto
0.12291 0.30363 lineto
stroke
0 setgray
[(-5)] 0.11011 0.29118 1 0.972624 Mshowa
0.33416 0.20906 moveto
0.34194 0.21808 lineto
stroke
0 setgray
[(0)] 0.33027 0.20455 0.862234 1 Mshowa
0.57645 0.114 moveto
0.58325 0.12377 lineto
stroke
0 setgray
[(5)] 0.57305 0.10912 0.696321 1 Mshowa
0 setgray
[(w1)] 0.2914 0.15947 0.862234 1 Mshowa
grestore
gsave
0.64594 0.09301 moveto
0.89589 0.47534 lineto
stroke
0.6824 0.13815 moveto
0.67127 0.14237 lineto
stroke
0 setgray
[(-5)] 0.68796 0.13603 -1 0.379876 Mshowa
0.78994 0.30274 moveto
0.77867 0.30657 lineto
stroke
0 setgray
[(0)] 0.79557 0.30082 -1 0.340282 Mshowa
0.88058 0.44146 moveto
0.8692 0.44497 lineto
stroke
0 setgray
[(5)] 0.88627 0.43971 -1 0.308163 Mshowa
0 setgray
[(w2)] 0.85193 0.28164 -1 0.340282 Mshowa
grestore
gsave
0.06558 0.32026 moveto
0.03248 0.52913 lineto
stroke
0.0593 0.32706 moveto
0.07039 0.32273 lineto
stroke
0 setgray
[(0)] 0.05375 0.32922 1 -0.390596 Mshowa
0.05096 0.3795 moveto
0.06209 0.37528 lineto
stroke
0 setgray
[(50)] 0.04539 0.38162 1 -0.379542 Mshowa
0.04229 0.434 moveto
0.05346 0.42989 lineto
stroke
0 setgray
[(100)] 0.03671 0.43605 1 -0.368012 Mshowa
0.03328 0.49065 moveto
0.0445 0.48666 lineto
stroke
0 setgray
[(150)] 0.02767 0.49265 1 -0.355977 Mshowa
0 setgray
[( )] -0.01735 0.44567 1 -0.370357 Mshowa
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; ]
{SurfaceGraphics[{{1.417233560090702948, 0.8916585729037567714, 
     0.2202214809870520593, 0.3182292602400151803, 
     0.3182292602400151803, 0.2202214809870520593, 
     0.8916585729037567714, 1.190476190476190476, 
     0.891658572903756771, 0.2202214809870520593, 
     0.3182292602400151785, 0.3182292602400151803, 
     0.2202214809870520593, 0.8916585729037567718, 
     1.084656084656084656}, 
    {0.8916585729037567714, 0.5609908155024783695, 
     0.1385532893019407843, 0.2002153039783153621, 
     0.2002153039783153621, 0.1385532893019407843, 
     0.5609908155024783695, 0.748993201239155688, 
     0.5609908155024783694, 0.1385532893019407843, 
     0.200215303978315361, 0.2002153039783153621, 
     0.1385532893019407843, 0.5609908155024783698, 
     0.6824160277956751824}, 
    {0.2202214809870520593, 0.1385532893019407843, 
     0.03421983648554490313, 0.04944909643473653423, 
     0.04944909643473653423, 0.03421983648554490313, 
     0.1385532893019407843, 0.1849860440291237298, 
     0.1385532893019407842, 0.03421983648554490313, 
     0.04944909643473653395, 0.04944909643473653422, 
     0.03421983648554490313, 0.1385532893019407843, 
     0.1685428401154238427}, 
    {0.3182292602400151803, 0.2002153039783153621, 
     0.04944909643473653423, 0.07145601467864339546, 
     0.07145601467864339546, 0.04944909643473653423, 
     0.2002153039783153621, 0.2673125786016127515, 
     0.200215303978315362, 0.04944909643473653423, 
     0.07145601467864339507, 0.07145601467864339546, 
     0.04944909643473653423, 0.2002153039783153622, 
     0.243551460503691618}, 
    {0.3182292602400151803, 0.2002153039783153621, 
     0.04944909643473653423, 0.07145601467864339546, 
     0.07145601467864339546, 0.04944909643473653423, 
     0.2002153039783153621, 0.2673125786016127515, 
     0.200215303978315362, 0.04944909643473653423, 
     0.07145601467864339507, 0.07145601467864339546, 
     0.04944909643473653423, 0.2002153039783153622, 
     0.243551460503691618}, 
    {0.2202214809870520593, 0.1385532893019407843, 
     0.03421983648554490313, 0.04944909643473653423, 
     0.04944909643473653423, 0.03421983648554490313, 
     0.1385532893019407843, 0.1849860440291237298, 
     0.1385532893019407842, 0.03421983648554490313, 
     0.04944909643473653395, 0.04944909643473653422, 
     0.03421983648554490313, 0.1385532893019407843, 
     0.1685428401154238427}, 
    {0.8916585729037567714, 0.5609908155024783695, 
     0.1385532893019407843, 0.2002153039783153621, 
     0.2002153039783153621, 0.1385532893019407843, 
     0.5609908155024783695, 0.748993201239155688, 
     0.5609908155024783694, 0.1385532893019407843, 
     0.200215303978315361, 0.2002153039783153621, 
     0.1385532893019407843, 0.5609908155024783698, 
     0.6824160277956751824}, 
    {1.190476190476190476, 0.748993201239155688, 
     0.1849860440291237298, 0.2673125786016127515, 
     0.2673125786016127515, 0.1849860440291237298, 
     0.748993201239155688, 1., 0.7489932012391556876, 
     0.1849860440291237298, 0.26731257860161275, 
     0.2673125786016127515, 0.1849860440291237298, 
     0.7489932012391556882, 0.9111111111111111112}, 
    {0.891658572903756771, 0.5609908155024783694, 
     0.1385532893019407842, 0.200215303978315362, 
     0.200215303978315362, 0.1385532893019407842, 
     0.5609908155024783694, 0.7489932012391556876, 
     0.5609908155024783691, 0.1385532893019407842, 
     0.2002153039783153609, 0.200215303978315362, 
     0.1385532893019407842, 0.5609908155024783695, 
     0.6824160277956751821}, 
    {0.2202214809870520593, 0.1385532893019407843, 
     0.03421983648554490313, 0.04944909643473653423, 
     0.04944909643473653423, 0.03421983648554490313, 
     0.1385532893019407843, 0.1849860440291237298, 
     0.1385532893019407842, 0.03421983648554490313, 
     0.04944909643473653395, 0.04944909643473653423, 
     0.03421983648554490313, 0.1385532893019407843, 
     0.1685428401154238428}, 
    {0.3182292602400151785, 0.200215303978315361, 
     0.04944909643473653395, 0.07145601467864339507, 
     0.07145601467864339507, 0.04944909643473653395, 
     0.200215303978315361, 0.26731257860161275, 
     0.2002153039783153609, 0.04944909643473653395, 
     0.07145601467864339468, 0.07145601467864339506, 
     0.04944909643473653395, 0.2002153039783153611, 
     0.2435514605036916167}, 
    {0.3182292602400151803, 0.2002153039783153621, 
     0.04944909643473653422, 0.07145601467864339546, 
     0.07145601467864339546, 0.04944909643473653422, 
     0.2002153039783153621, 0.2673125786016127515, 
     0.200215303978315362, 0.04944909643473653423, 
     0.07145601467864339506, 0.07145601467864339546, 
     0.04944909643473653423, 0.2002153039783153622, 
     0.243551460503691618}, 
    {0.2202214809870520593, 0.1385532893019407843, 
     0.03421983648554490313, 0.04944909643473653423, 
     0.04944909643473653423, 0.03421983648554490313, 
     0.1385532893019407843, 0.1849860440291237298, 
     0.1385532893019407842, 0.03421983648554490313, 
     0.04944909643473653395, 0.04944909643473653423, 
     0.03421983648554490313, 0.1385532893019407843, 
     0.1685428401154238428}, 
    {0.8916585729037567718, 0.5609908155024783698, 
     0.1385532893019407843, 0.2002153039783153622, 
     0.2002153039783153622, 0.1385532893019407843, 
     0.5609908155024783698, 0.7489932012391556882, 
     0.5609908155024783695, 0.1385532893019407843, 
     0.2002153039783153611, 0.2002153039783153622, 
     0.1385532893019407843, 0.56099081550247837, 
     0.6824160277956751827}, 
    {1.084656084656084656, 0.6824160277956751824, 
     0.1685428401154238427, 0.243551460503691618, 
     0.243551460503691618, 0.1685428401154238427, 
     0.6824160277956751824, 0.9111111111111111112, 
     0.6824160277956751821, 0.1685428401154238428, 
     0.2435514605036916167, 0.243551460503691618, 
     0.1685428401154238428, 0.6824160277956751827, 
     0.830123456790123457}}, 
   {PlotRange -> All, DisplayFunction -> 
     (Display[$Display, #1] & ), PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> "Magnitude Response", 
    AxesLabel -> {"w1", "w2", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> Automatic, Background -> Automatic, 
    DefaultColor -> Automatic, AspectRatio -> 1, 
    ViewPoint -> {1.3, -2.4, 2.}, Boxed -> True, 
    BoxRatios -> {1, 1, 0.4}, Plot3Matrix -> Automatic, 
    Lighting -> False, AmbientLight -> GrayLevel[0], 
    LightSources -> 
     {{{1., 0., 1.}, RGBColor[1, 0, 0]}, 
      {{1., 1., 1.}, RGBColor[0, 1, 0]}, 
      {{0., 1., 1.}, RGBColor[0, 0, 1]}}, Shading -> True, 
    HiddenSurface -> True, Mesh -> True, ClipFill -> Automatic, 
    AxesEdge -> Automatic, MeshStyle -> Automatic, 
    MeshRange -> 
     {{-6.283185307179586476, 6.283185307179586476}, 
      {-6.283185307179586476, 6.283185307179586476}}}], 
  SurfaceGraphics[{{0., 0., 0., 180.0000000000000001, 
     180.0000000000000001, 0., 0., 0., 0., 0., 
     180.0000000000000001, 180.0000000000000001, 0., 0., 0.}, 
    {0., 0., 0., 180.0000000000000001, 180.0000000000000001, 0., 
     0., 0., 0., 0., 180.0000000000000001, 180.0000000000000001, 
     0., 0., 0.}, {0., 0., 0., 180.0000000000000001, 
     180.0000000000000001, 0., 0., 0., 0., 0., 
     180.0000000000000001, 180.0000000000000001, 0., 0., 0.}, 
    {180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 0., 0., 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 0., 0., 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001}, 
    {180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 0., 0., 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 0., 0., 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001}, 
    {0., 0., 0., 180.0000000000000001, 180.0000000000000001, 0., 
     0., 0., 0., 0., 180.0000000000000001, 180.0000000000000001, 
     0., 0., 0.}, {0., 0., 0., 180.0000000000000001, 
     180.0000000000000001, 0., 0., 0., 0., 0., 
     180.0000000000000001, 180.0000000000000001, 0., 0., 0.}, 
    {0., 0., 0., 180.0000000000000001, 180.0000000000000001, 0., 
     0., 0., 0., 0., 180.0000000000000001, 180.0000000000000001, 
     0., 0., 0.}, {0., 0., 0., 180.0000000000000001, 
     180.0000000000000001, 0., 0., 0., 0., 0., 
     180.0000000000000001, 180.0000000000000001, 0., 0., 0.}, 
    {0., 0., 0., 180.0000000000000001, 180.0000000000000001, 0., 
     0., 0., 0., 0., 180.0000000000000001, 180.0000000000000001, 
     0., 0., 0.}, {180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 0., 0., 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 0., 0., 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001}, 
    {180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 0., 0., 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001, 180.0000000000000001, 0., 0., 
     180.0000000000000001, 180.0000000000000001, 
     180.0000000000000001}, 
    {0., 0., 0., 180.0000000000000001, 180.0000000000000001, 0., 
     0., 0., 0., 0., 180.0000000000000001, 180.0000000000000001, 
     0., 0., 0.}, {0., 0., 0., 180.0000000000000001, 
     180.0000000000000001, 0., 0., 0., 0., 0., 
     180.0000000000000001, 180.0000000000000001, 0., 0., 0.}, 
    {0., 0., 0., 180.0000000000000001, 180.0000000000000001, 0., 
     0., 0., 0., 0., 180.0000000000000001, 180.0000000000000001, 
     0., 0., 0.}}, {PlotRange -> All, 
    DisplayFunction -> (Display[$Display, #1] & ), 
    PlotColor -> Automatic, Axes -> Automatic, 
    PlotLabel -> "Phase Response (degrees)", 
    AxesLabel -> {"w1", "w2", " "}, Ticks -> Automatic, 
    Framed -> False, Prolog -> {}, Epilog -> {}, 
    AxesStyle -> Automatic, Background -> Automatic, 
    DefaultColor -> Automatic, AspectRatio -> 1, 
    ViewPoint -> {1.3, -2.4, 2.}, Boxed -> True, 
    BoxRatios -> {1, 1, 0.4}, Plot3Matrix -> Automatic, 
    Lighting -> False, AmbientLight -> GrayLevel[0], 
    LightSources -> 
     {{{1., 0., 1.}, RGBColor[1, 0, 0]}, 
      {{1., 1., 1.}, RGBColor[0, 1, 0]}, 
      {{0., 1., 1.}, RGBColor[0, 0, 1]}}, Shading -> True, 
    HiddenSurface -> True, Mesh -> True, ClipFill -> Automatic, 
    AxesEdge -> Automatic, MeshStyle -> Automatic, 
    MeshRange -> 
     {{-6.283185307179586476, 6.283185307179586476}, 
      {-6.283185307179586476, 6.283185307179586476}}}]}
;[o]
{-SurfaceGraphics-, -SurfaceGraphics-}
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Sinc Function
:[font = info; inactive; startGroup; Cclosed; ]
-- Time Response
:[font = input; startGroup; ]
i = 1;
formatstr = "Sequence Plot (frequency = `` rad)";
label = ToString[
      		    StringForm[formatstr,
      					   InputForm[2 Pi i / 20]] ]; 
Show[ SequencePlot[Sinc[2 Pi i n / 20], {n, -50, 50},
      			                    DisplayFunction -> Identity],
         DisplayFunction :> $DisplayFunction,
         PlotLabel -> label ]
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.00952 0.11936 0.48396 [
[(Sequence Plot \(frequency = Pi/10 rad\))] 0.5 0.62428 0 -1 Msboxa
[(-40)] 0.11905 0.10686 0 1 Msboxa
[(-20)] 0.30952 0.10686 0 1 Msboxa
[(20)] 0.69048 0.10686 0 1 Msboxa
[(40)] 0.88095 0.10686 0 1 Msboxa
[(n)] 1.00625 0.11936 -1 0 Msboxa
[(-0.2)] 0.4875 0.02257 1 0 Msboxa
[(0.2)] 0.4875 0.21615 1 0 Msboxa
[(0.4)] 0.4875 0.31295 1 0 Msboxa
[(0.6)] 0.4875 0.40974 1 0 Msboxa
[(0.8)] 0.4875 0.50653 1 0 Msboxa
[(1)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot \(frequency = Pi/10 rad\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.11936 moveto
1 0.11936 lineto
stroke
0.11905 0.11311 moveto
0.11905 0.12561 lineto
stroke
0 setgray
[(-40)] 0.11905 0.10686 0 1 Mshowa
0.30952 0.11311 moveto
0.30952 0.12561 lineto
stroke
0 setgray
[(-20)] 0.30952 0.10686 0 1 Mshowa
0.69048 0.11311 moveto
0.69048 0.12561 lineto
stroke
0 setgray
[(20)] 0.69048 0.10686 0 1 Mshowa
0.88095 0.11311 moveto
0.88095 0.12561 lineto
stroke
0 setgray
[(40)] 0.88095 0.10686 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.11936 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.02257 moveto
0.50625 0.02257 lineto
stroke
0 setgray
[(-0.2)] 0.4875 0.02257 1 0 Mshowa
0.49375 0.21615 moveto
0.50625 0.21615 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.21615 1 0 Mshowa
0.49375 0.31295 moveto
0.50625 0.31295 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.31295 1 0 Mshowa
0.49375 0.40974 moveto
0.50625 0.40974 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.40974 1 0 Mshowa
0.49375 0.50653 moveto
0.50625 0.50653 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.50653 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(1)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.00397 setlinewidth
0.02381 0.11936 moveto
0.02381 0.11936 lineto
stroke
0.01192 setlinewidth
0.02381 0.11936 Mdot
0.00397 setlinewidth
0.03333 0.11936 moveto
0.03333 0.12908 lineto
stroke
0.01192 setlinewidth
0.03333 0.12908 Mdot
0.00397 setlinewidth
0.04286 0.11936 moveto
0.04286 0.13823 lineto
stroke
0.01192 setlinewidth
0.04286 0.13823 Mdot
0.00397 setlinewidth
0.05238 0.11936 moveto
0.05238 0.14588 lineto
stroke
0.01192 setlinewidth
0.05238 0.14588 Mdot
0.00397 setlinewidth
0.0619 0.11936 moveto
0.0619 0.15121 lineto
stroke
0.01192 setlinewidth
0.0619 0.15121 Mdot
0.00397 setlinewidth
0.07143 0.11936 moveto
0.07143 0.1536 lineto
stroke
0.01192 setlinewidth
0.07143 0.1536 Mdot
0.00397 setlinewidth
0.08095 0.11936 moveto
0.08095 0.15266 lineto
stroke
0.01192 setlinewidth
0.08095 0.15266 Mdot
0.00397 setlinewidth
0.09048 0.11936 moveto
0.09048 0.14835 lineto
stroke
0.01192 setlinewidth
0.09048 0.14835 Mdot
0.00397 setlinewidth
0.1 0.11936 moveto
0.1 0.14092 lineto
stroke
0.01192 setlinewidth
0.1 0.14092 Mdot
0.00397 setlinewidth
0.10952 0.11936 moveto
0.10952 0.13097 lineto
stroke
0.01192 setlinewidth
0.10952 0.13097 Mdot
0.00397 setlinewidth
0.11905 0.11936 moveto
0.11905 0.11936 lineto
stroke
0.01192 setlinewidth
0.11905 0.11936 Mdot
0.00397 setlinewidth
0.12857 0.11936 moveto
0.12857 0.10716 lineto
stroke
0.01192 setlinewidth
0.12857 0.10716 Mdot
0.00397 setlinewidth
0.1381 0.11936 moveto
0.1381 0.09554 lineto
stroke
0.01192 setlinewidth
0.1381 0.09554 Mdot
0.00397 setlinewidth
0.14762 0.11936 moveto
0.14762 0.08568 lineto
stroke
0.01192 setlinewidth
0.14762 0.08568 Mdot
0.00397 setlinewidth
0.15714 0.11936 moveto
0.15714 0.07867 lineto
stroke
0.01192 setlinewidth
0.15714 0.07867 Mdot
0.00397 setlinewidth
0.16667 0.11936 moveto
0.16667 0.07535 lineto
stroke
0.01192 setlinewidth
0.16667 0.07535 Mdot
0.00397 setlinewidth
0.17619 0.11936 moveto
0.17619 0.07627 lineto
stroke
0.01192 setlinewidth
0.17619 0.07627 Mdot
0.00397 setlinewidth
0.18571 0.11936 moveto
0.18571 0.0816 lineto
stroke
0.01192 setlinewidth
0.18571 0.0816 Mdot
0.00397 setlinewidth
0.19524 0.11936 moveto
0.19524 0.09107 lineto
stroke
0.01192 setlinewidth
0.19524 0.09107 Mdot
0.00397 setlinewidth
0.20476 0.11936 moveto
0.20476 0.10401 lineto
stroke
0.01192 setlinewidth
0.20476 0.10401 Mdot
0.00397 setlinewidth
0.21429 0.11936 moveto
0.21429 0.11936 lineto
stroke
0.01192 setlinewidth
0.21429 0.11936 Mdot
0.00397 setlinewidth
0.22381 0.11936 moveto
0.22381 0.13578 lineto
stroke
0.01192 setlinewidth
0.22381 0.13578 Mdot
0.00397 setlinewidth
0.23333 0.11936 moveto
0.23333 0.1517 lineto
stroke
0.01192 setlinewidth
0.23333 0.1517 Mdot
0.00397 setlinewidth
0.24286 0.11936 moveto
0.24286 0.16552 lineto
stroke
0.01192 setlinewidth
0.24286 0.16552 Mdot
0.00397 setlinewidth
0.25238 0.11936 moveto
0.25238 0.17571 lineto
stroke
0.01192 setlinewidth
0.25238 0.17571 Mdot
0.00397 setlinewidth
0.2619 0.11936 moveto
0.2619 0.18098 lineto
stroke
0.01192 setlinewidth
0.2619 0.18098 Mdot
0.00397 setlinewidth
0.27143 0.11936 moveto
0.27143 0.18041 lineto
stroke
0.01192 setlinewidth
0.27143 0.18041 Mdot
0.00397 setlinewidth
0.28095 0.11936 moveto
0.28095 0.17355 lineto
stroke
0.01192 setlinewidth
0.28095 0.17355 Mdot
0.00397 setlinewidth
0.29048 0.11936 moveto
0.29048 0.16052 lineto
stroke
0.01192 setlinewidth
0.29048 0.16052 Mdot
0.00397 setlinewidth
0.3 0.11936 moveto
0.3 0.14203 lineto
stroke
0.01192 setlinewidth
0.3 0.14203 Mdot
0.00397 setlinewidth
0.30952 0.11936 moveto
0.30952 0.11936 lineto
stroke
0.01192 setlinewidth
0.30952 0.11936 Mdot
0.00397 setlinewidth
0.31905 0.11936 moveto
0.31905 0.09431 lineto
stroke
0.01192 setlinewidth
0.31905 0.09431 Mdot
0.00397 setlinewidth
0.32857 0.11936 moveto
0.32857 0.06906 lineto
stroke
0.01192 setlinewidth
0.32857 0.06906 Mdot
0.00397 setlinewidth
0.3381 0.11936 moveto
0.3381 0.04605 lineto
stroke
0.01192 setlinewidth
0.3381 0.04605 Mdot
0.00397 setlinewidth
0.34762 0.11936 moveto
0.34762 0.0278 lineto
stroke
0.01192 setlinewidth
0.34762 0.0278 Mdot
0.00397 setlinewidth
0.35714 0.11936 moveto
0.35714 0.01667 lineto
stroke
0.01192 setlinewidth
0.35714 0.01667 Mdot
0.00397 setlinewidth
0.36667 0.11936 moveto
0.36667 0.01472 lineto
stroke
0.01192 setlinewidth
0.36667 0.01472 Mdot
0.00397 setlinewidth
0.37619 0.11936 moveto
0.37619 0.0235 lineto
stroke
0.01192 setlinewidth
0.37619 0.0235 Mdot
0.00397 setlinewidth
0.38571 0.11936 moveto
0.38571 0.04391 lineto
stroke
0.01192 setlinewidth
0.38571 0.04391 Mdot
0.00397 setlinewidth
0.39524 0.11936 moveto
0.39524 0.07609 lineto
stroke
0.01192 setlinewidth
0.39524 0.07609 Mdot
0.00397 setlinewidth
0.40476 0.11936 moveto
0.40476 0.11936 lineto
stroke
0.01192 setlinewidth
0.40476 0.11936 Mdot
0.00397 setlinewidth
0.41429 0.11936 moveto
0.41429 0.17226 lineto
stroke
0.01192 setlinewidth
0.41429 0.17226 Mdot
0.00397 setlinewidth
0.42381 0.11936 moveto
0.42381 0.23255 lineto
stroke
0.01192 setlinewidth
0.42381 0.23255 Mdot
0.00397 setlinewidth
0.43333 0.11936 moveto
0.43333 0.2974 lineto
stroke
0.01192 setlinewidth
0.43333 0.2974 Mdot
0.00397 setlinewidth
0.44286 0.11936 moveto
0.44286 0.36354 lineto
stroke
0.01192 setlinewidth
0.44286 0.36354 Mdot
0.00397 setlinewidth
0.45238 0.11936 moveto
0.45238 0.42746 lineto
stroke
0.01192 setlinewidth
0.45238 0.42746 Mdot
0.00397 setlinewidth
0.4619 0.11936 moveto
0.4619 0.48563 lineto
stroke
0.01192 setlinewidth
0.4619 0.48563 Mdot
0.00397 setlinewidth
0.47143 0.11936 moveto
0.47143 0.53479 lineto
stroke
0.01192 setlinewidth
0.47143 0.53479 Mdot
0.00397 setlinewidth
0.48095 0.11936 moveto
0.48095 0.5721 lineto
stroke
0.01192 setlinewidth
0.48095 0.5721 Mdot
0.00397 setlinewidth
0.49048 0.11936 moveto
0.49048 0.5954 lineto
stroke
0.01192 setlinewidth
0.49048 0.5954 Mdot
0.00397 setlinewidth
0.5 0.11936 moveto
0.5 0.60332 lineto
stroke
0.01192 setlinewidth
0.5 0.60332 Mdot
0.00397 setlinewidth
0.50952 0.11936 moveto
0.50952 0.5954 lineto
stroke
0.01192 setlinewidth
0.50952 0.5954 Mdot
0.00397 setlinewidth
0.51905 0.11936 moveto
0.51905 0.5721 lineto
stroke
0.01192 setlinewidth
0.51905 0.5721 Mdot
0.00397 setlinewidth
0.52857 0.11936 moveto
0.52857 0.53479 lineto
stroke
0.01192 setlinewidth
0.52857 0.53479 Mdot
0.00397 setlinewidth
0.5381 0.11936 moveto
0.5381 0.48563 lineto
stroke
0.01192 setlinewidth
0.5381 0.48563 Mdot
0.00397 setlinewidth
0.54762 0.11936 moveto
0.54762 0.42746 lineto
stroke
0.01192 setlinewidth
0.54762 0.42746 Mdot
0.00397 setlinewidth
0.55714 0.11936 moveto
0.55714 0.36354 lineto
stroke
0.01192 setlinewidth
0.55714 0.36354 Mdot
0.00397 setlinewidth
0.56667 0.11936 moveto
0.56667 0.2974 lineto
stroke
0.01192 setlinewidth
0.56667 0.2974 Mdot
0.00397 setlinewidth
0.57619 0.11936 moveto
0.57619 0.23255 lineto
stroke
0.01192 setlinewidth
0.57619 0.23255 Mdot
0.00397 setlinewidth
0.58571 0.11936 moveto
0.58571 0.17226 lineto
stroke
0.01192 setlinewidth
0.58571 0.17226 Mdot
0.00397 setlinewidth
0.59524 0.11936 moveto
0.59524 0.11936 lineto
stroke
0.01192 setlinewidth
0.59524 0.11936 Mdot
0.00397 setlinewidth
0.60476 0.11936 moveto
0.60476 0.07609 lineto
stroke
0.01192 setlinewidth
0.60476 0.07609 Mdot
0.00397 setlinewidth
0.61429 0.11936 moveto
0.61429 0.04391 lineto
stroke
0.01192 setlinewidth
0.61429 0.04391 Mdot
0.00397 setlinewidth
0.62381 0.11936 moveto
0.62381 0.0235 lineto
stroke
0.01192 setlinewidth
0.62381 0.0235 Mdot
0.00397 setlinewidth
0.63333 0.11936 moveto
0.63333 0.01472 lineto
stroke
0.01192 setlinewidth
0.63333 0.01472 Mdot
0.00397 setlinewidth
0.64286 0.11936 moveto
0.64286 0.01667 lineto
stroke
0.01192 setlinewidth
0.64286 0.01667 Mdot
0.00397 setlinewidth
0.65238 0.11936 moveto
0.65238 0.0278 lineto
stroke
0.01192 setlinewidth
0.65238 0.0278 Mdot
0.00397 setlinewidth
0.6619 0.11936 moveto
0.6619 0.04605 lineto
stroke
0.01192 setlinewidth
0.6619 0.04605 Mdot
0.00397 setlinewidth
0.67143 0.11936 moveto
0.67143 0.06906 lineto
stroke
0.01192 setlinewidth
0.67143 0.06906 Mdot
0.00397 setlinewidth
0.68095 0.11936 moveto
0.68095 0.09431 lineto
stroke
0.01192 setlinewidth
0.68095 0.09431 Mdot
0.00397 setlinewidth
0.69048 0.11936 moveto
0.69048 0.11936 lineto
stroke
0.01192 setlinewidth
0.69048 0.11936 Mdot
0.00397 setlinewidth
0.7 0.11936 moveto
0.7 0.14203 lineto
stroke
0.01192 setlinewidth
0.7 0.14203 Mdot
0.00397 setlinewidth
0.70952 0.11936 moveto
0.70952 0.16052 lineto
stroke
0.01192 setlinewidth
0.70952 0.16052 Mdot
0.00397 setlinewidth
0.71905 0.11936 moveto
0.71905 0.17355 lineto
stroke
0.01192 setlinewidth
0.71905 0.17355 Mdot
0.00397 setlinewidth
0.72857 0.11936 moveto
0.72857 0.18041 lineto
stroke
0.01192 setlinewidth
0.72857 0.18041 Mdot
0.00397 setlinewidth
0.7381 0.11936 moveto
0.7381 0.18098 lineto
stroke
0.01192 setlinewidth
0.7381 0.18098 Mdot
0.00397 setlinewidth
0.74762 0.11936 moveto
0.74762 0.17571 lineto
stroke
0.01192 setlinewidth
0.74762 0.17571 Mdot
0.00397 setlinewidth
0.75714 0.11936 moveto
0.75714 0.16552 lineto
stroke
0.01192 setlinewidth
0.75714 0.16552 Mdot
0.00397 setlinewidth
0.76667 0.11936 moveto
0.76667 0.1517 lineto
stroke
0.01192 setlinewidth
0.76667 0.1517 Mdot
0.00397 setlinewidth
0.77619 0.11936 moveto
0.77619 0.13578 lineto
stroke
0.01192 setlinewidth
0.77619 0.13578 Mdot
0.00397 setlinewidth
0.78571 0.11936 moveto
0.78571 0.11936 lineto
stroke
0.01192 setlinewidth
0.78571 0.11936 Mdot
0.00397 setlinewidth
0.79524 0.11936 moveto
0.79524 0.10401 lineto
stroke
0.01192 setlinewidth
0.79524 0.10401 Mdot
0.00397 setlinewidth
0.80476 0.11936 moveto
0.80476 0.09107 lineto
stroke
0.01192 setlinewidth
0.80476 0.09107 Mdot
0.00397 setlinewidth
0.81429 0.11936 moveto
0.81429 0.0816 lineto
stroke
0.01192 setlinewidth
0.81429 0.0816 Mdot
0.00397 setlinewidth
0.82381 0.11936 moveto
0.82381 0.07627 lineto
stroke
0.01192 setlinewidth
0.82381 0.07627 Mdot
0.00397 setlinewidth
0.83333 0.11936 moveto
0.83333 0.07535 lineto
stroke
0.01192 setlinewidth
0.83333 0.07535 Mdot
0.00397 setlinewidth
0.84286 0.11936 moveto
0.84286 0.07867 lineto
stroke
0.01192 setlinewidth
0.84286 0.07867 Mdot
0.00397 setlinewidth
0.85238 0.11936 moveto
0.85238 0.08568 lineto
stroke
0.01192 setlinewidth
0.85238 0.08568 Mdot
0.00397 setlinewidth
0.8619 0.11936 moveto
0.8619 0.09554 lineto
stroke
0.01192 setlinewidth
0.8619 0.09554 Mdot
0.00397 setlinewidth
0.87143 0.11936 moveto
0.87143 0.10716 lineto
stroke
0.01192 setlinewidth
0.87143 0.10716 Mdot
0.00397 setlinewidth
0.88095 0.11936 moveto
0.88095 0.11936 lineto
stroke
0.01192 setlinewidth
0.88095 0.11936 Mdot
0.00397 setlinewidth
0.89048 0.11936 moveto
0.89048 0.13097 lineto
stroke
0.01192 setlinewidth
0.89048 0.13097 Mdot
0.00397 setlinewidth
0.9 0.11936 moveto
0.9 0.14092 lineto
stroke
0.01192 setlinewidth
0.9 0.14092 Mdot
0.00397 setlinewidth
0.90952 0.11936 moveto
0.90952 0.14835 lineto
stroke
0.01192 setlinewidth
0.90952 0.14835 Mdot
0.00397 setlinewidth
0.91905 0.11936 moveto
0.91905 0.15266 lineto
stroke
0.01192 setlinewidth
0.91905 0.15266 Mdot
0.00397 setlinewidth
0.92857 0.11936 moveto
0.92857 0.1536 lineto
stroke
0.01192 setlinewidth
0.92857 0.1536 Mdot
0.00397 setlinewidth
0.9381 0.11936 moveto
0.9381 0.15121 lineto
stroke
0.01192 setlinewidth
0.9381 0.15121 Mdot
0.00397 setlinewidth
0.94762 0.11936 moveto
0.94762 0.14588 lineto
stroke
0.01192 setlinewidth
0.94762 0.14588 Mdot
0.00397 setlinewidth
0.95714 0.11936 moveto
0.95714 0.13823 lineto
stroke
0.01192 setlinewidth
0.95714 0.13823 Mdot
0.00397 setlinewidth
0.96667 0.11936 moveto
0.96667 0.12908 lineto
stroke
0.01192 setlinewidth
0.96667 0.12908 Mdot
0.00397 setlinewidth
0.97619 0.11936 moveto
0.97619 0.11936 lineto
stroke
0.01192 setlinewidth
0.97619 0.11936 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = info; inactive; startGroup; Cclosed; ]
-- Frequency Response
:[font = input; startGroup; ]
 MagPhasePlot[DTFTransform[Sinc[2 Pi n / 20], n, w],
		           {w, -Pi, 3 Pi},
		           PhaseRangeScale -> Null ] 
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.2619 0.07579 0.01472 0.05886 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-2)] 0.11033 0.00222 0 1 Msboxa
[(2)] 0.41348 0.00222 0 1 Msboxa
[(4)] 0.56506 0.00222 0 1 Msboxa
[(6)] 0.71663 0.00222 0 1 Msboxa
[(8)] 0.86821 0.00222 0 1 Msboxa
[(w)] 1.00625 0.01472 -1 0 Msboxa
[(2)] 0.2494 0.13244 1 0 Msboxa
[(4)] 0.2494 0.25016 1 0 Msboxa
[(6)] 0.2494 0.36788 1 0 Msboxa
[(8)] 0.2494 0.4856 1 0 Msboxa
[(10)] 0.2494 0.60332 1 0 Msboxa
[( )] 0.2619 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.11033 0.00847 moveto
0.11033 0.02097 lineto
stroke
0 setgray
[(-2)] 0.11033 0.00222 0 1 Mshowa
0.41348 0.00847 moveto
0.41348 0.02097 lineto
stroke
0 setgray
[(2)] 0.41348 0.00222 0 1 Mshowa
0.56506 0.00847 moveto
0.56506 0.02097 lineto
stroke
0 setgray
[(4)] 0.56506 0.00222 0 1 Mshowa
0.71663 0.00847 moveto
0.71663 0.02097 lineto
stroke
0 setgray
[(6)] 0.71663 0.00222 0 1 Mshowa
0.86821 0.00847 moveto
0.86821 0.02097 lineto
stroke
0 setgray
[(8)] 0.86821 0.00222 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.01472 -1 0 Mshowa
0.2619 0 moveto
0.2619 0.61803 lineto
stroke
0.25565 0.13244 moveto
0.26815 0.13244 lineto
stroke
0 setgray
[(2)] 0.2494 0.13244 1 0 Mshowa
0.25565 0.25016 moveto
0.26815 0.25016 lineto
stroke
0 setgray
[(4)] 0.2494 0.25016 1 0 Mshowa
0.25565 0.36788 moveto
0.26815 0.36788 lineto
stroke
0 setgray
[(6)] 0.2494 0.36788 1 0 Mshowa
0.25565 0.4856 moveto
0.26815 0.4856 lineto
stroke
0 setgray
[(8)] 0.2494 0.4856 1 0 Mshowa
0.25565 0.60332 moveto
0.26815 0.60332 lineto
stroke
0 setgray
[(10)] 0.2494 0.60332 1 0 Mshowa
0 setgray
[( )] 0.2619 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.06349 0.01472 lineto
0.10317 0.01472 lineto
0.14286 0.01472 lineto
0.18254 0.01472 lineto
0.20238 0.01472 lineto
0.2123 0.01472 lineto
0.22222 0.01472 lineto
0.22718 0.01472 lineto
0.23214 0.01472 lineto
0.23462 0.01472 lineto
0.23586 0.01472 lineto
0.2371 0.01472 lineto
0.23834 0.60332 lineto
0.23958 0.60332 lineto
0.24206 0.60332 lineto
0.2619 0.60332 lineto
0.27183 0.60332 lineto
0.27679 0.60332 lineto
0.27927 0.60332 lineto
0.28175 0.60332 lineto
0.28299 0.60332 lineto
0.28423 0.60332 lineto
0.28547 0.60332 lineto
0.28671 0.01472 lineto
0.28919 0.01472 lineto
0.29167 0.01472 lineto
0.30159 0.01472 lineto
0.34127 0.01472 lineto
0.38095 0.01472 lineto
0.42063 0.01472 lineto
0.46032 0.01472 lineto
0.5 0.01472 lineto
0.53968 0.01472 lineto
0.57937 0.01472 lineto
0.61905 0.01472 lineto
0.65873 0.01472 lineto
0.69841 0.01472 lineto
0.7381 0.01472 lineto
0.77778 0.01472 lineto
0.81746 0.01472 lineto
0.85714 0.01472 lineto
0.89683 0.01472 lineto
0.93651 0.01472 lineto
0.97619 0.01472 lineto
stroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; endGroup; ]
{Graphics[{{Line[{{-3.141592653589793238, 0.}, 
       {-2.617993877991494365, 0.}, {-2.094395102393195492, 0.}, 
       {-1.570796326794896619, 0.}, {-1.047197551196597746, 0.}, 
       {-0.7853981633974483095, 0.}, {-0.6544984694978735912, 0.}, 
       {-0.523598775598298873, 0.}, {-0.4581489286485115139, 0.}, 
       {-0.3926990816987241548, 0.}, {-0.3599741582238304752, 0.}, 
       {-0.3436116964863836354, 0.}, {-0.3272492347489367956, 0.}, 
       {-0.3108867730114899558, 10.}, 
       {-0.2945243112740431161, 10.}, 
       {-0.2617993877991494365, 10.}, {0., 10.}, 
       {0.1308996938995747183, 10.}, {0.1963495408493620774, 10.}, 
       {0.229074464324255757, 10.}, {0.2617993877991494365, 10.}, 
       {0.2781618495365962763, 10.}, {0.2945243112740431161, 10.}, 
       {0.3108867730114899558, 10.}, {0.3272492347489367956, 0.}, 
       {0.3599741582238304752, 0.}, {0.3926990816987241548, 0.}, 
       {0.523598775598298873, 0.}, {1.047197551196597746, 0.}, 
       {1.570796326794896619, 0.}, {2.094395102393195492, 0.}, 
       {2.617993877991494365, 0.}, {3.141592653589793238, 0.}, 
       {3.665191429188092111, 0.}, {4.188790204786390984, 0.}, 
       {4.712388980384689857, 0.}, {5.235987755982988729, 0.}, 
       {5.759586531581287602, 0.}, {6.283185307179586475, 0.}, 
       {6.806784082777885348, 0.}, {7.330382858376184221, 0.}, 
       {7.853981633974483094, 0.}, {8.377580409572781968, 0.}, 
       {8.901179185171080841, 0.}, {9.424777960769379714, 0.}}]}}, 
   {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[Point[{0, 0}], DisplayFunction -> Identity]}
;[o]
{-Graphics-, -Graphics-}
:[font = section; inactive; startGroup; Cclosed; ]
The Discrete Fourier Transform (DFT)
:[font = text; inactive; ]
	The discrete Fourier transform (DFT) maps a finite length sequence in the time domain into a finite length sequence in the frequency domain.   Unlike the DTFT which maps a finite or infinite length sequence into a periodic continuous frequency domain, the DFT is a completely discrete transform, sampling both in time and in frequency.  The DFT is therefore a convenient way to represent spectral characteristics on a digital computer. 	Many efficient hardware implementations exist for the DFT such as the popular Fast Fourier Transform (FFT).
:[font = subsection; inactive; startGroup; Cclosed; ]
Definition
:[font = text; inactive; ]
	Let x[n] be an N-point complex-valued sequence that is non-zero for values of n between 0 and N-1.  The DFT sequence, which will be denoted X[k], is the N-point sequence that is defined by the summation
:[font = postscript; inactive; PostScript; output; pictureLeft = 57; pictureWidth = 314; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.149682 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.149682 scale
1 string
314 47 1 [314 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F03FFFFFF803FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1C7FFFFC7FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1F80001C7FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E3FFFFFC7FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E380001C7FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE381FFFFFFC7FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000000003FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000003FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFC003FFFFFFF000FFFFFFFFFFFFFFFFFFE3FFFFFFF03FFFFFFF
FF8007FFFFFFFC003FFFFFFFFFFE00FF8FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFC7FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFC7FFFFFFE3FFFFFFF
FF8FFFFFFFFFFFFE3FFFFFFFFFFFC7FF8FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFF
FC7FFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFC7FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFF8FFFFFFE3FFFFFFF
FF8FFFFFFFFFFFFE3FFFFFFFFFFFC7FC0FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFF
FF8FFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFC7FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFF
FF8FFFFFFFFFFFFE3FFFFFFFFFFFF8FC71FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFF
FF8FFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
0001C0000FC7FFF03F03FFF8FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFC0FF8
1F8FFFFC0FF803FE3FFC0FFF1FFFF8E3F1FFFFFFFFFFFFFFFFFFFFFFFFC0
03FFC003FE001FFFFFFF81F81FFFFFFFFFFFFFFFF8007FFF03FFFFE00007
FC0FFFFFFE07FC0FF81FF03FFFFFF803FFFF1FFFFFFFFFFFFC0000FC
FC0FFF007FC7FFF038007FF8FFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF81C0
038FFFFC0FF81C7E3FFC01FF03FFF8E3F1FFFFFFFFFFFFFFFFFFFFFFFFF8
1FFE07E07FC0FFFFFFFF81C003FFFFFFFFFFFFFFC0FC0FFF03FFFFFF81FF
FC0FFFFFFE07FC0FF81FF03FFFFFFF1FFFF81FFFFFFFFFFFFFF03FFC
FF8FFF03FFC7FFF0381FFFF8FFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFF1C0
FF8FFFFC0FF81FFE3FFC01FF03FFFF1FFE3FFFFFFFFFFFFFFFFFFFFFFFF8
1FF03FFC0FC0FFFFFFFF81C0FFFFC0000007FFFFC7FF8FFFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC01FFFFFFFFFFFFFF03FFC
FFF1FF03FFC7FFF000FFFFF8FFFFC0000007FFFFFFFFFFFF1FFFFFFFF007
FF8FFFFC0FF81FFE3FFC01FF007FFF1FFE3FFFFFFFFFFFFFFFFFFFFFFFF8
1FF03FFC0FC0FFFFFFFF8007FFFFFFFFFFFFFFFE07FF81FFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC01FFFFFFFFFFFFFF03FFC
FFFE381FFFC7FFFE00FFFFF8FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFE07
FF8FFFFF81FF03FE3FFC0E3F007FF81FF007FFFFFFFFFFFFFFFFFFFFFFF8
1FF03FFC0FC0FFFFFFFFF007FFFFFFFFFFFFFFFE07FF81FFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFE071FFFFFFC0007FFF03FFC
FFFE001FFFC7FFFE071FFFF8FFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFF000
FF8FFFFF803F03FE3FFC0E3F038FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FF03FFC0FC0FFFFFFFFF038FFFFFFFFFFFFFFFE07FF81FFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF03F1FFFFFFFFFFFFFF03FFC
FFFFC0FFFFC7FFFE07E07FF8FFFFC0000007FFFFFFFFFFC0FFFFFFFFF038
1F8FFFFF81C003FE3FFC0FC7038FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FFE07E07E00E07FFFFFF03F03FFC0000007FFFE07FF81FFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F803F1FFFFFFFFFFFFFF03FFC
FFFFC0FFFFC7FFFE07E00FF8FFFFFFFFFFFFFFFFFFFFFE07FFFFFFFF803F
038FFFFC01F81FFE3FFC0FC703F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
007FC003FFC7007FFFFFF03F007FFFFFFFFFFFFE07FF81FFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F81FF1FFFFFFFFFFFFFF03FFC
FFFE001FFFC7FFFE07FFFFF8FFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFF
FF8FFFFFFFFFFFFE3FFC0FC703F03F1F81C7FC7FFFFFFFFFFFFFFFFFFFF8
1FFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFE07FF81FFFFFFFFE381FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFF1FFFFFFFFFFFFC703FFC
FFFE07E3FFC7FFFFC7FFFFF8FFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FF8FFFFFFFFFFFFE3FFC0FF803FE3F1F8E07E38FFFFFFFFFFFFFFFFFFFF8
1FFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFC7FF8FFFFFFFFFFC01FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFF1FFFFFFFFFFFFF803FFC
FFF007E07FC7FFFFC0FFFFF8FFFFFFFFFFFFFFFFFFFC0FFFFFFE3FFFFFFF
FF8FFFFFFFFFFFFE3FFC0FF803FE071F8FF8E3FFFFFFFFFFFFFFFFFFFFF8
1F8FFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFC0FC0FFFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFF1FFFFFFFFFFFFFF03FFC
FFF03FFC0FC003FFC0FFF000FFFFFFFFFFFFFFFFFFE07FFFFFFE3FFFFFFF
FF8007FFFFFFFC003FFC0FF803FFC7E3F1F81FFFFFFFFFFFFFFFFFFFFFFF
007FFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFF8007FFFFFFFFFFFF1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFF803FFFFFFFFFFFFFE3FFC
FC0000E0003FFFFE00FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFFFE001C0007E00E3F1F8E3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000000003FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFF1C0FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FF8FFFFFFE00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF8FFFFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FC0FFFFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FC71FFFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E3F1C0000FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E3F1FFFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFE3FFFFE07FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFE3FFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
where
:[font = postscript; inactive; PostScript; output; pictureLeft = 178; pictureWidth = 81; pictureHeight = 38; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.469136 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.469136 scale
1 string
81 38 1 [81 0 0 38 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FFFFFFFFFFC01FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FFFFFFFFFFF8FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FFFFFFFFFFF8FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FFFFFFFFFFFF1F8E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FF81FFE3FFFF1C7E3FFFFFFFFFFFFFFFF000FFFFFFFFFFFFFFFFFFFFFFFF
E0
FF803FE07FFF1C7E3FFFFFFFFFFFFFFF803F1FFFFFFFFFFFFFFFFFFFFFFF
E0
FF803FE07FFFE3FFC7FFFFFFFFFFFFFF81FFE3FFFFFFFFFFFFFFFFFFFFFF
E0
FF803FE00FFFE3FFC7FFF0000001FFFF8007FFFFFFFFFFFFFFFFFFFFFFFF
E0
FF81C7E00FFF03FE00FFFFFFFFFFFFFF81F81FFFFFFFFFFFFFFFFFFFFFFF
E0
FF81C7E071FFFFFFFFFFFFFFFFFFFFFFF1FF03FFFFFFFFFFFFFFFFFFFFFF
E0
FF81F8E071FFFFFFFFFFF0000001FFFFF03F03FFFFFFFFFFFFF007FC7FFF
E0
FF81F8E07E3FFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFE3FFC7FFF
E0
FF81F8E07E07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FE07FFF
E0
FF81FF007FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E38FFF
E0
FF81FF007FC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC71F8FFF
E0
FF81FF007FF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC71F8FFF
E0
FC0038000FC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFF8FFF1FF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC71FFFFFFF8FFF1FF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFC0FF803F
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7000000000007
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80001FFFC7FFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E001FFFC7E07
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FE3FFC7E38
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFF8FC7
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF8FC7
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF81F8
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFF000
00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FE3FFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFF
E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
is often called a twiddle factor.  The inverse DFT can be evaluated using a similar formula: [Smith & Mersereau, 1992]
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 44; pictureWidth = 340; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.138235 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.138235 scale
1 string
340 47 1 [340 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF1FFFFF
FC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8E3FFFF
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE38FC0000
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFF8FFFFFFE38FC0000
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFC0FFFFFFFC703FFFF
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFC01FFFFFFC7FFFFFF
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFE001FFFFFFF8FFFFFF
FC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFE071FFFFFFC0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FE0703FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03F03F03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F03FE3FFFFFC0000000
0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3803FE3FFFFFF8000000
0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFFE381FFE07FFFFFF1FFFFF
FF81FFFFFFFFFFFE001FFFFFFFF000FFFFFFFFFFF803FE3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFE001FFFC7FFFFFFE3FFFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFF8FFFFFFFFFFFF1FFE3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFC0FFFFC7FFFFFFFC7FFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFF8FFFFFFFFFFFF1FF03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFF000FFF000FFFFFFFF8FFF
FFFFFFFFFFFFFFFE3FFFFFFFFFFFF8FFFFFFFFFFFFE3F1C7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
E07FC0FC7FFFE07FC01FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FF
FFFFFF0001C0000E3FFFF03F03FFF8FFFE07FF8FFFE38FC7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000FFF000FF8007FFFFFF03FE00FFFFFFFFFFFFFFF
000FFFE07FFFFF80001F81FFFFFFF81FF03FE07FC0FFFFFFE00FFFFC7FFF
FFFFFFFFF00003F0
FC0E001C7FFFE07FC0E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFC0FFF007E3FFFF038007FF8FFFE00FF81FFE38FC7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE07FF81F81FF03FFFFFFF03FE071FFFFFFFFFFFFF8
1F81FFE07FFFFFFE07FF81FFFFFFF81FF03FE07FC0FFFFFFFC7FFFE07FFF
FFFFFFFFFFC0FFF0
FF8E07FC7FFFE07FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7
FFFFFFFF8FFF03FE3FFFF0381FFFF8FFFE00FF81FFFC7FF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE07FC0FFF03F03FFFFFFF03FE07FFF0000001FFFF8
FFF1FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF007FFF
FFFFFFFFFFC0FFF0
FF803FFC7FFFE07FC0FFF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFF1FF03FE3FFFF000FFFFF8FFFE00FF803FFC7FF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE07FC0FFF03F03FFFFFFF03FE07FFFFFFFFFFFFFC0
FFF03FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF007FFF
FFFFFFFFFFC0FFF0
FFF03FFC7FFFFC0FF81FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FFFFFFFFE381FFE3FFFFE00FFFFF8FFFE071F803FE07FC01FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE07FC0FFF03F03FFFFFFFE07FC0FFFFFFFFFFFFFC0
FFF03FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF81C7FFF
FFF0001FFFC0FFF0
FF8007FC7FFFFC01F81FF1FFFFFFFFFFFFFFE00000000000FFFFFFFFFFC0
FFFFFFFFFE001FFE3FFFFE071FFFF8FFFE071F81C7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE07FC0FFF03F03FFFFFFFE00FC0FFFFFFFFFFFFFC0
FFF03FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FC0FC7FFF
FFFFFFFFFFC0FFF0
FF81C0FC7FFFFC0E001FF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFFFE07
FFFFFFFFFFC0FFFE3FFFFE07E07FF8FFFE07E381C7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE07FF81F81F80381FFFFFE07000FFF0000001FFFC0
FFF03FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E00FC7FFF
FFFFFFFFFFC0FFF0
FC01F81C7FFFE00FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03F
FFFFFFFFFFC0FFFE3FFFFE07E00FF8FFFE07E381F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0001FF000FFF1C01FFFFF007E07FFFFFFFFFFFFFC0
FFF03FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E07FC7FFF
FFFFFFFFFFC0FFF0
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF
FFFFFFFFFE001FFE3FFFFE07FFFFF8FFFE07E381F81FFFFFFC7E071FF1FF
FFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFF03FFFFFFFFF8E07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FFC7FFF
FFFFFFFFF1C0FFF0
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFF
FFFFFFFFFE07E3FE3FFFFFC7FFFFF8FFFE07FC01FF1FFFFFFC7E381F8E3F
FFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFF1FFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFC7FFF
FFFFFFFFFE00FFF0
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFF
FFF1FFFFF007E07E3FFFFFC0FFFFF8FFFE07FC01FF03FFFFFC7E3FE38FFF
FFFFFFFFFFFFFFFFFFE07E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1F81FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFC7FFF
FFFFFFFFFFC0FFF0
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFF1FFFFF03FFC0E001FFFC0FFF000FFFE07FC01FFE3FFFFFF8FC7E07FFF
FFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000FFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFE00FFF
FFFFFFFFFFF8FFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00007FFFFFFFF81FFFFF
FF81FFFC0000E0003FFFFE00FFFFFFFFF000E0003F0000001F8FC7E38FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFC0000000
0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FFC703F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF803FE3FFFF
FFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFF1FFE3FFFF
FFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE381FFFFFFFF1FF03FFFF
FFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFE3F1C7FFF
FFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFE38FC7E00
007E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFE38FC7FFF
FFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF8FFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF8FFF
FFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FC01FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = subsection; inactive; startGroup; Cclosed; ]
Interpretations of the DFT
:[font = text; inactive; ]
Three common interpretations of the DFT are presented below to provide more insight into the DFT.  [Smith & Mersereau, 1992]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
As a Linear Transformation
:[font = text; inactive; endGroup; ]
	One view regards the DFT as a computable, invertible, linear transformation between two vector spaces---  the signal space and the transform space.  In this case, signals are represented as the superposition of delayed Kronecker impulse functions.  The transform space is also a superposition but of complex-valued sinusoids.  This interpretation drives the use of the DFT for waveform coding because the frequency domain completely characterizes the sequence.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
As a Sampling of Other Discrete-Time Transforms
:[font = text; inactive; ]
	From the definition of the DFT, which is an infinite summation, the DFT can be viewed as the uniform sampling of one period of the DTFT (assuming that the DTFT exists):
:[font = postscript; inactive; PostScript; output; pictureLeft = 147; pictureWidth = 144; pictureHeight = 39; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.270833 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.270833 scale
1 string
144 39 8 [144 0 0 39 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFF000000000000
FFFFFF000000FFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFF000000000000000000000000
000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF000000000000FFFFFF
000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
Similarly, it can be viewed as the z-transform evaluated at N uniformly spaced points on the unit circle (assuming that the z-transform exists such that the unit circle is in the region of convergence):
:[font = postscript; inactive; PostScript; output; pictureLeft = 157; pictureWidth = 123; pictureHeight = 22; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.178862 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.178862 scale
1 string
123 22 8 [123 0 0 22 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFF000000FFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFF000000000000000000000000
000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFF000000FFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; endGroup; ]
This interpretation motivates the use pf the DFT for spectrum analysis.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
As a Periodically Extended Fourier Series
:[font = text; inactive; ]
	The DFT of x[n] is equivalent to the Fourier series of the periodic extension of N with period N (the periodic extension of x[n] is formed by repeating x[n] every N samples in both the positive and negative directions).  The Fourier series approximation improves as the number of coefficients increases.  In terms of the DFT, frequency resolution improves as N increases.  This was seen in the animation of the Fourier series of the square wave shown in the Fourier series section.
:[font = text; inactive; endGroup; endGroup; ]
		The DFT is a linear time-invariant operator that maps a discrete-time sequence into a discrete-frequency sequence.  Because the DFT is a linear operator, it is subject to the Heisenberg Uncertainty Principle which states that time and frequency resolution are inversely proportional.  So, high time resolution means low frequency resolution and vica-versa.  (It turns out that this trade-off is removed when a quadratic kernel is used; this fact is important in field of time-frequency analysis.)  Since Fourier techniques are based on linear time-invariant kernels, they are well suited for the analysis of linear time-invariant systems such as linear filters.
:[font = subsection; inactive; startGroup; Cclosed; ]
DFT Properties
:[font = text; inactive; ]
	Many propertiers of the DFT can be exploited to reduce computation in digital systems.  Since the DFT is a linear time-invariant transform for sequences, some of its properties are similiar to those of the DTFT and z-transform.  The table below contains a partial list of those properties.  In that table, X[k] is the DFT of x[n] and Y[k] is the DFT of y[n].  Furthermore, h[[k]] subscript N refers to the N-point periodic extention of h[k] which is equivalent to indexing sequence h by k mod N.
:[font = output; inactive; locked; output; ]
TableForm[{{a*x[n] + b*y[n], a*X[k] + b*Y[k]}, 
   {circular[x, n + n0, N], 
    WN^("-k"*n0)" "X[k]}, 
   {WN^(k0*n)*x[n], circular[X, k - k0, N]}, 
   {sum["m=0", "N-1", x[m], "y[[n-m]]"], 
    " "      }, {" "      , 
    " "          " "
    " "          " "
    X[k]*Y[k]    x[n]*y[n]
    " "" "sum["l=0", "N-1", X[l], "Y[[k-l]]"]}, 
    " "
    1
    "-"
    N
   {xs[n], circular[X^"*", -k, N]}}, 2]
;[o]

a x[n] + b y[n]       a X[k] + b Y[k]
 
                        -k n
                            0
x[[n + n ]]           W       X[k]
        0  N           N
 
  k  n
   0
W      x[n]           X[[k - k ]]
 N                            0  N
 
m=0                    
---                    
\                      
 )  x[m] y[[n-m]]     X[k] Y[k]
/                N
---
N-1
 
                        l=0
                        ---
                      1 \  
x[n] y[n]             -  )  X[l] Y[[k-l]]
                      N /                N
                        ---
                        N-1
 
 *                     *
x [n]                 X [[-k]]
                              N
:[font = text; inactive; ]
This table assumes that the time and frequency sequences begin at index 0 and end at index N - 1.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Code to Generate Table
:[font = input; ]
Format[ circular[x_, n_, m_] ] :=
  SequenceForm[ x, "[[", n, "]]", Subscript[m] ];
Format[ n0 ] := Subscripted[n[0]];
Format[ k0 ] := Subscripted[k[0]];
Format[ WN ] := Subscripted[W[N]];
Format[ xs ] :=
  SequenceForm[x, Superscript["*"]];
Format[ sum[l_, u_, x_, y_] ] :=
ColumnForm[ {l,
	     "---",
	     "\\  ",
	     SequenceForm[" )  ", x, " ", y],
	     "/                N",
	     "---",
	     u} ];
:[font = input; endGroup; endGroup; ]
TableForm[ 
{{a x[n] + b y[n],
  a X[k] + b Y[k]},
 {circular[x, n + n0, N],
  SequenceForm[ WN^("-k" n0), " ", X[k] ]},
 {WN^(n k0) x[n],
  circular[X, k - k0, N]},
 {sum["m=0", "N-1", x[m], "y[[n-m]]"],
  ColumnForm[ {" ", " ", " ", X[k] Y[k]} ] },
 {ColumnForm[ {" ", " ", " ", x[n] y[n] } ],
  SequenceForm[
     ColumnForm[{" ", " ", 1, "-", N}], " ",
     sum["l=0", "N-1", X[l], "Y[[k-l]]"]] },
 {xs[n],
  circular[X^("*"), -k, N] }}, 2 ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Computing the DFT with Mathematica
:[font = text; inactive; ]
	Mathematica  offers built-in routines to compute the forward and inverse discrete Fourier transforms numerically, namely Fourier and InverseFourier.  For these functions, sequences are represented as lists.  You can generate lollipop plots for sequences using SequencePlot, which is provided with the signal processing packages.  These packages also provide two routines to compute the forward and inverse discrete Fourier transform symbolically---  DFTransform and InvDFTransform.
:[font = subsubsection; inactive; startGroup; ]
Example
:[font = input; startGroup; ]
list = Table[i, {i, 1, 10} ]
:[font = output; inactive; output; endGroup; ]
{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}
;[o]
{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}
:[font = input; startGroup; ]
SequencePlot[ Element[list, k], {k, 1, 10} ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 160; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
-0.08201 0.10582 0.01472 0.05886 [
[(Sequence Plot)] 0.5 0.62428 0 -1 Msboxa
[(2)] 0.12963 0.00222 0 1 Msboxa
[(4)] 0.34127 0.00222 0 1 Msboxa
[(6)] 0.55291 0.00222 0 1 Msboxa
[(8)] 0.76455 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(k)] 1.00625 0.01472 -1 0 Msboxa
[(2)] -0.09451 0.13244 1 0 Msboxa
[(4)] -0.09451 0.25016 1 0 Msboxa
[(6)] -0.09451 0.36788 1 0 Msboxa
[(8)] -0.09451 0.4856 1 0 Msboxa
[(10)] -0.09451 0.60332 1 0 Msboxa
[( )] -0.08201 0.62428 0 -1 Msboxa
[ -0.08926 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.12963 0.00847 moveto
0.12963 0.02097 lineto
stroke
0 setgray
[(2)] 0.12963 0.00222 0 1 Mshowa
0.34127 0.00847 moveto
0.34127 0.02097 lineto
stroke
0 setgray
[(4)] 0.34127 0.00222 0 1 Mshowa
0.55291 0.00847 moveto
0.55291 0.02097 lineto
stroke
0 setgray
[(6)] 0.55291 0.00222 0 1 Mshowa
0.76455 0.00847 moveto
0.76455 0.02097 lineto
stroke
0 setgray
[(8)] 0.76455 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(k)] 1.00625 0.01472 -1 0 Mshowa
-0.08201 0 moveto
-0.08201 0.61803 lineto
stroke
-0.08826 0.13244 moveto
-0.07576 0.13244 lineto
stroke
0 setgray
[(2)] -0.09451 0.13244 1 0 Mshowa
-0.08826 0.25016 moveto
-0.07576 0.25016 lineto
stroke
0 setgray
[(4)] -0.09451 0.25016 1 0 Mshowa
-0.08826 0.36788 moveto
-0.07576 0.36788 lineto
stroke
0 setgray
[(6)] -0.09451 0.36788 1 0 Mshowa
-0.08826 0.4856 moveto
-0.07576 0.4856 lineto
stroke
0 setgray
[(8)] -0.09451 0.4856 1 0 Mshowa
-0.08826 0.60332 moveto
-0.07576 0.60332 lineto
stroke
0 setgray
[(10)] -0.09451 0.60332 1 0 Mshowa
0 setgray
[( )] -0.08201 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.00741 setlinewidth
0.02381 0.01472 moveto
0.02381 0.07358 lineto
stroke
0.02224 setlinewidth
0.02381 0.07358 Mdot
0.00741 setlinewidth
0.12963 0.01472 moveto
0.12963 0.13244 lineto
stroke
0.02224 setlinewidth
0.12963 0.13244 Mdot
0.00741 setlinewidth
0.23545 0.01472 moveto
0.23545 0.1913 lineto
stroke
0.02224 setlinewidth
0.23545 0.1913 Mdot
0.00741 setlinewidth
0.34127 0.01472 moveto
0.34127 0.25016 lineto
stroke
0.02224 setlinewidth
0.34127 0.25016 Mdot
0.00741 setlinewidth
0.44709 0.01472 moveto
0.44709 0.30902 lineto
stroke
0.02224 setlinewidth
0.44709 0.30902 Mdot
0.00741 setlinewidth
0.55291 0.01472 moveto
0.55291 0.36788 lineto
stroke
0.02224 setlinewidth
0.55291 0.36788 Mdot
0.00741 setlinewidth
0.65873 0.01472 moveto
0.65873 0.42674 lineto
stroke
0.02224 setlinewidth
0.65873 0.42674 Mdot
0.00741 setlinewidth
0.76455 0.01472 moveto
0.76455 0.4856 lineto
stroke
0.02224 setlinewidth
0.76455 0.4856 Mdot
0.00741 setlinewidth
0.87037 0.01472 moveto
0.87037 0.54446 lineto
stroke
0.02224 setlinewidth
0.87037 0.54446 Mdot
0.00741 setlinewidth
0.97619 0.01472 moveto
0.97619 0.60332 lineto
stroke
0.02224 setlinewidth
0.97619 0.60332 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = input; ]
dft = Fourier[list];
:[font = input; startGroup; ]
SequencePlot[ Element[Abs[dft], k], {k, 1, 10} ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 17; pictureWidth = 282; pictureHeight = 160; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
-0.08201 0.10582 0.01472 0.03384 [
[(Sequence Plot)] 0.5 0.62428 0 -1 Msboxa
[(2)] 0.12963 0.00222 0 1 Msboxa
[(4)] 0.34127 0.00222 0 1 Msboxa
[(6)] 0.55291 0.00222 0 1 Msboxa
[(8)] 0.76455 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(k)] 1.00625 0.01472 -1 0 Msboxa
[(2.5)] -0.09451 0.09932 1 0 Msboxa
[(5)] -0.09451 0.18393 1 0 Msboxa
[(7.5)] -0.09451 0.26853 1 0 Msboxa
[(10)] -0.09451 0.35314 1 0 Msboxa
[(12.5)] -0.09451 0.43774 1 0 Msboxa
[(15)] -0.09451 0.52235 1 0 Msboxa
[(17.5)] -0.09451 0.60696 1 0 Msboxa
[( )] -0.08201 0.62428 0 -1 Msboxa
[ -0.08926 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Sequence Plot)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.12963 0.00847 moveto
0.12963 0.02097 lineto
stroke
0 setgray
[(2)] 0.12963 0.00222 0 1 Mshowa
0.34127 0.00847 moveto
0.34127 0.02097 lineto
stroke
0 setgray
[(4)] 0.34127 0.00222 0 1 Mshowa
0.55291 0.00847 moveto
0.55291 0.02097 lineto
stroke
0 setgray
[(6)] 0.55291 0.00222 0 1 Mshowa
0.76455 0.00847 moveto
0.76455 0.02097 lineto
stroke
0 setgray
[(8)] 0.76455 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(k)] 1.00625 0.01472 -1 0 Mshowa
-0.08201 0 moveto
-0.08201 0.61803 lineto
stroke
-0.08826 0.09932 moveto
-0.07576 0.09932 lineto
stroke
0 setgray
[(2.5)] -0.09451 0.09932 1 0 Mshowa
-0.08826 0.18393 moveto
-0.07576 0.18393 lineto
stroke
0 setgray
[(5)] -0.09451 0.18393 1 0 Mshowa
-0.08826 0.26853 moveto
-0.07576 0.26853 lineto
stroke
0 setgray
[(7.5)] -0.09451 0.26853 1 0 Mshowa
-0.08826 0.35314 moveto
-0.07576 0.35314 lineto
stroke
0 setgray
[(10)] -0.09451 0.35314 1 0 Mshowa
-0.08826 0.43774 moveto
-0.07576 0.43774 lineto
stroke
0 setgray
[(12.5)] -0.09451 0.43774 1 0 Mshowa
-0.08826 0.52235 moveto
-0.07576 0.52235 lineto
stroke
0 setgray
[(15)] -0.09451 0.52235 1 0 Mshowa
-0.08826 0.60696 moveto
-0.07576 0.60696 lineto
stroke
0 setgray
[(17.5)] -0.09451 0.60696 1 0 Mshowa
0 setgray
[( )] -0.08201 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.00741 setlinewidth
0.02381 0.01472 moveto
0.02381 0.60332 lineto
stroke
0.02224 setlinewidth
0.02381 0.60332 Mdot
0.00741 setlinewidth
0.12963 0.01472 moveto
0.12963 0.18788 lineto
stroke
0.02224 setlinewidth
0.12963 0.18788 Mdot
0.00741 setlinewidth
0.23545 0.01472 moveto
0.23545 0.10575 lineto
stroke
0.02224 setlinewidth
0.23545 0.10575 Mdot
0.00741 setlinewidth
0.34127 0.01472 moveto
0.34127 0.08086 lineto
stroke
0.02224 setlinewidth
0.34127 0.08086 Mdot
0.00741 setlinewidth
0.44709 0.01472 moveto
0.44709 0.07098 lineto
stroke
0.02224 setlinewidth
0.44709 0.07098 Mdot
0.00741 setlinewidth
0.55291 0.01472 moveto
0.55291 0.06822 lineto
stroke
0.02224 setlinewidth
0.55291 0.06822 Mdot
0.00741 setlinewidth
0.65873 0.01472 moveto
0.65873 0.07098 lineto
stroke
0.02224 setlinewidth
0.65873 0.07098 Mdot
0.00741 setlinewidth
0.76455 0.01472 moveto
0.76455 0.08086 lineto
stroke
0.02224 setlinewidth
0.76455 0.08086 Mdot
0.00741 setlinewidth
0.87037 0.01472 moveto
0.87037 0.10575 lineto
stroke
0.02224 setlinewidth
0.87037 0.10575 Mdot
0.00741 setlinewidth
0.97619 0.01472 moveto
0.97619 0.18788 lineto
stroke
0.02224 setlinewidth
0.97619 0.18788 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
The Unformatted text for this cell was not generated.
Use options in the Actions Settings dialog box to control
when Unformatted text is generated.
;[o]
-Graphics-
:[font = section; inactive; startGroup; Cclosed; ]
Summary
:[font = text; inactive; ]
		The discrete-time Fourier transform (DTFT) is useful in analyzing many but not all sequences.  It is best-suited for sequences that are responses of linear systems.  However, not all sequences have a DTFT.   In fact, some sequences have a DTFT but not a z-transform and visa-versa (this is anomaly is discussed in the first z-transform notebook).
:[font = text; inactive; ]
		The DTFT maps a discrete function (sequence) into a continuous frequency domain which is periodic with period 2 Pi.  Sampling one period of the DTFT frequency domain at equally spaced samples yields the familiar discrete Fourier transform (DFT).
:[font = text; inactive; endGroup; ]
		Mathematica provides a numerical DFT called Fourier and InverseFourier.   The signal processing packages introduce the symbolic DFT and DTFT transforms DTFTransform, InvDTFTransform, DFTransform, and InvDFTransform.  These signal processing extensions also provide the routines SignalPlot, SequencePlot, and MagPhasePlot to plot signals, sequences, and frequency responses, respectively.  For more information on the implementation of concepts in digital signal processing, we invite you to read the piecewise convolution Notebook and the three-part z-transform notebook. or the articles [Evans, 1990; Evans, 1991; Evans, 1992].
:[font = section; inactive; startGroup; Cclosed; ]
References
:[font = subsection; inactive; startGroup; Cclosed; ]
[Dudgeon & Mersereau, 1984]
:[font = text; inactive; endGroup; ]
D. E. Dudgeon and R. M. Mersereau. 1984.  {Multidimensional Digital Signal Processing}.  Prentice Hall, Englewood Cliffs (NJ).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Evans, 1990]
:[font = text; inactive; endGroup; ]
B. L. Evans, J. H. McClellan, and W. B. McClure.  1990.  "Symbolic Transforms with Application to Signal Processing."  {The Mathematica Journal}.  Fall, 1990.  vol. 1, issue #2, pp. 70-80.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Evans, 1991]
:[font = text; inactive; endGroup; ]
B. L. Evans, J. H. McClellan, and K. A. West.  "Mathematica As An Educational Tool for Signal Processing".  Proc. of IEEE Southeastern Conference.  April, 1991.  pp. 1172-1176.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Evans, 1992]
:[font = text; inactive; endGroup; ]
B. L. Evans and J. H. McClellan.  1992.  "Symbolic Analysis of Signals and Systems."  ch. 3 of Symbolic and Knowledge-Based Signal Processing.  ed. by A. Oppenheim and H. Nawab.  Prentice-Hall, Englewood Cliffs (NJ).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Lathi, 1983]
:[font = text; inactive; endGroup; ]
B. P. Lathi. 1983.  {Modern Digital and Analog Communication Systems}.  Holt, Rinehart, and Winston, New York.
:[font = subsection; inactive; startGroup; Cclosed; ]
[Oppenheim & Schafer, 1989]
:[font = text; inactive; endGroup; ]
A. V. Oppenheim and R. W. Schafer. 1989.  {Discrete-Time Signal Processing}.  Prentice Hall, Englewood Cliffs (NJ).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Oppenheim & Willsky, 1983]
:[font = text; inactive; endGroup; ]
A. V. Oppenheim and A. Willsky. 1983.  {Signals and Systems}.  Prentice Hall, Englewood Cliffs (NJ).
:[font = subsection; inactive; startGroup; Cclosed; ]
[Smith & Mersereau, 1992]
:[font = text; inactive; endGroup; endGroup; ]
M. J. T. Smith and R. M. Mersereau.  1992.  {Introduction to Digital Signal Processing: A Computer Laboratory Textbook}.  John Wiley & Sons, Inc., New York.
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract DAAL-03-90-C-0004.  
^*)