(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
The z-Transform
:[font = special2; inactive; ]
Part I:
Definition, Stability, and Causality
:[font = subtitle; inactive; ]
by 
Lina J. Karam
with
Brian L. Evans and James H. McClellan
:[font = subsubtitle; inactive; ]

Digital Signal Processing  Laboratory
   School of Electrical Engineering
  Georgia Institute of Technology
  Atlanta, GA  30332-0250
  
  EMAIL:  evans@eedsp.gatech.edu
:[font = message; inactive; center; ]
This notebook has been divided into
three parts because of its size
:[font = text; inactive; ]
	This notebook is a highly interactive tutorial on the z-transform.  In addition to discussing the basic theoretical concept behind the z-transform, this notebook provides users with means to evaluate z-transforms and inverse z-transforms, to observe changes in parameters in the examples by animation, and to visualize z-transforms graphically.
:[font = text; inactive; ]
	This notebook automatically loads the needed Digital Signal Processing packages by executing the Needs command in the Initialization section.  Under Mathematica 1.2, the entire initialization process may take a few minutes. 
:[font = text; inactive; ]
	A Notebook is completely defined by a portable ASCII file but  machine-dependent binary information (bitmaps, etc.) is generated as side information to speed up the display of parts of the Notebook.   Mathematica 1.2 generates missing side information as needed whereas Mathematica 2.0 and higher generates all missing side information when a Notebook is opened.    Mathematica 2.0 and higher will display the message "Rendering ..." in the header of the Notebook when it is generating bitmaps for PostScript graphics contained in the Notebook.  This particular Notebook contains 30 or so graphics cells whose bitmaps will require an 600 kb of memory (30 cells x 20 kb/cell) to store.  The ASCII version of this Notebook occupies 250 kb.
:[font = text; inactive; ]
	As a reminder, in order to open a section below, just move the mouse to the downward-pointing arrow and double click. To get help information for any command, place the cursor in an input cell and type ?Command (like ?ZTransform).
:[font = special1; inactive; ]

Table of Contents

:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = input; initialization; startGroup; Cclosed; ]
*)
Needs [ "SignalProcessing`Digital`" ]
(*
:[font = print; inactive; ]
Loading the signal processing support packages ...
:[font = print; inactive; ]
Support module has been loaded.
:[font = print; inactive; ]
Supporting routines for filter design are loaded.
:[font = print; inactive; ]
The knowledge base of signal processing operators has been\
 
  loaded.
:[font = print; inactive; ]
Region of convergence routines for the transform rule\
 
  bases are loaded.
:[font = print; inactive; ]
Supporting routines for transform rule bases are loaded.
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically
    loaded (the signal processing packages no longer rely
    on the definitions in these files).
:[font = print; inactive; ]
Loading in the digital signal processing packages ...
:[font = print; inactive; ]
Supporting routines for the z-transform rule bases are\
 
  loaded.
:[font = print; inactive; ]
The supporting functions are loaded for symbolic Fourier\
 
  transforms.
:[font = print; inactive; ]
The forward z-transform rules have been loaded.
:[font = print; inactive; ]
The inverse z-transform rules have been loaded.
:[font = print; inactive; ]
The discrete-time Fourier transform (DTFT) rule bases are\
 
  loaded.
:[font = print; inactive; ]
Correlation functions are now loaded.
:[font = print; inactive; ]
ZSolve, a difference equation solver, is loaded.
:[font = print; inactive; ]
The digital signal analyzer is now loaded.
:[font = print; inactive; ]
The discrete Fourier transform (DFT) rule bases are\
 
  loaded.
:[font = message; inactive; ]
Digital::loaded: 
   Routines, objects, and rules for the digital signal
    processing package have been loaded successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
The digital signal processing extensions has been loaded.
:[font = print; inactive; ]
Good starting points are the objects DSPAnalyze and\
 
  ZTransform.
:[font = print; inactive; ]
Active packages are maintained in the variable\
 
  $ContextPath.
:[font = print; inactive; ]
  New signal primitives are in SPsignals.
:[font = print; inactive; ]
  New system primitives are in SPoperators.
:[font = print; inactive; ]
  New Mathematica functions are in SPfunctions.
:[font = print; inactive; ]
Note that all signal processing expressions will
:[font = print; inactive; ]
be automatically simplified.
:[font = print; inactive; endGroup; ]

:[font = input; initialization; ]
*)
AllPoleZeroPlots[ trans_, z_ ]:= 
   Block[ {i, numrocs, key,key1,key2, polelist, roclist}, 
             polelist = GetRootList [ Denominator[trans], z ]; 
             roclist = Join[ {0}, Sort[ Abs[polelist] ], {Infinity}];
             numrocs = Length [roclist];
            i = 1; 
             key1 = "";
             While [ (key1 != "y") && (key1 != "n"),
                   key1 = ToString [ Input[ "\
                            Want Inverse Z Transform (y/n)?"]]];
           While [ True, 
             key = "a";
             Print[" ROC # ", i];  
             PoleZeroPlot [trans, z, roclist[[i]], roclist[[i+1]],
                                  True];
             if [key1 === "y", Print[" The time sequence is: ", 
                           InvZTransform[{trans,roclist[[i]],roclist[[i+1]]},
                                         z,n,Dialogue -> False]]];                       
            While [ ! MemberQ[{"n","p","f","l","q","s"}, key ],                     
             key = ToString[ Input["PRESS THE FOLLOWING KEYS FOLLOWED\
                   BY A CARRIAGE RETURN: \n
 n : NEXT ROC - \
 p : PREVIOUS ROC - \n
 f : FIRST ROC - \
 l : LAST ROC - \n
 s : SAME - q : QUIT " ]];                
                   If [ (key === "n"),
                     If [i < (numrocs - 1), i = i + 1, i = 1 ] ];
                   If [ (key === "p"),
                      If [ i > 1, i = i - 1, i = numrocs - 1] ];
                   If [ key === "f", i = 1 ];
                   If [ key === "l", i = numrocs - 1];       
                   If [ key  === "q",
                           key2 = "";
                           While [ (key2 != "y") && (key2 != "n"),
                                 key2 = ToString [ Input[ "         \
                                            QUIT (y/n)?"]]
                                 ];
                           If [key2 === "n", key = "a" ]
                      ]
                     ];
                     If [key2 === "y", Break[] ] 
                  ];
             Print[" End of ROCs ! "]
        ]              
(*
:[font = input; initialization; endGroup; ]
*)

(*  InvalidZPoleQ  *)
InvalidZPoleQ[rminus_, r_, rplus_] := TrueQ[rminus < Abs[N[r]] < rplus]

(*  MyRationalPolyQ  *)
MyRationalPolyQ[f_, z_] :=
	MixedPolynomialQ[ Expand[Numerator[f]], z ] &&
	MixedPolynomialQ[ Expand[Denominator[f]], z ]

(*  One-dimensional pole-zero plotting in the z-domain  *)
VectorPoleZeroPlot[f_, z_Symbol, rm_, rp_, w_, True, op___] :=	
	Block [ {abspolelist, fillplot, invalidROClist, options, polelist,
		 poleplot, vectorsplot, polezerolist, rmax, rminus, rplus, 
		 rminuscircle,rpluscircle, unitcircle, xlabel, ylabel, dot, 
		 zeroplot, zstr, ztrans},

		options = ToList[op] ~Join~ Options[PoleZeroPlot];

		rmax = 1;				  (* default values *)
		unitcircle = CirclePS[1];

		(*  Analyze the z-transform function  *)

		ztrans = Together[f];
		If [ ! MyRationalPolyQ[ztrans, z],
		     Message[ PoleZeroPlot::notrational ] ];

		zerolist = GetRootList[Numerator[ztrans], z];
		polelist = GetRootList[Denominator[ztrans], z];
		If [ InformUserQ[Replace[Dialogue, options]],
		     Print[ " " ];
		     Print[ "The zeroes are:  ", zerolist ];
		     Print[ "The poles are:   ", polelist ] ];

		(*  Check consistency of poles with region of convergence  *)
		(*  Exit function if inconsistency encountered		   *)

		rminus = N[rm];			  (* numeric approximation *)
		rplus = N[rp];
		invalidROClist = Select[ polelist,
					 InvalidZPoleQ[rminus, #1, rplus]& ];
		If [ ! SameQ[invalidROClist, {}],
		     Message[PoleZeroPlot::invalidROC, invalidROClist, rm, rp];
		     Return[polelist] ];

		(*  Compute plot of poles and zeroes		*)
		(*  Determine the plot's its circular extent	*)

		rmax = Max[ Join[ {rmax},
				  Map[Abs, ToList[N[zerolist]]],
				  Map[Abs, ToList[N[polelist]]] ] ];

		zeroplot = If [ EmptyQ[zerolist],
		     	        NullPlot,
				PointwisePlot[ComplexTo2DCoordList[zerolist],
					      "O", "*O*"] ];

		poleplot = If [ EmptyQ[polelist],
				NullPlot,
				PointwisePlot[ComplexTo2DCoordList[polelist],
					      "X", "*X*"] ];
        (* Draw pole and zero vectors *)
         polezerolist = zerolist ~Join~ polelist;
         vectorsplot = Graphics[Map[Line[{{Cos[w],Sin[w]}, #1}]&,
                                ComplexTo2DCoordList[polezerolist]]];
         dot = Graphics[{PointSize[0.05], Point[{Cos[w],Sin[w]}]}];
        
		(*  Build region of convergence plot  *)
		If [ NumberQ[rminus],
		     rminuscircle = CirclePS[ rminus, Dashing[{0.05,0.05}] ];
			 rmax = Max[rmax, Abs[rminus]],
		     rminuscircle = NullPlot ];

		If [ NumberQ[rplus],
		     rpluscircle = CirclePS[ rplus, Dashing[{0.05,0.05}] ];
			 rmax = Max[rmax, Abs[rplus]],
		     rpluscircle = NullPlot ];

		rplus = N[ If[ SameQ[rp, Infinity], 2 rmax, rp] ];  (* kludge *)

		fillplot = If [ NumberQ[rminus] && NumberQ[rplus],
				ShadedAnnulus[rminus, rplus],
				NullPlot ];

		(*  Send the contour plot to the screen  *)
		rmax *= 1.25;
		zstr = StripPackage[z];
		xlabel = "Re " ~StringJoin~ zstr;
		ylabel = "Im " ~StringJoin~ zstr;

		Show [unitcircle, rminuscircle, rpluscircle,
		      fillplot, zeroplot, poleplot, vectorsplot, dot,
		      PlotRange -> {{-rmax, rmax}, {-rmax, rmax}},
		      AspectRatio -> Automatic,
		      AxesLabel -> { xlabel, ylabel },
		      Axes -> Automatic,
		      DisplayFunction -> $DisplayFunction ];

		polelist ]
(*
:[font = section; inactive; startGroup; Cclosed; ]
Introduction
:[font = text; inactive; endGroup; ]
 		The z-transform for discrete-time signals is the counterpart of the Laplace transform for continuous-time signals. One of the main advantages of the z-transform is that it uses the power of complex variable theory in solving the problems of discrete-time signals and systems.  Furthermore, the z-transform is, in a certain sense, a "generalization" of the discrete-time Fourier transform (DTFT) in that the DTFT can, in many (but not all) cases, be obtained from the z-transform by simple algebraic substitution of variables.
:[font = section; inactive; startGroup; Cclosed; ]
Definition of the z-Transform
:[font = text; inactive; ]
		The z-transform X(z) of a sequence x[n] is defined as follows:
:[font = postscript; inactive; PostScript; output; pictureLeft = 163; pictureWidth = 133; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.353384 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.353384 scale
1 string
133 47 1 [133 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8E3FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8FF80001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1FFFFFFFFFFFFF81C0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1F80001C0000FC7E3F
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFFFFFFFF81C0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFE3FFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFE07FFF
FFFFFF000FFFFFFFF8007FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFC7FFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFC7FFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFF8FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFE
0001C0000FF8FFF00003FFF8FFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF8
1FF03F1FFFC0FF803FFC7FF80001FFFFFFFFFFFE
FC0FFF007FC0FFF03FE3FFF81FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFF
0380071FFFC0FF81C7FC7FF81FF1FFFFFFFFFFFE
FF8FFF03FFC0FFFE07FFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFF
E381FF1FFFC0FF81FFFC7FFF03FFFFFFFFFFFFFE
FFF1FF03FFC0FFFFC0FFFFF81FFFC0000007FFFFFFFFFFFFFFFE3FFFFFFF
E00FFF1FFFC0FF81FFFC7FFFE07FFFFFFFFFFFFE
FFFE381FFFC0FFFFF81FFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF
FC0FFF1FFFF81FF03FFC7FFFFC0FFFFFFFFFFFFE
FFFE001FFFC0FFFFFF03FFF81FFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF
E001FF1FFFF803F03FFC7FFFFF81FFFFFFFFFFFE
FFFFC0FFFFC0FFFE3FE07FF81FFFC0000007FFFFFFFFFFFFFF81FFFFFFFF
E0703F1FFFF81C003FFC7FFF1FF03FFFFFFFFFFE
FFFFC0FFFFF8FFFE00007FF8FFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFF
007E071FFFC01F81FFFC7FFF00003FFFFFFFFFFE
FFFE001FFFF8FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFC7E07E
FFFE07E3FFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFC7E38E
FFF007E07FFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFF81FFFFFFC7FFF
FFFFFF1FFFFFFFFFFFFC7FFFFFFFFFFFFFC7E3FE
FFF03FFC0FFFE3FFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFC7FFF
FFFFFF000FFFFFFFF8007FFFFFFFFFFFFFF8FC7E
FC0000E0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFE07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF80001F8FC7E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0703FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8FC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0703FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
Z is the z-transform operator and z is a continuous complex variable. The notation
:[font = subsubtitle; inactive; ]
x[n] <-------> X(z)
:[font = text; inactive; ]
is commonly used to indicate the correspondence between a sequence and its z-transform.  Note that the z-transform, as defined by (1), is commonly referred to as the "two-sided" or "bilateral" z-transform.  The "one-sided" or "unilateral" transform is defined as follows:
:[font = postscript; inactive; PostScript; output; pictureLeft = 142; pictureWidth = 168; pictureHeight = 40; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.238095 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.238095 scale
1 string
168 40 1 [168 0 0 40 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000FFFFC0FFF03FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00001FFFC01F8007FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF1FFFFF03F038FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFF03F1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFC7E3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFC7E3FFFFFFF
007FC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFE38FC7FF81FF
E3FFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFE000001FF03F
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF800003FE3F
FC71FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFE3FFC01FFFFFFFFFFFFFFE3F
FC003FFFFFFFFFFFFFFC7FFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFC0000FFFFFFFFFFFFFFFE3F
FC7FC7FFFFFFFFFFFFE3FFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFFFE3F
FF8FF8FFFFFFFFFFFFE3FFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FF8FF8FFFFFFFFFFFF1FFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
E07FC0FC7FFFE07FC01FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FC0007E000380001FF1FFE00007FFF1FF00003FFFFFFFFFFFFFFFFE07E07
00003F
FC0E001C7FFFE07FC0E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFF81FFE00FF81FFE07FC7FFF03F03FE3FFFFFFFFFFFFFFF8038038
03FE3F
FF8E07FC7FFFE07FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007
FFFFFFFFF1FFE07FF81FFFC0FFFFFF03FE07FFFFFFFFFFFFFFFFF81FF03F
E07FFF
FF803FFC7FFFE07FC0FFF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFF8E38
FFFFFFFFFE3FE07FF81FFFF81FFFFF03FFC0FFFFFFFFFFFFFFFFF81FF03F
FC0FFF
FFF03FFC7FFFFC0FF81FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E3F
1FFFFFFFFFC703FFF81FFFFF03FFFF03FFF81FFFFFFFFFFFFFFFF81FFE3F
FF81FF
FF8007FC7FFFFC01F81FF1FFFFFFFFFFFFFFE00000000000000007FC7E3F
1FFFFFFFFFC003FFF81FFFFFE07FFF03FFFF03FFFFFFFFFFFFFFFF1FFE07
FFF03F
FF81C0FC7FFFFC0E001FF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFC7E3F
1FFFFFFFFFF81FFFF81FFFC7FC0FFF03FE3FE07FFFFFFFFFFFFFFF03F007
E3FE07
FC01F81C7FFFE00FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E38
FFFFFFFFFFF81FFFFF1FFFC0000FFF1FFE00007FFFFFFFFFFFFFFFFC01C7
E00007
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007
FFFFFFFFFFC003FFFF1FFFFFFFFFFF1FFFFFFFF1F81FFFFFE00FFFFFFFC7
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFFFFC0FC7FFFE3FFFFFFFFF8FFFFFFFFF1F8E3FFFFFC7FFFFFFFC0
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFFFE00FC0FFFE3FFFFFFFFF8FFFFFFFFF1F8FFFFFFFC7FFFFFFFC0
FFFFFF
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFFFE07FF81FFFC7FFFFFFFC7FFFFFFFFFE3F1FFFFFFC7FFFFFFFC0
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00003FFFFFFFFFFE3F
FFFFFFFF80001C0007FFFFFFFFFFFFFFFFFFFFFE3F1C0000FC7FFFFFFE00
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFE3F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFC7FFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFE3F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFE07
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
Whereas the unilateral z-transform is important in solving initial value problems (where n = 0 is the initial point), the bilateral z-transform is useful for digital filter design and implementation.
:[font = subsection; inactive; startGroup; Cclosed; ]
Region of Convergence 
:[font = text; inactive; ]
	The  bilateral z-transform, defined by above, does not converge for all sequences or for all values of z (i.e., the infinite sum may not always be finite).  Hence, for any given sequence, the set of values of z for which the z-transform converges is called the region of convergence (ROC). 
	The power series defining the z-transform converges if and only if                    
:[font = postscript; inactive; PostScript; output; pictureLeft = 163; pictureWidth = 123; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.382114 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.382114 scale
1 string
123 47 1 [123 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
1F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
1F8E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
1F8FF80001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
E3F1FFFFFFFFFFFFF81C0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
E3F1F80001C0000FC7E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
1C0FFFFFFFFFFFFFF81C0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFF000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFE00000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFC7FFFFFFE07FFFFFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFF8FFFFFFFC7FC7FFFFFFFC7FFFFFFFFFFFF1C7FFF1FFFFFFF8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFF1FFFFFFC7FC7FFFFFFFC7FFFFFFFFFFFF1C7FFF1FFFFFFF8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFE3FFFFFFFFC7FFFFFFFC7FFFFFFFFFFFF1C7FFF1FFFFFFF8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFC7FFFFFFFC7E07FC0FC7FFF03FE00FFF1C7FFF1C0000FF8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFF8FFFFFFFC7FC0E001C7FFF03FE071FF1C7FFF1C0FF8FF8FFF
FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF80
FFFFFFFFFFFF1FFFFFFC7FF8E07FC7FFF03FE07FFF1C7FFF1F81FFFF8FFF
FFFFFFFFFFFFFC0FFFFFFE00FFF007FF80
FFFFFFFFFFFFE3FFFFFC7FF803FFC7FFF03FE07FFF1C7FFF1FF03FFF8FFF
FFFFFFFFFFFF03FFFFFFF1FF1F8FF8FF80
FFFFFFFFFFFFE07FFFFC7FFF03FFC7FFFE07FC0FFF1C7FFF1FFE07FF8FFF
FFFFFFFFFFC0FFFFFFFFF1FFE07FF8FF80
FFFFFFFFFFFF03FFFFFC7FF8007FC7FFFE00FC0FFF1C7FFF1FFFC0FF8FFF
FFFFFFFFFFFF03FFFFFFF1FF1F8FF8FF80
FFFFFFFFFFF81FFFFFFC7FF81C0FC7FFFE07000FFF1C7FFF1F8FF81F8FFF
FFFFFFFFFFFFFC0FFFFFFE00FFF007FF80
FFFFFFFFFFC0FFFFFFFC7FC01F81C7FFF007E07FFF1C7FFF1F80001F8FFF
FFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF80
FFFFFFFFFE07FFFFFFFC7FFFFFFFC7FFFFFFFFFFFF1C7FFF1FFFFFFF8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFF03FFFFFFFFC7FFFFFFFC7FFFFFFFFFFFF1C7FFF1FFFFFFF8FFF
FFF1F81FFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFF81FFFFFFC7FC7FFFFFFFC7FFFFFFFFFFFF1C7FFF1FFFFFFF8FFF
FFF1F8E3FFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFC0FFFFFFFC7FC7FFFFFFFC003FFFFFFFE001C7FFF1FFFFFFF8FFF
FFF1F8FFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFE07FFFFFFE07FC7FFFFFFFFFFFFFFFFFFFFFFC7FFF1FFFFFFF8FFF
FFFE3F1FFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFF000000000007FC7FFFFFFFFFFFFFFFFFFFFFFC7FFF1FFFFFFF8E00
007E3F1FFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1C0FFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFE0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFF1F8FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFE0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
It follows that the ROC of X(z) consists of all values of z such that  above inequality holds. Note that if some value of z, e.g. z = a, is in the ROC then all values of z on the circle defined by |z| = |a| will also be in the ROC. Consequently, the ROC is an annular connected region centered at the origin that does not contain any poles (in pole-zero diagrams, the ROC is usually shaded).  The inner radius can be 0 or a positive number, and the outer radius is a positive number or infinity.  This means that every ROC falls into one of three categories:
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Open Disk
:[font = postscript; inactive; PostScript; locked; output; endGroup; height = 282; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.16667 0.5 0.16667 [
[(-3)] 0 0.4875 0 1 Msboxa
[(-2)] 0.16667 0.4875 0 1 Msboxa
[(-1)] 0.33333 0.4875 0 1 Msboxa
[(1)] 0.66667 0.4875 0 1 Msboxa
[(2)] 0.83333 0.4875 0 1 Msboxa
[(3)] 1 0.4875 0 1 Msboxa
[(-3)] 0.4875 0 1 0 Msboxa
[(-2)] 0.4875 0.16667 1 0 Msboxa
[(-1)] 0.4875 0.33333 1 0 Msboxa
[(1)] 0.4875 0.66667 1 0 Msboxa
[(2)] 0.4875 0.83333 1 0 Msboxa
[(3)] 0.4875 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0 0.49375 moveto
0 0.50625 lineto
stroke
0 setgray
[(-3)] 0 0.4875 0 1 Mshowa
0.16667 0.49375 moveto
0.16667 0.50625 lineto
stroke
0 setgray
[(-2)] 0.16667 0.4875 0 1 Mshowa
0.33333 0.49375 moveto
0.33333 0.50625 lineto
stroke
0 setgray
[(-1)] 0.33333 0.4875 0 1 Mshowa
0.66667 0.49375 moveto
0.66667 0.50625 lineto
stroke
0 setgray
[(1)] 0.66667 0.4875 0 1 Mshowa
0.83333 0.49375 moveto
0.83333 0.50625 lineto
stroke
0 setgray
[(2)] 0.83333 0.4875 0 1 Mshowa
1 0.49375 moveto
1 0.50625 lineto
stroke
0 setgray
[(3)] 1 0.4875 0 1 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-3)] 0.4875 0 1 0 Mshowa
0.49375 0.16667 moveto
0.50625 0.16667 lineto
stroke
0 setgray
[(-2)] 0.4875 0.16667 1 0 Mshowa
0.49375 0.33333 moveto
0.50625 0.33333 lineto
stroke
0 setgray
[(-1)] 0.4875 0.33333 1 0 Mshowa
0.49375 0.66667 moveto
0.50625 0.66667 lineto
stroke
0 setgray
[(1)] 0.4875 0.66667 1 0 Mshowa
0.49375 0.83333 moveto
0.50625 0.83333 lineto
stroke
0 setgray
[(2)] 0.4875 0.83333 1 0 Mshowa
0.49375 1 moveto
0.50625 1 lineto
stroke
0 setgray
[(3)] 0.4875 1 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.66667 0.5 moveto
0.66666 0.50136 lineto
0.66664 0.50273 lineto
0.66662 0.50409 lineto
0.66658 0.50545 lineto
0.66653 0.50682 lineto
0.66647 0.50818 lineto
0.66631 0.5109 lineto
0.66611 0.51362 lineto
0.66586 0.51634 lineto
0.66524 0.52175 lineto
0.66444 0.52715 lineto
0.66346 0.53252 lineto
0.66099 0.54314 lineto
0.65782 0.55357 lineto
0.65398 0.56378 lineto
0.64434 0.58333 lineto
0.63223 0.60146 lineto
0.61785 0.61785 lineto
0.60146 0.63223 lineto
0.58333 0.64434 lineto
0.57371 0.64948 lineto
0.56378 0.65398 lineto
0.55357 0.65782 lineto
0.54314 0.66099 lineto
0.53252 0.66346 lineto
0.52715 0.66444 lineto
0.52175 0.66524 lineto
0.51634 0.66586 lineto
0.51362 0.66611 lineto
0.5109 0.66631 lineto
0.50818 0.66647 lineto
0.50682 0.66653 lineto
0.50545 0.66658 lineto
0.50409 0.66662 lineto
0.50273 0.66664 lineto
0.50136 0.66666 lineto
0.5 0.66667 lineto
0.49864 0.66666 lineto
0.49727 0.66664 lineto
0.49591 0.66662 lineto
0.49455 0.66658 lineto
0.49182 0.66647 lineto
0.4891 0.66631 lineto
0.48638 0.66611 lineto
0.48366 0.66586 lineto
0.47825 0.66524 lineto
0.47285 0.66444 lineto
0.46748 0.66346 lineto
0.45686 0.66099 lineto
Mistroke
0.44643 0.65782 lineto
0.43622 0.65398 lineto
0.41667 0.64434 lineto
0.39854 0.63223 lineto
0.38215 0.61785 lineto
0.36777 0.60146 lineto
0.35566 0.58333 lineto
0.34602 0.56378 lineto
0.34218 0.55357 lineto
0.33901 0.54314 lineto
0.33654 0.53252 lineto
0.33556 0.52715 lineto
0.33476 0.52175 lineto
0.33414 0.51634 lineto
0.33389 0.51362 lineto
0.33369 0.5109 lineto
0.33353 0.50818 lineto
0.33347 0.50682 lineto
0.33342 0.50545 lineto
0.33338 0.50409 lineto
0.33336 0.50273 lineto
0.33334 0.50136 lineto
0.33333 0.5 lineto
0.33334 0.49864 lineto
0.33336 0.49727 lineto
0.33338 0.49591 lineto
0.33342 0.49455 lineto
0.33353 0.49182 lineto
0.33369 0.4891 lineto
0.33389 0.48638 lineto
0.33414 0.48366 lineto
0.33476 0.47825 lineto
0.33556 0.47285 lineto
0.33654 0.46748 lineto
0.33901 0.45686 lineto
0.34218 0.44643 lineto
0.34602 0.43622 lineto
0.35566 0.41667 lineto
0.36777 0.39854 lineto
0.38215 0.38215 lineto
0.39854 0.36777 lineto
0.41667 0.35566 lineto
0.42629 0.35052 lineto
0.43622 0.34602 lineto
0.44643 0.34218 lineto
0.45686 0.33901 lineto
0.46748 0.33654 lineto
0.47285 0.33556 lineto
0.47825 0.33476 lineto
0.48366 0.33414 lineto
Mistroke
0.48638 0.33389 lineto
0.4891 0.33369 lineto
0.49182 0.33353 lineto
0.49318 0.33347 lineto
0.49455 0.33342 lineto
0.49591 0.33338 lineto
0.49727 0.33336 lineto
0.49864 0.33334 lineto
0.5 0.33333 lineto
0.50136 0.33334 lineto
0.50273 0.33336 lineto
0.50409 0.33338 lineto
0.50545 0.33342 lineto
0.50818 0.33353 lineto
0.5109 0.33369 lineto
0.51362 0.33389 lineto
0.51634 0.33414 lineto
0.52175 0.33476 lineto
0.52715 0.33556 lineto
0.53252 0.33654 lineto
0.54314 0.33901 lineto
0.55357 0.34218 lineto
0.56378 0.34602 lineto
0.58333 0.35566 lineto
0.60146 0.36777 lineto
0.61785 0.38215 lineto
0.63223 0.39854 lineto
0.64434 0.41667 lineto
0.64948 0.42629 lineto
0.65398 0.43622 lineto
0.65782 0.44643 lineto
0.66099 0.45686 lineto
0.66346 0.46748 lineto
0.66444 0.47285 lineto
0.66524 0.47825 lineto
0.66586 0.48366 lineto
0.66611 0.48638 lineto
0.66631 0.4891 lineto
0.66647 0.49182 lineto
0.66653 0.49318 lineto
0.66658 0.49455 lineto
0.66662 0.49591 lineto
0.66664 0.49727 lineto
0.66666 0.49864 lineto
0.66667 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.65662 0.557 moveto
0.34338 0.443 lineto
stroke
0.65321 0.56562 moveto
0.34046 0.45179 lineto
stroke
0.64931 0.57405 moveto
0.33802 0.46075 lineto
stroke
0.64492 0.58231 moveto
0.33607 0.4699 lineto
stroke
0.64003 0.59038 moveto
0.33463 0.47923 lineto
stroke
0.63462 0.59826 moveto
0.33371 0.48874 lineto
stroke
0.62866 0.60595 moveto
0.33334 0.49846 lineto
stroke
0.62212 0.61342 moveto
0.33354 0.50839 lineto
stroke
0.61496 0.62067 moveto
0.33437 0.51854 lineto
stroke
0.60713 0.62767 moveto
0.33587 0.52894 lineto
stroke
0.59855 0.63441 moveto
0.33811 0.53961 lineto
stroke
0.58913 0.64083 moveto
0.3412 0.55059 lineto
stroke
0.57873 0.6469 moveto
0.34526 0.56192 lineto
stroke
0.56716 0.65254 moveto
0.35051 0.57368 lineto
stroke
0.5541 0.65764 moveto
0.35723 0.58598 lineto
stroke
0.53907 0.66202 moveto
0.36592 0.599 lineto
stroke
0.52108 0.66533 moveto
0.37758 0.6131 lineto
stroke
0.49764 0.66665 moveto
0.39469 0.62918 lineto
stroke
0.60531 0.37082 moveto
0.50236 0.33335 lineto
stroke
0.62242 0.3869 moveto
0.47892 0.33467 lineto
stroke
0.63408 0.401 moveto
0.46093 0.33798 lineto
stroke
0.64277 0.41402 moveto
0.4459 0.34236 lineto
stroke
0.64949 0.42632 moveto
0.43284 0.34746 lineto
stroke
0.65474 0.43808 moveto
0.42127 0.3531 lineto
stroke
0.6588 0.44941 moveto
0.41087 0.35917 lineto
stroke
0.66189 0.46039 moveto
0.40145 0.36559 lineto
stroke
0.66413 0.47106 moveto
0.39287 0.37233 lineto
stroke
0.66563 0.48146 moveto
0.38504 0.37933 lineto
stroke
0.66646 0.49161 moveto
0.37788 0.38658 lineto
stroke
0.66666 0.50154 moveto
0.37134 0.39405 lineto
stroke
0.66629 0.51126 moveto
0.36538 0.40174 lineto
stroke
0.66537 0.52077 moveto
0.35997 0.40962 lineto
stroke
0.66393 0.5301 moveto
0.35508 0.41769 lineto
stroke
0.66198 0.53925 moveto
0.35069 0.42595 lineto
stroke
0.65954 0.54821 moveto
0.34679 0.43438 lineto
stroke
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Annulus, or
:[font = postscript; inactive; PostScript; locked; output; endGroup; height = 282; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.16667 0.5 0.16667 [
[(-3)] 0 0.4875 0 1 Msboxa
[(-2)] 0.16667 0.4875 0 1 Msboxa
[(-1)] 0.33333 0.4875 0 1 Msboxa
[(1)] 0.66667 0.4875 0 1 Msboxa
[(2)] 0.83333 0.4875 0 1 Msboxa
[(3)] 1 0.4875 0 1 Msboxa
[(-3)] 0.4875 0 1 0 Msboxa
[(-2)] 0.4875 0.16667 1 0 Msboxa
[(-1)] 0.4875 0.33333 1 0 Msboxa
[(1)] 0.4875 0.66667 1 0 Msboxa
[(2)] 0.4875 0.83333 1 0 Msboxa
[(3)] 0.4875 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0 0.49375 moveto
0 0.50625 lineto
stroke
0 setgray
[(-3)] 0 0.4875 0 1 Mshowa
0.16667 0.49375 moveto
0.16667 0.50625 lineto
stroke
0 setgray
[(-2)] 0.16667 0.4875 0 1 Mshowa
0.33333 0.49375 moveto
0.33333 0.50625 lineto
stroke
0 setgray
[(-1)] 0.33333 0.4875 0 1 Mshowa
0.66667 0.49375 moveto
0.66667 0.50625 lineto
stroke
0 setgray
[(1)] 0.66667 0.4875 0 1 Mshowa
0.83333 0.49375 moveto
0.83333 0.50625 lineto
stroke
0 setgray
[(2)] 0.83333 0.4875 0 1 Mshowa
1 0.49375 moveto
1 0.50625 lineto
stroke
0 setgray
[(3)] 1 0.4875 0 1 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-3)] 0.4875 0 1 0 Mshowa
0.49375 0.16667 moveto
0.50625 0.16667 lineto
stroke
0 setgray
[(-2)] 0.4875 0.16667 1 0 Mshowa
0.49375 0.33333 moveto
0.50625 0.33333 lineto
stroke
0 setgray
[(-1)] 0.4875 0.33333 1 0 Mshowa
0.49375 0.66667 moveto
0.50625 0.66667 lineto
stroke
0 setgray
[(1)] 0.4875 0.66667 1 0 Mshowa
0.49375 0.83333 moveto
0.50625 0.83333 lineto
stroke
0 setgray
[(2)] 0.4875 0.83333 1 0 Mshowa
0.49375 1 moveto
0.50625 1 lineto
stroke
0 setgray
[(3)] 0.4875 1 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.83333 0.5 moveto
0.83332 0.50273 lineto
0.83329 0.50545 lineto
0.83323 0.50818 lineto
0.83315 0.51091 lineto
0.83305 0.51363 lineto
0.83293 0.51636 lineto
0.83262 0.5218 lineto
0.83222 0.52724 lineto
0.83173 0.53267 lineto
0.83048 0.54351 lineto
0.82888 0.5543 lineto
0.82693 0.56503 lineto
0.82198 0.58627 lineto
0.81564 0.60715 lineto
0.80796 0.62756 lineto
0.78868 0.66667 lineto
0.76445 0.70292 lineto
0.7357 0.7357 lineto
0.70292 0.76445 lineto
0.66667 0.78868 lineto
0.64743 0.79896 lineto
0.62756 0.80796 lineto
0.60715 0.81564 lineto
0.58627 0.82198 lineto
0.56503 0.82693 lineto
0.5543 0.82888 lineto
0.54351 0.83048 lineto
0.53267 0.83173 lineto
0.52724 0.83222 lineto
0.5218 0.83262 lineto
0.51636 0.83293 lineto
0.51363 0.83305 lineto
0.51091 0.83315 lineto
0.50818 0.83323 lineto
0.50545 0.83329 lineto
0.50273 0.83332 lineto
0.5 0.83333 lineto
0.49727 0.83332 lineto
0.49455 0.83329 lineto
0.49182 0.83323 lineto
0.48909 0.83315 lineto
0.48364 0.83293 lineto
0.4782 0.83262 lineto
0.47276 0.83222 lineto
0.46733 0.83173 lineto
0.45649 0.83048 lineto
0.4457 0.82888 lineto
0.43497 0.82693 lineto
0.41373 0.82198 lineto
Mistroke
0.39285 0.81564 lineto
0.37244 0.80796 lineto
0.33333 0.78868 lineto
0.29708 0.76445 lineto
0.2643 0.7357 lineto
0.23555 0.70292 lineto
0.21132 0.66667 lineto
0.19204 0.62756 lineto
0.18436 0.60715 lineto
0.17802 0.58627 lineto
0.17307 0.56503 lineto
0.17112 0.5543 lineto
0.16952 0.54351 lineto
0.16827 0.53267 lineto
0.16778 0.52724 lineto
0.16738 0.5218 lineto
0.16707 0.51636 lineto
0.16695 0.51363 lineto
0.16685 0.51091 lineto
0.16677 0.50818 lineto
0.16671 0.50545 lineto
0.16668 0.50273 lineto
0.16667 0.5 lineto
0.16668 0.49727 lineto
0.16671 0.49455 lineto
0.16677 0.49182 lineto
0.16685 0.48909 lineto
0.16707 0.48364 lineto
0.16738 0.4782 lineto
0.16778 0.47276 lineto
0.16827 0.46733 lineto
0.16952 0.45649 lineto
0.17112 0.4457 lineto
0.17307 0.43497 lineto
0.17802 0.41373 lineto
0.18436 0.39285 lineto
0.19204 0.37244 lineto
0.21132 0.33333 lineto
0.23555 0.29708 lineto
0.2643 0.2643 lineto
0.29708 0.23555 lineto
0.33333 0.21132 lineto
0.35257 0.20104 lineto
0.37244 0.19204 lineto
0.39285 0.18436 lineto
0.41373 0.17802 lineto
0.43497 0.17307 lineto
0.4457 0.17112 lineto
0.45649 0.16952 lineto
0.46733 0.16827 lineto
Mistroke
0.47276 0.16778 lineto
0.4782 0.16738 lineto
0.48364 0.16707 lineto
0.48637 0.16695 lineto
0.48909 0.16685 lineto
0.49182 0.16677 lineto
0.49455 0.16671 lineto
0.49727 0.16668 lineto
0.5 0.16667 lineto
0.50273 0.16668 lineto
0.50545 0.16671 lineto
0.50818 0.16677 lineto
0.51091 0.16685 lineto
0.51636 0.16707 lineto
0.5218 0.16738 lineto
0.52724 0.16778 lineto
0.53267 0.16827 lineto
0.54351 0.16952 lineto
0.5543 0.17112 lineto
0.56503 0.17307 lineto
0.58627 0.17802 lineto
0.60715 0.18436 lineto
0.62756 0.19204 lineto
0.66667 0.21132 lineto
0.70292 0.23555 lineto
0.7357 0.2643 lineto
0.76445 0.29708 lineto
0.78868 0.33333 lineto
0.79896 0.35257 lineto
0.80796 0.37244 lineto
0.81564 0.39285 lineto
0.82198 0.41373 lineto
0.82693 0.43497 lineto
0.82888 0.4457 lineto
0.83048 0.45649 lineto
0.83173 0.46733 lineto
0.83222 0.47276 lineto
0.83262 0.4782 lineto
0.83293 0.48364 lineto
0.83305 0.48637 lineto
0.83315 0.48909 lineto
0.83323 0.49182 lineto
0.83329 0.49455 lineto
0.83332 0.49727 lineto
0.83333 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.81323 0.61401 moveto
0.65662 0.557 lineto
stroke
0.33802 0.46075 moveto
0.18092 0.40357 lineto
stroke
0.33463 0.47923 moveto
0.17604 0.4215 lineto
stroke
0.33334 0.49846 moveto
0.17215 0.43979 lineto
stroke
0.33437 0.51854 moveto
0.16927 0.45845 lineto
stroke
0.33811 0.53961 moveto
0.16743 0.47749 lineto
stroke
0.34526 0.56192 moveto
0.16668 0.49692 lineto
stroke
0.35723 0.58598 moveto
0.16709 0.51678 lineto
stroke
0.37758 0.6131 moveto
0.16874 0.53709 lineto
stroke
0.443 0.65662 moveto
0.17173 0.55788 lineto
stroke
0.69711 0.76881 moveto
0.17622 0.57922 lineto
stroke
0.67827 0.78166 moveto
0.18239 0.60118 lineto
stroke
0.65746 0.7938 moveto
0.19053 0.62384 lineto
stroke
0.63431 0.80508 moveto
0.20101 0.64737 lineto
stroke
0.60821 0.81528 moveto
0.21445 0.67197 lineto
stroke
0.57814 0.82405 moveto
0.23185 0.69801 lineto
stroke
0.54216 0.83066 moveto
0.25516 0.7262 lineto
stroke
0.49528 0.8333 moveto
0.28938 0.75836 lineto
stroke
0.71062 0.24164 moveto
0.50472 0.1667 lineto
stroke
0.74484 0.2738 moveto
0.45784 0.16934 lineto
stroke
0.76815 0.30199 moveto
0.42186 0.17595 lineto
stroke
0.78555 0.32803 moveto
0.39179 0.18472 lineto
stroke
0.79899 0.35263 moveto
0.36569 0.19492 lineto
stroke
0.80947 0.37616 moveto
0.34254 0.2062 lineto
stroke
0.81761 0.39882 moveto
0.32173 0.21834 lineto
stroke
0.82378 0.42078 moveto
0.30289 0.23119 lineto
stroke
0.557 0.34338 moveto
0.28574 0.24465 lineto
stroke
0.47892 0.33467 moveto
0.27008 0.25866 lineto
stroke
0.4459 0.34236 moveto
0.25576 0.27316 lineto
stroke
0.42127 0.3531 moveto
0.24269 0.2881 lineto
stroke
0.40145 0.36559 moveto
0.23076 0.30347 lineto
stroke
0.38504 0.37933 moveto
0.21994 0.31924 lineto
stroke
0.37134 0.39405 moveto
0.21015 0.33538 lineto
stroke
0.35997 0.40962 moveto
0.20138 0.3519 lineto
stroke
0.35069 0.42595 moveto
0.19359 0.36877 lineto
stroke
0.34338 0.443 moveto
0.18677 0.38599 lineto
stroke
0.80641 0.63123 moveto
0.64931 0.57405 lineto
stroke
0.81908 0.59643 moveto
0.66198 0.53925 lineto
stroke
0.79862 0.6481 moveto
0.64003 0.59038 lineto
stroke
0.82396 0.5785 moveto
0.66537 0.52077 lineto
stroke
0.78985 0.66462 moveto
0.62866 0.60595 lineto
stroke
0.82785 0.56021 moveto
0.66666 0.50154 lineto
stroke
0.78006 0.68076 moveto
0.61496 0.62067 lineto
stroke
0.83073 0.54155 moveto
0.66563 0.48146 lineto
stroke
0.76924 0.69653 moveto
0.59855 0.63441 lineto
stroke
0.83257 0.52251 moveto
0.66189 0.46039 lineto
stroke
0.75731 0.7119 moveto
0.57873 0.6469 lineto
stroke
0.83332 0.50308 moveto
0.65474 0.43808 lineto
stroke
0.74424 0.72684 moveto
0.5541 0.65764 lineto
stroke
0.83291 0.48322 moveto
0.64277 0.41402 lineto
stroke
0.72992 0.74134 moveto
0.52108 0.66533 lineto
stroke
0.83126 0.46291 moveto
0.62242 0.3869 lineto
stroke
0.71426 0.75535 moveto
0.443 0.65662 lineto
stroke
0.82827 0.44212 moveto
0.557 0.34338 lineto
stroke
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.66667 0.5 moveto
0.66666 0.50136 lineto
0.66664 0.50273 lineto
0.66662 0.50409 lineto
0.66658 0.50545 lineto
0.66653 0.50682 lineto
0.66647 0.50818 lineto
0.66631 0.5109 lineto
0.66611 0.51362 lineto
0.66586 0.51634 lineto
0.66524 0.52175 lineto
0.66444 0.52715 lineto
0.66346 0.53252 lineto
0.66099 0.54314 lineto
0.65782 0.55357 lineto
0.65398 0.56378 lineto
0.64434 0.58333 lineto
0.63223 0.60146 lineto
0.61785 0.61785 lineto
0.60146 0.63223 lineto
0.58333 0.64434 lineto
0.57371 0.64948 lineto
0.56378 0.65398 lineto
0.55357 0.65782 lineto
0.54314 0.66099 lineto
0.53252 0.66346 lineto
0.52715 0.66444 lineto
0.52175 0.66524 lineto
0.51634 0.66586 lineto
0.51362 0.66611 lineto
0.5109 0.66631 lineto
0.50818 0.66647 lineto
0.50682 0.66653 lineto
0.50545 0.66658 lineto
0.50409 0.66662 lineto
0.50273 0.66664 lineto
0.50136 0.66666 lineto
0.5 0.66667 lineto
0.49864 0.66666 lineto
0.49727 0.66664 lineto
0.49591 0.66662 lineto
0.49455 0.66658 lineto
0.49182 0.66647 lineto
0.4891 0.66631 lineto
0.48638 0.66611 lineto
0.48366 0.66586 lineto
0.47825 0.66524 lineto
0.47285 0.66444 lineto
0.46748 0.66346 lineto
0.45686 0.66099 lineto
Mistroke
0.44643 0.65782 lineto
0.43622 0.65398 lineto
0.41667 0.64434 lineto
0.39854 0.63223 lineto
0.38215 0.61785 lineto
0.36777 0.60146 lineto
0.35566 0.58333 lineto
0.34602 0.56378 lineto
0.34218 0.55357 lineto
0.33901 0.54314 lineto
0.33654 0.53252 lineto
0.33556 0.52715 lineto
0.33476 0.52175 lineto
0.33414 0.51634 lineto
0.33389 0.51362 lineto
0.33369 0.5109 lineto
0.33353 0.50818 lineto
0.33347 0.50682 lineto
0.33342 0.50545 lineto
0.33338 0.50409 lineto
0.33336 0.50273 lineto
0.33334 0.50136 lineto
0.33333 0.5 lineto
0.33334 0.49864 lineto
0.33336 0.49727 lineto
0.33338 0.49591 lineto
0.33342 0.49455 lineto
0.33353 0.49182 lineto
0.33369 0.4891 lineto
0.33389 0.48638 lineto
0.33414 0.48366 lineto
0.33476 0.47825 lineto
0.33556 0.47285 lineto
0.33654 0.46748 lineto
0.33901 0.45686 lineto
0.34218 0.44643 lineto
0.34602 0.43622 lineto
0.35566 0.41667 lineto
0.36777 0.39854 lineto
0.38215 0.38215 lineto
0.39854 0.36777 lineto
0.41667 0.35566 lineto
0.42629 0.35052 lineto
0.43622 0.34602 lineto
0.44643 0.34218 lineto
0.45686 0.33901 lineto
0.46748 0.33654 lineto
0.47285 0.33556 lineto
0.47825 0.33476 lineto
0.48366 0.33414 lineto
Mistroke
0.48638 0.33389 lineto
0.4891 0.33369 lineto
0.49182 0.33353 lineto
0.49318 0.33347 lineto
0.49455 0.33342 lineto
0.49591 0.33338 lineto
0.49727 0.33336 lineto
0.49864 0.33334 lineto
0.5 0.33333 lineto
0.50136 0.33334 lineto
0.50273 0.33336 lineto
0.50409 0.33338 lineto
0.50545 0.33342 lineto
0.50818 0.33353 lineto
0.5109 0.33369 lineto
0.51362 0.33389 lineto
0.51634 0.33414 lineto
0.52175 0.33476 lineto
0.52715 0.33556 lineto
0.53252 0.33654 lineto
0.54314 0.33901 lineto
0.55357 0.34218 lineto
0.56378 0.34602 lineto
0.58333 0.35566 lineto
0.60146 0.36777 lineto
0.61785 0.38215 lineto
0.63223 0.39854 lineto
0.64434 0.41667 lineto
0.64948 0.42629 lineto
0.65398 0.43622 lineto
0.65782 0.44643 lineto
0.66099 0.45686 lineto
0.66346 0.46748 lineto
0.66444 0.47285 lineto
0.66524 0.47825 lineto
0.66586 0.48366 lineto
0.66611 0.48638 lineto
0.66631 0.4891 lineto
0.66647 0.49182 lineto
0.66653 0.49318 lineto
0.66658 0.49455 lineto
0.66662 0.49591 lineto
0.66664 0.49727 lineto
0.66666 0.49864 lineto
0.66667 0.5 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Complement of a Closed Disk
:[font = postscript; inactive; PostScript; locked; output; endGroup; height = 282; pictureLeft = 58; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.16667 0.5 0.16667 [
[(-3)] 0 0.4875 0 1 Msboxa
[(-2)] 0.16667 0.4875 0 1 Msboxa
[(-1)] 0.33333 0.4875 0 1 Msboxa
[(1)] 0.66667 0.4875 0 1 Msboxa
[(2)] 0.83333 0.4875 0 1 Msboxa
[(3)] 1 0.4875 0 1 Msboxa
[(-3)] 0.4875 0 1 0 Msboxa
[(-2)] 0.4875 0.16667 1 0 Msboxa
[(-1)] 0.4875 0.33333 1 0 Msboxa
[(1)] 0.4875 0.66667 1 0 Msboxa
[(2)] 0.4875 0.83333 1 0 Msboxa
[(3)] 0.4875 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0 0.49375 moveto
0 0.50625 lineto
stroke
0 setgray
[(-3)] 0 0.4875 0 1 Mshowa
0.16667 0.49375 moveto
0.16667 0.50625 lineto
stroke
0 setgray
[(-2)] 0.16667 0.4875 0 1 Mshowa
0.33333 0.49375 moveto
0.33333 0.50625 lineto
stroke
0 setgray
[(-1)] 0.33333 0.4875 0 1 Mshowa
0.66667 0.49375 moveto
0.66667 0.50625 lineto
stroke
0 setgray
[(1)] 0.66667 0.4875 0 1 Mshowa
0.83333 0.49375 moveto
0.83333 0.50625 lineto
stroke
0 setgray
[(2)] 0.83333 0.4875 0 1 Mshowa
1 0.49375 moveto
1 0.50625 lineto
stroke
0 setgray
[(3)] 1 0.4875 0 1 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0 moveto
0.50625 0 lineto
stroke
0 setgray
[(-3)] 0.4875 0 1 0 Mshowa
0.49375 0.16667 moveto
0.50625 0.16667 lineto
stroke
0 setgray
[(-2)] 0.4875 0.16667 1 0 Mshowa
0.49375 0.33333 moveto
0.50625 0.33333 lineto
stroke
0 setgray
[(-1)] 0.4875 0.33333 1 0 Mshowa
0.49375 0.66667 moveto
0.50625 0.66667 lineto
stroke
0 setgray
[(1)] 0.4875 0.66667 1 0 Mshowa
0.49375 0.83333 moveto
0.50625 0.83333 lineto
stroke
0 setgray
[(2)] 0.4875 0.83333 1 0 Mshowa
0.49375 1 moveto
0.50625 1 lineto
stroke
0 setgray
[(3)] 0.4875 1 1 0 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
1.375 0.5 moveto
1.37497 0.50716 lineto
1.37488 0.51432 lineto
1.37474 0.52147 lineto
1.37453 0.52863 lineto
1.37427 0.53578 lineto
1.37395 0.54293 lineto
1.37313 0.55723 lineto
1.37207 0.57151 lineto
1.37079 0.58576 lineto
1.36751 0.61421 lineto
1.36331 0.64253 lineto
1.35819 0.6707 lineto
1.34519 0.72647 lineto
1.32856 0.78126 lineto
1.30839 0.83485 lineto
1.25777 0.9375 lineto
1.19418 1.03267 lineto
1.11872 1.11872 lineto
1.03267 1.19418 lineto
0.9375 1.25777 lineto
0.887 1.28476 lineto
0.83485 1.30839 lineto
0.78126 1.32856 lineto
0.72647 1.34519 lineto
0.6707 1.35819 lineto
0.64253 1.36331 lineto
0.61421 1.36751 lineto
0.58576 1.37079 lineto
0.57151 1.37207 lineto
0.55723 1.37313 lineto
0.54293 1.37395 lineto
0.53578 1.37427 lineto
0.52863 1.37453 lineto
0.52147 1.37474 lineto
0.51432 1.37488 lineto
0.50716 1.37497 lineto
0.5 1.375 lineto
0.49284 1.37497 lineto
0.48568 1.37488 lineto
0.47853 1.37474 lineto
0.47137 1.37453 lineto
0.45707 1.37395 lineto
0.44277 1.37313 lineto
0.42849 1.37207 lineto
0.41424 1.37079 lineto
0.38579 1.36751 lineto
0.35747 1.36331 lineto
0.3293 1.35819 lineto
0.27353 1.34519 lineto
Mistroke
0.21874 1.32856 lineto
0.16515 1.30839 lineto
0.0625 1.25777 lineto
-0.03267 1.19418 lineto
-0.11872 1.11872 lineto
-0.19418 1.03267 lineto
-0.25777 0.9375 lineto
-0.30839 0.83485 lineto
-0.32856 0.78126 lineto
-0.34519 0.72647 lineto
-0.35819 0.6707 lineto
-0.36331 0.64253 lineto
-0.36751 0.61421 lineto
-0.37079 0.58576 lineto
-0.37207 0.57151 lineto
-0.37313 0.55723 lineto
-0.37395 0.54293 lineto
-0.37427 0.53578 lineto
-0.37453 0.52863 lineto
-0.37474 0.52147 lineto
-0.37488 0.51432 lineto
-0.37497 0.50716 lineto
-0.375 0.5 lineto
-0.37497 0.49284 lineto
-0.37488 0.48568 lineto
-0.37474 0.47853 lineto
-0.37453 0.47137 lineto
-0.37395 0.45707 lineto
-0.37313 0.44277 lineto
-0.37207 0.42849 lineto
-0.37079 0.41424 lineto
-0.36751 0.38579 lineto
-0.36331 0.35747 lineto
-0.35819 0.3293 lineto
-0.34519 0.27353 lineto
-0.32856 0.21874 lineto
-0.30839 0.16515 lineto
-0.25777 0.0625 lineto
-0.19418 -0.03267 lineto
-0.11872 -0.11872 lineto
-0.03267 -0.19418 lineto
0.0625 -0.25777 lineto
0.113 -0.28476 lineto
0.16515 -0.30839 lineto
0.21874 -0.32856 lineto
0.27353 -0.34519 lineto
0.3293 -0.35819 lineto
0.35747 -0.36331 lineto
0.38579 -0.36751 lineto
0.41424 -0.37079 lineto
Mistroke
0.42849 -0.37207 lineto
0.44277 -0.37313 lineto
0.45707 -0.37395 lineto
0.46422 -0.37427 lineto
0.47137 -0.37453 lineto
0.47853 -0.37474 lineto
0.48568 -0.37488 lineto
0.49284 -0.37497 lineto
0.5 -0.375 lineto
0.50716 -0.37497 lineto
0.51432 -0.37488 lineto
0.52147 -0.37474 lineto
0.52863 -0.37453 lineto
0.54293 -0.37395 lineto
0.55723 -0.37313 lineto
0.57151 -0.37207 lineto
0.58576 -0.37079 lineto
0.61421 -0.36751 lineto
0.64253 -0.36331 lineto
0.6707 -0.35819 lineto
0.72647 -0.34519 lineto
0.78126 -0.32856 lineto
0.83485 -0.30839 lineto
0.9375 -0.25777 lineto
1.03267 -0.19418 lineto
1.11872 -0.11872 lineto
1.19418 -0.03267 lineto
1.25777 0.0625 lineto
1.28476 0.113 lineto
1.30839 0.16515 lineto
1.32856 0.21874 lineto
1.34519 0.27353 lineto
1.35819 0.3293 lineto
1.36331 0.35747 lineto
1.36751 0.38579 lineto
1.37079 0.41424 lineto
1.37207 0.42849 lineto
1.37313 0.44277 lineto
1.37395 0.45707 lineto
1.37427 0.46422 lineto
1.37453 0.47137 lineto
1.37474 0.47853 lineto
1.37488 0.48568 lineto
1.37497 0.49284 lineto
1.375 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
1.32223 0.79927 moveto
0.81323 0.61401 lineto
stroke
0.17349 0.43289 moveto
-0.33759 0.24687 lineto
stroke
0.16714 0.48231 moveto
-0.35039 0.29394 lineto
stroke
0.16846 0.53452 moveto
-0.36061 0.34196 lineto
stroke
0.17908 0.59012 moveto
-0.36818 0.39093 lineto
stroke
0.20251 0.65038 moveto
-0.373 0.44091 lineto
stroke
0.2486 0.71888 moveto
-0.37496 0.49192 lineto
stroke
0.38362 0.81976 moveto
-0.37389 0.54405 lineto
stroke
1.10355 1.13352 moveto
-0.36957 0.59735 lineto
stroke
1.06244 1.17029 moveto
-0.36171 0.65194 lineto
stroke
1.01741 1.20563 moveto
-0.34993 0.70796 lineto
stroke
0.96795 1.23936 moveto
-0.33372 0.76559 lineto
stroke
0.91334 1.27121 moveto
-0.31237 0.82509 lineto
stroke
0.85257 1.30083 moveto
-0.28484 0.88684 lineto
stroke
0.78404 1.32761 moveto
-0.24957 0.95141 lineto
stroke
0.70512 1.35062 moveto
-0.20389 1.01977 lineto
stroke
0.61067 1.36797 moveto
-0.1427 1.09377 lineto
stroke
0.4876 1.37491 moveto
-0.05289 1.17819 lineto
stroke
1.05289 -0.17819 moveto
0.5124 -0.37491 lineto
stroke
1.1427 -0.09377 moveto
0.38933 -0.36797 lineto
stroke
1.20389 -0.01977 moveto
0.29488 -0.35062 lineto
stroke
1.24957 0.04859 moveto
0.21596 -0.32761 lineto
stroke
1.28484 0.11316 moveto
0.14743 -0.30083 lineto
stroke
1.31237 0.17491 moveto
0.08666 -0.27121 lineto
stroke
1.33372 0.23441 moveto
0.03205 -0.23936 lineto
stroke
1.34993 0.29204 moveto
-0.01741 -0.20563 lineto
stroke
1.36171 0.34806 moveto
-0.06244 -0.17029 lineto
stroke
1.36957 0.40265 moveto
-0.10355 -0.13352 lineto
stroke
0.61638 0.18024 moveto
-0.14113 -0.09547 lineto
stroke
0.44811 0.17073 moveto
-0.17545 -0.05623 lineto
stroke
0.36877 0.19358 moveto
-0.20674 -0.01589 lineto
stroke
0.31209 0.22468 moveto
-0.23517 0.0255 lineto
stroke
0.26821 0.26044 moveto
-0.26085 0.06788 lineto
stroke
0.23364 0.29959 moveto
-0.28389 0.11123 lineto
stroke
0.20674 0.34153 moveto
-0.30434 0.15552 lineto
stroke
0.18677 0.38599 moveto
-0.32223 0.20073 lineto
stroke
1.30434 0.84448 moveto
0.79326 0.65847 lineto
stroke
1.33759 0.75313 moveto
0.82651 0.56711 lineto
stroke
1.28389 0.88877 moveto
0.76636 0.70041 lineto
stroke
1.35039 0.70606 moveto
0.83286 0.51769 lineto
stroke
1.26085 0.93212 moveto
0.73179 0.73956 lineto
stroke
1.36061 0.65804 moveto
0.83154 0.46548 lineto
stroke
1.23517 0.9745 moveto
0.68791 0.77532 lineto
stroke
1.36818 0.60907 moveto
0.82092 0.40988 lineto
stroke
1.20674 1.01589 moveto
0.63123 0.80642 lineto
stroke
1.373 0.55909 moveto
0.79749 0.34962 lineto
stroke
1.17545 1.05623 moveto
0.55189 0.82927 lineto
stroke
1.37496 0.50808 moveto
0.7514 0.28112 lineto
stroke
1.14113 1.09547 moveto
0.38362 0.81976 lineto
stroke
1.37389 0.45595 moveto
0.61638 0.18024 lineto
stroke
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.83333 0.5 moveto
0.83332 0.50273 lineto
0.83329 0.50545 lineto
0.83323 0.50818 lineto
0.83315 0.51091 lineto
0.83305 0.51363 lineto
0.83293 0.51636 lineto
0.83262 0.5218 lineto
0.83222 0.52724 lineto
0.83173 0.53267 lineto
0.83048 0.54351 lineto
0.82888 0.5543 lineto
0.82693 0.56503 lineto
0.82198 0.58627 lineto
0.81564 0.60715 lineto
0.80796 0.62756 lineto
0.78868 0.66667 lineto
0.76445 0.70292 lineto
0.7357 0.7357 lineto
0.70292 0.76445 lineto
0.66667 0.78868 lineto
0.64743 0.79896 lineto
0.62756 0.80796 lineto
0.60715 0.81564 lineto
0.58627 0.82198 lineto
0.56503 0.82693 lineto
0.5543 0.82888 lineto
0.54351 0.83048 lineto
0.53267 0.83173 lineto
0.52724 0.83222 lineto
0.5218 0.83262 lineto
0.51636 0.83293 lineto
0.51363 0.83305 lineto
0.51091 0.83315 lineto
0.50818 0.83323 lineto
0.50545 0.83329 lineto
0.50273 0.83332 lineto
0.5 0.83333 lineto
0.49727 0.83332 lineto
0.49455 0.83329 lineto
0.49182 0.83323 lineto
0.48909 0.83315 lineto
0.48364 0.83293 lineto
0.4782 0.83262 lineto
0.47276 0.83222 lineto
0.46733 0.83173 lineto
0.45649 0.83048 lineto
0.4457 0.82888 lineto
0.43497 0.82693 lineto
0.41373 0.82198 lineto
Mistroke
0.39285 0.81564 lineto
0.37244 0.80796 lineto
0.33333 0.78868 lineto
0.29708 0.76445 lineto
0.2643 0.7357 lineto
0.23555 0.70292 lineto
0.21132 0.66667 lineto
0.19204 0.62756 lineto
0.18436 0.60715 lineto
0.17802 0.58627 lineto
0.17307 0.56503 lineto
0.17112 0.5543 lineto
0.16952 0.54351 lineto
0.16827 0.53267 lineto
0.16778 0.52724 lineto
0.16738 0.5218 lineto
0.16707 0.51636 lineto
0.16695 0.51363 lineto
0.16685 0.51091 lineto
0.16677 0.50818 lineto
0.16671 0.50545 lineto
0.16668 0.50273 lineto
0.16667 0.5 lineto
0.16668 0.49727 lineto
0.16671 0.49455 lineto
0.16677 0.49182 lineto
0.16685 0.48909 lineto
0.16707 0.48364 lineto
0.16738 0.4782 lineto
0.16778 0.47276 lineto
0.16827 0.46733 lineto
0.16952 0.45649 lineto
0.17112 0.4457 lineto
0.17307 0.43497 lineto
0.17802 0.41373 lineto
0.18436 0.39285 lineto
0.19204 0.37244 lineto
0.21132 0.33333 lineto
0.23555 0.29708 lineto
0.2643 0.2643 lineto
0.29708 0.23555 lineto
0.33333 0.21132 lineto
0.35257 0.20104 lineto
0.37244 0.19204 lineto
0.39285 0.18436 lineto
0.41373 0.17802 lineto
0.43497 0.17307 lineto
0.4457 0.17112 lineto
0.45649 0.16952 lineto
0.46733 0.16827 lineto
Mistroke
0.47276 0.16778 lineto
0.4782 0.16738 lineto
0.48364 0.16707 lineto
0.48637 0.16695 lineto
0.48909 0.16685 lineto
0.49182 0.16677 lineto
0.49455 0.16671 lineto
0.49727 0.16668 lineto
0.5 0.16667 lineto
0.50273 0.16668 lineto
0.50545 0.16671 lineto
0.50818 0.16677 lineto
0.51091 0.16685 lineto
0.51636 0.16707 lineto
0.5218 0.16738 lineto
0.52724 0.16778 lineto
0.53267 0.16827 lineto
0.54351 0.16952 lineto
0.5543 0.17112 lineto
0.56503 0.17307 lineto
0.58627 0.17802 lineto
0.60715 0.18436 lineto
0.62756 0.19204 lineto
0.66667 0.21132 lineto
0.70292 0.23555 lineto
0.7357 0.2643 lineto
0.76445 0.29708 lineto
0.78868 0.33333 lineto
0.79896 0.35257 lineto
0.80796 0.37244 lineto
0.81564 0.39285 lineto
0.82198 0.41373 lineto
0.82693 0.43497 lineto
0.82888 0.4457 lineto
0.83048 0.45649 lineto
0.83173 0.46733 lineto
0.83222 0.47276 lineto
0.83262 0.4782 lineto
0.83293 0.48364 lineto
0.83305 0.48637 lineto
0.83315 0.48909 lineto
0.83323 0.49182 lineto
0.83329 0.49455 lineto
0.83332 0.49727 lineto
0.83333 0.5 lineto
Mfstroke
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; endGroup; ]
In the bilateral z-transform, the ROC indicates whether the sequence is left- or right-sided. In the case of a unilateral z-transform, no ROC is required for determining an inverse transform since the sequence is always assumed to be right-sided.
:[font = subsection; inactive; startGroup; Cclosed; ]
Absolutely Summable Sequences
:[font = text; inactive; ]
		Uniform convergence of the z-transform requires absolute summability of the exponentially weighted sequence, as stated by the inequality above.  However, many of the sequences are not absolutely summable even after being exponentially weighted (i.e. multiplied by z^-n).  Hence, these sequences will not have a z-transform. Example of such sequences are given below (you can try to evaluate the z-transform of the following sequences by placing the cursor in the input cell and simply pressing the ENTER key, not the RETURN key).
:[font = input; ]
ZTransform[ Cos[a n], n ]
:[font = input; ]
ZTransform[ a^n, n ]
:[font = input; endGroup; endGroup; ]
ZTransform[ Sin[w n] / (Pi n), n]
:[font = section; inactive; startGroup; Cclosed; ]
Rational z-Transforms
:[font = text; inactive; ]
		The z-transform is most useful when the infinite sum can be expressed as a closed form expression, i.e. when it can be "summed" and expressed as a simple mathematical formula. 
		In DSP, we frequently encounter sinc and rectangularly-shaped functions as well as exponential functions.  We typically analyze the first class using the DTFT and the second class with the z-transform.  Moreover, it turns out that any sequence which can be represented as a sum of exponentials can be represented by a rational z-transform.  In fact, among the most important and useful z-transforms are those for which X(z) is a rational function, i.e., X(z) = N(z) / D(z) where N(z) and D(z) are polynomials in z.  Note that the roots of N(z) are the zeros of X(z) (i.e. values of z for which X(z) = 0) and the roots of D(z) are the poles of X(z) (i.e. values of z for which X(z) is infinite). In addition, poles and zeros may occur at z = 0 or z = infinity.
		The location of poles of the rational z-transforms affects the locations of the possible regions of convergence as illustrated in the next section.  It is important to note that when the summation involves an infinite geometric sequence of the form shown in the next cell, then the ROC is determined from the convergence condition |q| < 1. HERE
:[font = postscript; inactive; PostScript; output; pictureLeft = 169; pictureWidth = 92; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.510870 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.510870 scale
1 string
92 47 1 [92 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
1F81FFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE001FF0
1F8E3FFFFFC7FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC0FFF0
1F8FF80001C7FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC0FFF0
E3F1FFFFFFC7FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8FFF0
E3F1F80001C7FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFE00007FFFFFFFFFFFF
FFF0381FF0
1C0FFFFFFFC7FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FC01C01FF0
FFFFFFFFFFC7FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FC0FF81FF0
FFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FC0FF81FF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFF8000000FFF
FC0FFF03F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FF8FFF03F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FF81FF03F0
FF800000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FFFE0003F0
FFF00000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFE381FFFFFFFFFFFFFF
FFFFFFFFF0
FFFE3FFFFFFF03FFFFE001FFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFF
FFFFFFFFF0
FFFFC7FFFFFFE3FFFFFC0FFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FFFFFFFFF0
FFFFF8FFFFFFE3FFFFFC0FFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFF1FFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFE3FFFFFFFFFF0381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFC7FFFFFFFC01C01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFF8FFFFFFFC0FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFFF1FFFFFFC0FF81FFFFFFFFFF8000000FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFFF03FFFFFC0FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFF81FFFFFFF8FFF03FFFFFFFFFFFFFFFFFFFE00000000000000000
00000003F0
FFFFFFFC0FFFFFFFF81FF03FFFFFFFFF8000000FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFE07FFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFF03FFFFFFFFFFFFFFF8FC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFF81FFFFFFFFFFFFFFFF8FC71FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFC0FFFFFFE3FFFFFFFFF8FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFE07FFFFFFE3FFFFFFFFFF1F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFF03FFFFFFF03FFFFFFFFFF1F8FFFFFFFFFFFFFFFFFFFFFFFFFC0000FFF
FFFFFFFFF0
FF800000000003FFFFFFFFF8E07FFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FFFF
FFFFFFFFF0
FFFFFF0381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFF
FFFFFFFFF0
FFFFF8FC7E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF
FFFFFFFFF0
FFFFFF0381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF0
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
when |q| < 1.
:[font = subsection; inactive; startGroup; Cclosed; ]
Generating Possible ROC's
:[font = text; inactive; ]
		In the following example, the poles of the given transfer function are determined and all of the typical ROCs corresponding to these poles are plotted.   The function AllPoleZeroPlots is an interactive function which takes input from the user who can request which ROC is to be displayed next.  Evaluate the following input cell by  placing the cursor in this cell and hitting the Enter key. 
:[font = input; ]
AllPoleZeroPlots[ (z + 1) / ((z - 1)(z - 2)), z ]
:[font = text; inactive; endGroup; ]
		From this example, one can see that different sequences may have the same closed form expression for the z-transform.  Only the regions of convergence are different. Therefore, whenever the infinite sum (c.f. equation 1 in the "Definition" section) converges to a closed form expression, it is necessary to specify the region for convergence for the z-transform, in addition to the closed form expression obtained, in order for the closed form z-transform to represent a sequence uniquely.
:[font = subsection; inactive; startGroup; Cclosed; ]
Finite-Length Sequences
:[font = text; inactive; ]
		An finite-length or finite-duration sequence is a sequence that is zero except in a finite interval :  -infinity < L<= n <= P < infinity.  The z-transform of a finite-length, finite-valued sequence can always be expressed as a polynomial in the z-domain (which can be also considered as a rational function ).  The ROC of any stable finite-duration sequence is the entire complex z-plane except possibly z = 0 or z = infinity.  In fact, the z-transform of a finite-length sequence.  HERE
:[font = postscript; inactive; PostScript; output; pictureLeft = 161; pictureWidth = 129; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.364341 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.364341 scale
1 string
129 47 1 [129 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F81FFFFFFF80001FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8E3FFFFFFF1FFE3FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F8FF80001FF1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1FFFFFFFFE3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F1F80001FFE3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFFFE3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000000003FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000003FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFE3FFFFFFFE3FFFFFFFFFFFFFFFFFFFE3FFFFFFF03FFFFFFF
FFF000FFFFFFFC003FFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFC7FFFFFFE3FFFFFFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFF8FFFFFFE3FFFFFFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFF8FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0
0001C0000FF8FFF00003FFF8FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF81FF
03F1FFFC0FF803FE3FFC0000FFFFFFFFFFFFE0
FC0FFF007FC0FFF03FE3FFF81FFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFF038
0071FFFC0FF81C7E3FFC0FF8FFFFFFFFFFFFE0
FF8FFF03FFC0FFFE07FFFFF81FFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFE38
1FF1FFFC0FF81FFE3FFF81FFFFFFFFFFFFFFE0
FFF1FF03FFC0FFFFC0FFFFF81FFFC0000007FFFFFFFFFFFF1FFFFFFFFE00
FFF1FFFC0FF81FFE3FFFF03FFFFFFFFFFFFFE0
FFFE381FFFC0FFFFF81FFFF81FFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFC0
FFF1FFFF81FF03FE3FFFFE07FFFFFFFFFFFFE0
FFFE001FFFC0FFFFFF03FFF81FFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFE00
1FF1FFFF803F03FE3FFFFFC0FFFFFFFFFFFFE0
FFFFC0FFFFC0FFFE3FE07FF81FFFC0000007FFFFFFFFFFC0FFFFFFFFFE07
03F1FFFF81C003FE3FFF8FF81FFFFFFFFFFFE0
FFFFC0FFFFF8FFFE00007FF8FFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFF007
E071FFFC01F81FFE3FFF80001FFFFFFFFFFFE0
FFFE001FFFF8FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFFFFC7E07E0
FFFE07E3FFFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFFFFC7E38E0
FFF007E07FFF1FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFC0FFFFFFE3FFFFFFF
FFF1FFFFFFFFFFFE3FFFFFFFFFFFFFFC7E3FE0
FFF03FFC0FFFE3FFFFFFFE3FFFFFFFFFFFFFFFFFFFE07FFFFFFE3FFFFFFF
FFF000FFFFFFFC003FFFFFFFFFFFFFFF8FC7E0
FC0000E0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC0000FF8FC7E0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000000003FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FE3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FC7FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FC7FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
converges as long as |x[n] z^-n| is finite for every n. From the equation above, it can be seen that, for a stable finite-length sequence x[n], X(z) will be infinite only if z is zero when n is positive, or z is infinite when n is negative. Hence, only z = 0 and/or z = infinity may lead X(z) to diverge and are the only ones which may be excluded from the ROC.  In fact, z = 0 is pole when L or P are positive, z = infinity is pole when L or P are negative.  Try to evaluate the ZTransform of the given finite sequence in the input cell below by placing the cursor in  the input cell and pressing the ENTER key. Also, try to replace the given sequence by other finite-length sequences and observe the resulting ROC.
:[font = input; startGroup; ]
ZTransform[ 4^n (Step[n] - Step[n-8]), n ]
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 4/z)^(-1) - 65536/((1 - 4/z)*z^8), 
  Rminus[0], Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
             1       65536
ZTransData[----- - ----------, Rminus[0], 
               4        4   8
           1 - -   (1 - -) z
               z        z
 
  Rplus[Infinity], ZVariables[z]]
:[font = text; inactive; ]
		The following input cell gives the pole-zero plot of a finite-length sequence. The ROC is also indicated by the shaded area in the plot.  Note that, in this case , the rational expression obtained for the z-transform identifies the finite-length sequence uniquely since there is only one possible ROC. 
:[font = input; startGroup; ]
PoleZeroPlot[
  ZTransform[4^n (Step[n] - Step[n-8]), n ] ]
:[font = print; inactive; startGroup; ]
 
The zeroes are:  {-4., 4. I, -4. I, 2.82843 + 2.82843 I, 
 
   -2.82843 + 2.82843 I, -2.82843 - 2.82843 I, 
 
   2.82843 - 2.82843 I}
The poles are:   {0., 0., 0., 0., 0., 0., 0.}
:[font = postscript; inactive; PostScript; output; pictureLeft = 79; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.1 0.5 0.1 [
[(-4)] 0.1 0.4875 0 1 Msboxa
[(-2)] 0.3 0.4875 0 1 Msboxa
[(2)] 0.7 0.4875 0 1 Msboxa
[(4)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-4)] 0.4875 0.1 1 0 Msboxa
[(-2)] 0.4875 0.3 1 0 Msboxa
[(2)] 0.4875 0.7 1 0 Msboxa
[(4)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-4)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-2)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(2)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(4)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-4)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-2)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(2)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(4)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.6 0.5 moveto
0.6 0.50082 lineto
0.59999 0.50164 lineto
0.59997 0.50245 lineto
0.59995 0.50327 lineto
0.59992 0.50409 lineto
0.59988 0.50491 lineto
0.59979 0.50654 lineto
0.59967 0.50817 lineto
0.59952 0.5098 lineto
0.59914 0.51305 lineto
0.59866 0.51629 lineto
0.59808 0.51951 lineto
0.59659 0.52588 lineto
0.59469 0.53214 lineto
0.59239 0.53827 lineto
0.5866 0.55 lineto
0.57934 0.56088 lineto
0.57071 0.57071 lineto
0.56088 0.57934 lineto
0.55 0.5866 lineto
0.54423 0.58969 lineto
0.53827 0.59239 lineto
0.53214 0.59469 lineto
0.52588 0.59659 lineto
0.51951 0.59808 lineto
0.51629 0.59866 lineto
0.51305 0.59914 lineto
0.5098 0.59952 lineto
0.50817 0.59967 lineto
0.50654 0.59979 lineto
0.50491 0.59988 lineto
0.50409 0.59992 lineto
0.50327 0.59995 lineto
0.50245 0.59997 lineto
0.50164 0.59999 lineto
0.50082 0.6 lineto
0.5 0.6 lineto
0.49918 0.6 lineto
0.49836 0.59999 lineto
0.49755 0.59997 lineto
0.49673 0.59995 lineto
0.49509 0.59988 lineto
0.49346 0.59979 lineto
0.49183 0.59967 lineto
0.4902 0.59952 lineto
0.48695 0.59914 lineto
0.48371 0.59866 lineto
0.48049 0.59808 lineto
0.47412 0.59659 lineto
Mistroke
0.46786 0.59469 lineto
0.46173 0.59239 lineto
0.45 0.5866 lineto
0.43912 0.57934 lineto
0.42929 0.57071 lineto
0.42066 0.56088 lineto
0.4134 0.55 lineto
0.40761 0.53827 lineto
0.40531 0.53214 lineto
0.40341 0.52588 lineto
0.40192 0.51951 lineto
0.40134 0.51629 lineto
0.40086 0.51305 lineto
0.40048 0.5098 lineto
0.40033 0.50817 lineto
0.40021 0.50654 lineto
0.40012 0.50491 lineto
0.40008 0.50409 lineto
0.40005 0.50327 lineto
0.40003 0.50245 lineto
0.40001 0.50164 lineto
0.4 0.50082 lineto
0.4 0.5 lineto
0.4 0.49918 lineto
0.40001 0.49836 lineto
0.40003 0.49755 lineto
0.40005 0.49673 lineto
0.40012 0.49509 lineto
0.40021 0.49346 lineto
0.40033 0.49183 lineto
0.40048 0.4902 lineto
0.40086 0.48695 lineto
0.40134 0.48371 lineto
0.40192 0.48049 lineto
0.40341 0.47412 lineto
0.40531 0.46786 lineto
0.40761 0.46173 lineto
0.4134 0.45 lineto
0.42066 0.43912 lineto
0.42929 0.42929 lineto
0.43912 0.42066 lineto
0.45 0.4134 lineto
0.45577 0.41031 lineto
0.46173 0.40761 lineto
0.46786 0.40531 lineto
0.47412 0.40341 lineto
0.48049 0.40192 lineto
0.48371 0.40134 lineto
0.48695 0.40086 lineto
0.4902 0.40048 lineto
Mistroke
0.49183 0.40033 lineto
0.49346 0.40021 lineto
0.49509 0.40012 lineto
0.49591 0.40008 lineto
0.49673 0.40005 lineto
0.49755 0.40003 lineto
0.49836 0.40001 lineto
0.49918 0.4 lineto
0.5 0.4 lineto
0.50082 0.4 lineto
0.50164 0.40001 lineto
0.50245 0.40003 lineto
0.50327 0.40005 lineto
0.50491 0.40012 lineto
0.50654 0.40021 lineto
0.50817 0.40033 lineto
0.5098 0.40048 lineto
0.51305 0.40086 lineto
0.51629 0.40134 lineto
0.51951 0.40192 lineto
0.52588 0.40341 lineto
0.53214 0.40531 lineto
0.53827 0.40761 lineto
0.55 0.4134 lineto
0.56088 0.42066 lineto
0.57071 0.42929 lineto
0.57934 0.43912 lineto
0.5866 0.45 lineto
0.58969 0.45577 lineto
0.59239 0.46173 lineto
0.59469 0.46786 lineto
0.59659 0.47412 lineto
0.59808 0.48049 lineto
0.59866 0.48371 lineto
0.59914 0.48695 lineto
0.59952 0.4902 lineto
0.59967 0.49183 lineto
0.59979 0.49346 lineto
0.59988 0.49509 lineto
0.59992 0.49591 lineto
0.59995 0.49673 lineto
0.59997 0.49755 lineto
0.59999 0.49836 lineto
0.6 0.49918 lineto
0.6 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.5 0.5 lineto
stroke
1.23539 0.81496 moveto
-0.26579 0.26857 lineto
stroke
1.2167 0.85545 moveto
-0.2775 0.31161 lineto
stroke
1.19564 0.89508 moveto
-0.28684 0.3555 lineto
stroke
1.17215 0.93383 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
1.29376 0.59972 moveto
-0.17215 0.06617 lineto
stroke
1.28684 0.6445 moveto
-0.19564 0.10492 lineto
stroke
1.2775 0.68839 moveto
-0.2167 0.14455 lineto
stroke
1.26579 0.73143 moveto
-0.23539 0.18504 lineto
stroke
0.5 0.5 moveto
-0.25175 0.22638 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.1 0.5 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.21716 0.21716 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.21716 0.78284 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.1 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.9 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.78284 0.21716 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.78284 0.78284 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(*X*)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
{0., 0., 0., 0., 0., 0., 0.}
;[o]
{0., 0., 0., 0., 0., 0., 0.}
:[font = text; inactive; endGroup; ]
		The above examples clearly  shows that the ROC for finite-length sequences include the entire z-plane with the exception of the origin (z = 0) if n has at least one positive value. 
:[font = subsection; inactive; startGroup; Cclosed; ]
Right-sided Sequences
:[font = text; inactive; ]
	A right-sided sequence is a sequence that is zero for all n < C < infinity, where C is a positive or a negative constant.  If the z-transform of this sequence converges to some closed-form expression, the corresponding ROC will be located outside the circle whose radius is equal to the magnitude of the outermost (i.e. largest magnitude) finite pole of the z transform, and this ROC extends outward to (and possibly includes) infinity. 
:[font = text; inactive; ]
	The following input cells give the z transform of some right-sided sequences, and plot their ROC's and the corresponding frequency responses if they exist (for more info about the frequency response, refer to the next section).		 			 
:[font = input; ]
DSPAnalyze[3^n Step[n], n, -1, 10]
:[font = input; endGroup; ]
DSPAnalyze[0.5^n Step[n], n, -1, 5]
:[font = subsection; inactive; startGroup; Cclosed; ]
 Left-sided Sequences	
:[font = text; inactive; ]
	A left-sided sequence is a sequence that is zero for all n such that
:[font = text; inactive; center; ]
n > C > -infinity
:[font = text; inactive; ]
where C is some positive or negative constant.  If the z-transform of this sequence converges to a closed-form expression, the corresponding ROC will be located inside the circle whose radius is equal to the innermost (i.e. smallest in magnitude) non-zero pole of the z transform, and extends inward to (and possibly includes) zero.
:[font = text; inactive; ]
	The following input cell gives the z transform of a left-sided sequences, and plot its ROC's and the corresponding frequency responses (for more info about the frequency response, refer to the next section).
:[font = text; inactive; ]
	Note that a finite-length sequence can be considered as a  right-sided and a left-sided sequence, therefore the only possible poles can occur at z = 0 or z = infinity.
:[font = input; endGroup; ]
DSPAnalyze[ -0.5^n Step[-n], n, -5, 2 ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Two-sided Sequences	
:[font = text; inactive; ]
	A two-sided sequence is an  infinite-length sequence that is neither left-sided nor right-sided.  If the z-transform of this sequence converges to a closed-form expression, the corresponding ROC will consist of an annular ring in the z-plane, bounded on the interior and the exterior by one or more poles.  Note that a two-sided sequence can be expressed as the sum of  right-sided and left-sided sequences; hence, the resulting ROC will be the intersection of the ROC's of the right- and left-sided sequences used in the sum.
:[font = text; inactive; ]
	The following input cell gives the z transform of  the sum of the left-sided and the right-sided sequences  used in the previous input cells, and plots the ROC of the sum  and the corresponding frequency response if it exists (for more info about the frequency response, refer to the next section).	Note that the obtained ROC is just the intersection of the individual ROCs obtained in the previous examples.
:[font = input; ]
DSPAnalyze[ 3^n Step[-n] + 0.5^n Step[n],
            n, -7, 5 ]
:[font = text; inactive; ]
	The following input cell illustrates the case of the sum of two sequences whose individual ROCs do not overlap. What do you expect in this case?
:[font = input; startGroup; Cclosed; ]
DSPAnalyze[ 1.2^n Step[n] - 1.2^n Step[-n - 1],
            n, -10, 10 ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.04762 0.08454 0.08379 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-10)] 0.02381 0.07204 0 1 Msboxa
[(-5)] 0.2619 0.07204 0 1 Msboxa
[(5)] 0.7381 0.07204 0 1 Msboxa
[(10)] 0.97619 0.07204 0 1 Msboxa
[(n)] 1.00625 0.08454 -1 0 Msboxa
[(-1)] 0.4875 0.00075 1 0 Msboxa
[(1)] 0.4875 0.16832 1 0 Msboxa
[(2)] 0.4875 0.25211 1 0 Msboxa
[(3)] 0.4875 0.3359 1 0 Msboxa
[(4)] 0.4875 0.41968 1 0 Msboxa
[(5)] 0.4875 0.50347 1 0 Msboxa
[(6)] 0.4875 0.58725 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.08454 moveto
1 0.08454 lineto
stroke
0.02381 0.07829 moveto
0.02381 0.09079 lineto
stroke
0 setgray
[(-10)] 0.02381 0.07204 0 1 Mshowa
0.2619 0.07829 moveto
0.2619 0.09079 lineto
stroke
0 setgray
[(-5)] 0.2619 0.07204 0 1 Mshowa
0.7381 0.07829 moveto
0.7381 0.09079 lineto
stroke
0 setgray
[(5)] 0.7381 0.07204 0 1 Mshowa
0.97619 0.07829 moveto
0.97619 0.09079 lineto
stroke
0 setgray
[(10)] 0.97619 0.07204 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.08454 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.00075 moveto
0.50625 0.00075 lineto
stroke
0 setgray
[(-1)] 0.4875 0.00075 1 0 Mshowa
0.49375 0.16832 moveto
0.50625 0.16832 lineto
stroke
0 setgray
[(1)] 0.4875 0.16832 1 0 Mshowa
0.49375 0.25211 moveto
0.50625 0.25211 lineto
stroke
0 setgray
[(2)] 0.4875 0.25211 1 0 Mshowa
0.49375 0.3359 moveto
0.50625 0.3359 lineto
stroke
0 setgray
[(3)] 0.4875 0.3359 1 0 Mshowa
0.49375 0.41968 moveto
0.50625 0.41968 lineto
stroke
0 setgray
[(4)] 0.4875 0.41968 1 0 Mshowa
0.49375 0.50347 moveto
0.50625 0.50347 lineto
stroke
0 setgray
[(5)] 0.4875 0.50347 1 0 Mshowa
0.49375 0.58725 moveto
0.50625 0.58725 lineto
stroke
0 setgray
[(6)] 0.4875 0.58725 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.08454 moveto
0.02381 0.071 lineto
stroke
0.008 setlinewidth
0.02381 0.071 Mdot
0.004 setlinewidth
0.07143 0.08454 moveto
0.07143 0.0683 lineto
stroke
0.008 setlinewidth
0.07143 0.0683 Mdot
0.004 setlinewidth
0.11905 0.08454 moveto
0.11905 0.06505 lineto
stroke
0.008 setlinewidth
0.11905 0.06505 Mdot
0.004 setlinewidth
0.16667 0.08454 moveto
0.16667 0.06115 lineto
stroke
0.008 setlinewidth
0.16667 0.06115 Mdot
0.004 setlinewidth
0.21429 0.08454 moveto
0.21429 0.05648 lineto
stroke
0.008 setlinewidth
0.21429 0.05648 Mdot
0.004 setlinewidth
0.2619 0.08454 moveto
0.2619 0.05087 lineto
stroke
0.008 setlinewidth
0.2619 0.05087 Mdot
0.004 setlinewidth
0.30952 0.08454 moveto
0.30952 0.04413 lineto
stroke
0.008 setlinewidth
0.30952 0.04413 Mdot
0.004 setlinewidth
0.35714 0.08454 moveto
0.35714 0.03605 lineto
stroke
0.008 setlinewidth
0.35714 0.03605 Mdot
0.004 setlinewidth
0.40476 0.08454 moveto
0.40476 0.02635 lineto
stroke
0.008 setlinewidth
0.40476 0.02635 Mdot
0.004 setlinewidth
0.45238 0.08454 moveto
0.45238 0.01472 lineto
stroke
0.008 setlinewidth
0.45238 0.01472 Mdot
0.004 setlinewidth
0.5 0.08454 moveto
0.5 0.16832 lineto
stroke
0.008 setlinewidth
0.5 0.16832 Mdot
0.004 setlinewidth
0.54762 0.08454 moveto
0.54762 0.18508 lineto
stroke
0.008 setlinewidth
0.54762 0.18508 Mdot
0.004 setlinewidth
0.59524 0.08454 moveto
0.59524 0.20519 lineto
stroke
0.008 setlinewidth
0.59524 0.20519 Mdot
0.004 setlinewidth
0.64286 0.08454 moveto
0.64286 0.22932 lineto
stroke
0.008 setlinewidth
0.64286 0.22932 Mdot
0.004 setlinewidth
0.69048 0.08454 moveto
0.69048 0.25828 lineto
stroke
0.008 setlinewidth
0.69048 0.25828 Mdot
0.004 setlinewidth
0.7381 0.08454 moveto
0.7381 0.29302 lineto
stroke
0.008 setlinewidth
0.7381 0.29302 Mdot
0.004 setlinewidth
0.78571 0.08454 moveto
0.78571 0.33472 lineto
stroke
0.008 setlinewidth
0.78571 0.33472 Mdot
0.004 setlinewidth
0.83333 0.08454 moveto
0.83333 0.38476 lineto
stroke
0.008 setlinewidth
0.83333 0.38476 Mdot
0.004 setlinewidth
0.88095 0.08454 moveto
0.88095 0.4448 lineto
stroke
0.008 setlinewidth
0.88095 0.4448 Mdot
0.004 setlinewidth
0.92857 0.08454 moveto
0.92857 0.51686 lineto
stroke
0.008 setlinewidth
0.92857 0.51686 Mdot
0.004 setlinewidth
0.97619 0.08454 moveto
0.97619 0.60332 lineto
stroke
0.008 setlinewidth
0.97619 0.60332 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = message; inactive; ]
ZTransform::badROC: 
   Improper region of convergence in 
                  1        0.833333 z
    ZTransData[------- - --------------, Rminus[1.2], 
                   1.2   1 - 0.833333 z
               1 - ---
                    z
     Rplus[1.2], ZVariables[z]].
:[font = message; inactive; ]
ZTransform::notvalid: 
   The forward z-transform could not be found.
:[font = print; inactive; ]
     n                    n
-(1.2  Step[-1 - n]) + 1.2  Step[n]
:[font = print; inactive; ]
has the following frequency response:
:[font = print; inactive; ]
                            I w
      1           0.833333 E
------------- - -----------------
         -I w                 I w
1 - 1.2 E       1 - 0.833333 E
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 -0.04415 0.02158 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.05127 0 1 Msboxa
[(-4)] 0.19685 0.05127 0 1 Msboxa
[(-2)] 0.34842 0.05127 0 1 Msboxa
[(2)] 0.65158 0.05127 0 1 Msboxa
[(4)] 0.80315 0.05127 0 1 Msboxa
[(6)] 0.95473 0.05127 0 1 Msboxa
[(w)] 1.00625 0.06377 -1 0 Msboxa
[(10)] 0.4875 0.17168 1 0 Msboxa
[(15)] 0.4875 0.27959 1 0 Msboxa
[(20)] 0.4875 0.3875 1 0 Msboxa
[(25)] 0.4875 0.49541 1 0 Msboxa
[(30)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.06377 moveto
1 0.06377 lineto
stroke
0.04527 0.05752 moveto
0.04527 0.07002 lineto
stroke
0 setgray
[(-6)] 0.04527 0.05127 0 1 Mshowa
0.19685 0.05752 moveto
0.19685 0.07002 lineto
stroke
0 setgray
[(-4)] 0.19685 0.05127 0 1 Mshowa
0.34842 0.05752 moveto
0.34842 0.07002 lineto
stroke
0 setgray
[(-2)] 0.34842 0.05127 0 1 Mshowa
0.65158 0.05752 moveto
0.65158 0.07002 lineto
stroke
0 setgray
[(2)] 0.65158 0.05127 0 1 Mshowa
0.80315 0.05752 moveto
0.80315 0.07002 lineto
stroke
0 setgray
[(4)] 0.80315 0.05127 0 1 Mshowa
0.95473 0.05752 moveto
0.95473 0.07002 lineto
stroke
0 setgray
[(6)] 0.95473 0.05127 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.06377 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.17168 moveto
0.50625 0.17168 lineto
stroke
0 setgray
[(10)] 0.4875 0.17168 1 0 Mshowa
0.49375 0.27959 moveto
0.50625 0.27959 lineto
stroke
0 setgray
[(15)] 0.4875 0.27959 1 0 Mshowa
0.49375 0.3875 moveto
0.50625 0.3875 lineto
stroke
0 setgray
[(20)] 0.4875 0.3875 1 0 Mshowa
0.49375 0.49541 moveto
0.50625 0.49541 lineto
stroke
0 setgray
[(25)] 0.4875 0.49541 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(30)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.03373 0.48218 lineto
0.03869 0.39713 lineto
0.04365 0.32693 lineto
0.04861 0.27238 lineto
0.05357 0.23026 lineto
0.05853 0.19736 lineto
0.06349 0.17122 lineto
0.06845 0.15009 lineto
0.07341 0.13274 lineto
0.08333 0.10609 lineto
0.09325 0.08673 lineto
0.10317 0.07214 lineto
0.1131 0.06083 lineto
0.12302 0.05187 lineto
0.13294 0.04465 lineto
0.14286 0.03875 lineto
0.15278 0.0339 lineto
0.1627 0.02987 lineto
0.18254 0.02373 lineto
0.19246 0.02142 lineto
0.20238 0.01952 lineto
0.2123 0.01798 lineto
0.22222 0.01677 lineto
0.23214 0.01586 lineto
0.2371 0.01551 lineto
0.24206 0.01522 lineto
0.24702 0.015 lineto
0.2495 0.01491 lineto
0.25198 0.01484 lineto
0.25446 0.01479 lineto
0.2557 0.01476 lineto
0.25694 0.01475 lineto
0.25818 0.01473 lineto
0.25942 0.01472 lineto
0.26066 0.01472 lineto
0.2619 0.01472 lineto
0.26314 0.01472 lineto
0.26438 0.01472 lineto
0.26562 0.01473 lineto
0.26687 0.01475 lineto
0.26935 0.01479 lineto
0.27183 0.01484 lineto
0.27431 0.01491 lineto
0.27679 0.015 lineto
0.28175 0.01522 lineto
0.28671 0.01551 lineto
0.29167 0.01586 lineto
0.30159 0.01677 lineto
0.31151 0.01798 lineto
Mistroke
0.32143 0.01952 lineto
0.34127 0.02373 lineto
0.35119 0.02652 lineto
0.36111 0.02987 lineto
0.38095 0.03875 lineto
0.39087 0.04465 lineto
0.40079 0.05187 lineto
0.41071 0.06083 lineto
0.42063 0.07214 lineto
0.43056 0.08673 lineto
0.44048 0.10609 lineto
0.44544 0.11828 lineto
0.4504 0.13274 lineto
0.45536 0.15009 lineto
0.46032 0.17122 lineto
0.46528 0.19736 lineto
0.47024 0.23026 lineto
0.4752 0.27238 lineto
0.48016 0.32693 lineto
0.49008 0.48218 lineto
0.49256 0.52615 lineto
0.49504 0.56535 lineto
0.49628 0.58112 lineto
0.49752 0.59316 lineto
0.49876 0.60073 lineto
0.5 0.60332 lineto
0.50124 0.60073 lineto
0.50248 0.59316 lineto
0.50496 0.56535 lineto
0.50744 0.52615 lineto
0.50992 0.48218 lineto
0.51488 0.39713 lineto
0.51984 0.32693 lineto
0.5248 0.27238 lineto
0.52976 0.23026 lineto
0.53472 0.19736 lineto
0.53968 0.17122 lineto
0.5496 0.13274 lineto
0.55456 0.11828 lineto
0.55952 0.10609 lineto
0.56944 0.08673 lineto
0.57937 0.07214 lineto
0.58929 0.06083 lineto
0.59921 0.05187 lineto
0.60913 0.04465 lineto
0.61905 0.03875 lineto
0.62897 0.0339 lineto
0.63889 0.02987 lineto
0.64881 0.02652 lineto
0.65873 0.02373 lineto
Mistroke
0.67857 0.01952 lineto
0.68849 0.01798 lineto
0.69841 0.01677 lineto
0.70337 0.01628 lineto
0.70833 0.01586 lineto
0.71329 0.01551 lineto
0.71825 0.01522 lineto
0.72321 0.015 lineto
0.72569 0.01491 lineto
0.72817 0.01484 lineto
0.73065 0.01479 lineto
0.73189 0.01476 lineto
0.73313 0.01475 lineto
0.73438 0.01473 lineto
0.73562 0.01472 lineto
0.73686 0.01472 lineto
0.7381 0.01472 lineto
0.73934 0.01472 lineto
0.74058 0.01472 lineto
0.74182 0.01473 lineto
0.74306 0.01475 lineto
0.74554 0.01479 lineto
0.74802 0.01484 lineto
0.7505 0.01491 lineto
0.75298 0.015 lineto
0.75794 0.01522 lineto
0.7629 0.01551 lineto
0.76786 0.01586 lineto
0.77778 0.01677 lineto
0.7877 0.01798 lineto
0.79762 0.01952 lineto
0.80754 0.02142 lineto
0.81746 0.02373 lineto
0.8373 0.02987 lineto
0.84722 0.0339 lineto
0.85714 0.03875 lineto
0.86706 0.04465 lineto
0.87698 0.05187 lineto
0.8869 0.06083 lineto
0.89683 0.07214 lineto
0.90675 0.08673 lineto
0.91667 0.10609 lineto
0.92163 0.11828 lineto
0.92659 0.13274 lineto
0.93155 0.15009 lineto
0.93651 0.17122 lineto
0.94147 0.19736 lineto
0.94643 0.23026 lineto
0.95139 0.27238 lineto
0.95635 0.32693 lineto
Mistroke
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-150)] 0.4875 0.06377 1 0 Msboxa
[(-100)] 0.4875 0.14552 1 0 Msboxa
[(-50)] 0.4875 0.22727 1 0 Msboxa
[(50)] 0.4875 0.39077 1 0 Msboxa
[(100)] 0.4875 0.47252 1 0 Msboxa
[(150)] 0.4875 0.55427 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06377 moveto
0.50625 0.06377 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06377 1 0 Mshowa
0.49375 0.14552 moveto
0.50625 0.14552 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14552 1 0 Mshowa
0.49375 0.22727 moveto
0.50625 0.22727 lineto
stroke
0 setgray
[(-50)] 0.4875 0.22727 1 0 Mshowa
0.49375 0.39077 moveto
0.50625 0.39077 lineto
stroke
0 setgray
[(50)] 0.4875 0.39077 1 0 Mshowa
0.49375 0.47252 moveto
0.50625 0.47252 lineto
stroke
0 setgray
[(100)] 0.4875 0.47252 1 0 Mshowa
0.49375 0.55427 moveto
0.50625 0.55427 lineto
stroke
0 setgray
[(150)] 0.4875 0.55427 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02877 0.05016 lineto
0.03373 0.07936 lineto
0.03869 0.10124 lineto
0.04365 0.11751 lineto
0.04861 0.13004 lineto
0.05357 0.1401 lineto
0.06349 0.15575 lineto
0.08333 0.17841 lineto
0.10317 0.19629 lineto
0.14286 0.22695 lineto
0.18254 0.25505 lineto
0.22222 0.28221 lineto
0.2619 0.30902 lineto
0.30159 0.33582 lineto
0.34127 0.36298 lineto
0.38095 0.39109 lineto
0.42063 0.42175 lineto
0.44048 0.43962 lineto
0.4504 0.45002 lineto
0.46032 0.46228 lineto
0.47024 0.47793 lineto
0.4752 0.48799 lineto
0.48016 0.50052 lineto
0.48512 0.5168 lineto
0.49008 0.53867 lineto
0.49504 0.56787 lineto
0.49752 0.5851 lineto
0.49876 0.59414 lineto
0.5 0.60332 lineto
0.50124 0.02389 lineto
0.50248 0.03293 lineto
0.50496 0.05016 lineto
0.50992 0.07936 lineto
0.51488 0.10124 lineto
0.51984 0.11751 lineto
0.5248 0.13004 lineto
0.52976 0.1401 lineto
0.53968 0.15575 lineto
0.55952 0.17841 lineto
0.57937 0.19629 lineto
0.61905 0.22695 lineto
0.65873 0.25505 lineto
0.69841 0.28221 lineto
0.7381 0.30902 lineto
0.77778 0.33582 lineto
0.81746 0.36298 lineto
0.85714 0.39109 lineto
0.89683 0.42175 lineto
0.91667 0.43962 lineto
Mistroke
0.92659 0.45002 lineto
0.93651 0.46228 lineto
0.94147 0.46953 lineto
0.94643 0.47793 lineto
0.95139 0.48799 lineto
0.95635 0.50052 lineto
0.96131 0.5168 lineto
0.96627 0.53867 lineto
0.97123 0.56787 lineto
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; endGroup; endGroup; ]
 	Note that, for this last example, the DTFT does not exist. In fact, the DTFT function must be corrected so as to give a "Does Not Exist" message in this case !!
:[font = section; inactive; startGroup; Cclosed; ]
Inverse z-Transform
:[font = text; inactive; ]
	In practice, we are usually interested in the time- or space-domain sequences. The z-transform and DTFT are just tools that allow us to analyze sequences more easily and to perform operations that are simpler in transform domain.  In the z-domain, for instance, the convolution operation in the time/space domain corresponds to the inverse z-transform of the product of the z-transforms.  This is also true in the discrete-time frequency domain.  So, in many cases, it is more efficient to implement an operation in the transform domain, assuming that the forward and inverse transforms exist.
:[font = subsection; inactive; startGroup; Cclosed; ]
The Role of the Inverse z-Transform
:[font = text; inactive; endGroup; ]
	Since the z-transform provides us with many powerful tools which can be used in solving problems of discrete-time/space signals and systems, it would be useful to go from the time/space domain to the z-domain, perform all desired operations, and then be able to return back to the time/space domain and obtain the resulting sequence. While the mapping from the time/space domain to the z-domain is provided through the z-transform operation, an inverse mapping (a.k.a. inverse z-transform), which allows us to recover the corresponding  time/space domain sequence, is desired. In fact, the z-transform operation would be useless if the inverse z-transform did not exist!
:[font = subsection; inactive; startGroup; Cclosed; ]
Uniqueness of the z-Transform
:[font = text; inactive; endGroup; ]
	Given a certain time/space domain sequence, a unique z-transform expression can be associated with it.  However, given a z-transform closed-form expression, many time-sequences would correspond to this same z-transform.  This is because more than one time/space domain sequence may have the same closed-form z-transform expression but different ROC's (remember that the ROC represents the region in which the z-transform expression is valid).  Therefore, in order to determine a unique time/space domain sequence corresponding to a closed-form z-transform, the corresponding ROC must be indicated in addition to the z-transform expression.  In other words, it is necessary to specify the ROC associated with the z-transform expression in order to be able to determine the inverse z-transform. The following example illustrates the fact that a z-transform expression may have many corresponding time/space domain sequences, one for each possible ROC.
:[font = subsection; inactive; startGroup; Cclosed; ]
Example:  Associating Different ROC's with the Same z-Transform
:[font = text; inactive; ]
	The following functions is an interactive one which provides the user with many options and receives input from the keyboard. For this example, respond with a "y" when asked "Want Inverse ZTransform (y/n)?".
:[font = input; startGroup; Cclosed; ]
AllPoleZeroPlots[ z / (z - 0.5), z ]
:[font = print; inactive; ]
 ROC # 1
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {0.}
:[font = print; inactive; ]
The poles are:   {0.5}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.5 0.5 moveto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
0.5 0.5 lineto
stroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
0.004 setlinewidth
0.68794 0.5684 moveto
0.5 0.5 lineto
stroke
0.68385 0.57874 moveto
0.30855 0.44214 lineto
stroke
0.67917 0.58886 moveto
0.30562 0.4529 lineto
stroke
0.67391 0.59877 moveto
0.30329 0.46388 lineto
stroke
0.66804 0.60846 moveto
0.30156 0.47507 lineto
stroke
0.66154 0.61792 moveto
0.30046 0.48649 lineto
stroke
0.65439 0.62714 moveto
0.30001 0.49815 lineto
stroke
0.64654 0.63611 moveto
0.30025 0.51007 lineto
stroke
0.63795 0.64481 moveto
0.30124 0.52225 lineto
stroke
0.62856 0.65321 moveto
0.30304 0.53473 lineto
stroke
0.61826 0.66129 moveto
0.30573 0.54753 lineto
stroke
0.60696 0.669 moveto
0.30944 0.56071 lineto
stroke
0.59448 0.67628 moveto
0.31432 0.57431 lineto
stroke
0.58059 0.68305 moveto
0.32061 0.58842 lineto
stroke
0.56492 0.68917 moveto
0.32867 0.60318 lineto
stroke
0.54688 0.69443 moveto
0.33911 0.6188 lineto
stroke
0.5253 0.69839 moveto
0.3531 0.63572 lineto
stroke
0.49717 0.69998 moveto
0.37363 0.65502 lineto
stroke
0.62637 0.34498 moveto
0.50283 0.30002 lineto
stroke
0.6469 0.36428 moveto
0.4747 0.30161 lineto
stroke
0.66089 0.3812 moveto
0.45312 0.30557 lineto
stroke
0.67133 0.39682 moveto
0.43508 0.31083 lineto
stroke
0.67939 0.41158 moveto
0.41941 0.31695 lineto
stroke
0.68568 0.42569 moveto
0.40552 0.32372 lineto
stroke
0.69056 0.43929 moveto
0.39304 0.331 lineto
stroke
0.69427 0.45247 moveto
0.38174 0.33871 lineto
stroke
0.69696 0.46527 moveto
0.37144 0.34679 lineto
stroke
0.69876 0.47775 moveto
0.36205 0.35519 lineto
stroke
0.69975 0.48993 moveto
0.35346 0.36389 lineto
stroke
0.69999 0.50185 moveto
0.34561 0.37286 lineto
stroke
0.69954 0.51351 moveto
0.33846 0.38208 lineto
stroke
0.69844 0.52493 moveto
0.33196 0.39154 lineto
stroke
0.69671 0.53612 moveto
0.32609 0.40123 lineto
stroke
0.69438 0.5471 moveto
0.32083 0.41114 lineto
stroke
0.69145 0.55786 moveto
0.31615 0.42126 lineto
stroke
0.5 0.5 moveto
0.31206 0.4316 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.7 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
                            n
 The time sequence is: -(0.5  Step[-1 - n])
:[font = print; inactive; ]
 ROC # 2
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {0.}
:[font = print; inactive; ]
The poles are:   {0.5}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.7 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
                          n
 The time sequence is: 0.5  Step[n]
:[font = print; inactive; endGroup; endGroup; ]
 End of ROCs !
:[font = subsection; inactive; startGroup; Cclosed; ]
Definition of the Inverse z-Transform
:[font = text; inactive; ]
		There are several ways of determining the inverse z-transform from a given algebraic expression and an associated ROC. The formal mathematical way of determining the inverse z-transform is based on the Cauchy integral theorem and is quite involved, as illustrated below.
:[font = postscript; inactive; PostScript; output; pictureLeft = 129; pictureWidth = 168; pictureHeight = 40; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.238095 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.238095 scale
1 string
168 40 1 [168 0 0 40 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000FFFFC0FFF03FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00001FFFC01F8007FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF1FFFFF03F038FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFF03F1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFC7E3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFC7E3FFFFFFF
007FC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFE38FC7FF81FF
E3FFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFE000001FF03F
E3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF800003FE3F
FC71FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFE3FFC01FFFFFFFFFFFFFFE3F
FC003FFFFFFFFFFFFFFC7FFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFC0000FFFFFFFFFFFFFFFE3F
FC7FC7FFFFFFFFFFFFE3FFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFFFE3F
FF8FF8FFFFFFFFFFFFE3FFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FF8FF8FFFFFFFFFFFF1FFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
E07FC0FC7FFFE07FC01FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FC0007E000380001FF1FFE00007FFF1FF00003FFFFFFFFFFFFFFFFE07E07
00003F
FC0E001C7FFFE07FC0E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFF81FFE00FF81FFE07FC7FFF03F03FE3FFFFFFFFFFFFFFF8038038
03FE3F
FF8E07FC7FFFE07FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007
FFFFFFFFF1FFE07FF81FFFC0FFFFFF03FE07FFFFFFFFFFFFFFFFF81FF03F
E07FFF
FF803FFC7FFFE07FC0FFF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFF8E38
FFFFFFFFFE3FE07FF81FFFF81FFFFF03FFC0FFFFFFFFFFFFFFFFF81FF03F
FC0FFF
FFF03FFC7FFFFC0FF81FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E3F
1FFFFFFFFFC703FFF81FFFFF03FFFF03FFF81FFFFFFFFFFFFFFFF81FFE3F
FF81FF
FF8007FC7FFFFC01F81FF1FFFFFFFFFFFFFFE00000000000000007FC7E3F
1FFFFFFFFFC003FFF81FFFFFE07FFF03FFFF03FFFFFFFFFFFFFFFF1FFE07
FFF03F
FF81C0FC7FFFFC0E001FF1FFFC0000007FFFFFFFFFFFFFFFFFFFFFFC7E3F
1FFFFFFFFFF81FFFF81FFFC7FC0FFF03FE3FE07FFFFFFFFFFFFFFF03F007
E3FE07
FC01F81C7FFFE00FC0FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E38
FFFFFFFFFFF81FFFFF1FFFC0000FFF1FFE00007FFFFFFFFFFFFFFFFC01C7
E00007
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007
FFFFFFFFFFC003FFFF1FFFFFFFFFFF1FFFFFFFF1F81FFFFFE00FFFFFFFC7
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFFFFC0FC7FFFE3FFFFFFFFF8FFFFFFFFF1F8E3FFFFFC7FFFFFFFC0
FFFFFF
FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFFFE00FC0FFFE3FFFFFFFFF8FFFFFFFFF1F8FFFFFFFC7FFFFFFFC0
FFFFFF
FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFFFE07FF81FFFC7FFFFFFFC7FFFFFFFFFE3F1FFFFFFC7FFFFFFFC0
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00003FFFFFFFFFFE3F
FFFFFFFF80001C0007FFFFFFFFFFFFFFFFFFFFFE3F1C0000FC7FFFFFFE00
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFE3F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFC7FFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFE3F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFE07
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1C0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; endGroup; ]
However, for many kinds of sequences and z-transforms, simpler methods are often sufficient.  Some of these methods are the inspection method, partial fraction expansion, and power series expansion.  Each of these methods is discussed briefly in the next section. 
:[font = subsection; inactive; startGroup; Cclosed; ]
Strategies For Finding Inverse Transforms
:[font = text; inactive; ]
	The inspection method consists of referring to tables of z-transform pairs or becoming familiar with certain pairs, and then using these pairs to derive the corresponding time/space domain sequence. An example of  two commonly used z-transform pairs are:
:[font = postscript; inactive; PostScript; output; pictureLeft = 106; pictureWidth = 230; pictureHeight = 40; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.173913 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.173913 scale
1 string
230 40 1 [230 0 0 40 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC0000FFFFFFFFFFFFFFF03F0380001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFFFFFFFFC01C01C01FF1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFFFFFFFFC0FF81FF03FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFFFFFFFFC0FF81FFE07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFF0000001FFFC0FFF03FFC0FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFFFFFFFFF8FFF03FFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFFFFFFFFF81F803F1FF03FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFFFFFFFFFFE001C700003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80001F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FF81F81FFFFFFC0FC0FC7FFF03FE00FFF1FFFFF1FFFFFFFFFFFFFFFFFFFF
FFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFC0
03FFC003FE001FFFFFFC700003F1FFFFFFFFFFFFF8FFF03F038FC0
E00E00E3FFFFE001C01C7FFF03FE071FF1FFFF8FFFFFFFFFFFFFFFFFFFFF
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFF8
1FFE07E07FC0FFFFFFFC703FE3F1FFFC0FFFFFFFF8FC01C01C0FC0
E07FC0FFFFFFE07E00FC7FFF03FE07FFF1FFFC7FFFFFFFFFFFFFFFFFFFFF
FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFF8
1FF03FFC0FC0FFFFFFFC7E07FFF1FFFFF03FFFFFF8FC0FF81F8FC0
E07FC0FFFFFFE07FC0FC7FFF03FE07FFF1FFE3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FF03FFC0FC0FFFFFFFC7FC0FFF1FFFFFFC0FFFFF8FC0FF81F8FC0
E07FF81FFFFFFC7FC0FC7FFFE07FC0FFF1FF000000000000000000000000
000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FF03FFC0FC0FFFFFFFC7FF81FF1FFFFFFFF03FFF8FC0FFF038FC0
FC7FF81FFFFFFC0FF81C7FFFE00FC0FFF1FFE3FFFFFFFFFFFFFFFFFFFFFF
FFFFFFE3FFC0000000000000000000000000000000000000000FFFFFFFF8
1FF03FFC0FC0FFFFFFFC7FFF03F1FFFFFFC0FFFFF8FF8FFF038FC0
FC0FC01FFFFFFC0FF81C7FFFE07000FFF1FFFC7FFFFFFFFFFFFFFFFFFFFF
FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FFE07E07E00E07FFFFC7E3FE071FFFFF03FFFFFF8FF81F8038FC0
FFF000E3FFFFE00FF81C7FFF007E07FFF1FFFF8FFFFFFFFFFFFFFFFFFFFF
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
007FC003FFC7007FFFFC7E000071FFFC0FFFFFFFF8FFFE001C0FC0
FFFFFFFC7E07FFFFFFFC7FFFFFFFFFFFF1FFFFF1FFFFFFFFFFFFFFFFFFFF
FFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFC7E38FFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFC0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFC7E3FFFFFFFFC7FFFFFFFFFFFF1FFFFFFFFFFFFFFFC7FF8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1F8FFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFF8FC7FFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFF8FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
007FFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFF8FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFC703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC7FFFFFF1FFFFFFFFFFFFF8FFFFFFFF8FC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC703FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
and
:[font = postscript; inactive; PostScript; output; pictureLeft = 85; pictureWidth = 274; pictureHeight = 40; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.145985 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.145985 scale
1 string
274 40 1 [274 0 0 40 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80001FFFFFFFFFFF
FFFE07E0700003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FF803803803FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FF81FF03FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FF81FF03FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFE0000003F
FF81FFE07FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFF1FFE07FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFF03F007E3FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFC0038E00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8E07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF80001FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFC0FC0FFFFFFE07E07E3FFFFFFFFFFFC0FF803FFFFFFFFFFFC0
000FFF1FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFE001FFE001FF000FFFFFFFC700003F
1FFFFFFFFFFFFF8FFF03F038FC
FFFFFFFFF0070071FFFFF000E00E3FFFFFFFFFFFC0FF81C7FFFFFFFFFFFF
03FFFF1FFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF81FFFFFFFFFC0FFF03F03FE07FFFFFFFC703FE3F
1FFFFFFF81FFFF8FC01C01C0FC
FFFFFFFFF03FE07FFFFFF03F007E3FFFFFFFFFFFC0FF81FFFFFFFFFFFFFF
03FFFF1FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFC0FF81FFE07E07FFFFFFFC7E07FFF
1FFFFFE07FFFFF8FC0FF81F8FC
FFFFFFFFF03FE07FFFFFF03FE07E3FFFFFFFFFFFC0FF81FFFFFFFFFFFFFF
03FFFF1FFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF81FFE07E07FFFFFFFC7FC0FFF
1FFFF81FFFFFFF8FC0FF81F8FC
0000001FF03FFC0FFFFFFE3FE07E3FFC0000007FF81FF03FE0000003FFFF
03FFFF1FF000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF81FFE07E07FFFFFFFC7FF81FF
1FFE07FFFFFFFF8FC0FFF038FC
FFFFFFFFFE3FFC0FFFFFFE07FC0E3FFFFFFFFFFFF803F03FFFFFFFFFFFFF
03FFFF1FFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FF8000000000000000
0000000000000000000000001FFFFFFC0FF81FFE07E07FFFFFFFC7FFF03F
1FFFF81FFFFFFF8FF8FFF038FC
FFFFFFFFFE07E00FFFFFFE07FC0E3FFFFFFFFFFFF81C003FFFFFFFFFFFFF
03FFFF1FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFF03F03F00703FFFFFC7E3FE07
1FFFFFE07FFFFF8FF81F8038FC
FFFFFFFFFFF80071FFFFF007FC0E3FFFFFFFFFFFC01F81FFFFFFFFFFFFFF
03FFFF1FFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FE001FFE3803FFFFFC7E00007
1FFFFFFF81FFFF8FFFE001C0FC
FFFFFFFFFFFFFFFE3F03FFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7
03FFFF1FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFE3F1C7FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
03FFFF1FFFFFFFFFFFFFFFF80001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFE3F1FFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
03FFFF1FFFFFFFFFFFFFFFF8FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FC7FFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFFC7E3FFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E3FE001FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFFC7E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFE381FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFF
1FFFFFFFFFFFFF8FFFFFFFF8FC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE3FE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
	The partial fraction expansion is related to rational z-transforms and consists of finding the partial fraction expansion of a rational z-transform whose inverse z-transform cannot be found directly by inspection. The partial fraction expansion expands the rational z-transform into a sum of simpler terms whose inverse z-transforms can be easily found from tables or by inspection.
:[font = text; inactive; ]
	The power series expansion method is based on the fact that the defining equation of the z-transform (cf equation 1) is a power series  where the time/space domain sequence values, x[n], are the coefficients of z^-n. It follows that if the z-transform is given as power series, i.e.
:[font = text; inactive; ]
X{z] = ... + x[-2] z^2 + x[-1] z +x[0] + x[1] z^-1 + x[2] z^-2 + x[3] z^-3 +...,
:[font = text; inactive; ]
any particular value of the sequence x[n] can be determined by finding the coefficient of the appropriate power of z^-1. This method is especially useful for finite-length sequences where the z-transform X[z] has the form of a simple polynomial in z^-1. In addition, in this case, one can use the fact that  Z{Delta[n-m]} is z^-m and use the linearity property of the z-transform to express the corresponding time sequence in terms of a sequence of shifted delta functions.
:[font = text; inactive; ]
	In the following example, the function InvZTransform is used to find the inverse z-transform of an expression in function of z. Note that this function has the Dialogue -> All option which allows you to see every step that the inverse z-transform rule base makes when computing an inverse z-transform. For more information about the InvZTransform function type ?InvZTransform or ??InvZTransform in an input cell, then press the ENTER key.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Using Partial Fractions Expansion
:[font = text; inactive; startGroup; ]
		In the  following input cell, the partial fraction method is used.
:[font = input; startGroup; Cclosed; ]
InvZTransform[{z/((z-1)(z-2)),1,2},z,n, Dialogue -> All]
:[font = print; inactive; ]
  -1         z
Z   {-----------------}
  z  (-2 + z) (-1 + z)
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1         z
Z   {-----------------}
  z  (-2 + z) (-1 + z)
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1        1
Z   {----------------}
  z       2
     (1 - -) (-1 + z)
          z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1         1
Z   {-----------------}
  z       2       1
     (1 - -) (1 - -) z
          z       z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
( after the term
:[font = print; inactive; ]
          1
  -----------------
       2       1
  (1 - -) (1 - -) z
       z       z
:[font = print; inactive; ]
  has been broken up into its partial
:[font = print; inactive; ]
  fractions representation
:[font = print; inactive; ]
    1        1
  ------ - ------ )
       1        2
  -1 + -   -1 + -
       z        z
:[font = print; inactive; ]
  -1   1        1
Z   {------ - ------}
  z       1        2
     -1 + -   -1 + -
          z        z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
  -1   1         -1     1
Z   {------} + Z   {-(------)}
  z       1      z         2
     -1 + -           -1 + -
          z                z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
   -1     1         -1   1
-Z   {-(-----)} - Z   {-----}
   z        2       z      1
        1 - -          1 - -
            z              z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
   n
-(2  Step[-1 - n]) - Step[n]
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
   n
-(2  Step[-1 - n]) - Step[n]
:[font = output; inactive; output; endGroup; endGroup; ]
-(2^n*Step[-1 - n] + Step[n])
;[o]
   n
-(2  Step[-1 - n] + Step[n])
:[font = text; inactive; startGroup; ]
		In the following input cell, z^4 is first replaced by z and then the inverse z-transform is found for z/((z-1)(z-2)) as in the previous example. Finally, the resulting sequence is upsampled by 4 (i.e. three zeros are inserted between the samples of the sequence). 
:[font = input; startGroup; Cclosed; ]
InvZTransform[{z^4/((z^4 - 1)(z^4 - 2)),1,2},z,n,Dialogue -> All]
:[font = print; inactive; ]
              4
  -1         z
Z   {-------------------}
  z         4         4
     (-2 + z ) (-1 + z )
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                -1         z
Upsample     [Z   {-----------------}]
        4,0,n   z  (-2 + z) (-1 + z)
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                -1         z
Upsample     [Z   {-----------------}]
        4,0,n   z  (-2 + z) (-1 + z)
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                -1        1
Upsample     [Z   {----------------}]
        4,0,n   z       2
                   (1 - -) (-1 + z)
                        z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                -1         1
Upsample     [Z   {-----------------}]
        4,0,n   z       2       1
                   (1 - -) (1 - -) z
                        z       z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
( after the term
:[font = print; inactive; ]
          1
  -----------------
       2       1
  (1 - -) (1 - -) z
       z       z
:[font = print; inactive; ]
  has been broken up into its partial
:[font = print; inactive; ]
  fractions representation
:[font = print; inactive; ]
    1        1
  ------ - ------ )
       1        2
  -1 + -   -1 + -
       z        z
:[font = print; inactive; ]
                -1   1        1
Upsample     [Z   {------ - ------}]
        4,0,n   z       1        2
                   -1 + -   -1 + -
                        z        z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                -1   1         -1     1
Upsample     [Z   {------} + Z   {-(------)}]
        4,0,n   z       1      z         2
                   -1 + -           -1 + -
                        z                z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                 -1     1         -1   1
Upsample     [-Z   {-(-----)} - Z   {-----}]
        4,0,n    z        2       z      1
                      1 - -          1 - -
                          z              z
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                 n
Upsample     [-(2  Step[-1 - n]) - Step[n]]
        4,0,n
:[font = print; inactive; ]
which becomes
:[font = print; inactive; ]
                 n
Upsample     [-(2  Step[-1 - n]) - Step[n]]
        4,0,n
:[font = output; inactive; output; endGroup; endGroup; ]
Upsample[4, 0, n][-(2^n*Step[-1 - n] + Step[n])]
;[o]
                 n
Upsample     [-(2  Step[-1 - n] + Step[n])]
        4,0,n
:[font = text; inactive; startGroup; ]
		The following input cell expands the given factors into a power series (which will be a polynomial of degree two in this case) and then expresses the inverse z-transform sequence in terms of discrete-time impulses (or discrete-time delta functions). 
:[font = input; startGroup; Cclosed; ]
InvZTransform[{(z-2) (z-1),0,Infinity},z,n,Dialogue -> All]
:[font = print; inactive; startGroup; ]
  -1
Z   {(-2 + z) (-1 + z)}
  z
which becomes
( after the term
  (-2 + z) (-1 + z)
  has been broken up into its partial 
  fractions representation
             2
  2 - 3 z + z  )
  -1            2
Z   {2 - 3 z + z }
  z
which becomes
  -1        -1         2
Z   {2} + Z   {-3 z + z }
  z         z
which becomes
                 -1           -1  2
2 Impulse[n] + Z   {-3 z} + Z   {z }
                 z            z
which becomes
2 Impulse[n] - 3 Impulse[1 + n] + Impulse[2 + n]
which becomes
2 Impulse[n] - 3 Impulse[1 + n] + Impulse[2 + n]
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
2*Impulse[n] - 3*Impulse[1 + n] + Impulse[2 + n]
;[o]
2 Impulse[n] - 3 Impulse[1 + n] + Impulse[2 + n]
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Other Inverse z-Transforms
:[font = text; inactive; ]
		Inverse z-transforms of many expressions can be computed using the InvZTransform function as shown by the following input cell below.
:[font = input; startGroup; Cclosed; ]
InvZTransform[{Sqrt[z - 1],0,Infinity},z,n,Dialogue -> All]
:[font = print; inactive; startGroup; ]
  -1
Z   {Sqrt[-1 + z]}
  z
which becomes
  -1
Z   {Sqrt[-1 + z]}
  z
which becomes
  -1
Z   {Sqrt[-1 + z]}
  z
which becomes
  -1           1
Z   {Sqrt[-1 + -]}
  z            z
which becomes
    1/2 - n          1
(-1)        Binomial[-, n] Step[n]
                     2
which becomes
    1/2 - n          1
(-1)        Binomial[-, n] Step[n]
                     2
    1/2 + n          1
(-1)        Binomial[-, -n] Step[-n]
                     2
which becomes
    1/2 + n          1
(-1)        Binomial[-, -n] Step[-n]
                     2
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; endGroup; ]
I*(-1)^n*Binomial[1/2, -n]*Step[-n]
;[o]
      n          1
I (-1)  Binomial[-, -n] Step[-n]
                 2
:[font = section; inactive; startGroup; Cclosed; ]
Stability and Causality
:[font = subsection; inactive; startGroup; Cclosed; ]
Stability
:[font = text; inactive; ]
		A sequence is stable if and only if it is absolutely summable, i.e. if and only if	                             
:[font = postscript; inactive; PostScript; output; pictureLeft = 169; pictureWidth = 95; pictureHeight = 47; preserveAspect; ]
%!
%%Creator: Mathematica
MathPictureStart % Start of picture
% Scaling calculations
0 1 0 1
[
[ 0.000000 0.000000 0 0 ]
[ 1.000000 0.494737 0 0 ]
] MathScale
% Start of Graphics
0 setgray
0 setlinewidth
gsave
0.000000 0.000000 translate
1.000000 0.494737 scale
1 string
95 47 1 [95 0 0 47 0 0] {
 currentfile
 1 index
 readhexstring
 pop
} false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
1F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
1F8E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
1F8FF80001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
E3F1FFFFFFFFFFFFF81C0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
E3F1F80001C0000FC7E3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
1C0FFFFFFFFFFFFFF81C0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFF000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFE00000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFC7FFFFFFE07FFFFFFFFFFC003FFFFFFFE001FFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFF8FFFFFFFC7FC7FFFFFFFC7FFFFFFFFFFFF1C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFF1FFFFFFC7FC7FFFFFFFC7FFFFFFFFFFFF1C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFE3FFFFFFFFC7FFFFFFFC7FFFFFFFFFFFF1C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFC7FFFFFFFC7E07FC0FC7FFF03FE00FFF1C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFF8FFFFFFFC7FC0E001C7FFF03FE071FF1C7FFFFFFFFFE07FFF
FFFFFFFFFFF8
FFFFFFFFFFFF1FFFFFFC7FF8E07FC7FFF03FE07FFF1C7FFFFFFFF81FFFFF
FC01FFE00FF8
FFFFFFFFFFFFE3FFFFFC7FF803FFC7FFF03FE07FFF1C7FFFFFFE07FFFFFF
E3FE3F1FF1F8
FFFFFFFFFFFFE07FFFFC7FFF03FFC7FFFE07FC0FFF1C7FFFFF81FFFFFFFF
E3FFC0FFF1F8
FFFFFFFFFFFF03FFFFFC7FF8007FC7FFFE00FC0FFF1C7FFFFFFE07FFFFFF
E3FE3F1FF1F8
FFFFFFFFFFF81FFFFFFC7FF81C0FC7FFFE07000FFF1C7FFFFFFFF81FFFFF
FC01FFE00FF8
FFFFFFFFFFC0FFFFFFFC7FC01F81C7FFF007E07FFF1C7FFFFFFFFFE07FFF
FFFFFFFFFFF8
FFFFFFFFFE07FFFFFFFC7FFFFFFFC7FFFFFFFFFFFF1C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFF03FFFFFFFFC7FFFFFFFC7FFFFFFFFFFFF1C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFF81FFFFFFC7FC7FFFFFFFC7FFFFFFFFFFFF1C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFC0FFFFFFFC7FC7FFFFFFFC003FFFFFFFE001C7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFE07FFFFFFE07FC7FFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFF000000000007FC7FFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFE0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFF1F8FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFE0703FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8
pop
grestore
%% End of Graphics
MathPictureEnd %% End of picture

:[font = text; inactive; ]
However, note that this condition implies that the z transform must exist for |z| =1 (i.e. on the unit circle) and vice-versa (c.f. the equation in the Convergence section). It follows that stability can be determined also graphically by investigating the ROC of the z transform of a given sequence: the sequence will be a stable one if and only if the ROC includes the unit circle.  Moreover, the  fact that the unit circle is included in the ROC implies that the DTFT of the corresponding sequence exists. Refer to the next section for more information.
:[font = text; inactive; ]
		Determine whether each of the following sequences is stable or not, by looking at the corresponding pole-zero diagram, then check your answer by evaluating the function Stable in the input cells of the Solution parts. 
:[font = text; inactive; startGroup; ]
Exercise 1:
:[font = input; endGroup; ]
PoleZeroPlot[ ZTransform[0.5^n Step[n], n] ]
:[font = text; inactive; startGroup; ]
Solution 1:
:[font = input; endGroup; ]
Stable[ ZTransform[0.5^n Step[n], n] ]
:[font = text; inactive; startGroup; ]
Exercise 2:
:[font = input; endGroup; ]
PoleZeroPlot[ ZTransform[-0.5^n Step[-n-1], n] ]
:[font = text; inactive; startGroup; ]
Solution 2:
:[font = input; endGroup; ]
Stable[ ZTransform[-0.5^n Step[-n-1], n] ]
:[font = text; inactive; startGroup; ]
Exercise 3:
:[font = input; endGroup; ]
PoleZeroPlot[
ZTransform[0.5^n Step[n] - 1.5^n Step[-n-1], n ] ]
:[font = text; inactive; startGroup; ]
Solution 3:
:[font = input; endGroup; endGroup; ]
Stable[
ZTransform[0.5^n Step[n] - 1.5^n Step[-n-1], n ] ]
:[font = subsection; inactive; startGroup; Cclosed; ]
Causality
:[font = text; inactive; ]
		A causal sequence, x[n], is a sequence that is zero for all negative values of n. It follows that a causal sequence is a special case of a right-sided sequence with C = 0 (refer to the previous section for a definition of a right-sided sequence).  
:[font = text; inactive; ]
		It is important  to note that, whereas stability can be directly seen by investigating the ROC, causality cannot be determined from the ROC alone in many cases. In fact, we can directly conclude that a sequence is not causal if the corresponding ROC lies inside a circle, or inside an annular region; however, we cannot conclude that a sequence is causal if the ROC covers all the region outside a circle: in this latter case, we can only conclude that it is right-sided . Why? 
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Analysis of a Right Sided, Non-Causal Sequence
:[font = input; startGroup; ]
DSPAnalyze[0.5^n Step[n + 2], n,-4,10]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.29592 0.06803 0.01472 0.14715 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-4)] 0.02381 0.00222 0 1 Msboxa
[(-2)] 0.15986 0.00222 0 1 Msboxa
[(2)] 0.43197 0.00222 0 1 Msboxa
[(4)] 0.56803 0.00222 0 1 Msboxa
[(6)] 0.70408 0.00222 0 1 Msboxa
[(8)] 0.84014 0.00222 0 1 Msboxa
[(10)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(1)] 0.28342 0.16187 1 0 Msboxa
[(2)] 0.28342 0.30902 1 0 Msboxa
[(3)] 0.28342 0.45617 1 0 Msboxa
[(4)] 0.28342 0.60332 1 0 Msboxa
[( )] 0.29592 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.02381 0.00847 moveto
0.02381 0.02097 lineto
stroke
0 setgray
[(-4)] 0.02381 0.00222 0 1 Mshowa
0.15986 0.00847 moveto
0.15986 0.02097 lineto
stroke
0 setgray
[(-2)] 0.15986 0.00222 0 1 Mshowa
0.43197 0.00847 moveto
0.43197 0.02097 lineto
stroke
0 setgray
[(2)] 0.43197 0.00222 0 1 Mshowa
0.56803 0.00847 moveto
0.56803 0.02097 lineto
stroke
0 setgray
[(4)] 0.56803 0.00222 0 1 Mshowa
0.70408 0.00847 moveto
0.70408 0.02097 lineto
stroke
0 setgray
[(6)] 0.70408 0.00222 0 1 Mshowa
0.84014 0.00847 moveto
0.84014 0.02097 lineto
stroke
0 setgray
[(8)] 0.84014 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(10)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.29592 0 moveto
0.29592 0.61803 lineto
stroke
0.28967 0.16187 moveto
0.30217 0.16187 lineto
stroke
0 setgray
[(1)] 0.28342 0.16187 1 0 Mshowa
0.28967 0.30902 moveto
0.30217 0.30902 lineto
stroke
0 setgray
[(2)] 0.28342 0.30902 1 0 Mshowa
0.28967 0.45617 moveto
0.30217 0.45617 lineto
stroke
0 setgray
[(3)] 0.28342 0.45617 1 0 Mshowa
0.28967 0.60332 moveto
0.30217 0.60332 lineto
stroke
0 setgray
[(4)] 0.28342 0.60332 1 0 Mshowa
0 setgray
[( )] 0.29592 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.008 setlinewidth
0.02381 0.01472 Mdot
0.004 setlinewidth
0.09184 0.01472 moveto
0.09184 0.01472 lineto
stroke
0.008 setlinewidth
0.09184 0.01472 Mdot
0.004 setlinewidth
0.15986 0.01472 moveto
0.15986 0.60332 lineto
stroke
0.008 setlinewidth
0.15986 0.60332 Mdot
0.004 setlinewidth
0.22789 0.01472 moveto
0.22789 0.30902 lineto
stroke
0.008 setlinewidth
0.22789 0.30902 Mdot
0.004 setlinewidth
0.29592 0.01472 moveto
0.29592 0.16187 lineto
stroke
0.008 setlinewidth
0.29592 0.16187 Mdot
0.004 setlinewidth
0.36395 0.01472 moveto
0.36395 0.08829 lineto
stroke
0.008 setlinewidth
0.36395 0.08829 Mdot
0.004 setlinewidth
0.43197 0.01472 moveto
0.43197 0.0515 lineto
stroke
0.008 setlinewidth
0.43197 0.0515 Mdot
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.03311 lineto
stroke
0.008 setlinewidth
0.5 0.03311 Mdot
0.004 setlinewidth
0.56803 0.01472 moveto
0.56803 0.02391 lineto
stroke
0.008 setlinewidth
0.56803 0.02391 Mdot
0.004 setlinewidth
0.63605 0.01472 moveto
0.63605 0.01931 lineto
stroke
0.008 setlinewidth
0.63605 0.01931 Mdot
0.004 setlinewidth
0.70408 0.01472 moveto
0.70408 0.01701 lineto
stroke
0.008 setlinewidth
0.70408 0.01701 Mdot
0.004 setlinewidth
0.77211 0.01472 moveto
0.77211 0.01586 lineto
stroke
0.008 setlinewidth
0.77211 0.01586 Mdot
0.004 setlinewidth
0.84014 0.01472 moveto
0.84014 0.01529 lineto
stroke
0.008 setlinewidth
0.84014 0.01529 Mdot
0.004 setlinewidth
0.90816 0.01472 moveto
0.90816 0.015 lineto
stroke
0.008 setlinewidth
0.90816 0.015 Mdot
0.004 setlinewidth
0.97619 0.01472 moveto
0.97619 0.01486 lineto
stroke
0.008 setlinewidth
0.97619 0.01486 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
   n
0.5  Step[2 + n]
:[font = print; inactive; ]
has the following z-transform:
:[font = print; inactive; ]
     2
 4. z
-------
    0.5
1 - ---
     z
:[font = print; inactive; ]
The region of convergence is:
:[font = print; inactive; ]
0.5 < |z| < Infinity
:[font = print; inactive; ]
The system is stable.
:[font = message; inactive; ]
PoleZeroPlot::notrational: 
   Transform is not a rational polynomial.
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {0., 0., 0.}
:[font = print; inactive; ]
The poles are:   {0.5}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(*O*)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.7 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
By substituting into the z-transform,
:[font = print; inactive; ]
the frequency response is
:[font = print; inactive; ]
      2 I w
  4. E
-------------
         -I w
1 - 0.5 E
:[font = print; inactive; ]

:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 -1.09939 0.06168 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 -0.0016 0 1 Msboxa
[(-4)] 0.19685 -0.0016 0 1 Msboxa
[(-2)] 0.34842 -0.0016 0 1 Msboxa
[(2)] 0.65158 -0.0016 0 1 Msboxa
[(4)] 0.80315 -0.0016 0 1 Msboxa
[(6)] 0.95473 -0.0016 0 1 Msboxa
[(w)] 1.00625 0.0109 -1 0 Msboxa
[(20)] 0.4875 0.13427 1 0 Msboxa
[(22)] 0.4875 0.25763 1 0 Msboxa
[(24)] 0.4875 0.381 1 0 Msboxa
[(26)] 0.4875 0.50437 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.0109 moveto
1 0.0109 lineto
stroke
0.04527 0.00465 moveto
0.04527 0.01715 lineto
stroke
0 setgray
[(-6)] 0.04527 -0.0016 0 1 Mshowa
0.19685 0.00465 moveto
0.19685 0.01715 lineto
stroke
0 setgray
[(-4)] 0.19685 -0.0016 0 1 Mshowa
0.34842 0.00465 moveto
0.34842 0.01715 lineto
stroke
0 setgray
[(-2)] 0.34842 -0.0016 0 1 Mshowa
0.65158 0.00465 moveto
0.65158 0.01715 lineto
stroke
0 setgray
[(2)] 0.65158 -0.0016 0 1 Mshowa
0.80315 0.00465 moveto
0.80315 0.01715 lineto
stroke
0 setgray
[(4)] 0.80315 -0.0016 0 1 Mshowa
0.95473 0.00465 moveto
0.95473 0.01715 lineto
stroke
0 setgray
[(6)] 0.95473 -0.0016 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.0109 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.13427 moveto
0.50625 0.13427 lineto
stroke
0 setgray
[(20)] 0.4875 0.13427 1 0 Mshowa
0.49375 0.25763 moveto
0.50625 0.25763 lineto
stroke
0 setgray
[(22)] 0.4875 0.25763 1 0 Mshowa
0.49375 0.381 moveto
0.50625 0.381 lineto
stroke
0 setgray
[(24)] 0.4875 0.381 1 0 Mshowa
0.49375 0.50437 moveto
0.50625 0.50437 lineto
stroke
0 setgray
[(26)] 0.4875 0.50437 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.02505 0.60318 lineto
0.02629 0.60275 lineto
0.02753 0.60203 lineto
0.02877 0.60103 lineto
0.03125 0.59821 lineto
0.03373 0.59431 lineto
0.03869 0.58348 lineto
0.04365 0.56909 lineto
0.05357 0.53211 lineto
0.06349 0.48837 lineto
0.10317 0.30902 lineto
0.12302 0.23432 lineto
0.14286 0.17217 lineto
0.1627 0.12176 lineto
0.18254 0.08204 lineto
0.19246 0.06589 lineto
0.20238 0.05208 lineto
0.2123 0.04052 lineto
0.22222 0.03116 lineto
0.23214 0.02393 lineto
0.2371 0.02111 lineto
0.24206 0.0188 lineto
0.24702 0.01701 lineto
0.2495 0.01631 lineto
0.25198 0.01574 lineto
0.25446 0.01529 lineto
0.2557 0.01511 lineto
0.25694 0.01497 lineto
0.25818 0.01486 lineto
0.25942 0.01478 lineto
0.26066 0.01473 lineto
0.2619 0.01472 lineto
0.26314 0.01473 lineto
0.26438 0.01478 lineto
0.26562 0.01486 lineto
0.26687 0.01497 lineto
0.26935 0.01529 lineto
0.27183 0.01574 lineto
0.27431 0.01631 lineto
0.27679 0.01701 lineto
0.28175 0.0188 lineto
0.28671 0.02111 lineto
0.29167 0.02393 lineto
0.30159 0.03116 lineto
0.31151 0.04052 lineto
0.32143 0.05208 lineto
0.34127 0.08204 lineto
0.36111 0.12176 lineto
0.38095 0.17217 lineto
Mistroke
0.42063 0.30902 lineto
0.44048 0.39559 lineto
0.46032 0.48837 lineto
0.47024 0.53211 lineto
0.4752 0.55175 lineto
0.48016 0.56909 lineto
0.48512 0.58348 lineto
0.4876 0.58938 lineto
0.49008 0.59431 lineto
0.49256 0.59821 lineto
0.4938 0.59976 lineto
0.49504 0.60103 lineto
0.49628 0.60203 lineto
0.49752 0.60275 lineto
0.49876 0.60318 lineto
0.5 0.60332 lineto
0.50124 0.60318 lineto
0.50248 0.60275 lineto
0.50372 0.60203 lineto
0.50496 0.60103 lineto
0.5062 0.59976 lineto
0.50744 0.59821 lineto
0.50992 0.59431 lineto
0.51488 0.58348 lineto
0.51984 0.56909 lineto
0.53968 0.48837 lineto
0.57937 0.30902 lineto
0.59921 0.23432 lineto
0.61905 0.17217 lineto
0.63889 0.12176 lineto
0.65873 0.08204 lineto
0.67857 0.05208 lineto
0.68849 0.04052 lineto
0.69841 0.03116 lineto
0.70833 0.02393 lineto
0.71329 0.02111 lineto
0.71825 0.0188 lineto
0.72321 0.01701 lineto
0.72569 0.01631 lineto
0.72817 0.01574 lineto
0.73065 0.01529 lineto
0.73189 0.01511 lineto
0.73313 0.01497 lineto
0.73438 0.01486 lineto
0.73562 0.01478 lineto
0.73686 0.01473 lineto
0.7381 0.01472 lineto
0.73934 0.01473 lineto
0.74058 0.01478 lineto
0.74182 0.01486 lineto
Mistroke
0.74306 0.01497 lineto
0.74554 0.01529 lineto
0.74802 0.01574 lineto
0.7505 0.01631 lineto
0.75298 0.01701 lineto
0.75794 0.0188 lineto
0.7629 0.02111 lineto
0.76786 0.02393 lineto
0.77778 0.03116 lineto
0.7877 0.04052 lineto
0.79762 0.05208 lineto
0.81746 0.08204 lineto
0.8373 0.12176 lineto
0.85714 0.17217 lineto
0.89683 0.30902 lineto
0.93651 0.48837 lineto
0.94643 0.53211 lineto
0.95635 0.56909 lineto
0.96131 0.58348 lineto
0.96379 0.58938 lineto
0.96627 0.59431 lineto
0.96875 0.59821 lineto
0.96999 0.59976 lineto
0.97123 0.60103 lineto
0.97247 0.60203 lineto
0.97371 0.60275 lineto
0.97495 0.60318 lineto
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-150)] 0.4875 0.06305 1 0 Msboxa
[(-100)] 0.4875 0.14504 1 0 Msboxa
[(-50)] 0.4875 0.22703 1 0 Msboxa
[(50)] 0.4875 0.39101 1 0 Msboxa
[(100)] 0.4875 0.473 1 0 Msboxa
[(150)] 0.4875 0.55499 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06305 moveto
0.50625 0.06305 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06305 1 0 Mshowa
0.49375 0.14504 moveto
0.50625 0.14504 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14504 1 0 Mshowa
0.49375 0.22703 moveto
0.50625 0.22703 lineto
stroke
0 setgray
[(-50)] 0.4875 0.22703 1 0 Mshowa
0.49375 0.39101 moveto
0.50625 0.39101 lineto
stroke
0 setgray
[(50)] 0.4875 0.39101 1 0 Mshowa
0.49375 0.473 moveto
0.50625 0.473 lineto
stroke
0 setgray
[(100)] 0.4875 0.473 1 0 Mshowa
0.49375 0.55499 moveto
0.50625 0.55499 lineto
stroke
0 setgray
[(150)] 0.4875 0.55499 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.04365 0.33517 lineto
0.06349 0.36839 lineto
0.10317 0.4566 lineto
0.12302 0.5074 lineto
0.13294 0.53377 lineto
0.14286 0.56062 lineto
0.14782 0.5742 lineto
0.15278 0.58786 lineto
0.15526 0.59472 lineto
0.1565 0.59816 lineto
0.15774 0.6016 lineto
0.15898 0.01472 lineto
0.16022 0.01817 lineto
0.1627 0.02508 lineto
0.18254 0.08091 lineto
0.22222 0.1944 lineto
0.2619 0.30902 lineto
0.30159 0.42363 lineto
0.32143 0.4806 lineto
0.34127 0.53712 lineto
0.35119 0.56514 lineto
0.35615 0.57908 lineto
0.35863 0.58602 lineto
0.36111 0.59295 lineto
0.36359 0.59987 lineto
0.36483 0.60332 lineto
0.36607 0.01644 lineto
0.37103 0.03018 lineto
0.38095 0.05741 lineto
0.42063 0.16143 lineto
0.44048 0.20846 lineto
0.46032 0.24965 lineto
0.5 0.30902 lineto
0.51984 0.33517 lineto
0.53968 0.36839 lineto
0.57937 0.4566 lineto
0.59921 0.5074 lineto
0.60913 0.53377 lineto
0.61905 0.56062 lineto
0.62897 0.58786 lineto
0.63145 0.59472 lineto
0.63269 0.59816 lineto
0.63393 0.6016 lineto
0.63517 0.01472 lineto
0.63641 0.01817 lineto
0.63889 0.02508 lineto
0.65873 0.08091 lineto
0.69841 0.1944 lineto
0.7381 0.30902 lineto
Mistroke
0.77778 0.42363 lineto
0.81746 0.53712 lineto
0.82738 0.56514 lineto
0.83234 0.57908 lineto
0.83482 0.58602 lineto
0.8373 0.59295 lineto
0.83854 0.59641 lineto
0.83978 0.59987 lineto
0.84102 0.60332 lineto
0.84226 0.01644 lineto
0.84474 0.02332 lineto
0.84722 0.03018 lineto
0.85714 0.05741 lineto
0.89683 0.16143 lineto
0.93651 0.24965 lineto
0.95635 0.28287 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
ZTransData[(4.*z^2)/(1 - 0.5/z), Rminus[0.5], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
                2
            4. z
ZTransData[-------, Rminus[0.5], Rplus[Infinity], 
               0.5
           1 - ---
                z
 
  ZVariables[z]]
:[font = text; inactive; ]
	Note that, although it is not possible to determine whether a given sequence is causal or not fron the location of the ROC, a possible way to determine the causality of a sequence would be to take the limit of its z-transform as z -> infinity: the sequence will be causal if the obtained limit is finite, and noncausal otherwise !
:[font = text; inactive; ]
	The following example uses the "limit" method to check whether the right-sided sequence of the previous example is causal or not. Evaluate the following cell by placing the cursor in this cell and pressing the ENTER key.  What do you conclude?
:[font = input; startGroup; ]
Limit[ 4 z^2 / (1 - 0.5/z), z -> Infinity ]
:[font = output; inactive; output; endGroup; ]
DirectedInfinity[1]
;[o]
Infinity
:[font = text; inactive; endGroup; ]
	Due to the fact that we did not obtain a finite limit, we can conclude that the sequence given by the previous example is NOT causal.
:[font = subsection; inactive; startGroup; Cclosed; ]
Stable and Causal Sequences
:[font = text; inactive; ]
	It follows from the definition of stability and causality that the ROC of a stable and causal sequence covers all the region outside a circle of radius less than unity. This latter fact implies that all the poles of the z-transform corresponding to a stable AND causal sequence must be located inside the unit circle, since the ROC cannot contain a pole. 
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Region of Convergence of a Stable and Causal Sequence
:[font = input; startGroup; ]
DSPAnalyze[0.9^n Step[n],n,-1,9]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.11905 0.09524 0.01472 0.5886 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(2)] 0.30952 0.00222 0 1 Msboxa
[(4)] 0.5 0.00222 0 1 Msboxa
[(6)] 0.69048 0.00222 0 1 Msboxa
[(8)] 0.88095 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.10655 0.13244 1 0 Msboxa
[(0.4)] 0.10655 0.25016 1 0 Msboxa
[(0.6)] 0.10655 0.36788 1 0 Msboxa
[(0.8)] 0.10655 0.4856 1 0 Msboxa
[(1)] 0.10655 0.60332 1 0 Msboxa
[( )] 0.11905 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.30952 0.00847 moveto
0.30952 0.02097 lineto
stroke
0 setgray
[(2)] 0.30952 0.00222 0 1 Mshowa
0.5 0.00847 moveto
0.5 0.02097 lineto
stroke
0 setgray
[(4)] 0.5 0.00222 0 1 Mshowa
0.69048 0.00847 moveto
0.69048 0.02097 lineto
stroke
0 setgray
[(6)] 0.69048 0.00222 0 1 Mshowa
0.88095 0.00847 moveto
0.88095 0.02097 lineto
stroke
0 setgray
[(8)] 0.88095 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.11905 0 moveto
0.11905 0.61803 lineto
stroke
0.1128 0.13244 moveto
0.1253 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.10655 0.13244 1 0 Mshowa
0.1128 0.25016 moveto
0.1253 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.10655 0.25016 1 0 Mshowa
0.1128 0.36788 moveto
0.1253 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.10655 0.36788 1 0 Mshowa
0.1128 0.4856 moveto
0.1253 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.10655 0.4856 1 0 Mshowa
0.1128 0.60332 moveto
0.1253 0.60332 lineto
stroke
0 setgray
[(1)] 0.10655 0.60332 1 0 Mshowa
0 setgray
[( )] 0.11905 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.008 setlinewidth
0.02381 0.01472 Mdot
0.004 setlinewidth
0.11905 0.01472 moveto
0.11905 0.60332 lineto
stroke
0.008 setlinewidth
0.11905 0.60332 Mdot
0.004 setlinewidth
0.21429 0.01472 moveto
0.21429 0.54446 lineto
stroke
0.008 setlinewidth
0.21429 0.54446 Mdot
0.004 setlinewidth
0.30952 0.01472 moveto
0.30952 0.49148 lineto
stroke
0.008 setlinewidth
0.30952 0.49148 Mdot
0.004 setlinewidth
0.40476 0.01472 moveto
0.40476 0.44381 lineto
stroke
0.008 setlinewidth
0.40476 0.44381 Mdot
0.004 setlinewidth
0.5 0.01472 moveto
0.5 0.4009 lineto
stroke
0.008 setlinewidth
0.5 0.4009 Mdot
0.004 setlinewidth
0.59524 0.01472 moveto
0.59524 0.36228 lineto
stroke
0.008 setlinewidth
0.59524 0.36228 Mdot
0.004 setlinewidth
0.69048 0.01472 moveto
0.69048 0.32752 lineto
stroke
0.008 setlinewidth
0.69048 0.32752 Mdot
0.004 setlinewidth
0.78571 0.01472 moveto
0.78571 0.29624 lineto
stroke
0.008 setlinewidth
0.78571 0.29624 Mdot
0.004 setlinewidth
0.88095 0.01472 moveto
0.88095 0.26809 lineto
stroke
0.008 setlinewidth
0.88095 0.26809 Mdot
0.004 setlinewidth
0.97619 0.01472 moveto
0.97619 0.24275 lineto
stroke
0.008 setlinewidth
0.97619 0.24275 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
   n
0.9  Step[n]
:[font = print; inactive; ]
has the following z-transform:
:[font = print; inactive; ]
   1
-------
    0.9
1 - ---
     z
:[font = print; inactive; ]
The region of convergence is:
:[font = print; inactive; ]
0.9 < |z| < Infinity
:[font = print; inactive; ]
The system is stable.
:[font = message; inactive; ]
PoleZeroPlot::notrational: 
   Transform is not a rational polynomial.
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {0.}
:[font = print; inactive; ]
The poles are:   {0.9}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.86 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
By substituting into the z-transform,
:[font = print; inactive; ]
the frequency response is
:[font = print; inactive; ]
      1
-------------
         -I w
1 - 0.9 E
:[font = print; inactive; ]

:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 -0.07659 0.02301 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.02598 0 1 Msboxa
[(-4)] 0.19685 0.02598 0 1 Msboxa
[(-2)] 0.34842 0.02598 0 1 Msboxa
[(2)] 0.65158 0.02598 0 1 Msboxa
[(4)] 0.80315 0.02598 0 1 Msboxa
[(6)] 0.95473 0.02598 0 1 Msboxa
[(w)] 1.00625 0.03848 -1 0 Msboxa
[(10)] 0.4875 0.15355 1 0 Msboxa
[(15)] 0.4875 0.26863 1 0 Msboxa
[(20)] 0.4875 0.3837 1 0 Msboxa
[(25)] 0.4875 0.49878 1 0 Msboxa
[(30)] 0.4875 0.61385 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.03848 moveto
1 0.03848 lineto
stroke
0.04527 0.03223 moveto
0.04527 0.04473 lineto
stroke
0 setgray
[(-6)] 0.04527 0.02598 0 1 Mshowa
0.19685 0.03223 moveto
0.19685 0.04473 lineto
stroke
0 setgray
[(-4)] 0.19685 0.02598 0 1 Mshowa
0.34842 0.03223 moveto
0.34842 0.04473 lineto
stroke
0 setgray
[(-2)] 0.34842 0.02598 0 1 Mshowa
0.65158 0.03223 moveto
0.65158 0.04473 lineto
stroke
0 setgray
[(2)] 0.65158 0.02598 0 1 Mshowa
0.80315 0.03223 moveto
0.80315 0.04473 lineto
stroke
0 setgray
[(4)] 0.80315 0.02598 0 1 Mshowa
0.95473 0.03223 moveto
0.95473 0.04473 lineto
stroke
0 setgray
[(6)] 0.95473 0.02598 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.03848 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.15355 moveto
0.50625 0.15355 lineto
stroke
0 setgray
[(10)] 0.4875 0.15355 1 0 Mshowa
0.49375 0.26863 moveto
0.50625 0.26863 lineto
stroke
0 setgray
[(15)] 0.4875 0.26863 1 0 Mshowa
0.49375 0.3837 moveto
0.50625 0.3837 lineto
stroke
0 setgray
[(20)] 0.4875 0.3837 1 0 Mshowa
0.49375 0.49878 moveto
0.50625 0.49878 lineto
stroke
0 setgray
[(25)] 0.4875 0.49878 1 0 Mshowa
0.49375 0.61385 moveto
0.50625 0.61385 lineto
stroke
0 setgray
[(30)] 0.4875 0.61385 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.04365 0.40694 lineto
0.05357 0.33465 lineto
0.06349 0.28113 lineto
0.07341 0.23922 lineto
0.08333 0.20513 lineto
0.10317 0.15245 lineto
0.12302 0.11346 lineto
0.14286 0.08372 lineto
0.1627 0.06083 lineto
0.18254 0.04338 lineto
0.19246 0.03641 lineto
0.20238 0.03049 lineto
0.2123 0.02558 lineto
0.22222 0.02163 lineto
0.23214 0.01858 lineto
0.2371 0.0174 lineto
0.24206 0.01643 lineto
0.24702 0.01568 lineto
0.2495 0.01538 lineto
0.25198 0.01514 lineto
0.25446 0.01496 lineto
0.2557 0.01488 lineto
0.25694 0.01482 lineto
0.25818 0.01478 lineto
0.25942 0.01474 lineto
0.26066 0.01472 lineto
0.2619 0.01472 lineto
0.26314 0.01472 lineto
0.26438 0.01474 lineto
0.26562 0.01478 lineto
0.26687 0.01482 lineto
0.26935 0.01496 lineto
0.27183 0.01514 lineto
0.27431 0.01538 lineto
0.27679 0.01568 lineto
0.28175 0.01643 lineto
0.28671 0.0174 lineto
0.29167 0.01858 lineto
0.30159 0.02163 lineto
0.31151 0.02558 lineto
0.32143 0.03049 lineto
0.34127 0.04338 lineto
0.36111 0.06083 lineto
0.38095 0.08372 lineto
0.40079 0.11346 lineto
0.42063 0.15245 lineto
0.44048 0.20513 lineto
0.4504 0.23922 lineto
0.46032 0.28113 lineto
Mistroke
0.47024 0.33465 lineto
0.48016 0.40694 lineto
0.49008 0.51015 lineto
0.49256 0.54093 lineto
0.49504 0.57074 lineto
0.49628 0.5837 lineto
0.49752 0.59412 lineto
0.49876 0.60094 lineto
0.5 0.60332 lineto
0.50124 0.60094 lineto
0.50248 0.59412 lineto
0.50496 0.57074 lineto
0.50992 0.51015 lineto
0.51984 0.40694 lineto
0.5248 0.3678 lineto
0.52976 0.33465 lineto
0.53968 0.28113 lineto
0.5496 0.23922 lineto
0.55952 0.20513 lineto
0.57937 0.15245 lineto
0.59921 0.11346 lineto
0.61905 0.08372 lineto
0.63889 0.06083 lineto
0.65873 0.04338 lineto
0.67857 0.03049 lineto
0.68849 0.02558 lineto
0.69841 0.02163 lineto
0.70833 0.01858 lineto
0.71329 0.0174 lineto
0.71825 0.01643 lineto
0.72321 0.01568 lineto
0.72569 0.01538 lineto
0.72817 0.01514 lineto
0.73065 0.01496 lineto
0.73189 0.01488 lineto
0.73313 0.01482 lineto
0.73438 0.01478 lineto
0.73562 0.01474 lineto
0.73686 0.01472 lineto
0.7381 0.01472 lineto
0.73934 0.01472 lineto
0.74058 0.01474 lineto
0.74182 0.01478 lineto
0.74306 0.01482 lineto
0.74554 0.01496 lineto
0.74802 0.01514 lineto
0.7505 0.01538 lineto
0.75298 0.01568 lineto
0.75794 0.01643 lineto
0.7629 0.0174 lineto
Mistroke
0.76786 0.01858 lineto
0.77778 0.02163 lineto
0.7877 0.02558 lineto
0.79762 0.03049 lineto
0.81746 0.04338 lineto
0.8373 0.06083 lineto
0.85714 0.08372 lineto
0.87698 0.11346 lineto
0.89683 0.15245 lineto
0.90675 0.17666 lineto
0.91667 0.20513 lineto
0.92659 0.23922 lineto
0.93651 0.28113 lineto
0.94643 0.33465 lineto
0.95635 0.40694 lineto
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00459 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-60)] 0.4875 0.03378 1 0 Msboxa
[(-40)] 0.4875 0.12552 1 0 Msboxa
[(-20)] 0.4875 0.21727 1 0 Msboxa
[(20)] 0.4875 0.40076 1 0 Msboxa
[(40)] 0.4875 0.49251 1 0 Msboxa
[(60)] 0.4875 0.58426 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.03378 moveto
0.50625 0.03378 lineto
stroke
0 setgray
[(-60)] 0.4875 0.03378 1 0 Mshowa
0.49375 0.12552 moveto
0.50625 0.12552 lineto
stroke
0 setgray
[(-40)] 0.4875 0.12552 1 0 Mshowa
0.49375 0.21727 moveto
0.50625 0.21727 lineto
stroke
0 setgray
[(-20)] 0.4875 0.21727 1 0 Mshowa
0.49375 0.40076 moveto
0.50625 0.40076 lineto
stroke
0 setgray
[(20)] 0.4875 0.40076 1 0 Mshowa
0.49375 0.49251 moveto
0.50625 0.49251 lineto
stroke
0 setgray
[(40)] 0.4875 0.49251 1 0 Mshowa
0.49375 0.58426 moveto
0.50625 0.58426 lineto
stroke
0 setgray
[(60)] 0.4875 0.58426 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02629 0.23409 lineto
0.02877 0.17137 lineto
0.03125 0.12454 lineto
0.03373 0.09118 lineto
0.03621 0.06765 lineto
0.03869 0.05095 lineto
0.04117 0.03904 lineto
0.04365 0.03052 lineto
0.04489 0.02723 lineto
0.04613 0.02448 lineto
0.04737 0.02218 lineto
0.04861 0.02027 lineto
0.04985 0.01872 lineto
0.05109 0.01747 lineto
0.05233 0.01649 lineto
0.05357 0.01575 lineto
0.05481 0.01522 lineto
0.05605 0.01489 lineto
0.05729 0.01473 lineto
0.05853 0.01472 lineto
0.05977 0.01484 lineto
0.06101 0.0151 lineto
0.06225 0.01547 lineto
0.06349 0.01594 lineto
0.10317 0.05767 lineto
0.14286 0.11641 lineto
0.18254 0.17938 lineto
0.22222 0.24391 lineto
0.2619 0.30902 lineto
0.30159 0.37412 lineto
0.34127 0.43865 lineto
0.38095 0.50163 lineto
0.42063 0.56036 lineto
0.44048 0.58544 lineto
0.44544 0.59075 lineto
0.4504 0.59544 lineto
0.45536 0.59931 lineto
0.45784 0.60086 lineto
0.45908 0.60152 lineto
0.46032 0.60209 lineto
0.46156 0.60256 lineto
0.4628 0.60293 lineto
0.46404 0.60319 lineto
0.46528 0.60332 lineto
0.46652 0.60331 lineto
0.46776 0.60314 lineto
0.469 0.60281 lineto
0.47024 0.60228 lineto
0.47148 0.60154 lineto
Mistroke
0.47272 0.60056 lineto
0.47396 0.59932 lineto
0.4752 0.59776 lineto
0.47768 0.59356 lineto
0.47892 0.5908 lineto
0.48016 0.58751 lineto
0.5 0.30902 lineto
0.50248 0.23409 lineto
0.50496 0.17137 lineto
0.50744 0.12454 lineto
0.50992 0.09118 lineto
0.5124 0.06765 lineto
0.51488 0.05095 lineto
0.51736 0.03904 lineto
0.51984 0.03052 lineto
0.52108 0.02723 lineto
0.52232 0.02448 lineto
0.5248 0.02027 lineto
0.52604 0.01872 lineto
0.52728 0.01747 lineto
0.52852 0.01649 lineto
0.52976 0.01575 lineto
0.531 0.01522 lineto
0.53224 0.01489 lineto
0.53348 0.01473 lineto
0.53472 0.01472 lineto
0.53596 0.01484 lineto
0.5372 0.0151 lineto
0.53968 0.01594 lineto
0.54092 0.01651 lineto
0.54216 0.01717 lineto
0.54464 0.01872 lineto
0.5496 0.0226 lineto
0.55952 0.03259 lineto
0.57937 0.05767 lineto
0.61905 0.11641 lineto
0.65873 0.17938 lineto
0.69841 0.24391 lineto
0.7381 0.30902 lineto
0.77778 0.37412 lineto
0.81746 0.43865 lineto
0.85714 0.50163 lineto
0.89683 0.56036 lineto
0.90675 0.57351 lineto
0.91667 0.58544 lineto
0.92163 0.59075 lineto
0.92659 0.59544 lineto
0.93155 0.59931 lineto
0.93403 0.60086 lineto
0.93527 0.60152 lineto
Mistroke
0.93651 0.60209 lineto
0.93775 0.60256 lineto
0.93899 0.60293 lineto
0.94023 0.60319 lineto
0.94147 0.60332 lineto
0.94271 0.60331 lineto
0.94395 0.60314 lineto
0.94519 0.60281 lineto
0.94643 0.60228 lineto
0.94767 0.60154 lineto
0.94891 0.60056 lineto
0.95139 0.59776 lineto
0.95263 0.59586 lineto
0.95387 0.59356 lineto
0.95635 0.58751 lineto
0.95883 0.579 lineto
0.96131 0.56708 lineto
0.96379 0.55039 lineto
0.96627 0.52685 lineto
0.96875 0.4935 lineto
0.97123 0.44667 lineto
0.97371 0.38395 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
ZTransData[(1 - 0.9/z)^(-1), Rminus[0.9], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
              1
ZTransData[-------, Rminus[0.9], Rplus[Infinity], 
               0.9
           1 - ---
                z
 
  ZVariables[z]]
:[font = text; inactive; ]
	However, note that having all the poles of the z transform inside the unit circle does NOT imply that the sequence is necessarily causal.  This latter fact is illustrated by the following example.
:[font = subsubsection; inactive; startGroup; Cclosed; ]
Example:  Non-Causal Sequence Having All Poles Inside the Unit Circle
:[font = input; startGroup; ]
DSPAnalyze[0.9^n Step[n + 5],n,-7,8]
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.46825 0.06349 0.01472 0.34756 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.0873 0.00222 0 1 Msboxa
[(-4)] 0.21429 0.00222 0 1 Msboxa
[(-2)] 0.34127 0.00222 0 1 Msboxa
[(2)] 0.59524 0.00222 0 1 Msboxa
[(4)] 0.72222 0.00222 0 1 Msboxa
[(6)] 0.84921 0.00222 0 1 Msboxa
[(8)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(0.25)] 0.45575 0.10161 1 0 Msboxa
[(0.5)] 0.45575 0.1885 1 0 Msboxa
[(0.75)] 0.45575 0.27539 1 0 Msboxa
[(1)] 0.45575 0.36228 1 0 Msboxa
[(1.25)] 0.45575 0.44917 1 0 Msboxa
[(1.5)] 0.45575 0.53606 1 0 Msboxa
[( )] 0.46825 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.0873 0.00847 moveto
0.0873 0.02097 lineto
stroke
0 setgray
[(-6)] 0.0873 0.00222 0 1 Mshowa
0.21429 0.00847 moveto
0.21429 0.02097 lineto
stroke
0 setgray
[(-4)] 0.21429 0.00222 0 1 Mshowa
0.34127 0.00847 moveto
0.34127 0.02097 lineto
stroke
0 setgray
[(-2)] 0.34127 0.00222 0 1 Mshowa
0.59524 0.00847 moveto
0.59524 0.02097 lineto
stroke
0 setgray
[(2)] 0.59524 0.00222 0 1 Mshowa
0.72222 0.00847 moveto
0.72222 0.02097 lineto
stroke
0 setgray
[(4)] 0.72222 0.00222 0 1 Mshowa
0.84921 0.00847 moveto
0.84921 0.02097 lineto
stroke
0 setgray
[(6)] 0.84921 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(8)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.46825 0 moveto
0.46825 0.61803 lineto
stroke
0.462 0.10161 moveto
0.4745 0.10161 lineto
stroke
0 setgray
[(0.25)] 0.45575 0.10161 1 0 Mshowa
0.462 0.1885 moveto
0.4745 0.1885 lineto
stroke
0 setgray
[(0.5)] 0.45575 0.1885 1 0 Mshowa
0.462 0.27539 moveto
0.4745 0.27539 lineto
stroke
0 setgray
[(0.75)] 0.45575 0.27539 1 0 Mshowa
0.462 0.36228 moveto
0.4745 0.36228 lineto
stroke
0 setgray
[(1)] 0.45575 0.36228 1 0 Mshowa
0.462 0.44917 moveto
0.4745 0.44917 lineto
stroke
0 setgray
[(1.25)] 0.45575 0.44917 1 0 Mshowa
0.462 0.53606 moveto
0.4745 0.53606 lineto
stroke
0 setgray
[(1.5)] 0.45575 0.53606 1 0 Mshowa
0 setgray
[( )] 0.46825 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.008 setlinewidth
0.02381 0.01472 Mdot
0.004 setlinewidth
0.0873 0.01472 moveto
0.0873 0.01472 lineto
stroke
0.008 setlinewidth
0.0873 0.01472 Mdot
0.004 setlinewidth
0.15079 0.01472 moveto
0.15079 0.60332 lineto
stroke
0.008 setlinewidth
0.15079 0.60332 Mdot
0.004 setlinewidth
0.21429 0.01472 moveto
0.21429 0.54446 lineto
stroke
0.008 setlinewidth
0.21429 0.54446 Mdot
0.004 setlinewidth
0.27778 0.01472 moveto
0.27778 0.49148 lineto
stroke
0.008 setlinewidth
0.27778 0.49148 Mdot
0.004 setlinewidth
0.34127 0.01472 moveto
0.34127 0.44381 lineto
stroke
0.008 setlinewidth
0.34127 0.44381 Mdot
0.004 setlinewidth
0.40476 0.01472 moveto
0.40476 0.4009 lineto
stroke
0.008 setlinewidth
0.40476 0.4009 Mdot
0.004 setlinewidth
0.46825 0.01472 moveto
0.46825 0.36228 lineto
stroke
0.008 setlinewidth
0.46825 0.36228 Mdot
0.004 setlinewidth
0.53175 0.01472 moveto
0.53175 0.32752 lineto
stroke
0.008 setlinewidth
0.53175 0.32752 Mdot
0.004 setlinewidth
0.59524 0.01472 moveto
0.59524 0.29624 lineto
stroke
0.008 setlinewidth
0.59524 0.29624 Mdot
0.004 setlinewidth
0.65873 0.01472 moveto
0.65873 0.26809 lineto
stroke
0.008 setlinewidth
0.65873 0.26809 Mdot
0.004 setlinewidth
0.72222 0.01472 moveto
0.72222 0.24275 lineto
stroke
0.008 setlinewidth
0.72222 0.24275 Mdot
0.004 setlinewidth
0.78571 0.01472 moveto
0.78571 0.21995 lineto
stroke
0.008 setlinewidth
0.78571 0.21995 Mdot
0.004 setlinewidth
0.84921 0.01472 moveto
0.84921 0.19943 lineto
stroke
0.008 setlinewidth
0.84921 0.19943 Mdot
0.004 setlinewidth
0.9127 0.01472 moveto
0.9127 0.18095 lineto
stroke
0.008 setlinewidth
0.9127 0.18095 Mdot
0.004 setlinewidth
0.97619 0.01472 moveto
0.97619 0.16433 lineto
stroke
0.008 setlinewidth
0.97619 0.16433 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
   n
0.9  Step[5 + n]
:[font = print; inactive; ]
has the following z-transform:
:[font = print; inactive; ]
         5
1.69351 z
----------
     0.9
 1 - ---
      z
:[font = print; inactive; ]
The region of convergence is:
:[font = print; inactive; ]
0.9 < |z| < Infinity
:[font = print; inactive; ]
The system is stable.
:[font = message; inactive; ]
PoleZeroPlot::notrational: 
   Transform is not a rational polynomial.
:[font = print; inactive; ]

:[font = print; inactive; ]
The zeroes are:  {0., 0., 0., 0., 0., 0.}
:[font = print; inactive; ]
The poles are:   {0.9}
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86 0.5 moveto
0.85999 0.50295 lineto
0.85995 0.50589 lineto
0.85989 0.50883 lineto
0.85981 0.51178 lineto
0.8597 0.51472 lineto
0.85957 0.51766 lineto
0.85923 0.52355 lineto
0.8588 0.52942 lineto
0.85827 0.53529 lineto
0.85692 0.54699 lineto
0.85519 0.55864 lineto
0.85308 0.57023 lineto
0.84773 0.59317 lineto
0.84089 0.61572 lineto
0.8326 0.63777 lineto
0.81177 0.68 lineto
0.78561 0.71915 lineto
0.75456 0.75456 lineto
0.71915 0.78561 lineto
0.68 0.81177 lineto
0.65922 0.82287 lineto
0.63777 0.8326 lineto
0.61572 0.84089 lineto
0.59317 0.84773 lineto
0.57023 0.85308 lineto
0.55864 0.85519 lineto
0.54699 0.85692 lineto
0.53529 0.85827 lineto
0.52942 0.8588 lineto
0.52355 0.85923 lineto
0.51766 0.85957 lineto
0.51472 0.8597 lineto
0.51178 0.85981 lineto
0.50883 0.85989 lineto
0.50589 0.85995 lineto
0.50295 0.85999 lineto
0.5 0.86 lineto
0.49705 0.85999 lineto
0.49411 0.85995 lineto
0.49117 0.85989 lineto
0.48822 0.85981 lineto
0.48234 0.85957 lineto
0.47645 0.85923 lineto
0.47058 0.8588 lineto
0.46471 0.85827 lineto
0.45301 0.85692 lineto
0.44136 0.85519 lineto
0.42977 0.85308 lineto
0.40683 0.84773 lineto
Mistroke
0.38428 0.84089 lineto
0.36223 0.8326 lineto
0.32 0.81177 lineto
0.28085 0.78561 lineto
0.24544 0.75456 lineto
0.21439 0.71915 lineto
0.18823 0.68 lineto
0.1674 0.63777 lineto
0.15911 0.61572 lineto
0.15227 0.59317 lineto
0.14692 0.57023 lineto
0.14481 0.55864 lineto
0.14308 0.54699 lineto
0.14173 0.53529 lineto
0.1412 0.52942 lineto
0.14077 0.52355 lineto
0.14043 0.51766 lineto
0.1403 0.51472 lineto
0.14019 0.51178 lineto
0.14011 0.50883 lineto
0.14005 0.50589 lineto
0.14001 0.50295 lineto
0.14 0.5 lineto
0.14001 0.49705 lineto
0.14005 0.49411 lineto
0.14011 0.49117 lineto
0.14019 0.48822 lineto
0.14043 0.48234 lineto
0.14077 0.47645 lineto
0.1412 0.47058 lineto
0.14173 0.46471 lineto
0.14308 0.45301 lineto
0.14481 0.44136 lineto
0.14692 0.42977 lineto
0.15227 0.40683 lineto
0.15911 0.38428 lineto
0.1674 0.36223 lineto
0.18823 0.32 lineto
0.21439 0.28085 lineto
0.24544 0.24544 lineto
0.28085 0.21439 lineto
0.32 0.18823 lineto
0.34078 0.17713 lineto
0.36223 0.1674 lineto
0.38428 0.15911 lineto
0.40683 0.15227 lineto
0.42977 0.14692 lineto
0.44136 0.14481 lineto
0.45301 0.14308 lineto
0.46471 0.14173 lineto
Mistroke
0.47058 0.1412 lineto
0.47645 0.14077 lineto
0.48234 0.14043 lineto
0.48528 0.1403 lineto
0.48822 0.14019 lineto
0.49117 0.14011 lineto
0.49411 0.14005 lineto
0.49705 0.14001 lineto
0.5 0.14 lineto
0.50295 0.14001 lineto
0.50589 0.14005 lineto
0.50883 0.14011 lineto
0.51178 0.14019 lineto
0.51766 0.14043 lineto
0.52355 0.14077 lineto
0.52942 0.1412 lineto
0.53529 0.14173 lineto
0.54699 0.14308 lineto
0.55864 0.14481 lineto
0.57023 0.14692 lineto
0.59317 0.15227 lineto
0.61572 0.15911 lineto
0.63777 0.1674 lineto
0.68 0.18823 lineto
0.71915 0.21439 lineto
0.75456 0.24544 lineto
0.78561 0.28085 lineto
0.81177 0.32 lineto
0.82287 0.34078 lineto
0.8326 0.36223 lineto
0.84089 0.38428 lineto
0.84773 0.40683 lineto
0.85308 0.42977 lineto
0.85519 0.44136 lineto
0.85692 0.45301 lineto
0.85827 0.46471 lineto
0.8588 0.47058 lineto
0.85923 0.47645 lineto
0.85957 0.48234 lineto
0.8597 0.48528 lineto
0.85981 0.48822 lineto
0.85989 0.49117 lineto
0.85995 0.49411 lineto
0.85999 0.49705 lineto
0.86 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83829 0.62313 lineto
stroke
0.1491 0.41958 moveto
-0.26579 0.26857 lineto
stroke
0.14178 0.46421 moveto
-0.2775 0.31161 lineto
stroke
0.14017 0.51092 moveto
-0.28684 0.3555 lineto
stroke
0.14503 0.55999 moveto
-0.29376 0.40028 lineto
stroke
0.15785 0.61195 moveto
-0.29817 0.44597 lineto
stroke
0.18153 0.66787 moveto
-0.29997 0.49262 lineto
stroke
0.22338 0.7304 moveto
-0.29899 0.54027 lineto
stroke
0.3254 0.81483 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56861 0.1466 moveto
-0.05182 -0.07922 lineto
stroke
0.4362 0.1457 moveto
-0.08617 -0.04443 lineto
stroke
0.36395 0.1667 moveto
-0.11756 -0.00855 lineto
stroke
0.30986 0.19431 moveto
-0.14616 0.02833 lineto
stroke
0.26664 0.22588 moveto
-0.17215 0.06617 lineto
stroke
0.23137 0.26034 moveto
-0.19564 0.10492 lineto
stroke
0.20259 0.29716 moveto
-0.2167 0.14455 lineto
stroke
0.1795 0.33605 moveto
-0.23539 0.18504 lineto
stroke
0.16171 0.37687 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8205 0.66395 lineto
stroke
1.26579 0.73143 moveto
0.8509 0.58042 lineto
stroke
1.2167 0.85545 moveto
0.79741 0.70284 lineto
stroke
1.2775 0.68839 moveto
0.85822 0.53579 lineto
stroke
1.19564 0.89508 moveto
0.76863 0.73966 lineto
stroke
1.28684 0.6445 moveto
0.85983 0.48908 lineto
stroke
1.17215 0.93383 moveto
0.73336 0.77412 lineto
stroke
1.29376 0.59972 moveto
0.85497 0.44001 lineto
stroke
1.14616 0.97167 moveto
0.69014 0.80569 lineto
stroke
1.29817 0.55403 moveto
0.84215 0.38805 lineto
stroke
1.11756 1.00855 moveto
0.63605 0.8333 lineto
stroke
1.29997 0.50738 moveto
0.81847 0.33213 lineto
stroke
1.08617 1.04443 moveto
0.5638 0.8543 lineto
stroke
1.29899 0.45973 moveto
0.77662 0.2696 lineto
stroke
1.05182 1.07922 moveto
0.43139 0.8534 lineto
stroke
1.29503 0.41099 moveto
0.6746 0.18517 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(*O*)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.86 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
By substituting into the z-transform,
:[font = print; inactive; ]
the frequency response is
:[font = print; inactive; ]
         5 I w
1.69351 E
--------------
         -I w
1 - 0.9 E
:[font = print; inactive; ]

:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 -0.1819 0.02301 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.03575 0 1 Msboxa
[(-4)] 0.19685 0.03575 0 1 Msboxa
[(-2)] 0.34842 0.03575 0 1 Msboxa
[(2)] 0.65158 0.03575 0 1 Msboxa
[(4)] 0.80315 0.03575 0 1 Msboxa
[(6)] 0.95473 0.03575 0 1 Msboxa
[(w)] 1.00625 0.04825 -1 0 Msboxa
[(15)] 0.4875 0.16332 1 0 Msboxa
[(20)] 0.4875 0.27839 1 0 Msboxa
[(25)] 0.4875 0.39347 1 0 Msboxa
[(30)] 0.4875 0.50854 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.04825 moveto
1 0.04825 lineto
stroke
0.04527 0.042 moveto
0.04527 0.0545 lineto
stroke
0 setgray
[(-6)] 0.04527 0.03575 0 1 Mshowa
0.19685 0.042 moveto
0.19685 0.0545 lineto
stroke
0 setgray
[(-4)] 0.19685 0.03575 0 1 Mshowa
0.34842 0.042 moveto
0.34842 0.0545 lineto
stroke
0 setgray
[(-2)] 0.34842 0.03575 0 1 Mshowa
0.65158 0.042 moveto
0.65158 0.0545 lineto
stroke
0 setgray
[(2)] 0.65158 0.03575 0 1 Mshowa
0.80315 0.042 moveto
0.80315 0.0545 lineto
stroke
0 setgray
[(4)] 0.80315 0.03575 0 1 Mshowa
0.95473 0.042 moveto
0.95473 0.0545 lineto
stroke
0 setgray
[(6)] 0.95473 0.03575 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.04825 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.16332 moveto
0.50625 0.16332 lineto
stroke
0 setgray
[(15)] 0.4875 0.16332 1 0 Mshowa
0.49375 0.27839 moveto
0.50625 0.27839 lineto
stroke
0 setgray
[(20)] 0.4875 0.27839 1 0 Mshowa
0.49375 0.39347 moveto
0.50625 0.39347 lineto
stroke
0 setgray
[(25)] 0.4875 0.39347 1 0 Mshowa
0.49375 0.50854 moveto
0.50625 0.50854 lineto
stroke
0 setgray
[(30)] 0.4875 0.50854 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.60332 moveto
0.04365 0.40694 lineto
0.05357 0.33465 lineto
0.06349 0.28113 lineto
0.07341 0.23922 lineto
0.08333 0.20513 lineto
0.10317 0.15245 lineto
0.12302 0.11346 lineto
0.14286 0.08372 lineto
0.1627 0.06083 lineto
0.18254 0.04338 lineto
0.19246 0.03641 lineto
0.20238 0.03049 lineto
0.2123 0.02558 lineto
0.22222 0.02163 lineto
0.23214 0.01858 lineto
0.2371 0.0174 lineto
0.24206 0.01643 lineto
0.24702 0.01568 lineto
0.2495 0.01538 lineto
0.25198 0.01514 lineto
0.25446 0.01496 lineto
0.2557 0.01488 lineto
0.25694 0.01482 lineto
0.25818 0.01478 lineto
0.25942 0.01474 lineto
0.26066 0.01472 lineto
0.2619 0.01472 lineto
0.26314 0.01472 lineto
0.26438 0.01474 lineto
0.26562 0.01478 lineto
0.26687 0.01482 lineto
0.26935 0.01496 lineto
0.27183 0.01514 lineto
0.27431 0.01538 lineto
0.27679 0.01568 lineto
0.28175 0.01643 lineto
0.28671 0.0174 lineto
0.29167 0.01858 lineto
0.30159 0.02163 lineto
0.31151 0.02558 lineto
0.32143 0.03049 lineto
0.34127 0.04338 lineto
0.36111 0.06083 lineto
0.38095 0.08372 lineto
0.40079 0.11346 lineto
0.42063 0.15245 lineto
0.44048 0.20513 lineto
0.4504 0.23922 lineto
0.46032 0.28113 lineto
Mistroke
0.47024 0.33465 lineto
0.48016 0.40694 lineto
0.49008 0.51015 lineto
0.49256 0.54093 lineto
0.49504 0.57074 lineto
0.49628 0.5837 lineto
0.49752 0.59412 lineto
0.49876 0.60094 lineto
0.5 0.60332 lineto
0.50124 0.60094 lineto
0.50248 0.59412 lineto
0.50496 0.57074 lineto
0.50992 0.51015 lineto
0.51984 0.40694 lineto
0.5248 0.3678 lineto
0.52976 0.33465 lineto
0.53968 0.28113 lineto
0.5496 0.23922 lineto
0.55952 0.20513 lineto
0.57937 0.15245 lineto
0.59921 0.11346 lineto
0.61905 0.08372 lineto
0.63889 0.06083 lineto
0.65873 0.04338 lineto
0.67857 0.03049 lineto
0.68849 0.02558 lineto
0.69841 0.02163 lineto
0.70833 0.01858 lineto
0.71329 0.0174 lineto
0.71825 0.01643 lineto
0.72321 0.01568 lineto
0.72569 0.01538 lineto
0.72817 0.01514 lineto
0.73065 0.01496 lineto
0.73189 0.01488 lineto
0.73313 0.01482 lineto
0.73438 0.01478 lineto
0.73562 0.01474 lineto
0.73686 0.01472 lineto
0.7381 0.01472 lineto
0.73934 0.01472 lineto
0.74058 0.01474 lineto
0.74182 0.01478 lineto
0.74306 0.01482 lineto
0.74554 0.01496 lineto
0.74802 0.01514 lineto
0.7505 0.01538 lineto
0.75298 0.01568 lineto
0.75794 0.01643 lineto
0.7629 0.0174 lineto
Mistroke
0.76786 0.01858 lineto
0.77778 0.02163 lineto
0.7877 0.02558 lineto
0.79762 0.03049 lineto
0.81746 0.04338 lineto
0.8373 0.06083 lineto
0.85714 0.08372 lineto
0.87698 0.11346 lineto
0.89683 0.15245 lineto
0.90675 0.17666 lineto
0.91667 0.20513 lineto
0.92659 0.23922 lineto
0.93651 0.28113 lineto
0.94643 0.33465 lineto
0.95635 0.40694 lineto
0.97619 0.60332 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00164 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-150)] 0.4875 0.06377 1 0 Msboxa
[(-100)] 0.4875 0.14552 1 0 Msboxa
[(-50)] 0.4875 0.22727 1 0 Msboxa
[(50)] 0.4875 0.39077 1 0 Msboxa
[(100)] 0.4875 0.47252 1 0 Msboxa
[(150)] 0.4875 0.55427 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.06377 moveto
0.50625 0.06377 lineto
stroke
0 setgray
[(-150)] 0.4875 0.06377 1 0 Mshowa
0.49375 0.14552 moveto
0.50625 0.14552 lineto
stroke
0 setgray
[(-100)] 0.4875 0.14552 1 0 Mshowa
0.49375 0.22727 moveto
0.50625 0.22727 lineto
stroke
0 setgray
[(-50)] 0.4875 0.22727 1 0 Mshowa
0.49375 0.39077 moveto
0.50625 0.39077 lineto
stroke
0 setgray
[(50)] 0.4875 0.39077 1 0 Mshowa
0.49375 0.47252 moveto
0.50625 0.47252 lineto
stroke
0 setgray
[(100)] 0.4875 0.47252 1 0 Mshowa
0.49375 0.55427 moveto
0.50625 0.55427 lineto
stroke
0 setgray
[(150)] 0.4875 0.55427 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.02505 0.303 lineto
0.02629 0.29764 lineto
0.02753 0.29342 lineto
0.02877 0.29061 lineto
0.03001 0.28925 lineto
0.03125 0.28925 lineto
0.03249 0.29045 lineto
0.03373 0.29269 lineto
0.04365 0.33238 lineto
0.05357 0.38843 lineto
0.06349 0.44981 lineto
0.07341 0.5135 lineto
0.07837 0.54582 lineto
0.08085 0.56207 lineto
0.08333 0.57837 lineto
0.08457 0.58654 lineto
0.08581 0.59471 lineto
0.08705 0.60289 lineto
0.08829 0.02248 lineto
0.08953 0.03068 lineto
0.09077 0.03889 lineto
0.09325 0.05533 lineto
0.10317 0.12133 lineto
0.12302 0.25412 lineto
0.14286 0.38752 lineto
0.15278 0.45436 lineto
0.1627 0.52126 lineto
0.16766 0.55473 lineto
0.17014 0.57147 lineto
0.17138 0.57985 lineto
0.17262 0.58822 lineto
0.17386 0.59659 lineto
0.1751 0.01636 lineto
0.17758 0.03311 lineto
0.18254 0.06661 lineto
0.20238 0.2007 lineto
0.22222 0.33486 lineto
0.23214 0.40197 lineto
0.24206 0.46908 lineto
0.24702 0.50264 lineto
0.25198 0.5362 lineto
0.25446 0.55298 lineto
0.25694 0.56976 lineto
0.25942 0.58654 lineto
0.26066 0.59493 lineto
0.2619 0.01472 lineto
0.30159 0.28317 lineto
0.32143 0.41734 lineto
0.33135 0.48439 lineto
Mistroke
0.33631 0.51791 lineto
0.34127 0.55142 lineto
0.34375 0.56818 lineto
0.34623 0.58493 lineto
0.34747 0.5933 lineto
0.34871 0.60167 lineto
0.34995 0.02144 lineto
0.35119 0.02982 lineto
0.35367 0.04656 lineto
0.35615 0.0633 lineto
0.36111 0.09677 lineto
0.38095 0.23052 lineto
0.40079 0.36391 lineto
0.41071 0.43041 lineto
0.42063 0.4967 lineto
0.4256 0.52975 lineto
0.43056 0.5627 lineto
0.43304 0.57914 lineto
0.43428 0.58735 lineto
0.43552 0.59555 lineto
0.43676 0.01514 lineto
0.438 0.02332 lineto
0.44048 0.03966 lineto
0.46032 0.16822 lineto
0.47024 0.2296 lineto
0.48016 0.28565 lineto
0.48512 0.30903 lineto
0.4876 0.3184 lineto
0.48884 0.32224 lineto
0.49008 0.32534 lineto
0.49132 0.32758 lineto
0.49256 0.32878 lineto
0.4938 0.32878 lineto
0.49504 0.32742 lineto
0.5 0.30902 lineto
0.50124 0.303 lineto
0.50248 0.29764 lineto
0.50372 0.29342 lineto
0.50496 0.29061 lineto
0.5062 0.28925 lineto
0.50744 0.28925 lineto
0.50868 0.29045 lineto
0.50992 0.29269 lineto
0.5124 0.29963 lineto
0.51488 0.30901 lineto
0.51984 0.33238 lineto
0.53968 0.44981 lineto
0.5496 0.5135 lineto
0.55456 0.54582 lineto
0.55704 0.56207 lineto
Mistroke
0.55952 0.57837 lineto
0.56076 0.58654 lineto
0.562 0.59471 lineto
0.56324 0.60289 lineto
0.56448 0.02248 lineto
0.56696 0.03889 lineto
0.56944 0.05533 lineto
0.57937 0.12133 lineto
0.59921 0.25412 lineto
0.61905 0.38752 lineto
0.62897 0.45436 lineto
0.63889 0.52126 lineto
0.64385 0.55473 lineto
0.64633 0.57147 lineto
0.64757 0.57985 lineto
0.64881 0.58822 lineto
0.65005 0.59659 lineto
0.65129 0.01636 lineto
0.65377 0.03311 lineto
0.65873 0.06661 lineto
0.69841 0.33486 lineto
0.71825 0.46908 lineto
0.72817 0.5362 lineto
0.73313 0.56976 lineto
0.73562 0.58654 lineto
0.73686 0.59493 lineto
0.7381 0.60332 lineto
0.73934 0.02311 lineto
0.74058 0.0315 lineto
0.74306 0.04828 lineto
0.74802 0.08184 lineto
0.75794 0.14895 lineto
0.77778 0.28317 lineto
0.79762 0.41734 lineto
0.80754 0.48439 lineto
0.8125 0.51791 lineto
0.81746 0.55142 lineto
0.81994 0.56818 lineto
0.82242 0.58493 lineto
0.82366 0.5933 lineto
0.8249 0.60167 lineto
0.82614 0.02144 lineto
0.82738 0.02982 lineto
0.8373 0.09677 lineto
0.85714 0.23052 lineto
0.87698 0.36391 lineto
0.8869 0.43041 lineto
0.89683 0.4967 lineto
0.90179 0.52975 lineto
0.90675 0.5627 lineto
Mistroke
0.90923 0.57914 lineto
0.91047 0.58735 lineto
0.91171 0.59555 lineto
0.91295 0.01514 lineto
0.91419 0.02332 lineto
0.91667 0.03966 lineto
0.93651 0.16822 lineto
0.94643 0.2296 lineto
0.95635 0.28565 lineto
0.95883 0.29795 lineto
0.96131 0.30903 lineto
0.96379 0.3184 lineto
0.96503 0.32224 lineto
0.96627 0.32534 lineto
0.96751 0.32758 lineto
0.96875 0.32878 lineto
0.96999 0.32878 lineto
0.97123 0.32742 lineto
0.97247 0.32461 lineto
0.97371 0.32039 lineto
0.97495 0.31503 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; endGroup; endGroup; ]
ZTransData[(1.693508780843028*z^5)/(1 - 0.9/z), 
  Rminus[0.9], Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
                    5
           1.69351 z
ZTransData[----------, Rminus[0.9], Rplus[Infinity], 
                0.9
            1 - ---
                 z
 
  ZVariables[z]]
:[font = section; inactive; startGroup; Cclosed; ]
References
:[font = subsection; inactive; ]
Alan V. Oppenheim and Ronald W. Schafer.  Discrete-Time Signal Processing.  1989.  Chapters 4 & 5.
:[font = subsection; inactive; ]
T.W. Parks and C.S. Burrus. Digital Filter Design.
:[font = subsection; inactive; endGroup; ]
Churchill and Brown.  Complex Variables and Applications.
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)