(*^

::[paletteColors = 128; 
	fontset = text, "Times", 14, L2, nohscroll;
	fontset = smalltext, "Times", 12, L2, nohscroll;
	fontset = special1, "Times", 24, L2, center, italic, nowordwrap;
	fontset = special2, "Times", 20, L2, center, italic, nowordwrap;
	fontset = special3, "Times", 16, L2, italic, nowordwrap;
	fontset = special4, "New York", 16, L2, nowordwrap;
	fontset = special5, "New York", 20, L2, nowordwrap;]
:[font = title; inactive; ]
The z-Transform
:[font = special2; inactive; ]
Part III:
Filter Design
:[font = subtitle; inactive; ]
by 
Lina J. Karam
with
Brian L. Evans and James H. McClellan
:[font = subsubtitle; inactive; ]

Digital Signal Processing  Laboratory
   School of Electrical Engineering
  Georgia Institute of Technology
  Atlanta, GA  30332-0250
  
  EMAIL:  evans@eedsp.gatech.edu
:[font = message; inactive; center; ]
This notebook has been divided into
three parts because of its size
:[font = text; inactive; ]
	This notebook is a highly interactive tutorial on the z-transform.  In addition to discussing the basic theoretical concept behind the z-transform, this notebook provides users with means to evaluate z-transforms and inverse z-transforms, to observe changes in parameters in the examples by animation, and to visualize z-transforms graphically.
:[font = text; inactive; ]
	This notebook automatically loads the needed Digital Signal Processing packages by executing the Needs command in the Initialization section.  Under Mathematica 1.2, the entire initialization process may take a few minutes. 
:[font = text; inactive; ]
	A Notebook is completely defined by a portable ASCII file but  machine-dependent binary information (bitmaps, etc.) is generated as side information to speed up the display of parts of the Notebook.   Mathematica 1.2 generates missing side information as needed whereas Mathematica 2.0 and higher generates all missing side information when a Notebook is opened.    Mathematica 2.0 and higher will display the message "Rendering ..." in the header of the Notebook when it is generating bitmaps for PostScript graphics contained in the Notebook.  This particular Notebook contains 30 or so graphics cells whose bitmaps will require an 600 kb of memory (30 cells x 20 kb/cell) to store.  The ASCII version of this Notebook occupies 250 kb.
:[font = text; inactive; ]
	As a reminder, in order to open a section below, just move the mouse to the downward-pointing arrow and double click. To get help information for any command, place the cursor in an input cell and type ?Command (like ?ZTransform).
:[font = special1; inactive; ]

Table of Contents

:[font = section; inactive; startGroup; Cclosed; ]
Initialization
:[font = input; initialization; startGroup; Cclosed; ]
*)
Needs [ "SignalProcessing`Digital`" ]
(*
:[font = print; inactive; ]
Loading the signal processing support packages ...
:[font = print; inactive; ]
Support module has been loaded.
:[font = print; inactive; ]
Supporting routines for filter design are loaded.
:[font = print; inactive; ]
The knowledge base of signal processing operators has been\
 
  loaded.
:[font = print; inactive; ]
Region of convergence routines for the transform rule\
 
  bases are loaded.
:[font = print; inactive; ]
Supporting routines for transform rule bases are loaded.
:[font = message; inactive; ]
Support::loaded: 
   Supporting routines, objects, and rules for the signal
    processing package have been loaded successfully.
:[font = message; inactive; ]
Support::change: 
   The loading process has changed such that the files
    Tree.m and DataType.m are no longer automatically
    loaded (the signal processing packages no longer rely
    on the definitions in these files).
:[font = print; inactive; ]
Loading in the digital signal processing packages ...
:[font = print; inactive; ]
Supporting routines for the z-transform rule bases are\
 
  loaded.
:[font = print; inactive; ]
The supporting functions are loaded for symbolic Fourier\
 
  transforms.
:[font = print; inactive; ]
The forward z-transform rules have been loaded.
:[font = print; inactive; ]
The inverse z-transform rules have been loaded.
:[font = print; inactive; ]
The discrete-time Fourier transform (DTFT) rule bases are\
 
  loaded.
:[font = print; inactive; ]
Correlation functions are now loaded.
:[font = print; inactive; ]
ZSolve, a difference equation solver, is loaded.
:[font = print; inactive; ]
The digital signal analyzer is now loaded.
:[font = print; inactive; ]
The discrete Fourier transform (DFT) rule bases are\
 
  loaded.
:[font = message; inactive; ]
Digital::loaded: 
   Routines, objects, and rules for the digital signal
    processing package have been loaded successfully.
:[font = print; inactive; ]

:[font = print; inactive; ]
The digital signal processing extensions has been loaded.
:[font = print; inactive; ]
Good starting points are the objects DSPAnalyze and\
 
  ZTransform.
:[font = print; inactive; ]
Active packages are maintained in the variable\
 
  $ContextPath.
:[font = print; inactive; ]
  New signal primitives are in SPsignals.
:[font = print; inactive; ]
  New system primitives are in SPoperators.
:[font = print; inactive; ]
  New Mathematica functions are in SPfunctions.
:[font = print; inactive; ]
Note that all signal processing expressions will
:[font = print; inactive; ]
be automatically simplified.
:[font = print; inactive; endGroup; ]

:[font = input; initialization; ]
*)
AllPoleZeroPlots[ trans_, z_ ]:= 
   Block[ {i, numrocs, key,key1,key2, polelist, roclist}, 
             polelist = GetRootList [ Denominator[trans], z ]; 
             roclist = Join[ {0}, Sort[ Abs[polelist] ], {Infinity}];
             numrocs = Length [roclist];
            i = 1; 
             key1 = "";
             While [ (key1 != "y") && (key1 != "n"),
                   key1 = ToString [ Input[ "\
                            Want Inverse Z Transform (y/n)?"]]];
           While [ True, 
             key = "a";
             Print[" ROC # ", i];  
             PoleZeroPlot [trans, z, roclist[[i]], roclist[[i+1]],
                                  True];
             if [key1 === "y", Print[" The time sequence is: ", 
                           InvZTransform[{trans,roclist[[i]],roclist[[i+1]]},
                                         z,n,Dialogue -> False]]];                       
            While [ ! MemberQ[{"n","p","f","l","q","s"}, key ],                     
             key = ToString[ Input["PRESS THE FOLLOWING KEYS FOLLOWED\
                   BY A CARRIAGE RETURN: \n
 n : NEXT ROC - \
 p : PREVIOUS ROC - \n
 f : FIRST ROC - \
 l : LAST ROC - \n
 s : SAME - q : QUIT " ]];                
                   If [ (key === "n"),
                     If [i < (numrocs - 1), i = i + 1, i = 1 ] ];
                   If [ (key === "p"),
                      If [ i > 1, i = i - 1, i = numrocs - 1] ];
                   If [ key === "f", i = 1 ];
                   If [ key === "l", i = numrocs - 1];       
                   If [ key  === "q",
                           key2 = "";
                           While [ (key2 != "y") && (key2 != "n"),
                                 key2 = ToString [ Input[ "         \
                                            QUIT (y/n)?"]]
                                 ];
                           If [key2 === "n", key = "a" ]
                      ]
                     ];
                     If [key2 === "y", Break[] ] 
                  ];
             Print[" End of ROCs ! "]
        ]              
(*
:[font = input; initialization; endGroup; ]
*)

(*  InvalidZPoleQ  *)
InvalidZPoleQ[rminus_, r_, rplus_] := TrueQ[rminus < Abs[N[r]] < rplus]

(*  MyRationalPolyQ  *)
MyRationalPolyQ[f_, z_] :=
	MixedPolynomialQ[ Expand[Numerator[f]], z ] &&
	MixedPolynomialQ[ Expand[Denominator[f]], z ]

(*  One-dimensional pole-zero plotting in the z-domain  *)
VectorPoleZeroPlot[f_, z_Symbol, rm_, rp_, w_, True, op___] :=	
	Block [ {abspolelist, fillplot, invalidROClist, options, polelist,
		 poleplot, vectorsplot, polezerolist, rmax, rminus, rplus, 
		 rminuscircle,rpluscircle, unitcircle, xlabel, ylabel, dot, 
		 zeroplot, zstr, ztrans},

		options = ToList[op] ~Join~ Options[PoleZeroPlot];

		rmax = 1;				  (* default values *)
		unitcircle = CirclePS[1];

		(*  Analyze the z-transform function  *)

		ztrans = Together[f];
		If [ ! MyRationalPolyQ[ztrans, z],
		     Message[ PoleZeroPlot::notrational ] ];

		zerolist = GetRootList[Numerator[ztrans], z];
		polelist = GetRootList[Denominator[ztrans], z];
		If [ InformUserQ[Replace[Dialogue, options]],
		     Print[ " " ];
		     Print[ "The zeroes are:  ", zerolist ];
		     Print[ "The poles are:   ", polelist ] ];

		(*  Check consistency of poles with region of convergence  *)
		(*  Exit function if inconsistency encountered		   *)

		rminus = N[rm];			  (* numeric approximation *)
		rplus = N[rp];
		invalidROClist = Select[ polelist,
					 InvalidZPoleQ[rminus, #1, rplus]& ];
		If [ ! SameQ[invalidROClist, {}],
		     Message[PoleZeroPlot::invalidROC, invalidROClist, rm, rp];
		     Return[polelist] ];

		(*  Compute plot of poles and zeroes		*)
		(*  Determine the plot's its circular extent	*)

		rmax = Max[ Join[ {rmax},
				  Map[Abs, ToList[N[zerolist]]],
				  Map[Abs, ToList[N[polelist]]] ] ];

		zeroplot = If [ EmptyQ[zerolist],
		     	        NullPlot,
				PointwisePlot[ComplexTo2DCoordList[zerolist],
					      "O", "*O*"] ];

		poleplot = If [ EmptyQ[polelist],
				NullPlot,
				PointwisePlot[ComplexTo2DCoordList[polelist],
					      "X", "*X*"] ];
        (* Draw pole and zero vectors *)
         polezerolist = zerolist ~Join~ polelist;
         vectorsplot = Graphics[Map[Line[{{Cos[w],Sin[w]}, #1}]&,
                                ComplexTo2DCoordList[polezerolist]]];
         dot = Graphics[{PointSize[0.05], Point[{Cos[w],Sin[w]}]}];
        
		(*  Build region of convergence plot  *)
		If [ NumberQ[rminus],
		     rminuscircle = CirclePS[ rminus, Dashing[{0.05,0.05}] ];
			 rmax = Max[rmax, Abs[rminus]],
		     rminuscircle = NullPlot ];

		If [ NumberQ[rplus],
		     rpluscircle = CirclePS[ rplus, Dashing[{0.05,0.05}] ];
			 rmax = Max[rmax, Abs[rplus]],
		     rpluscircle = NullPlot ];

		rplus = N[ If[ SameQ[rp, Infinity], 2 rmax, rp] ];  (* kludge *)

		fillplot = If [ NumberQ[rminus] && NumberQ[rplus],
				ShadedAnnulus[rminus, rplus],
				NullPlot ];

		(*  Send the contour plot to the screen  *)
		rmax *= 1.25;
		zstr = StripPackage[z];
		xlabel = "Re " ~StringJoin~ zstr;
		ylabel = "Im " ~StringJoin~ zstr;

		Show [unitcircle, rminuscircle, rpluscircle,
		      fillplot, zeroplot, poleplot, vectorsplot, dot,
		      PlotRange -> {{-rmax, rmax}, {-rmax, rmax}},
		      AspectRatio -> Automatic,
		      AxesLabel -> { xlabel, ylabel },
		      Axes -> Automatic,
		      DisplayFunction -> $DisplayFunction ];

		polelist ]
(*
:[font = section; inactive; startGroup; Cclosed; ]
Filter Construction Using the Pole-Zero Diagram
:[font = text; inactive; ]
	By placing poles and zeros in proper locations inside the unit circle one can build a variety of stable filters, as will be illustrated by the exercises given below. In addition, one can easily construct an approximate sketch of the frequency response of the resulting filter by simply looking at the location of the poles and zeros  in the pole-zero diagram.
:[font = subsection; inactive; startGroup; Cclosed; ]
Exercises
:[font = text; inactive; ]
	Draw an approximate sketch of the filter frequency response corresponding to the given pole-zero diagrams, and determine the type of the filter from the resulting frequency response.  
	Check your solution by opening the corresponding "solution" cells.		
:[font = info; inactive; startGroup; Cclosed; center; ]
Exercise 1
:[font = input; startGroup; ]
PoleZeroPlot[z/(z + 0.5), z, 0.5, Infinity, True]
:[font = print; inactive; ]
 
The zeroes are:  {0.}
The poles are:   {-0.5}
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.3 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{-0.5}
;[o]
{-0.5}
:[font = info; inactive; startGroup; Cclosed; center; ]
Solution 1
:[font = input; startGroup; ]
MagPhasePlot[Exp[I w]/(Exp[I w] + 0.5), {w,-Pi,Pi},
              PhaseRangeScale -> Null, PlotRange -> {0,2.5} ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.24721 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.5)] 0.4875 0.12361 1 0 Msboxa
[(1)] 0.4875 0.24721 1 0 Msboxa
[(1.5)] 0.4875 0.37082 1 0 Msboxa
[(2)] 0.4875 0.49443 1 0 Msboxa
[(2.5)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(1)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(2)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.49443 moveto
0.02505 0.49439 lineto
0.02629 0.49429 lineto
0.02753 0.49413 lineto
0.02877 0.4939 lineto
0.03125 0.49324 lineto
0.03373 0.49232 lineto
0.03869 0.48973 lineto
0.04365 0.48618 lineto
0.05357 0.47646 lineto
0.06349 0.46383 lineto
0.10317 0.39895 lineto
0.14286 0.33552 lineto
0.18254 0.28546 lineto
0.22222 0.24831 lineto
0.2619 0.22111 lineto
0.30159 0.20126 lineto
0.34127 0.18688 lineto
0.38095 0.17671 lineto
0.40079 0.17294 lineto
0.42063 0.16995 lineto
0.44048 0.16767 lineto
0.4504 0.16679 lineto
0.46032 0.16607 lineto
0.47024 0.16552 lineto
0.4752 0.1653 lineto
0.48016 0.16512 lineto
0.48512 0.16499 lineto
0.4876 0.16493 lineto
0.49008 0.16489 lineto
0.49256 0.16485 lineto
0.4938 0.16484 lineto
0.49504 0.16483 lineto
0.49628 0.16482 lineto
0.49752 0.16481 lineto
0.49876 0.16481 lineto
0.5 0.16481 lineto
0.50124 0.16481 lineto
0.50248 0.16481 lineto
0.50372 0.16482 lineto
0.50496 0.16483 lineto
0.5062 0.16484 lineto
0.50744 0.16485 lineto
0.50992 0.16489 lineto
0.5124 0.16493 lineto
0.51488 0.16499 lineto
0.51984 0.16512 lineto
0.5248 0.1653 lineto
0.52976 0.16552 lineto
0.53968 0.16607 lineto
Mistroke
0.5496 0.16679 lineto
0.55952 0.16767 lineto
0.57937 0.16995 lineto
0.59921 0.17294 lineto
0.61905 0.17671 lineto
0.65873 0.18688 lineto
0.69841 0.20126 lineto
0.7381 0.22111 lineto
0.77778 0.24831 lineto
0.81746 0.28546 lineto
0.85714 0.33552 lineto
0.89683 0.39895 lineto
0.91667 0.4329 lineto
0.93651 0.46383 lineto
0.94643 0.47646 lineto
0.95635 0.48618 lineto
0.96131 0.48973 lineto
0.96379 0.49115 lineto
0.96627 0.49232 lineto
0.96875 0.49324 lineto
0.96999 0.4936 lineto
0.97123 0.4939 lineto
0.97247 0.49413 lineto
0.97371 0.49429 lineto
0.97495 0.49439 lineto
0.97619 0.49443 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{Graphics[{{Line[{{-3.141592653589793, 2.}, 
       {-3.133411422721069, 1.99986614910785}, 
       {-3.125230191852346, 1.999464766571056}, 
       {-3.117048960983623, 1.998796362215292}, 
       {-3.108867730114899, 1.997861783776396}, 
       {-3.092505268377453, 1.995199166315043}, 
       {-3.076142806640006, 1.991490313784595}, 
       {-3.043417883165112, 1.981012756919347}, 
       {-3.010692959690219, 1.966633411660013}, 
       {-2.945243112740431, 1.927305670340449}, 
       {-2.879793265790644, 1.876221567477559}, 
       {-2.617993877991494, 1.613796442710147}, 
       {-2.356194490192345, 1.357196689091694}, 
       {-2.094395102393196, 1.154700538379252}, 
       {-1.832595714594046, 1.004438904397893}, 
       {-1.570796326794897, 0.894427190999916}, 
       {-1.308996938995747, 0.814106873192444}, 
       {-1.047197551196598, 0.7559289460184544}, 
       {-0.7853981633974485, 0.7148134886731865}, 
       {-0.6544984694978737, 0.6995653073848652}, 
       {-0.523598775598299, 0.6874475386668806}, 
       {-0.3926990816987244, 0.6782382258689938}, 
       {-0.327249234748937, 0.674670743108333}, 
       {-0.2617993877991496, 0.6717727614720509}, 
       {-0.1963495408493623, 0.6695316548888327}, 
       {-0.1636246173744686, 0.6686542859982325}, 
       {-0.1308996938995749, 0.6679377204423989}, 
       {-0.0981747704246813, 0.6673811875689117}, 
       {-0.0818123086872344, 0.6671627399196826}, 
       {-0.06544984694978757, 0.6669840897843039}, 
       {-0.04908738521234074, 0.6668451892818685}, 
       {-0.04090615434361732, 0.6667906330979376}, 
       {-0.0327249234748939, 0.6667460011997202}, 
       {-0.02454369260617048, 0.6667112905990957}, 
       {-0.01636246173744706, 0.6666864989724081}, 
       {-0.00818123086872364, 0.6666716246601376}, 
       {-(2.220446049250313*10^-16), 0.6666666666666666}, 
       {0.0081812308687232, 0.6666716246601376}, 
       {0.01636246173744662, 0.6666864989724081}, 
       {0.02454369260617004, 0.6667112905990957}, 
       {0.03272492347489345, 0.6667460011997202}, 
       {0.04090615434361687, 0.6667906330979376}, 
       {0.0490873852123403, 0.6668451892818685}, 
       {0.06544984694978713, 0.6669840897843039}, 
       {0.081812308687234, 0.6671627399196824}, 
       {0.0981747704246808, 0.6673811875689116}, 
       {0.1308996938995745, 0.6679377204423989}, 
       {0.1636246173744682, 0.6686542859982326}, 
       {0.1963495408493618, 0.6695316548888328}, 
       {0.2617993877991492, 0.671772761472051}, 
       {0.3272492347489365, 0.6746707431083327}, 
       {0.3926990816987239, 0.6782382258689937}, 
       {0.5235987755982986, 0.6874475386668807}, 
       {0.6544984694978733, 0.6995653073848649}, 
       {0.7853981633974481, 0.7148134886731865}, 
       {1.047197551196597, 0.7559289460184544}, 
       {1.308996938995747, 0.814106873192444}, 
       {1.570796326794896, 0.894427190999916}, 
       {1.832595714594046, 1.004438904397893}, 
       {2.094395102393195, 1.154700538379251}, 
       {2.356194490192344, 1.357196689091694}, 
       {2.617993877991494, 1.613796442710147}, 
       {2.748893571891069, 1.751100096231899}, 
       {2.879793265790643, 1.876221567477559}, 
       {2.94524311274043, 1.927305670340448}, 
       {3.010692959690218, 1.966633411660013}, 
       {3.043417883165112, 1.981012756919346}, 
       {3.059780344902558, 1.986753726869169}, 
       {3.076142806640005, 1.991490313784595}, 
       {3.092505268377452, 1.995199166315042}, 
       {3.100686499246176, 1.996662213954056}, 
       {3.108867730114899, 1.997861783776396}, 
       {3.117048960983622, 1.998796362215292}, 
       {3.125230191852346, 1.999464766571056}, 
       {3.133411422721069, 1.99986614910785}, 
       {3.141592653589793, 2.}}]}}, 
   {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[Point[{0, 0}], DisplayFunction -> Identity]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; endGroup; endGroup; ]
THIS IS A HIGH-PASS FILTER !
:[font = info; inactive; startGroup; Cclosed; center; ]
Exercise 2
:[font = input; startGroup; ]
PoleZeroPlot[z^2/(z^2+0.25), z, 0.5, Infinity, True]
:[font = print; inactive; ]
 
The zeroes are:  {0., 0.}
The poles are:   {0.5 I, -0.5 I}
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(*O*)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.5 0.3 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.5 0.7 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{0.5*I, -0.5*I}
;[o]
{0.5 I, -0.5 I}
:[font = info; inactive; startGroup; Cclosed; center; ]
Solution 2
:[font = input; startGroup; ]
MagPhasePlot[Exp[2 I w]/(Exp[2 I w]+0.25),{w,-Pi,Pi},
             PhaseRangeScale -> Null, PlotRange -> {0,2}]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.24721 moveto
0.02505 0.24722 lineto
0.02629 0.24723 lineto
0.02753 0.24726 lineto
0.02877 0.2473 lineto
0.03125 0.2474 lineto
0.03373 0.24755 lineto
0.03621 0.24774 lineto
0.03869 0.24798 lineto
0.04365 0.24857 lineto
0.04861 0.24934 lineto
0.05357 0.25028 lineto
0.06349 0.25269 lineto
0.07341 0.25582 lineto
0.08333 0.25968 lineto
0.10317 0.26973 lineto
0.12302 0.28305 lineto
0.14286 0.29979 lineto
0.18254 0.34282 lineto
0.20238 0.36701 lineto
0.22222 0.38948 lineto
0.23214 0.39875 lineto
0.2371 0.40264 lineto
0.24206 0.40592 lineto
0.24702 0.40855 lineto
0.2495 0.4096 lineto
0.25198 0.41046 lineto
0.25446 0.41114 lineto
0.2557 0.41141 lineto
0.25694 0.41163 lineto
0.25818 0.4118 lineto
0.25942 0.41192 lineto
0.26066 0.412 lineto
0.2619 0.41202 lineto
0.26314 0.412 lineto
0.26438 0.41192 lineto
0.26562 0.4118 lineto
0.26687 0.41163 lineto
0.26935 0.41114 lineto
0.27183 0.41046 lineto
0.27679 0.40855 lineto
0.28175 0.40592 lineto
0.29167 0.39875 lineto
0.30159 0.38948 lineto
0.34127 0.34282 lineto
0.38095 0.29979 lineto
0.40079 0.28305 lineto
0.42063 0.26973 lineto
0.44048 0.25968 lineto
0.4504 0.25582 lineto
Mistroke
0.46032 0.25269 lineto
0.47024 0.25028 lineto
0.4752 0.24934 lineto
0.48016 0.24857 lineto
0.48512 0.24798 lineto
0.4876 0.24774 lineto
0.49008 0.24755 lineto
0.49256 0.2474 lineto
0.4938 0.24735 lineto
0.49504 0.2473 lineto
0.49628 0.24726 lineto
0.49752 0.24723 lineto
0.49876 0.24722 lineto
0.5 0.24721 lineto
0.50124 0.24722 lineto
0.50248 0.24723 lineto
0.50372 0.24726 lineto
0.50496 0.2473 lineto
0.5062 0.24735 lineto
0.50744 0.2474 lineto
0.50992 0.24755 lineto
0.5124 0.24774 lineto
0.51488 0.24798 lineto
0.51984 0.24857 lineto
0.5248 0.24934 lineto
0.52976 0.25028 lineto
0.53968 0.25269 lineto
0.5496 0.25582 lineto
0.55952 0.25968 lineto
0.57937 0.26973 lineto
0.59921 0.28305 lineto
0.61905 0.29979 lineto
0.65873 0.34282 lineto
0.67857 0.36701 lineto
0.69841 0.38948 lineto
0.70833 0.39875 lineto
0.71329 0.40264 lineto
0.71825 0.40592 lineto
0.72321 0.40855 lineto
0.72569 0.4096 lineto
0.72817 0.41046 lineto
0.73065 0.41114 lineto
0.73189 0.41141 lineto
0.73313 0.41163 lineto
0.73438 0.4118 lineto
0.73562 0.41192 lineto
0.73686 0.412 lineto
0.7381 0.41202 lineto
0.73934 0.412 lineto
0.74058 0.41192 lineto
Mistroke
0.74182 0.4118 lineto
0.74306 0.41163 lineto
0.74554 0.41114 lineto
0.74802 0.41046 lineto
0.75298 0.40855 lineto
0.75794 0.40592 lineto
0.76786 0.39875 lineto
0.77778 0.38948 lineto
0.81746 0.34282 lineto
0.8373 0.3199 lineto
0.85714 0.29979 lineto
0.87698 0.28305 lineto
0.89683 0.26973 lineto
0.90675 0.26431 lineto
0.91667 0.25968 lineto
0.92659 0.25582 lineto
0.93651 0.25269 lineto
0.94643 0.25028 lineto
0.95139 0.24934 lineto
0.95635 0.24857 lineto
0.96131 0.24798 lineto
0.96379 0.24774 lineto
0.96627 0.24755 lineto
0.96875 0.2474 lineto
0.96999 0.24735 lineto
0.97123 0.2473 lineto
0.97247 0.24726 lineto
0.97371 0.24723 lineto
0.97495 0.24722 lineto
0.97619 0.24721 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{Graphics[{{Line[{{-3.141592653589793, 0.8}, 
       {-3.133411422721069, 0.800017134898069}, 
       {-3.125230191852346, 0.80006854161068}, 
       {-3.117048960983623, 0.800154226192499}, 
       {-3.108867730114899, 0.800274198732835}, 
       {-3.092505268377453, 0.800617068202093}, 
       {-3.076142806640006, 0.801097311294916}, 
       {-3.059780344902559, 0.801715153552373}, 
       {-3.043417883165112, 0.80247088452971}, 
       {-3.010692959690219, 0.804397488882881}, 
       {-2.977968036215325, 0.806880706482489}, 
       {-2.945243112740431, 0.809925113477117}, 
       {-2.879793265790644, 0.817720615772213}, 
       {-2.814343418840856, 0.827839340986539}, 
       {-2.748893571891069, 0.840349964174696}, 
       {-2.617993877991494, 0.87287156094397}, 
       {-2.487094184091919, 0.915963895084744}, 
       {-2.356194490192345, 0.970142500145332}, 
       {-2.094395102393196, 1.109400392450458}, 
       {-1.963495408493621, 1.187663022587348}, 
       {-1.832595714594046, 1.26039454351782}, 
       {-1.767145867644259, 1.290392154939672}, 
       {-1.734420944169365, 1.302955169741218}, 
       {-1.701696020694471, 1.313588637930047}, 
       {-1.668971097219578, 1.322090646301997}, 
       {-1.652608635482131, 1.325488059963675}, 
       {-1.636246173744684, 1.328292354253876}, 
       {-1.619883712007237, 1.330488965716381}, 
       {-1.611702481138514, 1.331355661725155}, 
       {-1.60352125026979, 1.332066355282652}, 
       {-1.595340019401067, 1.332620102297335}, 
       {-1.587158788532343, 1.33301616504394}, 
       {-1.57897755766362, 1.333254014728543}, 
       {-1.570796326794897, 1.333333333333333}, 
       {-1.562615095926173, 1.333254014728543}, 
       {-1.55443386505745, 1.33301616504394}, 
       {-1.546252634188726, 1.332620102297335}, 
       {-1.538071403320003, 1.332066355282652}, 
       {-1.521708941582556, 1.330488965716381}, 
       {-1.505346479845109, 1.328292354253876}, 
       {-1.472621556370216, 1.322090646301997}, 
       {-1.439896632895322, 1.313588637930047}, 
       {-1.374446785945535, 1.290392154939672}, 
       {-1.308996938995747, 1.26039454351782}, 
       {-1.047197551196598, 1.109400392450458}, 
       {-0.7853981633974485, 0.970142500145332}, 
       {-0.6544984694978737, 0.915963895084744}, 
       {-0.523598775598299, 0.872871560943969}, 
       {-0.3926990816987244, 0.840349964174696}, 
       {-0.327249234748937, 0.827839340986539}, 
       {-0.2617993877991496, 0.817720615772213}, 
       {-0.1963495408493623, 0.809925113477117}, 
       {-0.1636246173744686, 0.806880706482489}, 
       {-0.1308996938995749, 0.804397488882881}, 
       {-0.0981747704246813, 0.80247088452971}, 
       {-0.0818123086872344, 0.801715153552373}, 
       {-0.06544984694978757, 0.801097311294917}, 
       {-0.04908738521234074, 0.800617068202093}, 
       {-0.04090615434361732, 0.800428473352919}, 
       {-0.0327249234748939, 0.800274198732835}, 
       {-0.02454369260617048, 0.800154226192499}, 
       {-0.01636246173744706, 0.80006854161068}, 
       {-0.00818123086872364, 0.800017134898069}, 
       {-(2.220446049250313*10^-16), 0.8}, 
       {0.0081812308687232, 0.800017134898069}, 
       {0.01636246173744662, 0.80006854161068}, 
       {0.02454369260617004, 0.800154226192499}, 
       {0.03272492347489345, 0.800274198732835}, 
       {0.04090615434361687, 0.800428473352919}, 
       {0.0490873852123403, 0.800617068202093}, 
       {0.06544984694978713, 0.801097311294917}, 
       {0.081812308687234, 0.801715153552373}, 
       {0.0981747704246808, 0.80247088452971}, 
       {0.1308996938995745, 0.804397488882881}, 
       {0.1636246173744682, 0.806880706482489}, 
       {0.1963495408493618, 0.809925113477117}, 
       {0.2617993877991492, 0.817720615772213}, 
       {0.3272492347489365, 0.827839340986538}, 
       {0.3926990816987239, 0.840349964174695}, 
       {0.5235987755982986, 0.872871560943969}, 
       {0.6544984694978733, 0.915963895084744}, 
       {0.7853981633974481, 0.970142500145332}, 
       {1.047197551196597, 1.109400392450458}, 
       {1.178097245096172, 1.187663022587347}, 
       {1.308996938995747, 1.26039454351782}, 
       {1.374446785945534, 1.290392154939672}, 
       {1.407171709420428, 1.302955169741218}, 
       {1.439896632895322, 1.313588637930047}, 
       {1.472621556370215, 1.322090646301997}, 
       {1.488984018107662, 1.325488059963675}, 
       {1.505346479845109, 1.328292354253876}, 
       {1.521708941582556, 1.330488965716381}, 
       {1.529890172451279, 1.331355661725154}, 
       {1.538071403320002, 1.332066355282652}, 
       {1.546252634188726, 1.332620102297335}, 
       {1.554433865057449, 1.33301616504394}, 
       {1.562615095926173, 1.333254014728543}, 
       {1.570796326794896, 1.333333333333333}, 
       {1.57897755766362, 1.333254014728543}, 
       {1.587158788532343, 1.33301616504394}, 
       {1.595340019401066, 1.332620102297335}, 
       {1.60352125026979, 1.332066355282652}, 
       {1.619883712007236, 1.330488965716381}, 
       {1.636246173744683, 1.328292354253876}, 
       {1.668971097219577, 1.322090646301997}, 
       {1.701696020694471, 1.313588637930047}, 
       {1.767145867644258, 1.290392154939672}, 
       {1.832595714594046, 1.26039454351782}, 
       {2.094395102393195, 1.109400392450459}, 
       {2.225294796292769, 1.035233033008534}, 
       {2.356194490192344, 0.970142500145332}, 
       {2.487094184091919, 0.915963895084744}, 
       {2.617993877991494, 0.87287156094397}, 
       {2.683443724941281, 0.855331944188374}, 
       {2.748893571891069, 0.840349964174696}, 
       {2.814343418840856, 0.827839340986538}, 
       {2.879793265790643, 0.817720615772213}, 
       {2.94524311274043, 0.809925113477117}, 
       {2.977968036215324, 0.806880706482489}, 
       {3.010692959690218, 0.804397488882881}, 
       {3.043417883165112, 0.80247088452971}, 
       {3.059780344902558, 0.801715153552373}, 
       {3.076142806640005, 0.801097311294917}, 
       {3.092505268377452, 0.800617068202093}, 
       {3.100686499246176, 0.800428473352919}, 
       {3.108867730114899, 0.800274198732835}, 
       {3.117048960983622, 0.800154226192499}, 
       {3.125230191852346, 0.80006854161068}, 
       {3.133411422721069, 0.800017134898069}, 
       {3.141592653589793, 0.8}}]}}, 
   {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[Point[{0, 0}], DisplayFunction -> Identity]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; endGroup; endGroup; ]
THIS IS A BAND-PASS FILTER !
:[font = info; inactive; startGroup; Cclosed; center; ]
Exercise 3
:[font = input; startGroup; ]
PoleZeroPlot[z/(z - 0.5), z, 0.5, Infinity, True]
:[font = print; inactive; ]
 
The zeroes are:  {0.}
The poles are:   {0.5}
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.5 0.5 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.7 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{0.5}
;[o]
{0.5}
:[font = info; inactive; startGroup; Cclosed; center; ]
Solution 3
:[font = input; startGroup; ]
MagPhasePlot[Exp[I w]/(Exp[I w] - 0.5), {w,-Pi,Pi},
             PhaseRangeScale -> Null, PlotRange -> {0, 2.5} ]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.24721 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.5)] 0.4875 0.12361 1 0 Msboxa
[(1)] 0.4875 0.24721 1 0 Msboxa
[(1.5)] 0.4875 0.37082 1 0 Msboxa
[(2)] 0.4875 0.49443 1 0 Msboxa
[(2.5)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.12361 moveto
0.50625 0.12361 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.12361 1 0 Mshowa
0.49375 0.24721 moveto
0.50625 0.24721 lineto
stroke
0 setgray
[(1)] 0.4875 0.24721 1 0 Mshowa
0.49375 0.37082 moveto
0.50625 0.37082 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.37082 1 0 Mshowa
0.49375 0.49443 moveto
0.50625 0.49443 lineto
stroke
0 setgray
[(2)] 0.4875 0.49443 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.16481 moveto
0.02505 0.16481 lineto
0.02629 0.16481 lineto
0.02753 0.16482 lineto
0.02877 0.16483 lineto
0.03125 0.16485 lineto
0.03373 0.16489 lineto
0.03621 0.16493 lineto
0.03869 0.16499 lineto
0.04365 0.16512 lineto
0.04861 0.1653 lineto
0.05357 0.16552 lineto
0.06349 0.16607 lineto
0.07341 0.16679 lineto
0.08333 0.16767 lineto
0.10317 0.16995 lineto
0.12302 0.17294 lineto
0.14286 0.17671 lineto
0.18254 0.18688 lineto
0.22222 0.20126 lineto
0.2619 0.22111 lineto
0.30159 0.24831 lineto
0.34127 0.28546 lineto
0.38095 0.33552 lineto
0.42063 0.39895 lineto
0.44048 0.4329 lineto
0.46032 0.46383 lineto
0.47024 0.47646 lineto
0.4752 0.48173 lineto
0.48016 0.48618 lineto
0.48512 0.48973 lineto
0.4876 0.49115 lineto
0.49008 0.49232 lineto
0.49256 0.49324 lineto
0.4938 0.4936 lineto
0.49504 0.4939 lineto
0.49628 0.49413 lineto
0.49752 0.49429 lineto
0.49876 0.49439 lineto
0.5 0.49443 lineto
0.50124 0.49439 lineto
0.50248 0.49429 lineto
0.50372 0.49413 lineto
0.50496 0.4939 lineto
0.5062 0.4936 lineto
0.50744 0.49324 lineto
0.50992 0.49232 lineto
0.51488 0.48973 lineto
0.51984 0.48618 lineto
0.52976 0.47646 lineto
Mistroke
0.53968 0.46383 lineto
0.57937 0.39895 lineto
0.61905 0.33552 lineto
0.65873 0.28546 lineto
0.69841 0.24831 lineto
0.7381 0.22111 lineto
0.77778 0.20126 lineto
0.81746 0.18688 lineto
0.8373 0.18133 lineto
0.85714 0.17671 lineto
0.87698 0.17294 lineto
0.89683 0.16995 lineto
0.90675 0.16872 lineto
0.91667 0.16767 lineto
0.92659 0.16679 lineto
0.93651 0.16607 lineto
0.94643 0.16552 lineto
0.95139 0.1653 lineto
0.95635 0.16512 lineto
0.96131 0.16499 lineto
0.96379 0.16493 lineto
0.96627 0.16489 lineto
0.96875 0.16485 lineto
0.96999 0.16484 lineto
0.97123 0.16483 lineto
0.97247 0.16482 lineto
0.97371 0.16481 lineto
0.97495 0.16481 lineto
0.97619 0.16481 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
{Graphics[{{Line[{{-3.141592653589793, 0.6666666666666666}, 
       {-3.133411422721069, 0.6666716246601376}, 
       {-3.125230191852346, 0.6666864989724081}, 
       {-3.117048960983623, 0.6667112905990957}, 
       {-3.108867730114899, 0.6667460011997202}, 
       {-3.092505268377453, 0.6668451892818685}, 
       {-3.076142806640006, 0.6669840897843039}, 
       {-3.059780344902559, 0.6671627399196826}, 
       {-3.043417883165112, 0.6673811875689116}, 
       {-3.010692959690219, 0.6679377204423989}, 
       {-2.977968036215325, 0.6686542859982325}, 
       {-2.945243112740431, 0.6695316548888327}, 
       {-2.879793265790644, 0.6717727614720509}, 
       {-2.814343418840856, 0.674670743108333}, 
       {-2.748893571891069, 0.6782382258689937}, 
       {-2.617993877991494, 0.6874475386668807}, 
       {-2.487094184091919, 0.6995653073848651}, 
       {-2.356194490192345, 0.7148134886731865}, 
       {-2.094395102393196, 0.7559289460184544}, 
       {-1.832595714594046, 0.814106873192444}, 
       {-1.570796326794897, 0.894427190999916}, 
       {-1.308996938995747, 1.004438904397893}, 
       {-1.047197551196598, 1.154700538379251}, 
       {-0.7853981633974485, 1.357196689091694}, 
       {-0.523598775598299, 1.613796442710147}, 
       {-0.3926990816987244, 1.7511000962319}, 
       {-0.2617993877991496, 1.87622156747756}, 
       {-0.1963495408493623, 1.927305670340449}, 
       {-0.1636246173744686, 1.948623073276259}, 
       {-0.1308996938995749, 1.966633411660014}, 
       {-0.0981747704246813, 1.981012756919347}, 
       {-0.0818123086872344, 1.986753726869169}, 
       {-0.06544984694978757, 1.991490313784594}, 
       {-0.04908738521234074, 1.995199166315042}, 
       {-0.04090615434361732, 1.996662213954055}, 
       {-0.0327249234748939, 1.997861783776396}, 
       {-0.02454369260617048, 1.998796362215292}, 
       {-0.01636246173744706, 1.999464766571056}, 
       {-0.00818123086872364, 1.99986614910785}, 
       {-(2.220446049250313*10^-16), 2.}, 
       {0.0081812308687232, 1.999866149107849}, 
       {0.01636246173744662, 1.999464766571056}, 
       {0.02454369260617004, 1.998796362215292}, 
       {0.03272492347489345, 1.997861783776396}, 
       {0.04090615434361687, 1.996662213954056}, 
       {0.0490873852123403, 1.995199166315043}, 
       {0.06544984694978713, 1.991490313784595}, 
       {0.0981747704246808, 1.981012756919347}, 
       {0.1308996938995745, 1.966633411660014}, 
       {0.1963495408493618, 1.927305670340449}, 
       {0.2617993877991492, 1.87622156747756}, 
       {0.5235987755982986, 1.613796442710147}, 
       {0.7853981633974481, 1.357196689091694}, 
       {1.047197551196597, 1.154700538379252}, 
       {1.308996938995747, 1.004438904397893}, 
       {1.570796326794896, 0.894427190999916}, 
       {1.832595714594046, 0.814106873192444}, 
       {2.094395102393195, 0.7559289460184546}, 
       {2.225294796292769, 0.7334798272905825}, 
       {2.356194490192344, 0.7148134886731865}, 
       {2.487094184091919, 0.6995653073848651}, 
       {2.617993877991494, 0.6874475386668807}, 
       {2.683443724941281, 0.68249087483022}, 
       {2.748893571891069, 0.6782382258689938}, 
       {2.814343418840856, 0.6746707431083327}, 
       {2.879793265790643, 0.6717727614720509}, 
       {2.94524311274043, 0.6695316548888327}, 
       {2.977968036215324, 0.6686542859982326}, 
       {3.010692959690218, 0.667937720442399}, 
       {3.043417883165112, 0.6673811875689117}, 
       {3.059780344902558, 0.6671627399196826}, 
       {3.076142806640005, 0.6669840897843039}, 
       {3.092505268377452, 0.6668451892818685}, 
       {3.100686499246176, 0.6667906330979376}, 
       {3.108867730114899, 0.6667460011997202}, 
       {3.117048960983622, 0.6667112905990957}, 
       {3.125230191852346, 0.6666864989724081}, 
       {3.133411422721069, 0.6666716246601376}, 
       {3.141592653589793, 0.6666666666666666}}]}}, 
   {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), 
    DisplayFunction -> Identity, PlotColor -> Automatic, 
    Axes -> Automatic, PlotLabel -> None, AxesLabel -> None, 
    Ticks -> Automatic, Framed -> False, Prolog -> {}, 
    Epilog -> {}, AxesStyle -> {}, Background -> Automatic, 
    DefaultColor -> Automatic}], 
  Graphics[Point[{0, 0}], DisplayFunction -> Identity]}
;[o]
{-Graphics-, -Graphics-}
:[font = text; inactive; endGroup; endGroup; endGroup; ]
THIS IS A LOW-PASS FILTER !
:[font = subsection; inactive; startGroup; Cclosed; ]
Simple LPF to HPF Transformation
:[font = text; inactive; ]
	How can we transform the following lowpass impulse response (h[n] = 0.5^n Step[n]) into a highpass impulse response?  Evaluate the following input cell and try to find a solution.   Check your answer by opening the corresponding solution cell !
:[font = input; startGroup; Cclosed; ]
DSPAnalyze[0.5^n Step[n], n, -1, 8]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.12963 0.10582 0.01472 0.5886 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(2)] 0.34127 0.00222 0 1 Msboxa
[(4)] 0.55291 0.00222 0 1 Msboxa
[(6)] 0.76455 0.00222 0 1 Msboxa
[(8)] 0.97619 0.00222 0 1 Msboxa
[(n)] 1.00625 0.01472 -1 0 Msboxa
[(0.2)] 0.11713 0.13244 1 0 Msboxa
[(0.4)] 0.11713 0.25016 1 0 Msboxa
[(0.6)] 0.11713 0.36788 1 0 Msboxa
[(0.8)] 0.11713 0.4856 1 0 Msboxa
[(1)] 0.11713 0.60332 1 0 Msboxa
[( )] 0.12963 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.01472 moveto
1 0.01472 lineto
stroke
0.34127 0.00847 moveto
0.34127 0.02097 lineto
stroke
0 setgray
[(2)] 0.34127 0.00222 0 1 Mshowa
0.55291 0.00847 moveto
0.55291 0.02097 lineto
stroke
0 setgray
[(4)] 0.55291 0.00222 0 1 Mshowa
0.76455 0.00847 moveto
0.76455 0.02097 lineto
stroke
0 setgray
[(6)] 0.76455 0.00222 0 1 Mshowa
0.97619 0.00847 moveto
0.97619 0.02097 lineto
stroke
0 setgray
[(8)] 0.97619 0.00222 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.01472 -1 0 Mshowa
0.12963 0 moveto
0.12963 0.61803 lineto
stroke
0.12338 0.13244 moveto
0.13588 0.13244 lineto
stroke
0 setgray
[(0.2)] 0.11713 0.13244 1 0 Mshowa
0.12338 0.25016 moveto
0.13588 0.25016 lineto
stroke
0 setgray
[(0.4)] 0.11713 0.25016 1 0 Mshowa
0.12338 0.36788 moveto
0.13588 0.36788 lineto
stroke
0 setgray
[(0.6)] 0.11713 0.36788 1 0 Mshowa
0.12338 0.4856 moveto
0.13588 0.4856 lineto
stroke
0 setgray
[(0.8)] 0.11713 0.4856 1 0 Mshowa
0.12338 0.60332 moveto
0.13588 0.60332 lineto
stroke
0 setgray
[(1)] 0.11713 0.60332 1 0 Mshowa
0 setgray
[( )] 0.12963 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.01472 moveto
0.02381 0.01472 lineto
stroke
0.008 setlinewidth
0.02381 0.01472 Mdot
0.004 setlinewidth
0.12963 0.01472 moveto
0.12963 0.60332 lineto
stroke
0.008 setlinewidth
0.12963 0.60332 Mdot
0.004 setlinewidth
0.23545 0.01472 moveto
0.23545 0.30902 lineto
stroke
0.008 setlinewidth
0.23545 0.30902 Mdot
0.004 setlinewidth
0.34127 0.01472 moveto
0.34127 0.16187 lineto
stroke
0.008 setlinewidth
0.34127 0.16187 Mdot
0.004 setlinewidth
0.44709 0.01472 moveto
0.44709 0.08829 lineto
stroke
0.008 setlinewidth
0.44709 0.08829 Mdot
0.004 setlinewidth
0.55291 0.01472 moveto
0.55291 0.0515 lineto
stroke
0.008 setlinewidth
0.55291 0.0515 Mdot
0.004 setlinewidth
0.65873 0.01472 moveto
0.65873 0.03311 lineto
stroke
0.008 setlinewidth
0.65873 0.03311 Mdot
0.004 setlinewidth
0.76455 0.01472 moveto
0.76455 0.02391 lineto
stroke
0.008 setlinewidth
0.76455 0.02391 Mdot
0.004 setlinewidth
0.87037 0.01472 moveto
0.87037 0.01931 lineto
stroke
0.008 setlinewidth
0.87037 0.01931 Mdot
0.004 setlinewidth
0.97619 0.01472 moveto
0.97619 0.01701 lineto
stroke
0.008 setlinewidth
0.97619 0.01701 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
   n
0.5  Step[n]
has the following z-transform:
   1
-------
    0.5
1 - ---
     z
The region of convergence is:
0.5 < |z| < Infinity
The system is stable.
 
The zeroes are:  {}
The poles are:   {0.5}
By substituting into the z-transform,
the frequency response is
      1
-------------
         -I w
1 - 0.5 E
 
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.7 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0 0.0309 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 -0.0125 0 1 Msboxa
[(-4)] 0.19685 -0.0125 0 1 Msboxa
[(-2)] 0.34842 -0.0125 0 1 Msboxa
[(2)] 0.65158 -0.0125 0 1 Msboxa
[(4)] 0.80315 -0.0125 0 1 Msboxa
[(6)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-6)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-4)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-2)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(2)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(4)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(6)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.48092 moveto
0.02505 0.48085 lineto
0.02629 0.48064 lineto
0.02753 0.48028 lineto
0.02877 0.47978 lineto
0.03125 0.47836 lineto
0.03373 0.47641 lineto
0.03869 0.47099 lineto
0.04365 0.46378 lineto
0.05357 0.44525 lineto
0.06349 0.42333 lineto
0.10317 0.33349 lineto
0.12302 0.29607 lineto
0.14286 0.26493 lineto
0.1627 0.23968 lineto
0.18254 0.21977 lineto
0.19246 0.21168 lineto
0.20238 0.20476 lineto
0.2123 0.19898 lineto
0.22222 0.19429 lineto
0.23214 0.19067 lineto
0.2371 0.18925 lineto
0.24206 0.18809 lineto
0.24702 0.1872 lineto
0.2495 0.18685 lineto
0.25198 0.18656 lineto
0.25446 0.18633 lineto
0.2557 0.18625 lineto
0.25694 0.18617 lineto
0.25818 0.18612 lineto
0.25942 0.18608 lineto
0.26066 0.18605 lineto
0.2619 0.18605 lineto
0.26314 0.18605 lineto
0.26438 0.18608 lineto
0.26562 0.18612 lineto
0.26687 0.18617 lineto
0.26935 0.18633 lineto
0.27183 0.18656 lineto
0.27431 0.18685 lineto
0.27679 0.1872 lineto
0.28175 0.18809 lineto
0.28671 0.18925 lineto
0.29167 0.19067 lineto
0.30159 0.19429 lineto
0.31151 0.19898 lineto
0.32143 0.20476 lineto
0.34127 0.21977 lineto
0.36111 0.23968 lineto
0.38095 0.26493 lineto
Mistroke
0.42063 0.33349 lineto
0.44048 0.37685 lineto
0.46032 0.42333 lineto
0.47024 0.44525 lineto
0.4752 0.45509 lineto
0.48016 0.46378 lineto
0.48512 0.47099 lineto
0.4876 0.47394 lineto
0.49008 0.47641 lineto
0.49256 0.47836 lineto
0.4938 0.47914 lineto
0.49504 0.47978 lineto
0.49628 0.48028 lineto
0.49752 0.48064 lineto
0.49876 0.48085 lineto
0.5 0.48092 lineto
0.50124 0.48085 lineto
0.50248 0.48064 lineto
0.50372 0.48028 lineto
0.50496 0.47978 lineto
0.5062 0.47914 lineto
0.50744 0.47836 lineto
0.50992 0.47641 lineto
0.51488 0.47099 lineto
0.51984 0.46378 lineto
0.53968 0.42333 lineto
0.57937 0.33349 lineto
0.59921 0.29607 lineto
0.61905 0.26493 lineto
0.63889 0.23968 lineto
0.65873 0.21977 lineto
0.67857 0.20476 lineto
0.68849 0.19898 lineto
0.69841 0.19429 lineto
0.70833 0.19067 lineto
0.71329 0.18925 lineto
0.71825 0.18809 lineto
0.72321 0.1872 lineto
0.72569 0.18685 lineto
0.72817 0.18656 lineto
0.73065 0.18633 lineto
0.73189 0.18625 lineto
0.73313 0.18617 lineto
0.73438 0.18612 lineto
0.73562 0.18608 lineto
0.73686 0.18605 lineto
0.7381 0.18605 lineto
0.73934 0.18605 lineto
0.74058 0.18608 lineto
0.74182 0.18612 lineto
Mistroke
0.74306 0.18617 lineto
0.74554 0.18633 lineto
0.74802 0.18656 lineto
0.7505 0.18685 lineto
0.75298 0.1872 lineto
0.75794 0.18809 lineto
0.7629 0.18925 lineto
0.76786 0.19067 lineto
0.77778 0.19429 lineto
0.7877 0.19898 lineto
0.79762 0.20476 lineto
0.81746 0.21977 lineto
0.8373 0.23968 lineto
0.85714 0.26493 lineto
0.89683 0.33349 lineto
0.93651 0.42333 lineto
0.94643 0.44525 lineto
0.95635 0.46378 lineto
0.96131 0.47099 lineto
0.96379 0.47394 lineto
0.96627 0.47641 lineto
0.96875 0.47836 lineto
0.96999 0.47914 lineto
0.97123 0.47978 lineto
0.97247 0.48028 lineto
0.97371 0.48064 lineto
0.97495 0.48085 lineto
0.97619 0.48092 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00981 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-30)] 0.4875 0.01472 1 0 Msboxa
[(-20)] 0.4875 0.11282 1 0 Msboxa
[(-10)] 0.4875 0.21092 1 0 Msboxa
[(10)] 0.4875 0.40712 1 0 Msboxa
[(20)] 0.4875 0.50522 1 0 Msboxa
[(30)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.01472 moveto
0.50625 0.01472 lineto
stroke
0 setgray
[(-30)] 0.4875 0.01472 1 0 Mshowa
0.49375 0.11282 moveto
0.50625 0.11282 lineto
stroke
0 setgray
[(-20)] 0.4875 0.11282 1 0 Mshowa
0.49375 0.21092 moveto
0.50625 0.21092 lineto
stroke
0 setgray
[(-10)] 0.4875 0.21092 1 0 Mshowa
0.49375 0.40712 moveto
0.50625 0.40712 lineto
stroke
0 setgray
[(10)] 0.4875 0.40712 1 0 Mshowa
0.49375 0.50522 moveto
0.50625 0.50522 lineto
stroke
0 setgray
[(20)] 0.4875 0.50522 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(30)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.04365 0.17117 lineto
0.05357 0.11697 lineto
0.06349 0.0756 lineto
0.06845 0.05956 lineto
0.07341 0.04639 lineto
0.07837 0.03585 lineto
0.08333 0.02771 lineto
0.08829 0.02174 lineto
0.09077 0.0195 lineto
0.09325 0.01772 lineto
0.09449 0.01699 lineto
0.09573 0.01637 lineto
0.09697 0.01585 lineto
0.09821 0.01544 lineto
0.09945 0.01512 lineto
0.10069 0.01489 lineto
0.10193 0.01476 lineto
0.10317 0.01472 lineto
0.10441 0.01476 lineto
0.10565 0.01489 lineto
0.10689 0.0151 lineto
0.10813 0.01538 lineto
0.10937 0.01575 lineto
0.11062 0.01619 lineto
0.1131 0.0173 lineto
0.11806 0.02032 lineto
0.12302 0.02433 lineto
0.13294 0.03494 lineto
0.14286 0.04841 lineto
0.18254 0.12158 lineto
0.22222 0.21194 lineto
0.2619 0.30902 lineto
0.30159 0.4061 lineto
0.34127 0.49645 lineto
0.36111 0.53615 lineto
0.38095 0.56962 lineto
0.39087 0.5831 lineto
0.39583 0.5888 lineto
0.40079 0.5937 lineto
0.40575 0.59771 lineto
0.40823 0.59936 lineto
0.41071 0.60074 lineto
0.41319 0.60184 lineto
0.41567 0.60265 lineto
0.41691 0.60294 lineto
0.41815 0.60315 lineto
0.41939 0.60328 lineto
0.42063 0.60332 lineto
0.42187 0.60328 lineto
Mistroke
0.42312 0.60314 lineto
0.42436 0.60292 lineto
0.4256 0.6026 lineto
0.42808 0.60166 lineto
0.42932 0.60104 lineto
0.43056 0.60032 lineto
0.43304 0.59853 lineto
0.43552 0.59629 lineto
0.44048 0.59032 lineto
0.44544 0.58218 lineto
0.4504 0.57164 lineto
0.46032 0.54244 lineto
0.47024 0.50106 lineto
0.48016 0.44687 lineto
0.5 0.30902 lineto
0.50992 0.23668 lineto
0.51984 0.17117 lineto
0.52976 0.11697 lineto
0.53968 0.0756 lineto
0.5496 0.04639 lineto
0.55456 0.03585 lineto
0.55952 0.02771 lineto
0.56448 0.02174 lineto
0.56696 0.0195 lineto
0.56944 0.01772 lineto
0.57068 0.01699 lineto
0.57192 0.01637 lineto
0.57316 0.01585 lineto
0.5744 0.01544 lineto
0.57564 0.01512 lineto
0.57688 0.01489 lineto
0.57813 0.01476 lineto
0.57937 0.01472 lineto
0.58061 0.01476 lineto
0.58185 0.01489 lineto
0.58309 0.0151 lineto
0.58433 0.01538 lineto
0.58681 0.01619 lineto
0.58929 0.0173 lineto
0.59425 0.02032 lineto
0.59921 0.02433 lineto
0.60913 0.03494 lineto
0.61905 0.04841 lineto
0.65873 0.12158 lineto
0.69841 0.21194 lineto
0.7381 0.30902 lineto
0.77778 0.4061 lineto
0.81746 0.49645 lineto
0.8373 0.53615 lineto
0.85714 0.56962 lineto
Mistroke
0.86706 0.5831 lineto
0.87202 0.5888 lineto
0.87698 0.5937 lineto
0.88194 0.59771 lineto
0.88442 0.59936 lineto
0.8869 0.60074 lineto
0.88938 0.60184 lineto
0.89187 0.60265 lineto
0.89311 0.60294 lineto
0.89435 0.60315 lineto
0.89559 0.60328 lineto
0.89683 0.60332 lineto
0.89807 0.60328 lineto
0.89931 0.60314 lineto
0.90055 0.60292 lineto
0.90179 0.6026 lineto
0.90427 0.60166 lineto
0.90551 0.60104 lineto
0.90675 0.60032 lineto
0.91171 0.59629 lineto
0.91419 0.59356 lineto
0.91667 0.59032 lineto
0.92163 0.58218 lineto
0.92659 0.57164 lineto
0.93651 0.54244 lineto
0.94643 0.50106 lineto
0.95635 0.44687 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; ]
ZTransData[(1 - 0.5/z)^(-1), Rminus[0.5], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
              1
ZTransData[-------, Rminus[0.5], Rplus[Infinity], ZVariables[z]]
               0.5
           1 - ---
                z
:[font = text; inactive; ]
Hint: Try to change the pole location given by the pole-zero diagram in the input cell above, and then find the corresponding stable HPF impulse response. it is also helpful to refer to the previous three exercises.
:[font = info; inactive; startGroup; Cclosed; center; ]
Solution
:[font = text; inactive; ]
Evaluate the following input cell. 
Compare the obtained impulse response and the obtained frequency response with the given LPF ones. What do you conclude?
:[font = input; startGroup; ]
DSPAnalyze[(-0.5)^n Step[n], n, -1, 8]
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.12963 0.10582 0.21092 0.3924 [
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Msboxa
[(2)] 0.34127 0.19842 0 1 Msboxa
[(4)] 0.55291 0.19842 0 1 Msboxa
[(6)] 0.76455 0.19842 0 1 Msboxa
[(8)] 0.97619 0.19842 0 1 Msboxa
[(n)] 1.00625 0.21092 -1 0 Msboxa
[(-0.4)] 0.11713 0.05396 1 0 Msboxa
[(-0.2)] 0.11713 0.13244 1 0 Msboxa
[(0.2)] 0.11713 0.2894 1 0 Msboxa
[(0.4)] 0.11713 0.36788 1 0 Msboxa
[(0.6)] 0.11713 0.44636 1 0 Msboxa
[(0.8)] 0.11713 0.52484 1 0 Msboxa
[(1)] 0.11713 0.60332 1 0 Msboxa
[( )] 0.12963 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Discrete-Time Domain Analysis)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.21092 moveto
1 0.21092 lineto
stroke
0.34127 0.20467 moveto
0.34127 0.21717 lineto
stroke
0 setgray
[(2)] 0.34127 0.19842 0 1 Mshowa
0.55291 0.20467 moveto
0.55291 0.21717 lineto
stroke
0 setgray
[(4)] 0.55291 0.19842 0 1 Mshowa
0.76455 0.20467 moveto
0.76455 0.21717 lineto
stroke
0 setgray
[(6)] 0.76455 0.19842 0 1 Mshowa
0.97619 0.20467 moveto
0.97619 0.21717 lineto
stroke
0 setgray
[(8)] 0.97619 0.19842 0 1 Mshowa
0 setgray
[(n)] 1.00625 0.21092 -1 0 Mshowa
0.12963 0 moveto
0.12963 0.61803 lineto
stroke
0.12338 0.05396 moveto
0.13588 0.05396 lineto
stroke
0 setgray
[(-0.4)] 0.11713 0.05396 1 0 Mshowa
0.12338 0.13244 moveto
0.13588 0.13244 lineto
stroke
0 setgray
[(-0.2)] 0.11713 0.13244 1 0 Mshowa
0.12338 0.2894 moveto
0.13588 0.2894 lineto
stroke
0 setgray
[(0.2)] 0.11713 0.2894 1 0 Mshowa
0.12338 0.36788 moveto
0.13588 0.36788 lineto
stroke
0 setgray
[(0.4)] 0.11713 0.36788 1 0 Mshowa
0.12338 0.44636 moveto
0.13588 0.44636 lineto
stroke
0 setgray
[(0.6)] 0.11713 0.44636 1 0 Mshowa
0.12338 0.52484 moveto
0.13588 0.52484 lineto
stroke
0 setgray
[(0.8)] 0.11713 0.52484 1 0 Mshowa
0.12338 0.60332 moveto
0.13588 0.60332 lineto
stroke
0 setgray
[(1)] 0.11713 0.60332 1 0 Mshowa
0 setgray
[( )] 0.12963 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
0.004 setlinewidth
0.02381 0.21092 moveto
0.02381 0.21092 lineto
stroke
0.008 setlinewidth
0.02381 0.21092 Mdot
0.004 setlinewidth
0.12963 0.21092 moveto
0.12963 0.60332 lineto
stroke
0.008 setlinewidth
0.12963 0.60332 Mdot
0.004 setlinewidth
0.23545 0.21092 moveto
0.23545 0.01472 lineto
stroke
0.008 setlinewidth
0.23545 0.01472 Mdot
0.004 setlinewidth
0.34127 0.21092 moveto
0.34127 0.30902 lineto
stroke
0.008 setlinewidth
0.34127 0.30902 Mdot
0.004 setlinewidth
0.44709 0.21092 moveto
0.44709 0.16187 lineto
stroke
0.008 setlinewidth
0.44709 0.16187 Mdot
0.004 setlinewidth
0.55291 0.21092 moveto
0.55291 0.23544 lineto
stroke
0.008 setlinewidth
0.55291 0.23544 Mdot
0.004 setlinewidth
0.65873 0.21092 moveto
0.65873 0.19865 lineto
stroke
0.008 setlinewidth
0.65873 0.19865 Mdot
0.004 setlinewidth
0.76455 0.21092 moveto
0.76455 0.21705 lineto
stroke
0.008 setlinewidth
0.76455 0.21705 Mdot
0.004 setlinewidth
0.87037 0.21092 moveto
0.87037 0.20785 lineto
stroke
0.008 setlinewidth
0.87037 0.20785 Mdot
0.004 setlinewidth
0.97619 0.21092 moveto
0.97619 0.21245 lineto
stroke
0.008 setlinewidth
0.97619 0.21245 Mdot
grestore
% End of Graphics
MathPictureEnd
:[font = print; inactive; ]
      n
(-0.5)  Step[n]
has the following z-transform:
   1
-------
    0.5
1 + ---
     z
The region of convergence is:
0.5 < |z| < Infinity
The system is stable.
 
The zeroes are:  {}
The poles are:   {-0.5}
By substituting into the z-transform,
the frequency response is
      1
-------------
         -I w
1 + 0.5 E
 
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.7 0.5 moveto
0.69999 0.50164 lineto
0.69997 0.50327 lineto
0.69994 0.50491 lineto
0.69989 0.50654 lineto
0.69983 0.50818 lineto
0.69976 0.50981 lineto
0.69957 0.51308 lineto
0.69933 0.51634 lineto
0.69904 0.5196 lineto
0.69829 0.52611 lineto
0.69733 0.53258 lineto
0.69616 0.53902 lineto
0.69319 0.55176 lineto
0.68939 0.56429 lineto
0.68478 0.57654 lineto
0.67321 0.6 lineto
0.65867 0.62175 lineto
0.64142 0.64142 lineto
0.62175 0.65867 lineto
0.6 0.67321 lineto
0.58846 0.67937 lineto
0.57654 0.68478 lineto
0.56429 0.68939 lineto
0.55176 0.69319 lineto
0.53902 0.69616 lineto
0.53258 0.69733 lineto
0.52611 0.69829 lineto
0.5196 0.69904 lineto
0.51634 0.69933 lineto
0.51308 0.69957 lineto
0.50981 0.69976 lineto
0.50818 0.69983 lineto
0.50654 0.69989 lineto
0.50491 0.69994 lineto
0.50327 0.69997 lineto
0.50164 0.69999 lineto
0.5 0.7 lineto
0.49836 0.69999 lineto
0.49673 0.69997 lineto
0.49509 0.69994 lineto
0.49346 0.69989 lineto
0.49019 0.69976 lineto
0.48692 0.69957 lineto
0.48366 0.69933 lineto
0.4804 0.69904 lineto
0.47389 0.69829 lineto
0.46742 0.69733 lineto
0.46098 0.69616 lineto
0.44824 0.69319 lineto
Mistroke
0.43571 0.68939 lineto
0.42346 0.68478 lineto
0.4 0.67321 lineto
0.37825 0.65867 lineto
0.35858 0.64142 lineto
0.34133 0.62175 lineto
0.32679 0.6 lineto
0.31522 0.57654 lineto
0.31061 0.56429 lineto
0.30681 0.55176 lineto
0.30384 0.53902 lineto
0.30267 0.53258 lineto
0.30171 0.52611 lineto
0.30096 0.5196 lineto
0.30067 0.51634 lineto
0.30043 0.51308 lineto
0.30024 0.50981 lineto
0.30017 0.50818 lineto
0.30011 0.50654 lineto
0.30006 0.50491 lineto
0.30003 0.50327 lineto
0.30001 0.50164 lineto
0.3 0.5 lineto
0.30001 0.49836 lineto
0.30003 0.49673 lineto
0.30006 0.49509 lineto
0.30011 0.49346 lineto
0.30024 0.49019 lineto
0.30043 0.48692 lineto
0.30067 0.48366 lineto
0.30096 0.4804 lineto
0.30171 0.47389 lineto
0.30267 0.46742 lineto
0.30384 0.46098 lineto
0.30681 0.44824 lineto
0.31061 0.43571 lineto
0.31522 0.42346 lineto
0.32679 0.4 lineto
0.34133 0.37825 lineto
0.35858 0.35858 lineto
0.37825 0.34133 lineto
0.4 0.32679 lineto
0.41154 0.32063 lineto
0.42346 0.31522 lineto
0.43571 0.31061 lineto
0.44824 0.30681 lineto
0.46098 0.30384 lineto
0.46742 0.30267 lineto
0.47389 0.30171 lineto
0.4804 0.30096 lineto
Mistroke
0.48366 0.30067 lineto
0.48692 0.30043 lineto
0.49019 0.30024 lineto
0.49182 0.30017 lineto
0.49346 0.30011 lineto
0.49509 0.30006 lineto
0.49673 0.30003 lineto
0.49836 0.30001 lineto
0.5 0.3 lineto
0.50164 0.30001 lineto
0.50327 0.30003 lineto
0.50491 0.30006 lineto
0.50654 0.30011 lineto
0.50981 0.30024 lineto
0.51308 0.30043 lineto
0.51634 0.30067 lineto
0.5196 0.30096 lineto
0.52611 0.30171 lineto
0.53258 0.30267 lineto
0.53902 0.30384 lineto
0.55176 0.30681 lineto
0.56429 0.31061 lineto
0.57654 0.31522 lineto
0.6 0.32679 lineto
0.62175 0.34133 lineto
0.64142 0.35858 lineto
0.65867 0.37825 lineto
0.67321 0.4 lineto
0.67937 0.41154 lineto
0.68478 0.42346 lineto
0.68939 0.43571 lineto
0.69319 0.44824 lineto
0.69616 0.46098 lineto
0.69733 0.46742 lineto
0.69829 0.47389 lineto
0.69904 0.4804 lineto
0.69933 0.48366 lineto
0.69957 0.48692 lineto
0.69976 0.49019 lineto
0.69983 0.49182 lineto
0.69989 0.49346 lineto
0.69994 0.49509 lineto
0.69997 0.49673 lineto
0.69999 0.49836 lineto
0.7 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.68794 0.5684 lineto
stroke
0.30156 0.47507 moveto
-0.26579 0.26857 lineto
stroke
0.30124 0.52225 moveto
-0.2775 0.31161 lineto
stroke
0.31432 0.57431 moveto
-0.28684 0.3555 lineto
stroke
0.3531 0.63572 moveto
-0.29376 0.40028 lineto
stroke
1.14616 0.97167 moveto
-0.29817 0.44597 lineto
stroke
1.11756 1.00855 moveto
-0.29997 0.49262 lineto
stroke
1.08617 1.04443 moveto
-0.29899 0.54027 lineto
stroke
1.05182 1.07922 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
1.29503 0.41099 moveto
-0.05182 -0.07922 lineto
stroke
1.29899 0.45973 moveto
-0.08617 -0.04443 lineto
stroke
1.29997 0.50738 moveto
-0.11756 -0.00855 lineto
stroke
1.29817 0.55403 moveto
-0.14616 0.02833 lineto
stroke
0.4747 0.30161 moveto
-0.17215 0.06617 lineto
stroke
0.40552 0.32372 moveto
-0.19564 0.10492 lineto
stroke
0.36205 0.35519 moveto
-0.2167 0.14455 lineto
stroke
0.33196 0.39154 moveto
-0.23539 0.18504 lineto
stroke
0.31206 0.4316 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.66804 0.60846 lineto
stroke
1.26579 0.73143 moveto
0.69844 0.52493 lineto
stroke
1.2167 0.85545 moveto
0.63795 0.64481 lineto
stroke
1.2775 0.68839 moveto
0.69876 0.47775 lineto
stroke
1.19564 0.89508 moveto
0.59448 0.67628 lineto
stroke
1.28684 0.6445 moveto
0.68568 0.42569 lineto
stroke
1.17215 0.93383 moveto
0.5253 0.69839 lineto
stroke
1.29376 0.59972 moveto
0.6469 0.36428 lineto
stroke
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.3 0.5 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0 0.0309 [
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 -0.0125 0 1 Msboxa
[(-4)] 0.19685 -0.0125 0 1 Msboxa
[(-2)] 0.34842 -0.0125 0 1 Msboxa
[(2)] 0.65158 -0.0125 0 1 Msboxa
[(4)] 0.80315 -0.0125 0 1 Msboxa
[(6)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(2.5)] 0.4875 0.07725 1 0 Msboxa
[(5)] 0.4875 0.15451 1 0 Msboxa
[(7.5)] 0.4875 0.23176 1 0 Msboxa
[(10)] 0.4875 0.30902 1 0 Msboxa
[(12.5)] 0.4875 0.38627 1 0 Msboxa
[(15)] 0.4875 0.46353 1 0 Msboxa
[(17.5)] 0.4875 0.54078 1 0 Msboxa
[(20)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response \(dB\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-6)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-4)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-2)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(2)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(4)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(6)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(2.5)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(7.5)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(10)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(12.5)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(15)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(17.5)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(20)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.18605 moveto
0.02505 0.18605 lineto
0.02629 0.18608 lineto
0.02753 0.18612 lineto
0.02877 0.18617 lineto
0.03125 0.18633 lineto
0.03373 0.18656 lineto
0.03621 0.18685 lineto
0.03869 0.1872 lineto
0.04365 0.18809 lineto
0.04861 0.18925 lineto
0.05357 0.19067 lineto
0.06349 0.19429 lineto
0.07341 0.19898 lineto
0.08333 0.20476 lineto
0.10317 0.21977 lineto
0.12302 0.23968 lineto
0.14286 0.26493 lineto
0.18254 0.33349 lineto
0.20238 0.37685 lineto
0.22222 0.42333 lineto
0.23214 0.44525 lineto
0.2371 0.45509 lineto
0.24206 0.46378 lineto
0.24702 0.47099 lineto
0.2495 0.47394 lineto
0.25198 0.47641 lineto
0.25446 0.47836 lineto
0.2557 0.47914 lineto
0.25694 0.47978 lineto
0.25818 0.48028 lineto
0.25942 0.48064 lineto
0.26066 0.48085 lineto
0.2619 0.48092 lineto
0.26314 0.48085 lineto
0.26438 0.48064 lineto
0.26562 0.48028 lineto
0.26687 0.47978 lineto
0.26935 0.47836 lineto
0.27183 0.47641 lineto
0.27679 0.47099 lineto
0.28175 0.46378 lineto
0.29167 0.44525 lineto
0.30159 0.42333 lineto
0.34127 0.33349 lineto
0.38095 0.26493 lineto
0.40079 0.23968 lineto
0.42063 0.21977 lineto
0.44048 0.20476 lineto
0.4504 0.19898 lineto
Mistroke
0.46032 0.19429 lineto
0.47024 0.19067 lineto
0.4752 0.18925 lineto
0.48016 0.18809 lineto
0.48512 0.1872 lineto
0.4876 0.18685 lineto
0.49008 0.18656 lineto
0.49256 0.18633 lineto
0.4938 0.18625 lineto
0.49504 0.18617 lineto
0.49628 0.18612 lineto
0.49752 0.18608 lineto
0.49876 0.18605 lineto
0.5 0.18605 lineto
0.50124 0.18605 lineto
0.50248 0.18608 lineto
0.50372 0.18612 lineto
0.50496 0.18617 lineto
0.5062 0.18625 lineto
0.50744 0.18633 lineto
0.50992 0.18656 lineto
0.5124 0.18685 lineto
0.51488 0.1872 lineto
0.51984 0.18809 lineto
0.5248 0.18925 lineto
0.52976 0.19067 lineto
0.53968 0.19429 lineto
0.5496 0.19898 lineto
0.55952 0.20476 lineto
0.57937 0.21977 lineto
0.59921 0.23968 lineto
0.61905 0.26493 lineto
0.65873 0.33349 lineto
0.67857 0.37685 lineto
0.69841 0.42333 lineto
0.70833 0.44525 lineto
0.71329 0.45509 lineto
0.71825 0.46378 lineto
0.72321 0.47099 lineto
0.72569 0.47394 lineto
0.72817 0.47641 lineto
0.73065 0.47836 lineto
0.73189 0.47914 lineto
0.73313 0.47978 lineto
0.73438 0.48028 lineto
0.73562 0.48064 lineto
0.73686 0.48085 lineto
0.7381 0.48092 lineto
0.73934 0.48085 lineto
0.74058 0.48064 lineto
Mistroke
0.74182 0.48028 lineto
0.74306 0.47978 lineto
0.74554 0.47836 lineto
0.74802 0.47641 lineto
0.75298 0.47099 lineto
0.75794 0.46378 lineto
0.77778 0.42333 lineto
0.81746 0.33349 lineto
0.8373 0.29607 lineto
0.85714 0.26493 lineto
0.87698 0.23968 lineto
0.89683 0.21977 lineto
0.90675 0.21168 lineto
0.91667 0.20476 lineto
0.92659 0.19898 lineto
0.93651 0.19429 lineto
0.94643 0.19067 lineto
0.95139 0.18925 lineto
0.95635 0.18809 lineto
0.96131 0.1872 lineto
0.96379 0.18685 lineto
0.96627 0.18656 lineto
0.96875 0.18633 lineto
0.96999 0.18625 lineto
0.97123 0.18617 lineto
0.97247 0.18612 lineto
0.97371 0.18608 lineto
0.97495 0.18605 lineto
0.97619 0.18605 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 174; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.07579 0.30902 0.00981 [
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Msboxa
[(-6)] 0.04527 0.29652 0 1 Msboxa
[(-4)] 0.19685 0.29652 0 1 Msboxa
[(-2)] 0.34842 0.29652 0 1 Msboxa
[(2)] 0.65158 0.29652 0 1 Msboxa
[(4)] 0.80315 0.29652 0 1 Msboxa
[(6)] 0.95473 0.29652 0 1 Msboxa
[(w)] 1.00625 0.30902 -1 0 Msboxa
[(-30)] 0.4875 0.01472 1 0 Msboxa
[(-20)] 0.4875 0.11282 1 0 Msboxa
[(-10)] 0.4875 0.21092 1 0 Msboxa
[(10)] 0.4875 0.40712 1 0 Msboxa
[(20)] 0.4875 0.50522 1 0 Msboxa
[(30)] 0.4875 0.60332 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Phase Response \(degrees\))] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0.30902 moveto
1 0.30902 lineto
stroke
0.04527 0.30277 moveto
0.04527 0.31527 lineto
stroke
0 setgray
[(-6)] 0.04527 0.29652 0 1 Mshowa
0.19685 0.30277 moveto
0.19685 0.31527 lineto
stroke
0 setgray
[(-4)] 0.19685 0.29652 0 1 Mshowa
0.34842 0.30277 moveto
0.34842 0.31527 lineto
stroke
0 setgray
[(-2)] 0.34842 0.29652 0 1 Mshowa
0.65158 0.30277 moveto
0.65158 0.31527 lineto
stroke
0 setgray
[(2)] 0.65158 0.29652 0 1 Mshowa
0.80315 0.30277 moveto
0.80315 0.31527 lineto
stroke
0 setgray
[(4)] 0.80315 0.29652 0 1 Mshowa
0.95473 0.30277 moveto
0.95473 0.31527 lineto
stroke
0 setgray
[(6)] 0.95473 0.29652 0 1 Mshowa
0 setgray
[(w)] 1.00625 0.30902 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.01472 moveto
0.50625 0.01472 lineto
stroke
0 setgray
[(-30)] 0.4875 0.01472 1 0 Mshowa
0.49375 0.11282 moveto
0.50625 0.11282 lineto
stroke
0 setgray
[(-20)] 0.4875 0.11282 1 0 Mshowa
0.49375 0.21092 moveto
0.50625 0.21092 lineto
stroke
0 setgray
[(-10)] 0.4875 0.21092 1 0 Mshowa
0.49375 0.40712 moveto
0.50625 0.40712 lineto
stroke
0 setgray
[(10)] 0.4875 0.40712 1 0 Mshowa
0.49375 0.50522 moveto
0.50625 0.50522 lineto
stroke
0 setgray
[(20)] 0.4875 0.50522 1 0 Mshowa
0.49375 0.60332 moveto
0.50625 0.60332 lineto
stroke
0 setgray
[(30)] 0.4875 0.60332 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.30902 moveto
0.06349 0.4061 lineto
0.10317 0.49645 lineto
0.12302 0.53615 lineto
0.14286 0.56962 lineto
0.15278 0.5831 lineto
0.15774 0.5888 lineto
0.1627 0.5937 lineto
0.16766 0.59771 lineto
0.17014 0.59936 lineto
0.17262 0.60074 lineto
0.1751 0.60184 lineto
0.17758 0.60265 lineto
0.17882 0.60294 lineto
0.18006 0.60315 lineto
0.1813 0.60328 lineto
0.18254 0.60332 lineto
0.18378 0.60328 lineto
0.18502 0.60314 lineto
0.18626 0.60292 lineto
0.1875 0.6026 lineto
0.18998 0.60166 lineto
0.19122 0.60104 lineto
0.19246 0.60032 lineto
0.19494 0.59853 lineto
0.19742 0.59629 lineto
0.20238 0.59032 lineto
0.20734 0.58218 lineto
0.2123 0.57164 lineto
0.22222 0.54244 lineto
0.23214 0.50106 lineto
0.24206 0.44687 lineto
0.2619 0.30902 lineto
0.28175 0.17117 lineto
0.29167 0.11697 lineto
0.30159 0.0756 lineto
0.30655 0.05956 lineto
0.31151 0.04639 lineto
0.31647 0.03585 lineto
0.32143 0.02771 lineto
0.32391 0.02447 lineto
0.32639 0.02174 lineto
0.32887 0.0195 lineto
0.33135 0.01772 lineto
0.33259 0.01699 lineto
0.33383 0.01637 lineto
0.33507 0.01585 lineto
0.33631 0.01544 lineto
0.33755 0.01512 lineto
0.33879 0.01489 lineto
Mistroke
0.34003 0.01476 lineto
0.34127 0.01472 lineto
0.34251 0.01476 lineto
0.34375 0.01489 lineto
0.34499 0.0151 lineto
0.34623 0.01538 lineto
0.34747 0.01575 lineto
0.34871 0.01619 lineto
0.35119 0.0173 lineto
0.35615 0.02032 lineto
0.36111 0.02433 lineto
0.37103 0.03494 lineto
0.38095 0.04841 lineto
0.40079 0.08189 lineto
0.42063 0.12158 lineto
0.46032 0.21194 lineto
0.5 0.30902 lineto
0.53968 0.4061 lineto
0.57937 0.49645 lineto
0.59921 0.53615 lineto
0.61905 0.56962 lineto
0.62897 0.5831 lineto
0.63393 0.5888 lineto
0.63889 0.5937 lineto
0.64385 0.59771 lineto
0.64633 0.59936 lineto
0.64881 0.60074 lineto
0.65129 0.60184 lineto
0.65253 0.60228 lineto
0.65377 0.60265 lineto
0.65501 0.60294 lineto
0.65625 0.60315 lineto
0.65749 0.60328 lineto
0.65873 0.60332 lineto
0.65997 0.60328 lineto
0.66121 0.60314 lineto
0.66245 0.60292 lineto
0.66369 0.6026 lineto
0.66617 0.60166 lineto
0.66741 0.60104 lineto
0.66865 0.60032 lineto
0.67113 0.59853 lineto
0.67361 0.59629 lineto
0.67857 0.59032 lineto
0.68353 0.58218 lineto
0.68849 0.57164 lineto
0.69841 0.54244 lineto
0.70833 0.50106 lineto
0.71825 0.44687 lineto
0.7381 0.30902 lineto
Mistroke
0.74802 0.23668 lineto
0.75794 0.17117 lineto
0.76786 0.11697 lineto
0.77778 0.0756 lineto
0.78274 0.05956 lineto
0.7877 0.04639 lineto
0.79266 0.03585 lineto
0.79762 0.02771 lineto
0.8001 0.02447 lineto
0.80258 0.02174 lineto
0.80506 0.0195 lineto
0.80754 0.01772 lineto
0.80878 0.01699 lineto
0.81002 0.01637 lineto
0.81126 0.01585 lineto
0.8125 0.01544 lineto
0.81374 0.01512 lineto
0.81498 0.01489 lineto
0.81622 0.01476 lineto
0.81746 0.01472 lineto
0.8187 0.01476 lineto
0.81994 0.01489 lineto
0.82118 0.0151 lineto
0.82242 0.01538 lineto
0.8249 0.01619 lineto
0.82738 0.0173 lineto
0.83234 0.02032 lineto
0.8373 0.02433 lineto
0.84722 0.03494 lineto
0.85714 0.04841 lineto
0.89683 0.12158 lineto
0.93651 0.21194 lineto
0.97619 0.30902 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = output; inactive; output; endGroup; endGroup; ]
ZTransData[(1 + 0.5/z)^(-1), Rminus[0.5], 
  Rplus[DirectedInfinity[1]], ZVariables[z]]
;[o]
              1
ZTransData[-------, Rminus[0.5], Rplus[Infinity], ZVariables[z]]
               0.5
           1 + ---
                z
:[font = info; inactive; startGroup; Cclosed; center; ]
Conclusion
:[font = text; inactive; endGroup; endGroup; ]
 The HPF impulse response can be obtained from the LPF impulse response by simply making the samples of the LPF impulse response alternate in sign.
:[font = subsection; inactive; startGroup; Cclosed; ]
Example:  Slightly perturbing pole locations destroys elliptic filter response 
:[font = text; inactive; startGroup; ]
	Animate the following cells by selecting the graphics cells to be animated and then choosing the Animation option from the Graph sub-menu. You can also set the desired animation speed by using the Preferences option in the main menu, or the options in the bottom right side of  the notebook border.
:[font = text; inactive; ]
	Note that you can change the transfer function used in the input cells and obtain other desired graphics cells to be animated.
:[font = text; inactive; ]
	The following input cells illustrate the effect of changing the poles location of a fourth-order elliptic filter on the magnitude response of the elliptic filter, defined as  
:[font = input; initialization; ]
*)
elliptic4thorder[z_, rlarger_, rsmaller_] :=
  0.1473035 z^4 *
  (1 + 1.621784 z^-1 + z^-2) (1 + 0.7158956 z^-1 + z^-2) /
  ( (z - rsmaller Exp[I w1]) (z - rsmaller Exp[-I w1])
    (z - rlarger Exp[I w2])  (z - rlarger Exp[-I w2]) ) /.
  { w1 -> 1.140341, w2 -> 1.599593 }
(*
:[font = text; inactive; ]
In the first pair of animations, we increase the radius of the two poles with the smaller radius.  Note that only a small distortion in the pole locations causes a tremendous deterioration of the frequency response of the elliptic filter. 
:[font = input; startGroup; ]
Do[ PoleZeroPlot[ ExpandAll[ elliptic4thorder[z, 0.8929096, rs] ],
                  z, 0.8929096, Infinity, True, Dialogue -> False ],
    { rs, 0.4829798, 0.5829798, 0.01 } ]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58229 0.3208 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58229 0.6792 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58395 0.31716 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58395 0.68284 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58562 0.31353 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58562 0.68647 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58729 0.30989 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58729 0.69011 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58896 0.30626 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58896 0.69374 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59063 0.30262 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59063 0.69738 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.5923 0.29899 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.5923 0.70101 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59397 0.29535 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59397 0.70465 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59564 0.29172 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59564 0.70828 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59731 0.28808 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.59731 0.71192 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]
Do[ MagPhasePlot[ ExpandAll[ elliptic4thorder[ Exp[I w], 0.8929096, rs ] ], 
                  { w, -Pi, Pi },
                  PhaseRangeScale -> Null,
                  PlotRange -> { 0, 1.2 } ],
    { rs, 0.4829798, 0.5829798, 0.01 } ]
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.0129 moveto
0.02505 0.01289 lineto
0.02629 0.01289 lineto
0.02753 0.01288 lineto
0.02877 0.01286 lineto
0.03125 0.01281 lineto
0.03373 0.01275 lineto
0.03621 0.01267 lineto
0.03869 0.01257 lineto
0.04365 0.01231 lineto
0.04861 0.01198 lineto
0.05357 0.01158 lineto
0.06349 0.01056 lineto
0.08333 0.00767 lineto
0.10317 0.00371 lineto
0.1131 0.00137 lineto
0.11558 0.00076 lineto
0.11682 0.00044 lineto
0.11806 0.00013 lineto
0.1193 0.00019 lineto
0.12054 0.00051 lineto
0.12302 0.00115 lineto
0.14286 0.00646 lineto
0.15278 0.009 lineto
0.15774 0.01016 lineto
0.1627 0.01118 lineto
0.16766 0.01202 lineto
0.17014 0.01236 lineto
0.17138 0.0125 lineto
0.17262 0.01262 lineto
0.17386 0.01272 lineto
0.1751 0.0128 lineto
0.17634 0.01286 lineto
0.17758 0.01289 lineto
0.17882 0.0129 lineto
0.18006 0.01287 lineto
0.1813 0.01282 lineto
0.18254 0.01273 lineto
0.18378 0.01261 lineto
0.18502 0.01244 lineto
0.1875 0.012 lineto
0.18998 0.01137 lineto
0.19246 0.01052 lineto
0.19494 0.00943 lineto
0.19742 0.00806 lineto
0.20238 0.0043 lineto
0.20486 0.00181 lineto
0.2061 0.00038 lineto
0.20734 0.00118 lineto
0.20982 0.00474 lineto
Mistroke
0.2123 0.00896 lineto
0.21726 0.01988 lineto
0.22222 0.03507 lineto
0.22718 0.0562 lineto
0.23214 0.08558 lineto
0.2371 0.12641 lineto
0.24206 0.18242 lineto
0.25198 0.34356 lineto
0.25446 0.38764 lineto
0.25694 0.42787 lineto
0.25942 0.4613 lineto
0.26066 0.47487 lineto
0.2619 0.48622 lineto
0.26314 0.4954 lineto
0.26438 0.50253 lineto
0.26562 0.5078 lineto
0.26687 0.51144 lineto
0.26811 0.5137 lineto
0.26935 0.51481 lineto
0.27059 0.515 lineto
0.27183 0.51447 lineto
0.28175 0.50039 lineto
0.28423 0.49683 lineto
0.28671 0.49376 lineto
0.28919 0.49124 lineto
0.29167 0.48926 lineto
0.29291 0.48847 lineto
0.29415 0.48781 lineto
0.29539 0.48727 lineto
0.29663 0.48685 lineto
0.29787 0.48654 lineto
0.29911 0.48634 lineto
0.30035 0.48624 lineto
0.30159 0.48623 lineto
0.30283 0.48631 lineto
0.30407 0.48647 lineto
0.30531 0.4867 lineto
0.30655 0.487 lineto
0.31151 0.48881 lineto
0.31647 0.49133 lineto
0.32143 0.49429 lineto
0.34127 0.50646 lineto
0.35119 0.51099 lineto
0.35615 0.51264 lineto
0.35863 0.5133 lineto
0.36111 0.51385 lineto
0.36359 0.51429 lineto
0.36483 0.51448 lineto
0.36607 0.51463 lineto
0.36731 0.51476 lineto
Mistroke
0.36855 0.51486 lineto
0.36979 0.51494 lineto
0.37103 0.51499 lineto
0.37227 0.51502 lineto
0.37351 0.51502 lineto
0.37475 0.51501 lineto
0.37599 0.51496 lineto
0.37723 0.5149 lineto
0.37847 0.51482 lineto
0.38095 0.51458 lineto
0.38343 0.51427 lineto
0.38591 0.51388 lineto
0.39087 0.51291 lineto
0.40079 0.51033 lineto
0.42063 0.50368 lineto
0.44048 0.49681 lineto
0.4504 0.49376 lineto
0.46032 0.49114 lineto
0.47024 0.48903 lineto
0.4752 0.48818 lineto
0.48016 0.48748 lineto
0.48512 0.48693 lineto
0.4876 0.48672 lineto
0.49008 0.48654 lineto
0.49256 0.4864 lineto
0.4938 0.48635 lineto
0.49504 0.4863 lineto
0.49628 0.48627 lineto
0.49752 0.48624 lineto
0.49876 0.48623 lineto
0.5 0.48622 lineto
0.50124 0.48623 lineto
0.50248 0.48624 lineto
0.50372 0.48627 lineto
0.50496 0.4863 lineto
0.5062 0.48635 lineto
0.50744 0.4864 lineto
0.50992 0.48654 lineto
0.5124 0.48672 lineto
0.51488 0.48693 lineto
0.51984 0.48748 lineto
0.52976 0.48903 lineto
0.53968 0.49114 lineto
0.55952 0.49681 lineto
0.57937 0.50368 lineto
0.59921 0.51033 lineto
0.60417 0.51171 lineto
0.60913 0.51291 lineto
0.61409 0.51388 lineto
0.61657 0.51427 lineto
Mistroke
0.61905 0.51458 lineto
0.62029 0.51471 lineto
0.62153 0.51482 lineto
0.62277 0.5149 lineto
0.62401 0.51496 lineto
0.62525 0.51501 lineto
0.62649 0.51502 lineto
0.62773 0.51502 lineto
0.62897 0.51499 lineto
0.63021 0.51494 lineto
0.63145 0.51486 lineto
0.63393 0.51463 lineto
0.63517 0.51448 lineto
0.63641 0.51429 lineto
0.63889 0.51385 lineto
0.64385 0.51264 lineto
0.64881 0.51099 lineto
0.65873 0.50646 lineto
0.67857 0.49429 lineto
0.68353 0.49133 lineto
0.68849 0.48881 lineto
0.69097 0.4878 lineto
0.69221 0.48737 lineto
0.69345 0.487 lineto
0.69469 0.4867 lineto
0.69593 0.48647 lineto
0.69717 0.48631 lineto
0.69841 0.48623 lineto
0.69965 0.48624 lineto
0.70089 0.48634 lineto
0.70213 0.48654 lineto
0.70337 0.48685 lineto
0.70461 0.48727 lineto
0.70585 0.48781 lineto
0.70833 0.48926 lineto
0.71081 0.49124 lineto
0.71329 0.49376 lineto
0.71825 0.50039 lineto
0.72321 0.5083 lineto
0.72569 0.51193 lineto
0.72693 0.5134 lineto
0.72817 0.51447 lineto
0.72941 0.515 lineto
0.73065 0.51481 lineto
0.73189 0.5137 lineto
0.73313 0.51144 lineto
0.73438 0.5078 lineto
0.73562 0.50253 lineto
0.73686 0.4954 lineto
0.7381 0.48622 lineto
Mistroke
0.74802 0.34356 lineto
0.75298 0.25612 lineto
0.75794 0.18242 lineto
0.7629 0.12641 lineto
0.76786 0.08558 lineto
0.77282 0.0562 lineto
0.77778 0.03507 lineto
0.78274 0.01988 lineto
0.7877 0.00896 lineto
0.79018 0.00474 lineto
0.79142 0.00288 lineto
0.79266 0.00118 lineto
0.7939 0.00038 lineto
0.79514 0.00181 lineto
0.79638 0.00312 lineto
0.79762 0.0043 lineto
0.8001 0.00637 lineto
0.80258 0.00806 lineto
0.80506 0.00943 lineto
0.80754 0.01052 lineto
0.81002 0.01137 lineto
0.8125 0.012 lineto
0.81374 0.01224 lineto
0.81498 0.01244 lineto
0.81622 0.01261 lineto
0.81746 0.01273 lineto
0.8187 0.01282 lineto
0.81994 0.01287 lineto
0.82118 0.0129 lineto
0.82242 0.01289 lineto
0.82366 0.01286 lineto
0.8249 0.0128 lineto
0.82614 0.01272 lineto
0.82738 0.01262 lineto
0.8373 0.01118 lineto
0.84226 0.01016 lineto
0.84722 0.009 lineto
0.85714 0.00646 lineto
0.86706 0.0038 lineto
0.87202 0.00246 lineto
0.87698 0.00115 lineto
0.87822 0.00083 lineto
0.87946 0.00051 lineto
0.8807 0.00019 lineto
0.88194 0.00013 lineto
0.88442 0.00076 lineto
0.8869 0.00137 lineto
0.89683 0.00371 lineto
0.91667 0.00767 lineto
0.92659 0.00926 lineto
Mistroke
0.93651 0.01056 lineto
0.94643 0.01158 lineto
0.95139 0.01198 lineto
0.95635 0.01231 lineto
0.96131 0.01257 lineto
0.96379 0.01267 lineto
0.96627 0.01275 lineto
0.96875 0.01281 lineto
0.96999 0.01284 lineto
0.97123 0.01286 lineto
0.97247 0.01288 lineto
0.97371 0.01289 lineto
0.97495 0.01289 lineto
0.97619 0.0129 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01276 moveto
0.02505 0.01275 lineto
0.02629 0.01275 lineto
0.02753 0.01274 lineto
0.02877 0.01272 lineto
0.03125 0.01267 lineto
0.03373 0.01261 lineto
0.03621 0.01253 lineto
0.03869 0.01243 lineto
0.04365 0.01218 lineto
0.04861 0.01185 lineto
0.05357 0.01146 lineto
0.06349 0.01045 lineto
0.08333 0.00759 lineto
0.10317 0.00367 lineto
0.1131 0.00136 lineto
0.11558 0.00075 lineto
0.11682 0.00044 lineto
0.11806 0.00013 lineto
0.1193 0.00019 lineto
0.12054 0.0005 lineto
0.12302 0.00114 lineto
0.14286 0.00641 lineto
0.15278 0.00894 lineto
0.15774 0.01008 lineto
0.1627 0.0111 lineto
0.16766 0.01194 lineto
0.17014 0.01228 lineto
0.17138 0.01242 lineto
0.17262 0.01254 lineto
0.17386 0.01264 lineto
0.1751 0.01273 lineto
0.17634 0.01278 lineto
0.17758 0.01282 lineto
0.17882 0.01282 lineto
0.18006 0.0128 lineto
0.1813 0.01275 lineto
0.18254 0.01266 lineto
0.18378 0.01254 lineto
0.18502 0.01238 lineto
0.1875 0.01194 lineto
0.18998 0.01131 lineto
0.19246 0.01047 lineto
0.19494 0.00939 lineto
0.19742 0.00803 lineto
0.20238 0.00429 lineto
0.20486 0.00181 lineto
0.2061 0.00038 lineto
0.20734 0.00117 lineto
0.20982 0.00472 lineto
Mistroke
0.2123 0.00894 lineto
0.21726 0.01984 lineto
0.22222 0.03504 lineto
0.22718 0.05618 lineto
0.23214 0.08563 lineto
0.2371 0.12657 lineto
0.24206 0.18279 lineto
0.25198 0.34483 lineto
0.25446 0.38924 lineto
0.25694 0.42982 lineto
0.25942 0.4636 lineto
0.26066 0.47734 lineto
0.2619 0.48886 lineto
0.26314 0.49819 lineto
0.26438 0.50547 lineto
0.26562 0.51089 lineto
0.26687 0.51466 lineto
0.26811 0.51705 lineto
0.26935 0.51828 lineto
0.27059 0.51858 lineto
0.27183 0.51816 lineto
0.28175 0.50483 lineto
0.28423 0.50145 lineto
0.28671 0.49854 lineto
0.28919 0.49618 lineto
0.29167 0.49437 lineto
0.29291 0.49366 lineto
0.29415 0.49308 lineto
0.29539 0.49262 lineto
0.29663 0.49228 lineto
0.29787 0.49205 lineto
0.29911 0.49192 lineto
0.30035 0.49189 lineto
0.30159 0.49196 lineto
0.30283 0.49211 lineto
0.30407 0.49234 lineto
0.30531 0.49264 lineto
0.30655 0.49301 lineto
0.31151 0.49507 lineto
0.32143 0.50091 lineto
0.33135 0.5074 lineto
0.34127 0.51316 lineto
0.34623 0.51549 lineto
0.35119 0.51738 lineto
0.35615 0.51879 lineto
0.35863 0.51932 lineto
0.36111 0.51972 lineto
0.36235 0.51988 lineto
0.36359 0.52001 lineto
0.36483 0.52011 lineto
Mistroke
0.36607 0.52018 lineto
0.36731 0.52023 lineto
0.36855 0.52024 lineto
0.36979 0.52024 lineto
0.37103 0.5202 lineto
0.37227 0.52014 lineto
0.37351 0.52005 lineto
0.37599 0.5198 lineto
0.37847 0.51947 lineto
0.38095 0.51904 lineto
0.38591 0.51795 lineto
0.39087 0.51659 lineto
0.40079 0.51323 lineto
0.42063 0.50521 lineto
0.44048 0.49728 lineto
0.4504 0.49382 lineto
0.46032 0.49087 lineto
0.47024 0.48851 lineto
0.4752 0.48757 lineto
0.48016 0.48679 lineto
0.48512 0.48618 lineto
0.4876 0.48594 lineto
0.49008 0.48575 lineto
0.49256 0.48559 lineto
0.4938 0.48553 lineto
0.49504 0.48548 lineto
0.49628 0.48544 lineto
0.49752 0.48542 lineto
0.49876 0.4854 lineto
0.5 0.4854 lineto
0.50124 0.4854 lineto
0.50248 0.48542 lineto
0.50372 0.48544 lineto
0.50496 0.48548 lineto
0.5062 0.48553 lineto
0.50744 0.48559 lineto
0.50992 0.48575 lineto
0.5124 0.48594 lineto
0.51488 0.48618 lineto
0.51984 0.48679 lineto
0.52976 0.48851 lineto
0.53968 0.49087 lineto
0.55952 0.49728 lineto
0.57937 0.50521 lineto
0.59921 0.51323 lineto
0.60913 0.51659 lineto
0.61409 0.51795 lineto
0.61657 0.51853 lineto
0.61905 0.51904 lineto
0.62153 0.51947 lineto
Mistroke
0.62401 0.5198 lineto
0.62525 0.51994 lineto
0.62649 0.52005 lineto
0.62773 0.52014 lineto
0.62897 0.5202 lineto
0.63021 0.52024 lineto
0.63145 0.52024 lineto
0.63269 0.52023 lineto
0.63393 0.52018 lineto
0.63517 0.52011 lineto
0.63641 0.52001 lineto
0.63889 0.51972 lineto
0.64137 0.51932 lineto
0.64385 0.51879 lineto
0.64881 0.51738 lineto
0.65377 0.51549 lineto
0.65873 0.51316 lineto
0.67857 0.50091 lineto
0.68849 0.49507 lineto
0.69097 0.49394 lineto
0.69345 0.49301 lineto
0.69469 0.49264 lineto
0.69593 0.49234 lineto
0.69717 0.49211 lineto
0.69841 0.49196 lineto
0.69965 0.49189 lineto
0.70089 0.49192 lineto
0.70213 0.49205 lineto
0.70337 0.49228 lineto
0.70461 0.49262 lineto
0.70585 0.49308 lineto
0.70833 0.49437 lineto
0.71081 0.49618 lineto
0.71329 0.49854 lineto
0.71825 0.50483 lineto
0.72321 0.51238 lineto
0.72569 0.51582 lineto
0.72693 0.51719 lineto
0.72817 0.51816 lineto
0.72941 0.51858 lineto
0.73065 0.51828 lineto
0.73189 0.51705 lineto
0.73313 0.51466 lineto
0.73438 0.51089 lineto
0.73562 0.50547 lineto
0.73686 0.49819 lineto
0.7381 0.48886 lineto
0.74802 0.34483 lineto
0.75298 0.25686 lineto
0.75794 0.18279 lineto
Mistroke
0.7629 0.12657 lineto
0.76786 0.08563 lineto
0.77282 0.05618 lineto
0.77778 0.03504 lineto
0.78274 0.01984 lineto
0.7877 0.00894 lineto
0.79018 0.00472 lineto
0.79142 0.00287 lineto
0.79266 0.00117 lineto
0.7939 0.00038 lineto
0.79514 0.00181 lineto
0.79638 0.00311 lineto
0.79762 0.00429 lineto
0.8001 0.00634 lineto
0.80258 0.00803 lineto
0.80506 0.00939 lineto
0.80754 0.01047 lineto
0.81002 0.01131 lineto
0.8125 0.01194 lineto
0.81374 0.01218 lineto
0.81498 0.01238 lineto
0.81622 0.01254 lineto
0.81746 0.01266 lineto
0.8187 0.01275 lineto
0.81994 0.0128 lineto
0.82118 0.01282 lineto
0.82242 0.01282 lineto
0.82366 0.01278 lineto
0.8249 0.01273 lineto
0.82614 0.01264 lineto
0.82738 0.01254 lineto
0.8373 0.0111 lineto
0.84226 0.01008 lineto
0.84722 0.00894 lineto
0.85714 0.00641 lineto
0.86706 0.00376 lineto
0.87202 0.00244 lineto
0.87698 0.00114 lineto
0.87822 0.00082 lineto
0.87946 0.0005 lineto
0.8807 0.00019 lineto
0.88194 0.00013 lineto
0.88442 0.00075 lineto
0.8869 0.00136 lineto
0.89683 0.00367 lineto
0.91667 0.00759 lineto
0.92659 0.00916 lineto
0.93651 0.01045 lineto
0.94643 0.01146 lineto
0.95139 0.01185 lineto
Mistroke
0.95635 0.01218 lineto
0.96131 0.01243 lineto
0.96379 0.01253 lineto
0.96627 0.01261 lineto
0.96875 0.01267 lineto
0.96999 0.0127 lineto
0.97123 0.01272 lineto
0.97247 0.01274 lineto
0.97371 0.01275 lineto
0.97495 0.01275 lineto
0.97619 0.01276 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01262 moveto
0.02505 0.01261 lineto
0.02629 0.01261 lineto
0.02753 0.0126 lineto
0.02877 0.01258 lineto
0.03125 0.01254 lineto
0.03373 0.01247 lineto
0.03621 0.01239 lineto
0.03869 0.0123 lineto
0.04365 0.01205 lineto
0.04861 0.01173 lineto
0.05357 0.01133 lineto
0.06349 0.01034 lineto
0.08333 0.00751 lineto
0.10317 0.00363 lineto
0.1131 0.00134 lineto
0.11558 0.00074 lineto
0.11682 0.00044 lineto
0.11806 0.00013 lineto
0.1193 0.00018 lineto
0.12054 0.0005 lineto
0.12302 0.00113 lineto
0.14286 0.00636 lineto
0.15278 0.00887 lineto
0.15774 0.01001 lineto
0.1627 0.01102 lineto
0.16766 0.01186 lineto
0.17014 0.0122 lineto
0.17138 0.01234 lineto
0.17262 0.01246 lineto
0.17386 0.01257 lineto
0.1751 0.01265 lineto
0.17634 0.01271 lineto
0.17758 0.01274 lineto
0.17882 0.01275 lineto
0.18006 0.01273 lineto
0.1813 0.01268 lineto
0.18254 0.01259 lineto
0.18378 0.01247 lineto
0.18502 0.01232 lineto
0.18626 0.01212 lineto
0.1875 0.01188 lineto
0.18998 0.01126 lineto
0.19246 0.01043 lineto
0.19494 0.00935 lineto
0.19742 0.008 lineto
0.20238 0.00427 lineto
0.20486 0.0018 lineto
0.2061 0.00038 lineto
0.20734 0.00117 lineto
Mistroke
0.20982 0.00471 lineto
0.2123 0.00892 lineto
0.21726 0.01981 lineto
0.22222 0.035 lineto
0.22718 0.05617 lineto
0.23214 0.08566 lineto
0.2371 0.12672 lineto
0.24206 0.18316 lineto
0.25198 0.3461 lineto
0.25446 0.39084 lineto
0.25694 0.43178 lineto
0.25942 0.46593 lineto
0.26066 0.47984 lineto
0.2619 0.49153 lineto
0.26314 0.50103 lineto
0.26438 0.50846 lineto
0.26562 0.51402 lineto
0.26687 0.51794 lineto
0.26811 0.52045 lineto
0.26935 0.52181 lineto
0.27059 0.52223 lineto
0.27183 0.52192 lineto
0.28175 0.5094 lineto
0.28423 0.5062 lineto
0.28671 0.50348 lineto
0.28919 0.50129 lineto
0.29043 0.50041 lineto
0.29167 0.49966 lineto
0.29291 0.49903 lineto
0.29415 0.49854 lineto
0.29539 0.49817 lineto
0.29663 0.49791 lineto
0.29787 0.49776 lineto
0.29911 0.49772 lineto
0.30035 0.49777 lineto
0.30159 0.49792 lineto
0.30407 0.49845 lineto
0.30531 0.49883 lineto
0.30655 0.49927 lineto
0.31151 0.50159 lineto
0.32143 0.50783 lineto
0.33135 0.51448 lineto
0.33631 0.5175 lineto
0.34127 0.52014 lineto
0.34623 0.52232 lineto
0.34871 0.52323 lineto
0.35119 0.524 lineto
0.35367 0.52465 lineto
0.35615 0.52516 lineto
0.35739 0.52536 lineto
Mistroke
0.35863 0.52553 lineto
0.35987 0.52567 lineto
0.36111 0.52578 lineto
0.36235 0.52586 lineto
0.36359 0.5259 lineto
0.36483 0.52592 lineto
0.36607 0.5259 lineto
0.36731 0.52585 lineto
0.36855 0.52578 lineto
0.36979 0.52567 lineto
0.37103 0.52554 lineto
0.37351 0.52519 lineto
0.37599 0.52475 lineto
0.38095 0.52357 lineto
0.39087 0.52029 lineto
0.40079 0.51613 lineto
0.42063 0.50667 lineto
0.44048 0.49765 lineto
0.4504 0.49378 lineto
0.46032 0.4905 lineto
0.47024 0.48789 lineto
0.4752 0.48685 lineto
0.48016 0.48599 lineto
0.48512 0.48532 lineto
0.4876 0.48506 lineto
0.49008 0.48484 lineto
0.49256 0.48467 lineto
0.4938 0.48461 lineto
0.49504 0.48455 lineto
0.49628 0.48451 lineto
0.49752 0.48448 lineto
0.49876 0.48446 lineto
0.5 0.48446 lineto
0.50124 0.48446 lineto
0.50248 0.48448 lineto
0.50372 0.48451 lineto
0.50496 0.48455 lineto
0.5062 0.48461 lineto
0.50744 0.48467 lineto
0.50992 0.48484 lineto
0.5124 0.48506 lineto
0.51488 0.48532 lineto
0.51984 0.48599 lineto
0.52976 0.48789 lineto
0.53968 0.4905 lineto
0.55952 0.49765 lineto
0.57937 0.50667 lineto
0.59921 0.51613 lineto
0.60913 0.52029 lineto
0.61409 0.52207 lineto
Mistroke
0.61905 0.52357 lineto
0.62153 0.5242 lineto
0.62401 0.52475 lineto
0.62649 0.52519 lineto
0.62773 0.52538 lineto
0.62897 0.52554 lineto
0.63021 0.52567 lineto
0.63145 0.52578 lineto
0.63269 0.52585 lineto
0.63393 0.5259 lineto
0.63517 0.52592 lineto
0.63641 0.5259 lineto
0.63765 0.52586 lineto
0.63889 0.52578 lineto
0.64137 0.52553 lineto
0.64261 0.52536 lineto
0.64385 0.52516 lineto
0.64633 0.52465 lineto
0.64881 0.524 lineto
0.65377 0.52232 lineto
0.65873 0.52014 lineto
0.67857 0.50783 lineto
0.68849 0.50159 lineto
0.69097 0.50033 lineto
0.69345 0.49927 lineto
0.69469 0.49883 lineto
0.69593 0.49845 lineto
0.69717 0.49814 lineto
0.69841 0.49792 lineto
0.69965 0.49777 lineto
0.70089 0.49772 lineto
0.70213 0.49776 lineto
0.70337 0.49791 lineto
0.70461 0.49817 lineto
0.70585 0.49854 lineto
0.70709 0.49903 lineto
0.70833 0.49966 lineto
0.71081 0.50129 lineto
0.71329 0.50348 lineto
0.71825 0.5094 lineto
0.72321 0.51657 lineto
0.72569 0.51981 lineto
0.72693 0.52107 lineto
0.72817 0.52192 lineto
0.72941 0.52223 lineto
0.73065 0.52181 lineto
0.73189 0.52045 lineto
0.73313 0.51794 lineto
0.73438 0.51402 lineto
0.73562 0.50846 lineto
Mistroke
0.73686 0.50103 lineto
0.7381 0.49153 lineto
0.74802 0.3461 lineto
0.75298 0.25758 lineto
0.75794 0.18316 lineto
0.7629 0.12672 lineto
0.76786 0.08566 lineto
0.77282 0.05617 lineto
0.77778 0.035 lineto
0.78274 0.01981 lineto
0.7877 0.00892 lineto
0.79018 0.00471 lineto
0.79142 0.00286 lineto
0.79266 0.00117 lineto
0.7939 0.00038 lineto
0.79514 0.0018 lineto
0.79638 0.00309 lineto
0.79762 0.00427 lineto
0.8001 0.00632 lineto
0.80258 0.008 lineto
0.80506 0.00935 lineto
0.80754 0.01043 lineto
0.81002 0.01126 lineto
0.8125 0.01188 lineto
0.81374 0.01212 lineto
0.81498 0.01232 lineto
0.81622 0.01247 lineto
0.81746 0.01259 lineto
0.8187 0.01268 lineto
0.81994 0.01273 lineto
0.82118 0.01275 lineto
0.82242 0.01274 lineto
0.82366 0.01271 lineto
0.8249 0.01265 lineto
0.82614 0.01257 lineto
0.82738 0.01246 lineto
0.8373 0.01102 lineto
0.84226 0.01001 lineto
0.84722 0.00887 lineto
0.85714 0.00636 lineto
0.86706 0.00373 lineto
0.87202 0.00242 lineto
0.87698 0.00113 lineto
0.87822 0.00081 lineto
0.87946 0.0005 lineto
0.8807 0.00018 lineto
0.88194 0.00013 lineto
0.88442 0.00074 lineto
0.8869 0.00134 lineto
0.89683 0.00363 lineto
Mistroke
0.91667 0.00751 lineto
0.92659 0.00906 lineto
0.93651 0.01034 lineto
0.94643 0.01133 lineto
0.95139 0.01173 lineto
0.95635 0.01205 lineto
0.96131 0.0123 lineto
0.96379 0.01239 lineto
0.96627 0.01247 lineto
0.96875 0.01254 lineto
0.96999 0.01256 lineto
0.97123 0.01258 lineto
0.97247 0.0126 lineto
0.97371 0.01261 lineto
0.97495 0.01261 lineto
0.97619 0.01262 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01248 moveto
0.02505 0.01248 lineto
0.02629 0.01247 lineto
0.02753 0.01246 lineto
0.02877 0.01244 lineto
0.03125 0.0124 lineto
0.03373 0.01234 lineto
0.03621 0.01226 lineto
0.03869 0.01216 lineto
0.04365 0.01192 lineto
0.04861 0.0116 lineto
0.05357 0.01121 lineto
0.06349 0.01023 lineto
0.08333 0.00744 lineto
0.10317 0.0036 lineto
0.1131 0.00133 lineto
0.11558 0.00073 lineto
0.11682 0.00043 lineto
0.11806 0.00013 lineto
0.1193 0.00018 lineto
0.12054 0.00049 lineto
0.12302 0.00112 lineto
0.14286 0.00631 lineto
0.15278 0.0088 lineto
0.15774 0.00993 lineto
0.1627 0.01095 lineto
0.16766 0.01178 lineto
0.17014 0.01212 lineto
0.17138 0.01226 lineto
0.17262 0.01238 lineto
0.17386 0.01249 lineto
0.1751 0.01257 lineto
0.17634 0.01263 lineto
0.17758 0.01266 lineto
0.17882 0.01267 lineto
0.18006 0.01265 lineto
0.1813 0.0126 lineto
0.18254 0.01252 lineto
0.18378 0.0124 lineto
0.18502 0.01225 lineto
0.18626 0.01206 lineto
0.1875 0.01182 lineto
0.18998 0.0112 lineto
0.19246 0.01038 lineto
0.19494 0.00931 lineto
0.19742 0.00796 lineto
0.20238 0.00426 lineto
0.20486 0.00179 lineto
0.2061 0.00038 lineto
0.20734 0.00116 lineto
Mistroke
0.20982 0.0047 lineto
0.2123 0.0089 lineto
0.21726 0.01978 lineto
0.22222 0.03497 lineto
0.22718 0.05614 lineto
0.23214 0.08569 lineto
0.2371 0.12686 lineto
0.24206 0.18351 lineto
0.25198 0.34737 lineto
0.25446 0.39245 lineto
0.25694 0.43375 lineto
0.25942 0.46827 lineto
0.26066 0.48237 lineto
0.2619 0.49423 lineto
0.26314 0.50389 lineto
0.26438 0.51149 lineto
0.26562 0.51721 lineto
0.26687 0.52127 lineto
0.26811 0.52392 lineto
0.26935 0.52541 lineto
0.27059 0.52596 lineto
0.27183 0.52577 lineto
0.28175 0.5141 lineto
0.28423 0.51109 lineto
0.28671 0.50857 lineto
0.28919 0.50657 lineto
0.29043 0.50578 lineto
0.29167 0.50513 lineto
0.29291 0.5046 lineto
0.29415 0.5042 lineto
0.29539 0.50392 lineto
0.29663 0.50375 lineto
0.29787 0.5037 lineto
0.29911 0.50374 lineto
0.30035 0.50388 lineto
0.30159 0.50411 lineto
0.30407 0.50481 lineto
0.30655 0.50579 lineto
0.31151 0.5084 lineto
0.32143 0.51506 lineto
0.33135 0.52188 lineto
0.33631 0.52487 lineto
0.34127 0.52742 lineto
0.34623 0.52944 lineto
0.34871 0.53024 lineto
0.35119 0.53089 lineto
0.35367 0.53139 lineto
0.35491 0.53159 lineto
0.35615 0.53175 lineto
0.35739 0.53188 lineto
Mistroke
0.35863 0.53197 lineto
0.35987 0.53202 lineto
0.36111 0.53204 lineto
0.36235 0.53203 lineto
0.36359 0.53198 lineto
0.36483 0.53189 lineto
0.36607 0.53178 lineto
0.36855 0.53146 lineto
0.37103 0.53101 lineto
0.37599 0.52979 lineto
0.38095 0.52818 lineto
0.40079 0.51899 lineto
0.42063 0.50806 lineto
0.44048 0.49791 lineto
0.4504 0.49363 lineto
0.46032 0.49002 lineto
0.47024 0.48715 lineto
0.4752 0.48601 lineto
0.48016 0.48508 lineto
0.48512 0.48435 lineto
0.4876 0.48406 lineto
0.49008 0.48382 lineto
0.49256 0.48364 lineto
0.4938 0.48357 lineto
0.49504 0.48351 lineto
0.49628 0.48346 lineto
0.49752 0.48343 lineto
0.49876 0.48341 lineto
0.5 0.4834 lineto
0.50124 0.48341 lineto
0.50248 0.48343 lineto
0.50372 0.48346 lineto
0.50496 0.48351 lineto
0.5062 0.48357 lineto
0.50744 0.48364 lineto
0.50992 0.48382 lineto
0.5124 0.48406 lineto
0.51488 0.48435 lineto
0.51984 0.48508 lineto
0.52976 0.48715 lineto
0.53968 0.49002 lineto
0.55952 0.49791 lineto
0.57937 0.50806 lineto
0.59921 0.51899 lineto
0.60913 0.52401 lineto
0.61409 0.52623 lineto
0.61905 0.52818 lineto
0.62401 0.52979 lineto
0.62649 0.53046 lineto
0.62897 0.53101 lineto
Mistroke
0.63145 0.53146 lineto
0.63393 0.53178 lineto
0.63517 0.53189 lineto
0.63641 0.53198 lineto
0.63765 0.53203 lineto
0.63889 0.53204 lineto
0.64013 0.53202 lineto
0.64137 0.53197 lineto
0.64261 0.53188 lineto
0.64385 0.53175 lineto
0.64633 0.53139 lineto
0.64881 0.53089 lineto
0.65129 0.53024 lineto
0.65377 0.52944 lineto
0.65873 0.52742 lineto
0.66865 0.52188 lineto
0.67857 0.51506 lineto
0.68849 0.5084 lineto
0.69097 0.507 lineto
0.69345 0.50579 lineto
0.69593 0.50481 lineto
0.69717 0.50442 lineto
0.69841 0.50411 lineto
0.69965 0.50388 lineto
0.70089 0.50374 lineto
0.70213 0.5037 lineto
0.70337 0.50375 lineto
0.70461 0.50392 lineto
0.70585 0.5042 lineto
0.70709 0.5046 lineto
0.70833 0.50513 lineto
0.71081 0.50657 lineto
0.71329 0.50857 lineto
0.71825 0.5141 lineto
0.72321 0.52086 lineto
0.72569 0.52388 lineto
0.72693 0.52503 lineto
0.72817 0.52577 lineto
0.72941 0.52596 lineto
0.73065 0.52541 lineto
0.73189 0.52392 lineto
0.73313 0.52127 lineto
0.73438 0.51721 lineto
0.73562 0.51149 lineto
0.73686 0.50389 lineto
0.7381 0.49423 lineto
0.74802 0.34737 lineto
0.75298 0.2583 lineto
0.75794 0.18351 lineto
0.7629 0.12686 lineto
Mistroke
0.76786 0.08569 lineto
0.77282 0.05614 lineto
0.77778 0.03497 lineto
0.78274 0.01978 lineto
0.7877 0.0089 lineto
0.79018 0.0047 lineto
0.79142 0.00285 lineto
0.79266 0.00116 lineto
0.7939 0.00038 lineto
0.79514 0.00179 lineto
0.79638 0.00308 lineto
0.79762 0.00426 lineto
0.8001 0.0063 lineto
0.80258 0.00796 lineto
0.80506 0.00931 lineto
0.80754 0.01038 lineto
0.81002 0.0112 lineto
0.8125 0.01182 lineto
0.81374 0.01206 lineto
0.81498 0.01225 lineto
0.81622 0.0124 lineto
0.81746 0.01252 lineto
0.8187 0.0126 lineto
0.81994 0.01265 lineto
0.82118 0.01267 lineto
0.82242 0.01266 lineto
0.82366 0.01263 lineto
0.8249 0.01257 lineto
0.82614 0.01249 lineto
0.82738 0.01238 lineto
0.8373 0.01095 lineto
0.84226 0.00993 lineto
0.84722 0.0088 lineto
0.85714 0.00631 lineto
0.86706 0.0037 lineto
0.87202 0.0024 lineto
0.87698 0.00112 lineto
0.87822 0.00081 lineto
0.87946 0.00049 lineto
0.8807 0.00018 lineto
0.88194 0.00013 lineto
0.88442 0.00073 lineto
0.8869 0.00133 lineto
0.89683 0.0036 lineto
0.91667 0.00744 lineto
0.92659 0.00897 lineto
0.93651 0.01023 lineto
0.94643 0.01121 lineto
0.95139 0.0116 lineto
0.95635 0.01192 lineto
Mistroke
0.96131 0.01216 lineto
0.96379 0.01226 lineto
0.96627 0.01234 lineto
0.96875 0.0124 lineto
0.96999 0.01242 lineto
0.97123 0.01244 lineto
0.97247 0.01246 lineto
0.97371 0.01247 lineto
0.97495 0.01248 lineto
0.97619 0.01248 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01234 moveto
0.02505 0.01234 lineto
0.02629 0.01233 lineto
0.02753 0.01232 lineto
0.02877 0.01231 lineto
0.03125 0.01226 lineto
0.03373 0.0122 lineto
0.03621 0.01212 lineto
0.03869 0.01203 lineto
0.04365 0.01179 lineto
0.04861 0.01147 lineto
0.05357 0.01109 lineto
0.06349 0.01012 lineto
0.08333 0.00736 lineto
0.10317 0.00356 lineto
0.1131 0.00132 lineto
0.11558 0.00073 lineto
0.11682 0.00043 lineto
0.11806 0.00012 lineto
0.1193 0.00018 lineto
0.12054 0.00049 lineto
0.12302 0.00111 lineto
0.14286 0.00625 lineto
0.15278 0.00873 lineto
0.15774 0.00986 lineto
0.1627 0.01087 lineto
0.16766 0.0117 lineto
0.17014 0.01204 lineto
0.17262 0.0123 lineto
0.17386 0.01241 lineto
0.1751 0.01249 lineto
0.17634 0.01255 lineto
0.17758 0.01259 lineto
0.17882 0.0126 lineto
0.18006 0.01258 lineto
0.1813 0.01253 lineto
0.18254 0.01245 lineto
0.18378 0.01234 lineto
0.18502 0.01218 lineto
0.18626 0.01199 lineto
0.1875 0.01176 lineto
0.18998 0.01115 lineto
0.19246 0.01033 lineto
0.19494 0.00927 lineto
0.19742 0.00793 lineto
0.20238 0.00424 lineto
0.20486 0.00179 lineto
0.2061 0.00038 lineto
0.20734 0.00116 lineto
0.20982 0.00469 lineto
Mistroke
0.2123 0.00888 lineto
0.21726 0.01974 lineto
0.22222 0.03492 lineto
0.22718 0.05612 lineto
0.23214 0.08571 lineto
0.2371 0.127 lineto
0.24206 0.18386 lineto
0.25198 0.34863 lineto
0.25446 0.39406 lineto
0.25694 0.43573 lineto
0.25942 0.47063 lineto
0.26066 0.48491 lineto
0.2619 0.49695 lineto
0.26314 0.50679 lineto
0.26438 0.51456 lineto
0.26562 0.52043 lineto
0.26687 0.52465 lineto
0.26811 0.52745 lineto
0.26935 0.52907 lineto
0.27059 0.52975 lineto
0.27183 0.52969 lineto
0.28175 0.51892 lineto
0.28423 0.51613 lineto
0.28671 0.51382 lineto
0.28919 0.51203 lineto
0.29043 0.51134 lineto
0.29167 0.51079 lineto
0.29291 0.51037 lineto
0.29415 0.51007 lineto
0.29539 0.50988 lineto
0.29663 0.50982 lineto
0.29787 0.50986 lineto
0.29911 0.51 lineto
0.30035 0.51023 lineto
0.30159 0.51056 lineto
0.30407 0.51144 lineto
0.30655 0.51259 lineto
0.31151 0.51551 lineto
0.32143 0.52262 lineto
0.33135 0.52962 lineto
0.33631 0.53258 lineto
0.34127 0.53502 lineto
0.34375 0.53601 lineto
0.34623 0.53685 lineto
0.34871 0.53753 lineto
0.34995 0.5378 lineto
0.35119 0.53804 lineto
0.35243 0.53824 lineto
0.35367 0.53839 lineto
0.35491 0.53851 lineto
Mistroke
0.35615 0.53859 lineto
0.35739 0.53862 lineto
0.35863 0.53862 lineto
0.35987 0.53858 lineto
0.36111 0.53851 lineto
0.36359 0.53824 lineto
0.36483 0.53805 lineto
0.36607 0.53783 lineto
0.37103 0.53662 lineto
0.37599 0.53494 lineto
0.38095 0.53286 lineto
0.42063 0.50936 lineto
0.44048 0.49808 lineto
0.4504 0.49337 lineto
0.46032 0.48942 lineto
0.47024 0.4863 lineto
0.4752 0.48507 lineto
0.48016 0.48405 lineto
0.48512 0.48326 lineto
0.4876 0.48295 lineto
0.49008 0.48269 lineto
0.49256 0.4825 lineto
0.4938 0.48242 lineto
0.49504 0.48235 lineto
0.49628 0.4823 lineto
0.49752 0.48227 lineto
0.49876 0.48225 lineto
0.5 0.48224 lineto
0.50124 0.48225 lineto
0.50248 0.48227 lineto
0.50372 0.4823 lineto
0.50496 0.48235 lineto
0.5062 0.48242 lineto
0.50744 0.4825 lineto
0.50992 0.48269 lineto
0.5124 0.48295 lineto
0.51488 0.48326 lineto
0.51984 0.48405 lineto
0.52976 0.4863 lineto
0.53968 0.48942 lineto
0.55952 0.49808 lineto
0.57937 0.50936 lineto
0.59921 0.52184 lineto
0.60913 0.52775 lineto
0.61905 0.53286 lineto
0.62401 0.53494 lineto
0.62897 0.53662 lineto
0.63145 0.53729 lineto
0.63393 0.53783 lineto
0.63517 0.53805 lineto
Mistroke
0.63641 0.53824 lineto
0.63765 0.53839 lineto
0.63889 0.53851 lineto
0.64013 0.53858 lineto
0.64137 0.53862 lineto
0.64261 0.53862 lineto
0.64385 0.53859 lineto
0.64509 0.53851 lineto
0.64633 0.53839 lineto
0.64757 0.53824 lineto
0.64881 0.53804 lineto
0.65129 0.53753 lineto
0.65377 0.53685 lineto
0.65873 0.53502 lineto
0.66369 0.53258 lineto
0.66865 0.52962 lineto
0.67857 0.52262 lineto
0.68849 0.51551 lineto
0.69097 0.51396 lineto
0.69345 0.51259 lineto
0.69593 0.51144 lineto
0.69717 0.51096 lineto
0.69841 0.51056 lineto
0.69965 0.51023 lineto
0.70089 0.51 lineto
0.70213 0.50986 lineto
0.70337 0.50982 lineto
0.70461 0.50988 lineto
0.70585 0.51007 lineto
0.70709 0.51037 lineto
0.70833 0.51079 lineto
0.70957 0.51134 lineto
0.71081 0.51203 lineto
0.71329 0.51382 lineto
0.71577 0.51613 lineto
0.71825 0.51892 lineto
0.72073 0.52205 lineto
0.72321 0.52525 lineto
0.72569 0.52804 lineto
0.72693 0.52907 lineto
0.72817 0.52969 lineto
0.72941 0.52975 lineto
0.73065 0.52907 lineto
0.73189 0.52745 lineto
0.73313 0.52465 lineto
0.73438 0.52043 lineto
0.73562 0.51456 lineto
0.73686 0.50679 lineto
0.7381 0.49695 lineto
0.74802 0.34863 lineto
Mistroke
0.75298 0.25901 lineto
0.75794 0.18386 lineto
0.7629 0.127 lineto
0.76786 0.08571 lineto
0.77282 0.05612 lineto
0.77778 0.03492 lineto
0.78274 0.01974 lineto
0.7877 0.00888 lineto
0.79018 0.00469 lineto
0.79142 0.00285 lineto
0.79266 0.00116 lineto
0.7939 0.00038 lineto
0.79514 0.00179 lineto
0.79638 0.00307 lineto
0.79762 0.00424 lineto
0.8001 0.00627 lineto
0.80258 0.00793 lineto
0.80506 0.00927 lineto
0.80754 0.01033 lineto
0.81002 0.01115 lineto
0.8125 0.01176 lineto
0.81374 0.01199 lineto
0.81498 0.01218 lineto
0.81622 0.01234 lineto
0.81746 0.01245 lineto
0.8187 0.01253 lineto
0.81994 0.01258 lineto
0.82118 0.0126 lineto
0.82242 0.01259 lineto
0.82366 0.01255 lineto
0.8249 0.01249 lineto
0.82614 0.01241 lineto
0.82738 0.0123 lineto
0.8373 0.01087 lineto
0.84226 0.00986 lineto
0.84722 0.00873 lineto
0.85714 0.00625 lineto
0.86706 0.00366 lineto
0.87202 0.00238 lineto
0.87698 0.00111 lineto
0.87822 0.0008 lineto
0.87946 0.00049 lineto
0.8807 0.00018 lineto
0.88194 0.00012 lineto
0.88442 0.00073 lineto
0.8869 0.00132 lineto
0.89683 0.00356 lineto
0.91667 0.00736 lineto
0.92659 0.00887 lineto
0.93651 0.01012 lineto
Mistroke
0.94643 0.01109 lineto
0.95139 0.01147 lineto
0.95635 0.01179 lineto
0.96131 0.01203 lineto
0.96379 0.01212 lineto
0.96627 0.0122 lineto
0.96875 0.01226 lineto
0.96999 0.01229 lineto
0.97123 0.01231 lineto
0.97247 0.01232 lineto
0.97371 0.01233 lineto
0.97495 0.01234 lineto
0.97619 0.01234 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01221 moveto
0.02505 0.0122 lineto
0.02629 0.0122 lineto
0.02753 0.01219 lineto
0.02877 0.01217 lineto
0.03125 0.01213 lineto
0.03373 0.01207 lineto
0.03621 0.01199 lineto
0.03869 0.0119 lineto
0.04365 0.01166 lineto
0.04861 0.01135 lineto
0.05357 0.01097 lineto
0.06349 0.01001 lineto
0.08333 0.00728 lineto
0.10317 0.00353 lineto
0.1131 0.00131 lineto
0.11558 0.00072 lineto
0.11682 0.00042 lineto
0.11806 0.00012 lineto
0.1193 0.00018 lineto
0.12054 0.00048 lineto
0.12302 0.0011 lineto
0.14286 0.0062 lineto
0.15278 0.00866 lineto
0.15774 0.00979 lineto
0.1627 0.01079 lineto
0.16766 0.01162 lineto
0.17014 0.01196 lineto
0.17262 0.01222 lineto
0.17386 0.01233 lineto
0.1751 0.01241 lineto
0.17634 0.01247 lineto
0.17758 0.01251 lineto
0.17882 0.01252 lineto
0.18006 0.0125 lineto
0.1813 0.01246 lineto
0.18254 0.01238 lineto
0.18378 0.01227 lineto
0.18502 0.01212 lineto
0.18626 0.01193 lineto
0.1875 0.01169 lineto
0.18998 0.01109 lineto
0.19246 0.01028 lineto
0.19494 0.00923 lineto
0.19742 0.0079 lineto
0.20238 0.00423 lineto
0.20486 0.00178 lineto
0.2061 0.00038 lineto
0.20734 0.00116 lineto
0.20982 0.00467 lineto
Mistroke
0.2123 0.00885 lineto
0.21726 0.0197 lineto
0.22222 0.03488 lineto
0.22718 0.05608 lineto
0.23214 0.08573 lineto
0.2371 0.12712 lineto
0.24206 0.18419 lineto
0.25198 0.34989 lineto
0.25694 0.43771 lineto
0.25942 0.473 lineto
0.26066 0.48747 lineto
0.2619 0.4997 lineto
0.26314 0.50972 lineto
0.26438 0.51766 lineto
0.26562 0.5237 lineto
0.26687 0.52807 lineto
0.26811 0.53102 lineto
0.26935 0.53279 lineto
0.27059 0.53361 lineto
0.27183 0.53369 lineto
0.28175 0.52389 lineto
0.28423 0.52132 lineto
0.28671 0.51923 lineto
0.28919 0.51767 lineto
0.29043 0.51709 lineto
0.29167 0.51665 lineto
0.29291 0.51633 lineto
0.29415 0.51614 lineto
0.29539 0.51607 lineto
0.29663 0.51611 lineto
0.29787 0.51626 lineto
0.29911 0.5165 lineto
0.30159 0.51726 lineto
0.30407 0.51834 lineto
0.30655 0.51968 lineto
0.31151 0.52293 lineto
0.32143 0.53054 lineto
0.33135 0.53772 lineto
0.33631 0.54064 lineto
0.33879 0.54187 lineto
0.34127 0.54295 lineto
0.34375 0.54385 lineto
0.34623 0.54457 lineto
0.34747 0.54486 lineto
0.34871 0.54511 lineto
0.34995 0.54532 lineto
0.35119 0.54548 lineto
0.35243 0.54559 lineto
0.35367 0.54566 lineto
0.35491 0.54569 lineto
Mistroke
0.35615 0.54567 lineto
0.35739 0.54561 lineto
0.35863 0.54551 lineto
0.35987 0.54537 lineto
0.36111 0.54518 lineto
0.36359 0.5447 lineto
0.36607 0.54406 lineto
0.37103 0.54238 lineto
0.38095 0.53761 lineto
0.42063 0.51058 lineto
0.44048 0.49813 lineto
0.4504 0.49299 lineto
0.46032 0.48871 lineto
0.47024 0.48534 lineto
0.4752 0.48401 lineto
0.48016 0.48292 lineto
0.48512 0.48206 lineto
0.4876 0.48173 lineto
0.49008 0.48146 lineto
0.49256 0.48124 lineto
0.4938 0.48116 lineto
0.49504 0.48109 lineto
0.49628 0.48104 lineto
0.49752 0.481 lineto
0.49876 0.48098 lineto
0.5 0.48097 lineto
0.50124 0.48098 lineto
0.50248 0.481 lineto
0.50372 0.48104 lineto
0.50496 0.48109 lineto
0.5062 0.48116 lineto
0.50744 0.48124 lineto
0.50992 0.48146 lineto
0.5124 0.48173 lineto
0.51488 0.48206 lineto
0.51984 0.48292 lineto
0.5248 0.48401 lineto
0.52976 0.48534 lineto
0.53968 0.48871 lineto
0.55952 0.49813 lineto
0.57937 0.51058 lineto
0.59921 0.52465 lineto
0.60913 0.5315 lineto
0.61905 0.53761 lineto
0.62897 0.54238 lineto
0.63393 0.54406 lineto
0.63641 0.5447 lineto
0.63765 0.54496 lineto
0.63889 0.54518 lineto
0.64013 0.54537 lineto
Mistroke
0.64137 0.54551 lineto
0.64261 0.54561 lineto
0.64385 0.54567 lineto
0.64509 0.54569 lineto
0.64633 0.54566 lineto
0.64757 0.54559 lineto
0.64881 0.54548 lineto
0.65005 0.54532 lineto
0.65129 0.54511 lineto
0.65377 0.54457 lineto
0.65625 0.54385 lineto
0.65873 0.54295 lineto
0.66369 0.54064 lineto
0.66865 0.53772 lineto
0.67857 0.53054 lineto
0.68849 0.52293 lineto
0.69345 0.51968 lineto
0.69593 0.51834 lineto
0.69841 0.51726 lineto
0.69965 0.51684 lineto
0.70089 0.5165 lineto
0.70213 0.51626 lineto
0.70337 0.51611 lineto
0.70461 0.51607 lineto
0.70585 0.51614 lineto
0.70709 0.51633 lineto
0.70833 0.51665 lineto
0.70957 0.51709 lineto
0.71081 0.51767 lineto
0.71329 0.51923 lineto
0.71577 0.52132 lineto
0.71825 0.52389 lineto
0.72073 0.52678 lineto
0.72321 0.52974 lineto
0.72569 0.5323 lineto
0.72693 0.5332 lineto
0.72817 0.53369 lineto
0.72941 0.53361 lineto
0.73065 0.53279 lineto
0.73189 0.53102 lineto
0.73313 0.52807 lineto
0.73438 0.5237 lineto
0.73562 0.51766 lineto
0.73686 0.50972 lineto
0.7381 0.4997 lineto
0.74802 0.34989 lineto
0.75298 0.2597 lineto
0.75794 0.18419 lineto
0.7629 0.12712 lineto
0.76786 0.08573 lineto
Mistroke
0.77282 0.05608 lineto
0.77778 0.03488 lineto
0.78274 0.0197 lineto
0.7877 0.00885 lineto
0.79018 0.00467 lineto
0.79142 0.00284 lineto
0.79266 0.00116 lineto
0.7939 0.00038 lineto
0.79514 0.00178 lineto
0.79638 0.00306 lineto
0.79762 0.00423 lineto
0.8001 0.00625 lineto
0.80258 0.0079 lineto
0.80506 0.00923 lineto
0.80754 0.01028 lineto
0.81002 0.01109 lineto
0.8125 0.01169 lineto
0.81374 0.01193 lineto
0.81498 0.01212 lineto
0.81622 0.01227 lineto
0.81746 0.01238 lineto
0.8187 0.01246 lineto
0.81994 0.0125 lineto
0.82118 0.01252 lineto
0.82242 0.01251 lineto
0.82366 0.01247 lineto
0.8249 0.01241 lineto
0.82614 0.01233 lineto
0.82738 0.01222 lineto
0.8373 0.01079 lineto
0.84226 0.00979 lineto
0.84722 0.00866 lineto
0.85714 0.0062 lineto
0.86706 0.00363 lineto
0.87202 0.00235 lineto
0.87698 0.0011 lineto
0.87822 0.00079 lineto
0.87946 0.00048 lineto
0.8807 0.00018 lineto
0.88194 0.00012 lineto
0.88442 0.00072 lineto
0.8869 0.00131 lineto
0.89683 0.00353 lineto
0.91667 0.00728 lineto
0.92659 0.00878 lineto
0.93651 0.01001 lineto
0.94643 0.01097 lineto
0.95139 0.01135 lineto
0.95635 0.01166 lineto
0.96131 0.0119 lineto
Mistroke
0.96379 0.01199 lineto
0.96627 0.01207 lineto
0.96875 0.01213 lineto
0.96999 0.01215 lineto
0.97123 0.01217 lineto
0.97247 0.01219 lineto
0.97371 0.0122 lineto
0.97495 0.0122 lineto
0.97619 0.01221 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01207 moveto
0.02505 0.01207 lineto
0.02629 0.01207 lineto
0.02753 0.01205 lineto
0.02877 0.01204 lineto
0.03125 0.012 lineto
0.03373 0.01194 lineto
0.03621 0.01186 lineto
0.03869 0.01177 lineto
0.04365 0.01153 lineto
0.04861 0.01123 lineto
0.05357 0.01085 lineto
0.06349 0.0099 lineto
0.08333 0.00721 lineto
0.10317 0.00349 lineto
0.1131 0.00129 lineto
0.11558 0.00071 lineto
0.11682 0.00042 lineto
0.11806 0.00012 lineto
0.1193 0.00018 lineto
0.12054 0.00048 lineto
0.12302 0.00109 lineto
0.14286 0.00615 lineto
0.15278 0.00859 lineto
0.15774 0.00971 lineto
0.1627 0.01071 lineto
0.16766 0.01154 lineto
0.17014 0.01187 lineto
0.17262 0.01214 lineto
0.17386 0.01225 lineto
0.1751 0.01233 lineto
0.17634 0.01239 lineto
0.17758 0.01243 lineto
0.17882 0.01244 lineto
0.18006 0.01243 lineto
0.1813 0.01238 lineto
0.18254 0.01231 lineto
0.18378 0.0122 lineto
0.18502 0.01205 lineto
0.18626 0.01186 lineto
0.1875 0.01163 lineto
0.18998 0.01103 lineto
0.19246 0.01023 lineto
0.19494 0.00918 lineto
0.19742 0.00786 lineto
0.20238 0.00421 lineto
0.20486 0.00178 lineto
0.2061 0.00038 lineto
0.20734 0.00115 lineto
0.20982 0.00466 lineto
Mistroke
0.2123 0.00883 lineto
0.21726 0.01966 lineto
0.22222 0.03483 lineto
0.22718 0.05604 lineto
0.23214 0.08573 lineto
0.2371 0.12722 lineto
0.24206 0.1845 lineto
0.25198 0.35113 lineto
0.25694 0.43969 lineto
0.25942 0.47538 lineto
0.26066 0.49004 lineto
0.2619 0.50247 lineto
0.26314 0.51267 lineto
0.26438 0.52079 lineto
0.26562 0.527 lineto
0.26687 0.53154 lineto
0.26811 0.53465 lineto
0.26935 0.53657 lineto
0.27059 0.53754 lineto
0.27183 0.53775 lineto
0.28175 0.52898 lineto
0.28423 0.52666 lineto
0.28671 0.52481 lineto
0.28795 0.52409 lineto
0.28919 0.5235 lineto
0.29043 0.52304 lineto
0.29167 0.52271 lineto
0.29291 0.52252 lineto
0.29415 0.52244 lineto
0.29539 0.52249 lineto
0.29663 0.52264 lineto
0.29787 0.5229 lineto
0.29911 0.52326 lineto
0.30159 0.52424 lineto
0.30407 0.52553 lineto
0.30655 0.52707 lineto
0.31151 0.53069 lineto
0.32143 0.53883 lineto
0.32639 0.54273 lineto
0.33135 0.5462 lineto
0.33631 0.54907 lineto
0.33879 0.55024 lineto
0.34127 0.55123 lineto
0.34375 0.55202 lineto
0.34623 0.55262 lineto
0.34747 0.55284 lineto
0.34871 0.55301 lineto
0.34995 0.55313 lineto
0.35119 0.55321 lineto
0.35243 0.55323 lineto
Mistroke
0.35367 0.55321 lineto
0.35491 0.55313 lineto
0.35615 0.55301 lineto
0.35739 0.55285 lineto
0.35863 0.55264 lineto
0.36111 0.55208 lineto
0.36359 0.55136 lineto
0.36607 0.55047 lineto
0.37103 0.54827 lineto
0.38095 0.54243 lineto
0.42063 0.5117 lineto
0.44048 0.49808 lineto
0.4504 0.49251 lineto
0.46032 0.48789 lineto
0.47024 0.48427 lineto
0.4752 0.48284 lineto
0.48016 0.48167 lineto
0.48512 0.48076 lineto
0.4876 0.4804 lineto
0.49008 0.48011 lineto
0.49256 0.47988 lineto
0.4938 0.47979 lineto
0.49504 0.47972 lineto
0.49628 0.47966 lineto
0.49752 0.47962 lineto
0.49876 0.4796 lineto
0.5 0.47959 lineto
0.50124 0.4796 lineto
0.50248 0.47962 lineto
0.50372 0.47966 lineto
0.50496 0.47972 lineto
0.5062 0.47979 lineto
0.50744 0.47988 lineto
0.50992 0.48011 lineto
0.5124 0.4804 lineto
0.51488 0.48076 lineto
0.51984 0.48167 lineto
0.5248 0.48284 lineto
0.52976 0.48427 lineto
0.53968 0.48789 lineto
0.55952 0.49808 lineto
0.57937 0.5117 lineto
0.59921 0.52742 lineto
0.60913 0.53526 lineto
0.61905 0.54243 lineto
0.62897 0.54827 lineto
0.63393 0.55047 lineto
0.63641 0.55136 lineto
0.63889 0.55208 lineto
0.64137 0.55264 lineto
Mistroke
0.64261 0.55285 lineto
0.64385 0.55301 lineto
0.64509 0.55313 lineto
0.64633 0.55321 lineto
0.64757 0.55323 lineto
0.64881 0.55321 lineto
0.65005 0.55313 lineto
0.65129 0.55301 lineto
0.65253 0.55284 lineto
0.65377 0.55262 lineto
0.65625 0.55202 lineto
0.65873 0.55123 lineto
0.66369 0.54907 lineto
0.66865 0.5462 lineto
0.67857 0.53883 lineto
0.69841 0.52424 lineto
0.70089 0.52326 lineto
0.70213 0.5229 lineto
0.70337 0.52264 lineto
0.70461 0.52249 lineto
0.70585 0.52244 lineto
0.70709 0.52252 lineto
0.70833 0.52271 lineto
0.70957 0.52304 lineto
0.71081 0.5235 lineto
0.71329 0.52481 lineto
0.71577 0.52666 lineto
0.71825 0.52898 lineto
0.72073 0.53163 lineto
0.72321 0.53434 lineto
0.72445 0.53558 lineto
0.72569 0.53663 lineto
0.72693 0.5374 lineto
0.72817 0.53775 lineto
0.72941 0.53754 lineto
0.73065 0.53657 lineto
0.73189 0.53465 lineto
0.73313 0.53154 lineto
0.73438 0.527 lineto
0.73562 0.52079 lineto
0.73686 0.51267 lineto
0.7381 0.50247 lineto
0.74802 0.35113 lineto
0.75298 0.26038 lineto
0.75794 0.1845 lineto
0.7629 0.12722 lineto
0.76786 0.08573 lineto
0.77282 0.05604 lineto
0.77778 0.03483 lineto
0.78274 0.01966 lineto
Mistroke
0.7877 0.00883 lineto
0.79018 0.00466 lineto
0.79142 0.00283 lineto
0.79266 0.00115 lineto
0.7939 0.00038 lineto
0.79514 0.00178 lineto
0.79638 0.00305 lineto
0.79762 0.00421 lineto
0.8001 0.00622 lineto
0.80258 0.00786 lineto
0.80506 0.00918 lineto
0.80754 0.01023 lineto
0.81002 0.01103 lineto
0.8125 0.01163 lineto
0.81374 0.01186 lineto
0.81498 0.01205 lineto
0.81622 0.0122 lineto
0.81746 0.01231 lineto
0.8187 0.01238 lineto
0.81994 0.01243 lineto
0.82118 0.01244 lineto
0.82242 0.01243 lineto
0.82366 0.01239 lineto
0.8249 0.01233 lineto
0.82614 0.01225 lineto
0.82738 0.01214 lineto
0.8373 0.01071 lineto
0.84226 0.00971 lineto
0.84722 0.00859 lineto
0.85714 0.00615 lineto
0.86706 0.0036 lineto
0.87202 0.00233 lineto
0.87698 0.00109 lineto
0.87822 0.00078 lineto
0.87946 0.00048 lineto
0.8807 0.00018 lineto
0.88194 0.00012 lineto
0.88442 0.00071 lineto
0.8869 0.00129 lineto
0.89683 0.00349 lineto
0.91667 0.00721 lineto
0.92659 0.00869 lineto
0.93651 0.0099 lineto
0.94643 0.01085 lineto
0.95139 0.01123 lineto
0.95635 0.01153 lineto
0.96131 0.01177 lineto
0.96379 0.01186 lineto
0.96627 0.01194 lineto
0.96875 0.012 lineto
Mistroke
0.96999 0.01202 lineto
0.97123 0.01204 lineto
0.97247 0.01205 lineto
0.97371 0.01207 lineto
0.97495 0.01207 lineto
0.97619 0.01207 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01194 moveto
0.02505 0.01194 lineto
0.02629 0.01193 lineto
0.02753 0.01192 lineto
0.02877 0.01191 lineto
0.03125 0.01187 lineto
0.03373 0.01181 lineto
0.03621 0.01173 lineto
0.03869 0.01164 lineto
0.04365 0.01141 lineto
0.04861 0.0111 lineto
0.05357 0.01073 lineto
0.06349 0.0098 lineto
0.07341 0.0086 lineto
0.08333 0.00713 lineto
0.10317 0.00346 lineto
0.1131 0.00128 lineto
0.11558 0.00071 lineto
0.11682 0.00042 lineto
0.11806 0.00012 lineto
0.1193 0.00018 lineto
0.12054 0.00047 lineto
0.12302 0.00108 lineto
0.14286 0.0061 lineto
0.15278 0.00852 lineto
0.15774 0.00964 lineto
0.1627 0.01063 lineto
0.16766 0.01146 lineto
0.17014 0.01179 lineto
0.17262 0.01206 lineto
0.17386 0.01217 lineto
0.1751 0.01225 lineto
0.17634 0.01231 lineto
0.17758 0.01235 lineto
0.17882 0.01237 lineto
0.18006 0.01235 lineto
0.1813 0.01231 lineto
0.18254 0.01223 lineto
0.18378 0.01212 lineto
0.18502 0.01198 lineto
0.18626 0.01179 lineto
0.1875 0.01157 lineto
0.18998 0.01097 lineto
0.19246 0.01018 lineto
0.19494 0.00914 lineto
0.19742 0.00782 lineto
0.20238 0.00419 lineto
0.20486 0.00177 lineto
0.2061 0.00038 lineto
0.20734 0.00115 lineto
Mistroke
0.20982 0.00464 lineto
0.2123 0.0088 lineto
0.21726 0.01961 lineto
0.22222 0.03477 lineto
0.22718 0.05599 lineto
0.23214 0.08572 lineto
0.2371 0.12732 lineto
0.24206 0.1848 lineto
0.25198 0.35235 lineto
0.25694 0.44167 lineto
0.25942 0.47775 lineto
0.26066 0.49262 lineto
0.2619 0.50524 lineto
0.26314 0.51564 lineto
0.26438 0.52395 lineto
0.26562 0.53034 lineto
0.26687 0.53505 lineto
0.26811 0.53832 lineto
0.26935 0.5404 lineto
0.27059 0.54152 lineto
0.27183 0.54189 lineto
0.27307 0.54168 lineto
0.27431 0.54106 lineto
0.27679 0.53904 lineto
0.28175 0.53421 lineto
0.28423 0.53215 lineto
0.28547 0.5313 lineto
0.28671 0.53057 lineto
0.28795 0.52997 lineto
0.28919 0.52951 lineto
0.29043 0.52918 lineto
0.29167 0.52899 lineto
0.29291 0.52892 lineto
0.29415 0.52897 lineto
0.29539 0.52914 lineto
0.29663 0.52942 lineto
0.29911 0.53029 lineto
0.30159 0.53151 lineto
0.30655 0.53479 lineto
0.31151 0.53881 lineto
0.32143 0.54752 lineto
0.32639 0.55157 lineto
0.33135 0.55508 lineto
0.33631 0.55789 lineto
0.33879 0.559 lineto
0.34127 0.55989 lineto
0.34251 0.56026 lineto
0.34375 0.56056 lineto
0.34499 0.56082 lineto
0.34623 0.56101 lineto
Mistroke
0.34747 0.56116 lineto
0.34871 0.56124 lineto
0.34995 0.56127 lineto
0.35119 0.56125 lineto
0.35243 0.56117 lineto
0.35367 0.56104 lineto
0.35615 0.56063 lineto
0.35739 0.56035 lineto
0.35863 0.56001 lineto
0.36111 0.55921 lineto
0.36607 0.55707 lineto
0.37103 0.55431 lineto
0.38095 0.54731 lineto
0.42063 0.51274 lineto
0.44048 0.49792 lineto
0.4504 0.49192 lineto
0.46032 0.48697 lineto
0.47024 0.4831 lineto
0.4752 0.48157 lineto
0.48016 0.48032 lineto
0.48512 0.47935 lineto
0.4876 0.47897 lineto
0.49008 0.47866 lineto
0.49256 0.47842 lineto
0.4938 0.47832 lineto
0.49504 0.47824 lineto
0.49628 0.47818 lineto
0.49752 0.47814 lineto
0.49876 0.47811 lineto
0.5 0.4781 lineto
0.50124 0.47811 lineto
0.50248 0.47814 lineto
0.50372 0.47818 lineto
0.50496 0.47824 lineto
0.5062 0.47832 lineto
0.50744 0.47842 lineto
0.50992 0.47866 lineto
0.5124 0.47897 lineto
0.51488 0.47935 lineto
0.51984 0.48032 lineto
0.5248 0.48157 lineto
0.52976 0.4831 lineto
0.53968 0.48697 lineto
0.55952 0.49792 lineto
0.57937 0.51274 lineto
0.59921 0.53015 lineto
0.60913 0.53902 lineto
0.61905 0.54731 lineto
0.62897 0.55431 lineto
0.63393 0.55707 lineto
Mistroke
0.63641 0.55822 lineto
0.63889 0.55921 lineto
0.64137 0.56001 lineto
0.64261 0.56035 lineto
0.64385 0.56063 lineto
0.64509 0.56086 lineto
0.64633 0.56104 lineto
0.64757 0.56117 lineto
0.64881 0.56125 lineto
0.65005 0.56127 lineto
0.65129 0.56124 lineto
0.65253 0.56116 lineto
0.65377 0.56101 lineto
0.65625 0.56056 lineto
0.65749 0.56026 lineto
0.65873 0.55989 lineto
0.69841 0.53151 lineto
0.70089 0.53029 lineto
0.70213 0.52981 lineto
0.70337 0.52942 lineto
0.70461 0.52914 lineto
0.70585 0.52897 lineto
0.70709 0.52892 lineto
0.70833 0.52899 lineto
0.70957 0.52918 lineto
0.71081 0.52951 lineto
0.71205 0.52997 lineto
0.71329 0.53057 lineto
0.71577 0.53215 lineto
0.71825 0.53421 lineto
0.72073 0.5366 lineto
0.72321 0.53904 lineto
0.72445 0.54014 lineto
0.72569 0.54106 lineto
0.72693 0.54168 lineto
0.72817 0.54189 lineto
0.72941 0.54152 lineto
0.73065 0.5404 lineto
0.73189 0.53832 lineto
0.73313 0.53505 lineto
0.73438 0.53034 lineto
0.73562 0.52395 lineto
0.73686 0.51564 lineto
0.7381 0.50524 lineto
0.74802 0.35235 lineto
0.75298 0.26104 lineto
0.75794 0.1848 lineto
0.7629 0.12732 lineto
0.76786 0.08572 lineto
0.77282 0.05599 lineto
Mistroke
0.77778 0.03477 lineto
0.78274 0.01961 lineto
0.7877 0.0088 lineto
0.79018 0.00464 lineto
0.79142 0.00282 lineto
0.79266 0.00115 lineto
0.7939 0.00038 lineto
0.79514 0.00177 lineto
0.79638 0.00304 lineto
0.79762 0.00419 lineto
0.8001 0.00619 lineto
0.80258 0.00782 lineto
0.80506 0.00914 lineto
0.80754 0.01018 lineto
0.81002 0.01097 lineto
0.8125 0.01157 lineto
0.81374 0.01179 lineto
0.81498 0.01198 lineto
0.81622 0.01212 lineto
0.81746 0.01223 lineto
0.8187 0.01231 lineto
0.81994 0.01235 lineto
0.82118 0.01237 lineto
0.82242 0.01235 lineto
0.82366 0.01231 lineto
0.8249 0.01225 lineto
0.82614 0.01217 lineto
0.82738 0.01206 lineto
0.8373 0.01063 lineto
0.84226 0.00964 lineto
0.84722 0.00852 lineto
0.85714 0.0061 lineto
0.86706 0.00357 lineto
0.87202 0.00231 lineto
0.87698 0.00108 lineto
0.87822 0.00078 lineto
0.87946 0.00047 lineto
0.8807 0.00018 lineto
0.88194 0.00012 lineto
0.88442 0.00071 lineto
0.8869 0.00128 lineto
0.89683 0.00346 lineto
0.91667 0.00713 lineto
0.92659 0.0086 lineto
0.93651 0.0098 lineto
0.94643 0.01073 lineto
0.95139 0.0111 lineto
0.95635 0.01141 lineto
0.96131 0.01164 lineto
0.96379 0.01173 lineto
Mistroke
0.96627 0.01181 lineto
0.96875 0.01187 lineto
0.96999 0.01189 lineto
0.97123 0.01191 lineto
0.97247 0.01192 lineto
0.97371 0.01193 lineto
0.97495 0.01194 lineto
0.97619 0.01194 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01181 moveto
0.02505 0.01181 lineto
0.02629 0.0118 lineto
0.02753 0.01179 lineto
0.02877 0.01178 lineto
0.03125 0.01174 lineto
0.03373 0.01168 lineto
0.03621 0.0116 lineto
0.03869 0.01151 lineto
0.04365 0.01128 lineto
0.04861 0.01098 lineto
0.05357 0.01062 lineto
0.06349 0.00969 lineto
0.07341 0.0085 lineto
0.08333 0.00706 lineto
0.10317 0.00342 lineto
0.1131 0.00127 lineto
0.11558 0.0007 lineto
0.11682 0.00041 lineto
0.11806 0.00012 lineto
0.1193 0.00017 lineto
0.12054 0.00047 lineto
0.12302 0.00107 lineto
0.14286 0.00604 lineto
0.15278 0.00845 lineto
0.15774 0.00956 lineto
0.1627 0.01055 lineto
0.16766 0.01138 lineto
0.17014 0.01171 lineto
0.17262 0.01198 lineto
0.17386 0.01208 lineto
0.1751 0.01217 lineto
0.17634 0.01223 lineto
0.17758 0.01227 lineto
0.17882 0.01229 lineto
0.18006 0.01227 lineto
0.1813 0.01223 lineto
0.18254 0.01216 lineto
0.18378 0.01205 lineto
0.18502 0.01191 lineto
0.18626 0.01173 lineto
0.1875 0.0115 lineto
0.18998 0.01091 lineto
0.19246 0.01012 lineto
0.19494 0.00909 lineto
0.19742 0.00779 lineto
0.20238 0.00418 lineto
0.20486 0.00176 lineto
0.2061 0.00037 lineto
0.20734 0.00115 lineto
Mistroke
0.20982 0.00463 lineto
0.2123 0.00878 lineto
0.21726 0.01957 lineto
0.22222 0.03471 lineto
0.22718 0.05594 lineto
0.23214 0.08571 lineto
0.2371 0.1274 lineto
0.24206 0.18508 lineto
0.25198 0.35356 lineto
0.25694 0.44363 lineto
0.25942 0.48013 lineto
0.26066 0.49521 lineto
0.2619 0.50803 lineto
0.26314 0.51863 lineto
0.26438 0.52712 lineto
0.26562 0.5337 lineto
0.26687 0.53859 lineto
0.26811 0.54204 lineto
0.26935 0.54428 lineto
0.27059 0.54557 lineto
0.27183 0.54609 lineto
0.27307 0.54603 lineto
0.27431 0.54556 lineto
0.27679 0.54383 lineto
0.28175 0.53958 lineto
0.28423 0.5378 lineto
0.28547 0.53708 lineto
0.28671 0.5365 lineto
0.28795 0.53604 lineto
0.28919 0.53572 lineto
0.29043 0.53553 lineto
0.29167 0.53547 lineto
0.29291 0.53554 lineto
0.29415 0.53574 lineto
0.29539 0.53604 lineto
0.29663 0.53646 lineto
0.29911 0.5376 lineto
0.30159 0.53908 lineto
0.31151 0.5473 lineto
0.32143 0.55664 lineto
0.32639 0.56085 lineto
0.33135 0.56441 lineto
0.33383 0.56589 lineto
0.33631 0.56715 lineto
0.33879 0.56817 lineto
0.34003 0.56859 lineto
0.34127 0.56895 lineto
0.34251 0.56925 lineto
0.34375 0.56949 lineto
0.34499 0.56966 lineto
Mistroke
0.34623 0.56978 lineto
0.34747 0.56983 lineto
0.34871 0.56982 lineto
0.34995 0.56975 lineto
0.35119 0.56962 lineto
0.35243 0.56943 lineto
0.35367 0.56919 lineto
0.35615 0.56853 lineto
0.35863 0.56765 lineto
0.36111 0.56657 lineto
0.37103 0.56049 lineto
0.38095 0.55226 lineto
0.42063 0.51368 lineto
0.44048 0.49765 lineto
0.4504 0.49122 lineto
0.46032 0.48593 lineto
0.47024 0.48181 lineto
0.4752 0.48019 lineto
0.48016 0.47887 lineto
0.48512 0.47784 lineto
0.4876 0.47743 lineto
0.49008 0.4771 lineto
0.49256 0.47685 lineto
0.4938 0.47675 lineto
0.49504 0.47666 lineto
0.49628 0.4766 lineto
0.49752 0.47655 lineto
0.49876 0.47652 lineto
0.5 0.47652 lineto
0.50124 0.47652 lineto
0.50248 0.47655 lineto
0.50372 0.4766 lineto
0.50496 0.47666 lineto
0.5062 0.47675 lineto
0.50744 0.47685 lineto
0.50992 0.4771 lineto
0.5124 0.47743 lineto
0.51488 0.47784 lineto
0.51984 0.47887 lineto
0.5248 0.48019 lineto
0.52976 0.48181 lineto
0.53968 0.48593 lineto
0.5496 0.49122 lineto
0.55952 0.49765 lineto
0.57937 0.51368 lineto
0.59921 0.53284 lineto
0.61905 0.55226 lineto
0.62897 0.56049 lineto
0.63393 0.56386 lineto
0.63889 0.56657 lineto
Mistroke
0.64137 0.56765 lineto
0.64385 0.56853 lineto
0.64509 0.56889 lineto
0.64633 0.56919 lineto
0.64757 0.56943 lineto
0.64881 0.56962 lineto
0.65005 0.56975 lineto
0.65129 0.56982 lineto
0.65253 0.56983 lineto
0.65377 0.56978 lineto
0.65501 0.56966 lineto
0.65625 0.56949 lineto
0.65749 0.56925 lineto
0.65873 0.56895 lineto
0.69841 0.53908 lineto
0.70089 0.5376 lineto
0.70213 0.53698 lineto
0.70337 0.53646 lineto
0.70461 0.53604 lineto
0.70585 0.53574 lineto
0.70709 0.53554 lineto
0.70833 0.53547 lineto
0.70957 0.53553 lineto
0.71081 0.53572 lineto
0.71205 0.53604 lineto
0.71329 0.5365 lineto
0.71577 0.5378 lineto
0.71825 0.53958 lineto
0.72073 0.54168 lineto
0.72321 0.54383 lineto
0.72445 0.54479 lineto
0.72569 0.54556 lineto
0.72693 0.54603 lineto
0.72817 0.54609 lineto
0.72941 0.54557 lineto
0.73065 0.54428 lineto
0.73189 0.54204 lineto
0.73313 0.53859 lineto
0.73438 0.5337 lineto
0.73562 0.52712 lineto
0.73686 0.51863 lineto
0.7381 0.50803 lineto
0.74802 0.35356 lineto
0.75298 0.26167 lineto
0.75794 0.18508 lineto
0.7629 0.1274 lineto
0.76786 0.08571 lineto
0.77282 0.05594 lineto
0.77778 0.03471 lineto
0.78274 0.01957 lineto
Mistroke
0.7877 0.00878 lineto
0.79018 0.00463 lineto
0.79142 0.00281 lineto
0.79266 0.00115 lineto
0.7939 0.00037 lineto
0.79514 0.00176 lineto
0.79638 0.00303 lineto
0.79762 0.00418 lineto
0.8001 0.00616 lineto
0.80258 0.00779 lineto
0.80506 0.00909 lineto
0.80754 0.01012 lineto
0.81002 0.01091 lineto
0.8125 0.0115 lineto
0.81374 0.01173 lineto
0.81498 0.01191 lineto
0.81622 0.01205 lineto
0.81746 0.01216 lineto
0.8187 0.01223 lineto
0.81994 0.01227 lineto
0.82118 0.01229 lineto
0.82242 0.01227 lineto
0.82366 0.01223 lineto
0.8249 0.01217 lineto
0.82614 0.01208 lineto
0.82738 0.01198 lineto
0.8373 0.01055 lineto
0.84226 0.00956 lineto
0.84722 0.00845 lineto
0.85714 0.00604 lineto
0.86706 0.00354 lineto
0.87202 0.00229 lineto
0.87698 0.00107 lineto
0.87822 0.00077 lineto
0.87946 0.00047 lineto
0.8807 0.00017 lineto
0.88194 0.00012 lineto
0.88442 0.0007 lineto
0.8869 0.00127 lineto
0.89683 0.00342 lineto
0.91667 0.00706 lineto
0.92659 0.0085 lineto
0.93651 0.00969 lineto
0.94643 0.01062 lineto
0.95139 0.01098 lineto
0.95635 0.01128 lineto
0.96131 0.01151 lineto
0.96379 0.0116 lineto
0.96627 0.01168 lineto
0.96875 0.01174 lineto
Mistroke
0.96999 0.01176 lineto
0.97123 0.01178 lineto
0.97247 0.01179 lineto
0.97371 0.0118 lineto
0.97495 0.01181 lineto
0.97619 0.01181 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01168 moveto
0.02505 0.01168 lineto
0.02629 0.01167 lineto
0.02753 0.01166 lineto
0.02877 0.01165 lineto
0.03125 0.01161 lineto
0.03373 0.01155 lineto
0.03621 0.01148 lineto
0.03869 0.01139 lineto
0.04365 0.01116 lineto
0.04861 0.01086 lineto
0.05357 0.0105 lineto
0.06349 0.00959 lineto
0.07341 0.00841 lineto
0.08333 0.00698 lineto
0.10317 0.00339 lineto
0.1131 0.00126 lineto
0.11558 0.00069 lineto
0.11682 0.00041 lineto
0.11806 0.00012 lineto
0.1193 0.00017 lineto
0.12054 0.00047 lineto
0.12302 0.00106 lineto
0.14286 0.00599 lineto
0.15278 0.00839 lineto
0.15774 0.00948 lineto
0.1627 0.01047 lineto
0.16766 0.01129 lineto
0.17014 0.01163 lineto
0.17262 0.01189 lineto
0.17386 0.012 lineto
0.1751 0.01209 lineto
0.17634 0.01215 lineto
0.17758 0.01219 lineto
0.17882 0.01221 lineto
0.18006 0.0122 lineto
0.1813 0.01215 lineto
0.18254 0.01208 lineto
0.18378 0.01198 lineto
0.18502 0.01184 lineto
0.18626 0.01166 lineto
0.1875 0.01143 lineto
0.18998 0.01085 lineto
0.19246 0.01007 lineto
0.19494 0.00905 lineto
0.19742 0.00775 lineto
0.20238 0.00416 lineto
0.20486 0.00175 lineto
0.2061 0.00037 lineto
0.20734 0.00114 lineto
Mistroke
0.20982 0.00461 lineto
0.2123 0.00875 lineto
0.21726 0.01952 lineto
0.22222 0.03465 lineto
0.22718 0.05587 lineto
0.23214 0.08568 lineto
0.2371 0.12746 lineto
0.24206 0.18533 lineto
0.25198 0.35473 lineto
0.25694 0.44557 lineto
0.25942 0.4825 lineto
0.26066 0.49778 lineto
0.2619 0.51081 lineto
0.26314 0.52162 lineto
0.26438 0.53031 lineto
0.26562 0.53708 lineto
0.26687 0.54216 lineto
0.26811 0.54578 lineto
0.26935 0.54821 lineto
0.27059 0.54966 lineto
0.27183 0.55035 lineto
0.27307 0.55045 lineto
0.27431 0.55014 lineto
0.27679 0.54872 lineto
0.27927 0.54688 lineto
0.28175 0.54508 lineto
0.28299 0.54429 lineto
0.28423 0.5436 lineto
0.28547 0.54304 lineto
0.28671 0.5426 lineto
0.28795 0.5423 lineto
0.28919 0.54213 lineto
0.29043 0.54209 lineto
0.29167 0.54218 lineto
0.29291 0.54241 lineto
0.29415 0.54275 lineto
0.29663 0.54377 lineto
0.29911 0.54519 lineto
0.30159 0.54696 lineto
0.31151 0.5562 lineto
0.32143 0.56621 lineto
0.32639 0.57059 lineto
0.33135 0.5742 lineto
0.33383 0.57565 lineto
0.33631 0.57685 lineto
0.33879 0.57778 lineto
0.34003 0.57814 lineto
0.34127 0.57844 lineto
0.34251 0.57867 lineto
0.34375 0.57882 lineto
Mistroke
0.34499 0.57891 lineto
0.34623 0.57893 lineto
0.34747 0.57888 lineto
0.34871 0.57877 lineto
0.34995 0.57859 lineto
0.35119 0.57834 lineto
0.35367 0.57765 lineto
0.35615 0.57673 lineto
0.36111 0.57419 lineto
0.36607 0.57084 lineto
0.37103 0.56681 lineto
0.38095 0.55727 lineto
0.40079 0.53547 lineto
0.42063 0.51452 lineto
0.44048 0.49727 lineto
0.4504 0.49041 lineto
0.46032 0.48479 lineto
0.47024 0.48042 lineto
0.4752 0.47871 lineto
0.48016 0.47731 lineto
0.48512 0.47622 lineto
0.4876 0.4758 lineto
0.49008 0.47545 lineto
0.49256 0.47517 lineto
0.4938 0.47507 lineto
0.49504 0.47498 lineto
0.49628 0.47491 lineto
0.49752 0.47486 lineto
0.49876 0.47484 lineto
0.5 0.47483 lineto
0.50124 0.47484 lineto
0.50248 0.47486 lineto
0.50372 0.47491 lineto
0.50496 0.47498 lineto
0.5062 0.47507 lineto
0.50744 0.47517 lineto
0.50992 0.47545 lineto
0.5124 0.4758 lineto
0.51488 0.47622 lineto
0.51984 0.47731 lineto
0.5248 0.47871 lineto
0.52976 0.48042 lineto
0.53968 0.48479 lineto
0.5496 0.49041 lineto
0.55952 0.49727 lineto
0.57937 0.51452 lineto
0.59921 0.53547 lineto
0.61905 0.55727 lineto
0.62897 0.56681 lineto
0.63393 0.57084 lineto
Mistroke
0.63889 0.57419 lineto
0.64137 0.57556 lineto
0.64385 0.57673 lineto
0.64633 0.57765 lineto
0.64757 0.57803 lineto
0.64881 0.57834 lineto
0.65005 0.57859 lineto
0.65129 0.57877 lineto
0.65253 0.57888 lineto
0.65377 0.57893 lineto
0.65501 0.57891 lineto
0.65625 0.57882 lineto
0.65749 0.57867 lineto
0.65873 0.57844 lineto
0.69841 0.54696 lineto
0.70089 0.54519 lineto
0.70337 0.54377 lineto
0.70461 0.5432 lineto
0.70585 0.54275 lineto
0.70709 0.54241 lineto
0.70833 0.54218 lineto
0.70957 0.54209 lineto
0.71081 0.54213 lineto
0.71205 0.5423 lineto
0.71329 0.5426 lineto
0.71577 0.5436 lineto
0.71701 0.54429 lineto
0.71825 0.54508 lineto
0.72073 0.54688 lineto
0.72321 0.54872 lineto
0.72445 0.54952 lineto
0.72569 0.55014 lineto
0.72693 0.55045 lineto
0.72817 0.55035 lineto
0.72941 0.54966 lineto
0.73065 0.54821 lineto
0.73189 0.54578 lineto
0.73313 0.54216 lineto
0.73438 0.53708 lineto
0.73562 0.53031 lineto
0.73686 0.52162 lineto
0.7381 0.51081 lineto
0.74802 0.35473 lineto
0.75298 0.26229 lineto
0.75794 0.18533 lineto
0.7629 0.12746 lineto
0.76786 0.08568 lineto
0.77282 0.05587 lineto
0.77778 0.03465 lineto
0.78274 0.01952 lineto
Mistroke
0.7877 0.00875 lineto
0.79018 0.00461 lineto
0.79142 0.0028 lineto
0.79266 0.00114 lineto
0.7939 0.00037 lineto
0.79514 0.00175 lineto
0.79638 0.00301 lineto
0.79762 0.00416 lineto
0.8001 0.00614 lineto
0.80258 0.00775 lineto
0.80506 0.00905 lineto
0.80754 0.01007 lineto
0.81002 0.01085 lineto
0.8125 0.01143 lineto
0.81374 0.01166 lineto
0.81498 0.01184 lineto
0.81622 0.01198 lineto
0.81746 0.01208 lineto
0.8187 0.01215 lineto
0.81994 0.0122 lineto
0.82118 0.01221 lineto
0.82242 0.01219 lineto
0.82366 0.01215 lineto
0.8249 0.01209 lineto
0.82614 0.012 lineto
0.82738 0.01189 lineto
0.8373 0.01047 lineto
0.84226 0.00948 lineto
0.84722 0.00839 lineto
0.85714 0.00599 lineto
0.86706 0.0035 lineto
0.87202 0.00227 lineto
0.87698 0.00106 lineto
0.87822 0.00076 lineto
0.87946 0.00047 lineto
0.8807 0.00017 lineto
0.88194 0.00012 lineto
0.88442 0.00069 lineto
0.8869 0.00126 lineto
0.89683 0.00339 lineto
0.91667 0.00698 lineto
0.92659 0.00841 lineto
0.93651 0.00959 lineto
0.94643 0.0105 lineto
0.95139 0.01086 lineto
0.95635 0.01116 lineto
0.96131 0.01139 lineto
0.96379 0.01148 lineto
0.96627 0.01155 lineto
0.96875 0.01161 lineto
Mistroke
0.96999 0.01163 lineto
0.97123 0.01165 lineto
0.97247 0.01166 lineto
0.97371 0.01167 lineto
0.97495 0.01168 lineto
0.97619 0.01168 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 39; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.51503 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.2)] 0.4875 0.10301 1 0 Msboxa
[(0.4)] 0.4875 0.20601 1 0 Msboxa
[(0.6)] 0.4875 0.30902 1 0 Msboxa
[(0.8)] 0.4875 0.41202 1 0 Msboxa
[(1)] 0.4875 0.51503 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.10301 moveto
0.50625 0.10301 lineto
stroke
0 setgray
[(0.2)] 0.4875 0.10301 1 0 Mshowa
0.49375 0.20601 moveto
0.50625 0.20601 lineto
stroke
0 setgray
[(0.4)] 0.4875 0.20601 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(0.6)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.41202 moveto
0.50625 0.41202 lineto
stroke
0 setgray
[(0.8)] 0.4875 0.41202 1 0 Mshowa
0.49375 0.51503 moveto
0.50625 0.51503 lineto
stroke
0 setgray
[(1)] 0.4875 0.51503 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.01156 moveto
0.02505 0.01155 lineto
0.02629 0.01155 lineto
0.02753 0.01154 lineto
0.02877 0.01152 lineto
0.03125 0.01148 lineto
0.03373 0.01143 lineto
0.03621 0.01135 lineto
0.03869 0.01126 lineto
0.04365 0.01104 lineto
0.04861 0.01075 lineto
0.05357 0.01039 lineto
0.06349 0.00949 lineto
0.07341 0.00833 lineto
0.08333 0.00691 lineto
0.10317 0.00335 lineto
0.1131 0.00124 lineto
0.11558 0.00069 lineto
0.11682 0.0004 lineto
0.11806 0.00012 lineto
0.1193 0.00017 lineto
0.12054 0.00046 lineto
0.12302 0.00105 lineto
0.14286 0.00594 lineto
0.15278 0.00832 lineto
0.15774 0.00941 lineto
0.1627 0.01039 lineto
0.16766 0.01121 lineto
0.17014 0.01154 lineto
0.17262 0.01181 lineto
0.17386 0.01192 lineto
0.1751 0.012 lineto
0.17634 0.01207 lineto
0.17758 0.01211 lineto
0.17882 0.01213 lineto
0.18006 0.01212 lineto
0.1813 0.01208 lineto
0.18254 0.01201 lineto
0.18378 0.0119 lineto
0.18502 0.01176 lineto
0.18626 0.01159 lineto
0.1875 0.01137 lineto
0.18998 0.01079 lineto
0.19246 0.01001 lineto
0.19494 0.009 lineto
0.19742 0.00771 lineto
0.20238 0.00414 lineto
0.20486 0.00175 lineto
0.2061 0.00037 lineto
0.20734 0.00114 lineto
Mistroke
0.20982 0.00459 lineto
0.2123 0.00872 lineto
0.21726 0.01946 lineto
0.22222 0.03458 lineto
0.22718 0.0558 lineto
0.23214 0.08564 lineto
0.2371 0.12751 lineto
0.24206 0.18557 lineto
0.25198 0.35589 lineto
0.25694 0.4475 lineto
0.25942 0.48485 lineto
0.26066 0.50035 lineto
0.2619 0.5136 lineto
0.26314 0.52461 lineto
0.26438 0.53351 lineto
0.26562 0.54048 lineto
0.26687 0.54575 lineto
0.26811 0.54956 lineto
0.26935 0.55217 lineto
0.27059 0.5538 lineto
0.27183 0.55466 lineto
0.27307 0.55494 lineto
0.27431 0.55479 lineto
0.27679 0.55371 lineto
0.27927 0.55219 lineto
0.28175 0.55071 lineto
0.28299 0.55008 lineto
0.28423 0.54956 lineto
0.28547 0.54916 lineto
0.28671 0.54889 lineto
0.28795 0.54874 lineto
0.28919 0.54874 lineto
0.29043 0.54886 lineto
0.29167 0.54912 lineto
0.30159 0.55518 lineto
0.31151 0.56552 lineto
0.32143 0.57628 lineto
0.32639 0.58084 lineto
0.32887 0.58279 lineto
0.33135 0.58448 lineto
0.33383 0.5859 lineto
0.33631 0.58703 lineto
0.33879 0.58786 lineto
0.34003 0.58816 lineto
0.34127 0.58838 lineto
0.34251 0.58852 lineto
0.34375 0.58859 lineto
0.34499 0.58858 lineto
0.34623 0.5885 lineto
0.34747 0.58834 lineto
Mistroke
0.34871 0.5881 lineto
0.35119 0.58742 lineto
0.35367 0.58646 lineto
0.35615 0.58523 lineto
0.36111 0.58205 lineto
0.37103 0.57329 lineto
0.38095 0.56233 lineto
0.40079 0.53804 lineto
0.42063 0.51525 lineto
0.44048 0.49678 lineto
0.4504 0.48948 lineto
0.46032 0.48353 lineto
0.47024 0.47893 lineto
0.4752 0.47712 lineto
0.48016 0.47565 lineto
0.48512 0.47451 lineto
0.4876 0.47406 lineto
0.49008 0.47369 lineto
0.49256 0.4734 lineto
0.4938 0.47329 lineto
0.49504 0.4732 lineto
0.49628 0.47313 lineto
0.49752 0.47308 lineto
0.49876 0.47305 lineto
0.5 0.47304 lineto
0.50124 0.47305 lineto
0.50248 0.47308 lineto
0.50372 0.47313 lineto
0.50496 0.4732 lineto
0.5062 0.47329 lineto
0.50744 0.4734 lineto
0.50992 0.47369 lineto
0.5124 0.47406 lineto
0.51488 0.47451 lineto
0.51984 0.47565 lineto
0.5248 0.47712 lineto
0.52976 0.47893 lineto
0.53968 0.48353 lineto
0.5496 0.48948 lineto
0.55952 0.49678 lineto
0.57937 0.51525 lineto
0.59921 0.53804 lineto
0.61905 0.56233 lineto
0.62897 0.57329 lineto
0.63393 0.57802 lineto
0.63889 0.58205 lineto
0.64137 0.58376 lineto
0.64385 0.58523 lineto
0.64633 0.58646 lineto
0.64881 0.58742 lineto
Mistroke
0.65005 0.5878 lineto
0.65129 0.5881 lineto
0.65253 0.58834 lineto
0.65377 0.5885 lineto
0.65501 0.58858 lineto
0.65625 0.58859 lineto
0.65749 0.58852 lineto
0.65873 0.58838 lineto
0.69841 0.55518 lineto
0.70337 0.55136 lineto
0.70461 0.55063 lineto
0.70585 0.55001 lineto
0.70709 0.54951 lineto
0.70833 0.54912 lineto
0.70957 0.54886 lineto
0.71081 0.54874 lineto
0.71205 0.54874 lineto
0.71329 0.54889 lineto
0.71453 0.54916 lineto
0.71577 0.54956 lineto
0.71701 0.55008 lineto
0.71825 0.55071 lineto
0.72073 0.55219 lineto
0.72321 0.55371 lineto
0.72445 0.55434 lineto
0.72569 0.55479 lineto
0.72693 0.55494 lineto
0.72817 0.55466 lineto
0.72941 0.5538 lineto
0.73065 0.55217 lineto
0.73189 0.54956 lineto
0.73313 0.54575 lineto
0.73438 0.54048 lineto
0.73562 0.53351 lineto
0.73686 0.52461 lineto
0.7381 0.5136 lineto
0.74802 0.35589 lineto
0.75298 0.26287 lineto
0.75794 0.18557 lineto
0.7629 0.12751 lineto
0.76786 0.08564 lineto
0.77282 0.0558 lineto
0.77778 0.03458 lineto
0.78274 0.01946 lineto
0.7877 0.00872 lineto
0.79018 0.00459 lineto
0.79142 0.00279 lineto
0.79266 0.00114 lineto
0.7939 0.00037 lineto
0.79514 0.00175 lineto
Mistroke
0.79638 0.003 lineto
0.79762 0.00414 lineto
0.8001 0.00611 lineto
0.80258 0.00771 lineto
0.80506 0.009 lineto
0.80754 0.01001 lineto
0.81002 0.01079 lineto
0.8125 0.01137 lineto
0.81374 0.01159 lineto
0.81498 0.01176 lineto
0.81622 0.0119 lineto
0.81746 0.01201 lineto
0.8187 0.01208 lineto
0.81994 0.01212 lineto
0.82118 0.01213 lineto
0.82242 0.01211 lineto
0.82366 0.01207 lineto
0.8249 0.012 lineto
0.82614 0.01192 lineto
0.82738 0.01181 lineto
0.8373 0.01039 lineto
0.84226 0.00941 lineto
0.84722 0.00832 lineto
0.85714 0.00594 lineto
0.86706 0.00347 lineto
0.87202 0.00225 lineto
0.87698 0.00105 lineto
0.87822 0.00075 lineto
0.87946 0.00046 lineto
0.8807 0.00017 lineto
0.88194 0.00012 lineto
0.88442 0.00069 lineto
0.8869 0.00124 lineto
0.89683 0.00335 lineto
0.91667 0.00691 lineto
0.92659 0.00833 lineto
0.93651 0.00949 lineto
0.94643 0.01039 lineto
0.95139 0.01075 lineto
0.95635 0.01104 lineto
0.96131 0.01126 lineto
0.96379 0.01135 lineto
0.96627 0.01143 lineto
0.96875 0.01148 lineto
0.96999 0.0115 lineto
0.97123 0.01152 lineto
0.97247 0.01154 lineto
0.97371 0.01155 lineto
0.97495 0.01155 lineto
0.97619 0.01156 lineto
Mistroke
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = text; inactive; ]
	In the second pair of animations, we increase the radius of the two poles with the larger radius.  Note that only a small distortion in the pole locations causes a tremendous deterioration of the frequency response of the elliptic filter. 
:[font = input; startGroup; ]
Do[ PoleZeroPlot[ ExpandAll[ elliptic4thorder[ z, rl, 0.4829798 ] ],   
                  z, rl, Infinity, True, Dialogue -> False],
    { rl, 0.8929096, 0.9929096, 0.01 } ] 
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.85716 0.5 moveto
0.85715 0.50292 lineto
0.85712 0.50584 lineto
0.85706 0.50877 lineto
0.85697 0.51169 lineto
0.85687 0.51461 lineto
0.85673 0.51753 lineto
0.8564 0.52336 lineto
0.85597 0.52919 lineto
0.85544 0.53501 lineto
0.85411 0.54662 lineto
0.85239 0.55818 lineto
0.8503 0.56968 lineto
0.84499 0.59244 lineto
0.83821 0.61481 lineto
0.82998 0.63668 lineto
0.80931 0.67858 lineto
0.78336 0.71743 lineto
0.75255 0.75255 lineto
0.71743 0.78336 lineto
0.67858 0.80931 lineto
0.65797 0.82033 lineto
0.63668 0.82998 lineto
0.61481 0.83821 lineto
0.59244 0.84499 lineto
0.56968 0.8503 lineto
0.55818 0.85239 lineto
0.54662 0.85411 lineto
0.53501 0.85544 lineto
0.52919 0.85597 lineto
0.52336 0.8564 lineto
0.51753 0.85673 lineto
0.51461 0.85687 lineto
0.51169 0.85697 lineto
0.50877 0.85706 lineto
0.50584 0.85712 lineto
0.50292 0.85715 lineto
0.5 0.85716 lineto
0.49708 0.85715 lineto
0.49416 0.85712 lineto
0.49123 0.85706 lineto
0.48831 0.85697 lineto
0.48247 0.85673 lineto
0.47664 0.8564 lineto
0.47081 0.85597 lineto
0.46499 0.85544 lineto
0.45338 0.85411 lineto
0.44182 0.85239 lineto
0.43032 0.8503 lineto
0.40756 0.84499 lineto
Mistroke
0.38519 0.83821 lineto
0.36332 0.82998 lineto
0.32142 0.80931 lineto
0.28257 0.78336 lineto
0.24745 0.75255 lineto
0.21664 0.71743 lineto
0.19069 0.67858 lineto
0.17002 0.63668 lineto
0.16179 0.61481 lineto
0.15501 0.59244 lineto
0.1497 0.56968 lineto
0.14761 0.55818 lineto
0.14589 0.54662 lineto
0.14456 0.53501 lineto
0.14403 0.52919 lineto
0.1436 0.52336 lineto
0.14327 0.51753 lineto
0.14313 0.51461 lineto
0.14303 0.51169 lineto
0.14294 0.50877 lineto
0.14288 0.50584 lineto
0.14285 0.50292 lineto
0.14284 0.5 lineto
0.14285 0.49708 lineto
0.14288 0.49416 lineto
0.14294 0.49123 lineto
0.14303 0.48831 lineto
0.14327 0.48247 lineto
0.1436 0.47664 lineto
0.14403 0.47081 lineto
0.14456 0.46499 lineto
0.14589 0.45338 lineto
0.14761 0.44182 lineto
0.1497 0.43032 lineto
0.15501 0.40756 lineto
0.16179 0.38519 lineto
0.17002 0.36332 lineto
0.19069 0.32142 lineto
0.21664 0.28257 lineto
0.24745 0.24745 lineto
0.28257 0.21664 lineto
0.32142 0.19069 lineto
0.34203 0.17967 lineto
0.36332 0.17002 lineto
0.38519 0.16179 lineto
0.40756 0.15501 lineto
0.43032 0.1497 lineto
0.44182 0.14761 lineto
0.45338 0.14589 lineto
0.46499 0.14456 lineto
Mistroke
0.47081 0.14403 lineto
0.47664 0.1436 lineto
0.48247 0.14327 lineto
0.48539 0.14313 lineto
0.48831 0.14303 lineto
0.49123 0.14294 lineto
0.49416 0.14288 lineto
0.49708 0.14285 lineto
0.5 0.14284 lineto
0.50292 0.14285 lineto
0.50584 0.14288 lineto
0.50877 0.14294 lineto
0.51169 0.14303 lineto
0.51753 0.14327 lineto
0.52336 0.1436 lineto
0.52919 0.14403 lineto
0.53501 0.14456 lineto
0.54662 0.14589 lineto
0.55818 0.14761 lineto
0.56968 0.1497 lineto
0.59244 0.15501 lineto
0.61481 0.16179 lineto
0.63668 0.17002 lineto
0.67858 0.19069 lineto
0.71743 0.21664 lineto
0.75255 0.24745 lineto
0.78336 0.28257 lineto
0.80931 0.32142 lineto
0.82033 0.34203 lineto
0.82998 0.36332 lineto
0.83821 0.38519 lineto
0.84499 0.40756 lineto
0.8503 0.43032 lineto
0.85239 0.44182 lineto
0.85411 0.45338 lineto
0.85544 0.46499 lineto
0.85597 0.47081 lineto
0.8564 0.47664 lineto
0.85673 0.48247 lineto
0.85687 0.48539 lineto
0.85697 0.48831 lineto
0.85706 0.49123 lineto
0.85712 0.49416 lineto
0.85715 0.49708 lineto
0.85716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83562 0.62216 lineto
stroke
0.15178 0.42056 moveto
-0.26579 0.26857 lineto
stroke
0.14453 0.46521 moveto
-0.2775 0.31161 lineto
stroke
0.14304 0.51197 moveto
-0.28684 0.3555 lineto
stroke
0.1481 0.56111 moveto
-0.29376 0.40028 lineto
stroke
0.16125 0.61319 moveto
-0.29817 0.44597 lineto
stroke
0.18552 0.66932 moveto
-0.29997 0.49262 lineto
stroke
0.22874 0.73235 moveto
-0.29899 0.54027 lineto
stroke
0.34658 0.82253 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.58979 0.15431 moveto
-0.05182 -0.07922 lineto
stroke
0.44156 0.14765 moveto
-0.08617 -0.04443 lineto
stroke
0.36793 0.16815 moveto
-0.11756 -0.00855 lineto
stroke
0.31325 0.19555 moveto
-0.14616 0.02833 lineto
stroke
0.26971 0.22699 moveto
-0.17215 0.06617 lineto
stroke
0.23424 0.26138 moveto
-0.19564 0.10492 lineto
stroke
0.20534 0.29816 moveto
-0.2167 0.14455 lineto
stroke
0.18219 0.33703 moveto
-0.23539 0.18504 lineto
stroke
0.16438 0.37784 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.81781 0.66297 lineto
stroke
1.26579 0.73143 moveto
0.84822 0.57944 lineto
stroke
1.2167 0.85545 moveto
0.79466 0.70184 lineto
stroke
1.2775 0.68839 moveto
0.85547 0.53479 lineto
stroke
1.19564 0.89508 moveto
0.76576 0.73862 lineto
stroke
1.28684 0.6445 moveto
0.85696 0.48803 lineto
stroke
1.17215 0.93383 moveto
0.73029 0.77301 lineto
stroke
1.29376 0.59972 moveto
0.8519 0.43889 lineto
stroke
1.14616 0.97167 moveto
0.68675 0.80445 lineto
stroke
1.29817 0.55403 moveto
0.83875 0.38681 lineto
stroke
1.11756 1.00855 moveto
0.63207 0.83185 lineto
stroke
1.29997 0.50738 moveto
0.81448 0.33068 lineto
stroke
1.08617 1.04443 moveto
0.55844 0.85235 lineto
stroke
1.29899 0.45973 moveto
0.77126 0.26765 lineto
stroke
1.05182 1.07922 moveto
0.41021 0.84569 lineto
stroke
1.29503 0.41099 moveto
0.65342 0.17747 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.14298 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48972 0.85702 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86116 0.5 moveto
0.86115 0.50295 lineto
0.86112 0.50591 lineto
0.86106 0.50886 lineto
0.86097 0.51182 lineto
0.86086 0.51477 lineto
0.86073 0.51772 lineto
0.86039 0.52362 lineto
0.85996 0.52951 lineto
0.85942 0.5354 lineto
0.85807 0.54714 lineto
0.85634 0.55883 lineto
0.85422 0.57046 lineto
0.84886 0.59348 lineto
0.842 0.61609 lineto
0.83367 0.63821 lineto
0.81278 0.68058 lineto
0.78653 0.71986 lineto
0.75538 0.75538 lineto
0.71986 0.78653 lineto
0.68058 0.81278 lineto
0.65974 0.82392 lineto
0.63821 0.83367 lineto
0.61609 0.842 lineto
0.59348 0.84886 lineto
0.57046 0.85422 lineto
0.55883 0.85634 lineto
0.54714 0.85807 lineto
0.5354 0.85942 lineto
0.52951 0.85996 lineto
0.52362 0.86039 lineto
0.51772 0.86073 lineto
0.51477 0.86086 lineto
0.51182 0.86097 lineto
0.50886 0.86106 lineto
0.50591 0.86112 lineto
0.50295 0.86115 lineto
0.5 0.86116 lineto
0.49705 0.86115 lineto
0.49409 0.86112 lineto
0.49114 0.86106 lineto
0.48818 0.86097 lineto
0.48228 0.86073 lineto
0.47638 0.86039 lineto
0.47049 0.85996 lineto
0.4646 0.85942 lineto
0.45286 0.85807 lineto
0.44117 0.85634 lineto
0.42954 0.85422 lineto
0.40652 0.84886 lineto
Mistroke
0.38391 0.842 lineto
0.36179 0.83367 lineto
0.31942 0.81278 lineto
0.28014 0.78653 lineto
0.24462 0.75538 lineto
0.21347 0.71986 lineto
0.18722 0.68058 lineto
0.16633 0.63821 lineto
0.158 0.61609 lineto
0.15114 0.59348 lineto
0.14578 0.57046 lineto
0.14366 0.55883 lineto
0.14193 0.54714 lineto
0.14058 0.5354 lineto
0.14004 0.52951 lineto
0.13961 0.52362 lineto
0.13927 0.51772 lineto
0.13914 0.51477 lineto
0.13903 0.51182 lineto
0.13894 0.50886 lineto
0.13888 0.50591 lineto
0.13885 0.50295 lineto
0.13884 0.5 lineto
0.13885 0.49705 lineto
0.13888 0.49409 lineto
0.13894 0.49114 lineto
0.13903 0.48818 lineto
0.13927 0.48228 lineto
0.13961 0.47638 lineto
0.14004 0.47049 lineto
0.14058 0.4646 lineto
0.14193 0.45286 lineto
0.14366 0.44117 lineto
0.14578 0.42954 lineto
0.15114 0.40652 lineto
0.158 0.38391 lineto
0.16633 0.36179 lineto
0.18722 0.31942 lineto
0.21347 0.28014 lineto
0.24462 0.24462 lineto
0.28014 0.21347 lineto
0.31942 0.18722 lineto
0.34026 0.17608 lineto
0.36179 0.16633 lineto
0.38391 0.158 lineto
0.40652 0.15114 lineto
0.42954 0.14578 lineto
0.44117 0.14366 lineto
0.45286 0.14193 lineto
0.4646 0.14058 lineto
Mistroke
0.47049 0.14004 lineto
0.47638 0.13961 lineto
0.48228 0.13927 lineto
0.48523 0.13914 lineto
0.48818 0.13903 lineto
0.49114 0.13894 lineto
0.49409 0.13888 lineto
0.49705 0.13885 lineto
0.5 0.13884 lineto
0.50295 0.13885 lineto
0.50591 0.13888 lineto
0.50886 0.13894 lineto
0.51182 0.13903 lineto
0.51772 0.13927 lineto
0.52362 0.13961 lineto
0.52951 0.14004 lineto
0.5354 0.14058 lineto
0.54714 0.14193 lineto
0.55883 0.14366 lineto
0.57046 0.14578 lineto
0.59348 0.15114 lineto
0.61609 0.158 lineto
0.63821 0.16633 lineto
0.68058 0.18722 lineto
0.71986 0.21347 lineto
0.75538 0.24462 lineto
0.78653 0.28014 lineto
0.81278 0.31942 lineto
0.82392 0.34026 lineto
0.83367 0.36179 lineto
0.842 0.38391 lineto
0.84886 0.40652 lineto
0.85422 0.42954 lineto
0.85634 0.44117 lineto
0.85807 0.45286 lineto
0.85942 0.4646 lineto
0.85996 0.47049 lineto
0.86039 0.47638 lineto
0.86073 0.48228 lineto
0.86086 0.48523 lineto
0.86097 0.48818 lineto
0.86106 0.49114 lineto
0.86112 0.49409 lineto
0.86115 0.49705 lineto
0.86116 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.83938 0.62353 lineto
stroke
0.148 0.41918 moveto
-0.26579 0.26857 lineto
stroke
0.14065 0.4638 moveto
-0.2775 0.31161 lineto
stroke
0.13899 0.51049 moveto
-0.28684 0.3555 lineto
stroke
0.14378 0.55953 moveto
-0.29376 0.40028 lineto
stroke
0.15646 0.61145 moveto
-0.29817 0.44597 lineto
stroke
0.17991 0.66728 moveto
-0.29997 0.49262 lineto
stroke
0.22122 0.72961 moveto
-0.29899 0.54027 lineto
stroke
0.31882 0.81243 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.56203 0.1442 moveto
-0.05182 -0.07922 lineto
stroke
0.43403 0.14491 moveto
-0.08617 -0.04443 lineto
stroke
0.36232 0.16611 moveto
-0.11756 -0.00855 lineto
stroke
0.30847 0.1938 moveto
-0.14616 0.02833 lineto
stroke
0.26538 0.22542 moveto
-0.17215 0.06617 lineto
stroke
0.23019 0.25991 moveto
-0.19564 0.10492 lineto
stroke
0.20146 0.29675 moveto
-0.2167 0.14455 lineto
stroke
0.1784 0.33565 moveto
-0.23539 0.18504 lineto
stroke
0.16062 0.37647 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8216 0.66435 lineto
stroke
1.26579 0.73143 moveto
0.852 0.58082 lineto
stroke
1.2167 0.85545 moveto
0.79854 0.70325 lineto
stroke
1.2775 0.68839 moveto
0.85935 0.5362 lineto
stroke
1.19564 0.89508 moveto
0.76981 0.74009 lineto
stroke
1.28684 0.6445 moveto
0.86101 0.48951 lineto
stroke
1.17215 0.93383 moveto
0.73462 0.77458 lineto
stroke
1.29376 0.59972 moveto
0.85622 0.44047 lineto
stroke
1.14616 0.97167 moveto
0.69153 0.8062 lineto
stroke
1.29817 0.55403 moveto
0.84354 0.38855 lineto
stroke
1.11756 1.00855 moveto
0.63768 0.83389 lineto
stroke
1.29997 0.50738 moveto
0.82009 0.33272 lineto
stroke
1.08617 1.04443 moveto
0.56597 0.85509 lineto
stroke
1.29899 0.45973 moveto
0.77878 0.27039 lineto
stroke
1.05182 1.07922 moveto
0.43797 0.8558 lineto
stroke
1.29503 0.41099 moveto
0.68118 0.18757 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.4896 0.13899 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.4896 0.86101 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86516 0.5 moveto
0.86515 0.50299 lineto
0.86511 0.50597 lineto
0.86505 0.50896 lineto
0.86497 0.51195 lineto
0.86486 0.51493 lineto
0.86472 0.51792 lineto
0.86438 0.52388 lineto
0.86394 0.52984 lineto
0.86341 0.53579 lineto
0.86204 0.54766 lineto
0.86029 0.55948 lineto
0.85815 0.57124 lineto
0.85272 0.59451 lineto
0.84578 0.61738 lineto
0.83737 0.63974 lineto
0.81624 0.68258 lineto
0.7897 0.7223 lineto
0.75821 0.75821 lineto
0.7223 0.7897 lineto
0.68258 0.81624 lineto
0.66151 0.82751 lineto
0.63974 0.83737 lineto
0.61738 0.84578 lineto
0.59451 0.85272 lineto
0.57124 0.85815 lineto
0.55948 0.86029 lineto
0.54766 0.86204 lineto
0.53579 0.86341 lineto
0.52984 0.86394 lineto
0.52388 0.86438 lineto
0.51792 0.86472 lineto
0.51493 0.86486 lineto
0.51195 0.86497 lineto
0.50896 0.86505 lineto
0.50597 0.86511 lineto
0.50299 0.86515 lineto
0.5 0.86516 lineto
0.49701 0.86515 lineto
0.49403 0.86511 lineto
0.49104 0.86505 lineto
0.48805 0.86497 lineto
0.48208 0.86472 lineto
0.47612 0.86438 lineto
0.47016 0.86394 lineto
0.46421 0.86341 lineto
0.45234 0.86204 lineto
0.44052 0.86029 lineto
0.42876 0.85815 lineto
0.40549 0.85272 lineto
Mistroke
0.38262 0.84578 lineto
0.36026 0.83737 lineto
0.31742 0.81624 lineto
0.2777 0.7897 lineto
0.24179 0.75821 lineto
0.2103 0.7223 lineto
0.18376 0.68258 lineto
0.16263 0.63974 lineto
0.15422 0.61738 lineto
0.14728 0.59451 lineto
0.14185 0.57124 lineto
0.13971 0.55948 lineto
0.13796 0.54766 lineto
0.13659 0.53579 lineto
0.13606 0.52984 lineto
0.13562 0.52388 lineto
0.13528 0.51792 lineto
0.13514 0.51493 lineto
0.13503 0.51195 lineto
0.13495 0.50896 lineto
0.13489 0.50597 lineto
0.13485 0.50299 lineto
0.13484 0.5 lineto
0.13485 0.49701 lineto
0.13489 0.49403 lineto
0.13495 0.49104 lineto
0.13503 0.48805 lineto
0.13528 0.48208 lineto
0.13562 0.47612 lineto
0.13606 0.47016 lineto
0.13659 0.46421 lineto
0.13796 0.45234 lineto
0.13971 0.44052 lineto
0.14185 0.42876 lineto
0.14728 0.40549 lineto
0.15422 0.38262 lineto
0.16263 0.36026 lineto
0.18376 0.31742 lineto
0.2103 0.2777 lineto
0.24179 0.24179 lineto
0.2777 0.2103 lineto
0.31742 0.18376 lineto
0.33849 0.17249 lineto
0.36026 0.16263 lineto
0.38262 0.15422 lineto
0.40549 0.14728 lineto
0.42876 0.14185 lineto
0.44052 0.13971 lineto
0.45234 0.13796 lineto
0.46421 0.13659 lineto
Mistroke
0.47016 0.13606 lineto
0.47612 0.13562 lineto
0.48208 0.13528 lineto
0.48507 0.13514 lineto
0.48805 0.13503 lineto
0.49104 0.13495 lineto
0.49403 0.13489 lineto
0.49701 0.13485 lineto
0.5 0.13484 lineto
0.50299 0.13485 lineto
0.50597 0.13489 lineto
0.50896 0.13495 lineto
0.51195 0.13503 lineto
0.51792 0.13528 lineto
0.52388 0.13562 lineto
0.52984 0.13606 lineto
0.53579 0.13659 lineto
0.54766 0.13796 lineto
0.55948 0.13971 lineto
0.57124 0.14185 lineto
0.59451 0.14728 lineto
0.61738 0.15422 lineto
0.63974 0.16263 lineto
0.68258 0.18376 lineto
0.7223 0.2103 lineto
0.75821 0.24179 lineto
0.7897 0.2777 lineto
0.81624 0.31742 lineto
0.82751 0.33849 lineto
0.83737 0.36026 lineto
0.84578 0.38262 lineto
0.85272 0.40549 lineto
0.85815 0.42876 lineto
0.86029 0.44052 lineto
0.86204 0.45234 lineto
0.86341 0.46421 lineto
0.86394 0.47016 lineto
0.86438 0.47612 lineto
0.86472 0.48208 lineto
0.86486 0.48507 lineto
0.86497 0.48805 lineto
0.86505 0.49104 lineto
0.86511 0.49403 lineto
0.86515 0.49701 lineto
0.86516 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.84314 0.62489 lineto
stroke
0.14421 0.4178 moveto
-0.26579 0.26857 lineto
stroke
0.13678 0.46239 moveto
-0.2775 0.31161 lineto
stroke
0.13495 0.50902 moveto
-0.28684 0.3555 lineto
stroke
0.13947 0.55796 moveto
-0.29376 0.40028 lineto
stroke
0.15171 0.60972 moveto
-0.29817 0.44597 lineto
stroke
0.17437 0.66526 moveto
-0.29997 0.49262 lineto
stroke
0.21393 0.72696 moveto
-0.29899 0.54027 lineto
stroke
0.3002 0.80565 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.54341 0.13743 moveto
-0.05182 -0.07922 lineto
stroke
0.42674 0.14226 moveto
-0.08617 -0.04443 lineto
stroke
0.35678 0.16409 moveto
-0.11756 -0.00855 lineto
stroke
0.30372 0.19208 moveto
-0.14616 0.02833 lineto
stroke
0.26107 0.22385 moveto
-0.17215 0.06617 lineto
stroke
0.22615 0.25844 moveto
-0.19564 0.10492 lineto
stroke
0.19758 0.29534 moveto
-0.2167 0.14455 lineto
stroke
0.17461 0.33427 moveto
-0.23539 0.18504 lineto
stroke
0.15686 0.37511 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.82539 0.66573 lineto
stroke
1.26579 0.73143 moveto
0.85579 0.5822 lineto
stroke
1.2167 0.85545 moveto
0.80242 0.70466 lineto
stroke
1.2775 0.68839 moveto
0.86322 0.53761 lineto
stroke
1.19564 0.89508 moveto
0.77385 0.74156 lineto
stroke
1.28684 0.6445 moveto
0.86505 0.49098 lineto
stroke
1.17215 0.93383 moveto
0.73893 0.77615 lineto
stroke
1.29376 0.59972 moveto
0.86053 0.44204 lineto
stroke
1.14616 0.97167 moveto
0.69628 0.80792 lineto
stroke
1.29817 0.55403 moveto
0.84829 0.39028 lineto
stroke
1.11756 1.00855 moveto
0.64322 0.83591 lineto
stroke
1.29997 0.50738 moveto
0.82563 0.33474 lineto
stroke
1.08617 1.04443 moveto
0.57326 0.85774 lineto
stroke
1.29899 0.45973 moveto
0.78607 0.27304 lineto
stroke
1.05182 1.07922 moveto
0.45659 0.86257 lineto
stroke
1.29503 0.41099 moveto
0.6998 0.19435 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48949 0.13499 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48949 0.86501 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.86916 0.5 moveto
0.86915 0.50302 lineto
0.86911 0.50604 lineto
0.86905 0.50906 lineto
0.86897 0.51208 lineto
0.86886 0.5151 lineto
0.86872 0.51811 lineto
0.86837 0.52414 lineto
0.86793 0.53017 lineto
0.86739 0.53618 lineto
0.86601 0.54819 lineto
0.86423 0.56014 lineto
0.86207 0.57202 lineto
0.85658 0.59555 lineto
0.84957 0.61866 lineto
0.84106 0.64127 lineto
0.81971 0.68458 lineto
0.79288 0.72473 lineto
0.76104 0.76104 lineto
0.72473 0.79288 lineto
0.68458 0.81971 lineto
0.66328 0.83109 lineto
0.64127 0.84106 lineto
0.61866 0.84957 lineto
0.59555 0.85658 lineto
0.57202 0.86207 lineto
0.56014 0.86423 lineto
0.54819 0.86601 lineto
0.53618 0.86739 lineto
0.53017 0.86793 lineto
0.52414 0.86837 lineto
0.51811 0.86872 lineto
0.5151 0.86886 lineto
0.51208 0.86897 lineto
0.50906 0.86905 lineto
0.50604 0.86911 lineto
0.50302 0.86915 lineto
0.5 0.86916 lineto
0.49698 0.86915 lineto
0.49396 0.86911 lineto
0.49094 0.86905 lineto
0.48792 0.86897 lineto
0.48189 0.86872 lineto
0.47586 0.86837 lineto
0.46983 0.86793 lineto
0.46382 0.86739 lineto
0.45181 0.86601 lineto
0.43986 0.86423 lineto
0.42798 0.86207 lineto
0.40445 0.85658 lineto
Mistroke
0.38134 0.84957 lineto
0.35873 0.84106 lineto
0.31542 0.81971 lineto
0.27527 0.79288 lineto
0.23896 0.76104 lineto
0.20712 0.72473 lineto
0.18029 0.68458 lineto
0.15894 0.64127 lineto
0.15043 0.61866 lineto
0.14342 0.59555 lineto
0.13793 0.57202 lineto
0.13577 0.56014 lineto
0.13399 0.54819 lineto
0.13261 0.53618 lineto
0.13207 0.53017 lineto
0.13163 0.52414 lineto
0.13128 0.51811 lineto
0.13114 0.5151 lineto
0.13103 0.51208 lineto
0.13095 0.50906 lineto
0.13089 0.50604 lineto
0.13085 0.50302 lineto
0.13084 0.5 lineto
0.13085 0.49698 lineto
0.13089 0.49396 lineto
0.13095 0.49094 lineto
0.13103 0.48792 lineto
0.13128 0.48189 lineto
0.13163 0.47586 lineto
0.13207 0.46983 lineto
0.13261 0.46382 lineto
0.13399 0.45181 lineto
0.13577 0.43986 lineto
0.13793 0.42798 lineto
0.14342 0.40445 lineto
0.15043 0.38134 lineto
0.15894 0.35873 lineto
0.18029 0.31542 lineto
0.20712 0.27527 lineto
0.23896 0.23896 lineto
0.27527 0.20712 lineto
0.31542 0.18029 lineto
0.33672 0.16891 lineto
0.35873 0.15894 lineto
0.38134 0.15043 lineto
0.40445 0.14342 lineto
0.42798 0.13793 lineto
0.43986 0.13577 lineto
0.45181 0.13399 lineto
0.46382 0.13261 lineto
Mistroke
0.46983 0.13207 lineto
0.47586 0.13163 lineto
0.48189 0.13128 lineto
0.4849 0.13114 lineto
0.48792 0.13103 lineto
0.49094 0.13095 lineto
0.49396 0.13089 lineto
0.49698 0.13085 lineto
0.5 0.13084 lineto
0.50302 0.13085 lineto
0.50604 0.13089 lineto
0.50906 0.13095 lineto
0.51208 0.13103 lineto
0.51811 0.13128 lineto
0.52414 0.13163 lineto
0.53017 0.13207 lineto
0.53618 0.13261 lineto
0.54819 0.13399 lineto
0.56014 0.13577 lineto
0.57202 0.13793 lineto
0.59555 0.14342 lineto
0.61866 0.15043 lineto
0.64127 0.15894 lineto
0.68458 0.18029 lineto
0.72473 0.20712 lineto
0.76104 0.23896 lineto
0.79288 0.27527 lineto
0.81971 0.31542 lineto
0.83109 0.33672 lineto
0.84106 0.35873 lineto
0.84957 0.38134 lineto
0.85658 0.40445 lineto
0.86207 0.42798 lineto
0.86423 0.43986 lineto
0.86601 0.45181 lineto
0.86739 0.46382 lineto
0.86793 0.46983 lineto
0.86837 0.47586 lineto
0.86872 0.48189 lineto
0.86886 0.4849 lineto
0.86897 0.48792 lineto
0.86905 0.49094 lineto
0.86911 0.49396 lineto
0.86915 0.49698 lineto
0.86916 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.8469 0.62626 lineto
stroke
0.14042 0.41642 moveto
-0.26579 0.26857 lineto
stroke
0.1329 0.46098 moveto
-0.2775 0.31161 lineto
stroke
0.13091 0.50755 moveto
-0.28684 0.3555 lineto
stroke
0.13517 0.5564 moveto
-0.29376 0.40028 lineto
stroke
0.14699 0.608 moveto
-0.29817 0.44597 lineto
stroke
0.1689 0.66327 moveto
-0.29997 0.49262 lineto
stroke
0.20685 0.72438 moveto
-0.29899 0.54027 lineto
stroke
0.28507 0.80015 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.52829 0.13192 moveto
-0.05182 -0.07922 lineto
stroke
0.41967 0.13968 moveto
-0.08617 -0.04443 lineto
stroke
0.35132 0.1621 moveto
-0.11756 -0.00855 lineto
stroke
0.299 0.19036 moveto
-0.14616 0.02833 lineto
stroke
0.25678 0.22229 moveto
-0.17215 0.06617 lineto
stroke
0.22212 0.25697 moveto
-0.19564 0.10492 lineto
stroke
0.19371 0.29393 moveto
-0.2167 0.14455 lineto
stroke
0.17082 0.33289 moveto
-0.23539 0.18504 lineto
stroke
0.1531 0.37374 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.82918 0.66711 lineto
stroke
1.26579 0.73143 moveto
0.85958 0.58358 lineto
stroke
1.2167 0.85545 moveto
0.80629 0.70607 lineto
stroke
1.2775 0.68839 moveto
0.8671 0.53902 lineto
stroke
1.19564 0.89508 moveto
0.77788 0.74303 lineto
stroke
1.28684 0.6445 moveto
0.86909 0.49245 lineto
stroke
1.17215 0.93383 moveto
0.74322 0.77771 lineto
stroke
1.29376 0.59972 moveto
0.86483 0.4436 lineto
stroke
1.14616 0.97167 moveto
0.701 0.80964 lineto
stroke
1.29817 0.55403 moveto
0.85301 0.392 lineto
stroke
1.11756 1.00855 moveto
0.64868 0.8379 lineto
stroke
1.29997 0.50738 moveto
0.8311 0.33673 lineto
stroke
1.08617 1.04443 moveto
0.58033 0.86032 lineto
stroke
1.29899 0.45973 moveto
0.79315 0.27562 lineto
stroke
1.05182 1.07922 moveto
0.47171 0.86808 lineto
stroke
1.29503 0.41099 moveto
0.71493 0.19985 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48937 0.13099 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48937 0.86901 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.87316 0.5 moveto
0.87315 0.50305 lineto
0.87311 0.50611 lineto
0.87305 0.50916 lineto
0.87296 0.51221 lineto
0.87285 0.51526 lineto
0.87271 0.51831 lineto
0.87236 0.52441 lineto
0.87192 0.5305 lineto
0.87137 0.53658 lineto
0.86997 0.54871 lineto
0.86818 0.56079 lineto
0.86599 0.5728 lineto
0.86045 0.59658 lineto
0.85336 0.61995 lineto
0.84476 0.6428 lineto
0.82317 0.68658 lineto
0.79605 0.72717 lineto
0.76387 0.76387 lineto
0.72717 0.79605 lineto
0.68658 0.82317 lineto
0.66505 0.83468 lineto
0.6428 0.84476 lineto
0.61995 0.85336 lineto
0.59658 0.86045 lineto
0.5728 0.86599 lineto
0.56079 0.86818 lineto
0.54871 0.86997 lineto
0.53658 0.87137 lineto
0.5305 0.87192 lineto
0.52441 0.87236 lineto
0.51831 0.87271 lineto
0.51526 0.87285 lineto
0.51221 0.87296 lineto
0.50916 0.87305 lineto
0.50611 0.87311 lineto
0.50305 0.87315 lineto
0.5 0.87316 lineto
0.49695 0.87315 lineto
0.49389 0.87311 lineto
0.49084 0.87305 lineto
0.48779 0.87296 lineto
0.48169 0.87271 lineto
0.47559 0.87236 lineto
0.4695 0.87192 lineto
0.46342 0.87137 lineto
0.45129 0.86997 lineto
0.43921 0.86818 lineto
0.4272 0.86599 lineto
0.40342 0.86045 lineto
Mistroke
0.38005 0.85336 lineto
0.3572 0.84476 lineto
0.31342 0.82317 lineto
0.27283 0.79605 lineto
0.23613 0.76387 lineto
0.20395 0.72717 lineto
0.17683 0.68658 lineto
0.15524 0.6428 lineto
0.14664 0.61995 lineto
0.13955 0.59658 lineto
0.13401 0.5728 lineto
0.13182 0.56079 lineto
0.13003 0.54871 lineto
0.12863 0.53658 lineto
0.12808 0.5305 lineto
0.12764 0.52441 lineto
0.12729 0.51831 lineto
0.12715 0.51526 lineto
0.12704 0.51221 lineto
0.12695 0.50916 lineto
0.12689 0.50611 lineto
0.12685 0.50305 lineto
0.12684 0.5 lineto
0.12685 0.49695 lineto
0.12689 0.49389 lineto
0.12695 0.49084 lineto
0.12704 0.48779 lineto
0.12729 0.48169 lineto
0.12764 0.47559 lineto
0.12808 0.4695 lineto
0.12863 0.46342 lineto
0.13003 0.45129 lineto
0.13182 0.43921 lineto
0.13401 0.4272 lineto
0.13955 0.40342 lineto
0.14664 0.38005 lineto
0.15524 0.3572 lineto
0.17683 0.31342 lineto
0.20395 0.27283 lineto
0.23613 0.23613 lineto
0.27283 0.20395 lineto
0.31342 0.17683 lineto
0.33495 0.16532 lineto
0.3572 0.15524 lineto
0.38005 0.14664 lineto
0.40342 0.13955 lineto
0.4272 0.13401 lineto
0.43921 0.13182 lineto
0.45129 0.13003 lineto
0.46342 0.12863 lineto
Mistroke
0.4695 0.12808 lineto
0.47559 0.12764 lineto
0.48169 0.12729 lineto
0.48474 0.12715 lineto
0.48779 0.12704 lineto
0.49084 0.12695 lineto
0.49389 0.12689 lineto
0.49695 0.12685 lineto
0.5 0.12684 lineto
0.50305 0.12685 lineto
0.50611 0.12689 lineto
0.50916 0.12695 lineto
0.51221 0.12704 lineto
0.51831 0.12729 lineto
0.52441 0.12764 lineto
0.5305 0.12808 lineto
0.53658 0.12863 lineto
0.54871 0.13003 lineto
0.56079 0.13182 lineto
0.5728 0.13401 lineto
0.59658 0.13955 lineto
0.61995 0.14664 lineto
0.6428 0.15524 lineto
0.68658 0.17683 lineto
0.72717 0.20395 lineto
0.76387 0.23613 lineto
0.79605 0.27283 lineto
0.82317 0.31342 lineto
0.83468 0.33495 lineto
0.84476 0.3572 lineto
0.85336 0.38005 lineto
0.86045 0.40342 lineto
0.86599 0.4272 lineto
0.86818 0.43921 lineto
0.86997 0.45129 lineto
0.87137 0.46342 lineto
0.87192 0.4695 lineto
0.87236 0.47559 lineto
0.87271 0.48169 lineto
0.87285 0.48474 lineto
0.87296 0.48779 lineto
0.87305 0.49084 lineto
0.87311 0.49389 lineto
0.87315 0.49695 lineto
0.87316 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.85066 0.62763 lineto
stroke
0.13664 0.41504 moveto
-0.26579 0.26857 lineto
stroke
0.12903 0.45957 moveto
-0.2775 0.31161 lineto
stroke
0.12689 0.50609 moveto
-0.28684 0.3555 lineto
stroke
0.13089 0.55484 moveto
-0.29376 0.40028 lineto
stroke
0.14229 0.60629 moveto
-0.29817 0.44597 lineto
stroke
0.1635 0.6613 moveto
-0.29997 0.49262 lineto
stroke
0.19996 0.72187 moveto
-0.29899 0.54027 lineto
stroke
0.27195 0.79537 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.51516 0.12714 moveto
-0.05182 -0.07922 lineto
stroke
0.41277 0.13717 moveto
-0.08617 -0.04443 lineto
stroke
0.34591 0.16014 moveto
-0.11756 -0.00855 lineto
stroke
0.2943 0.18865 moveto
-0.14616 0.02833 lineto
stroke
0.2525 0.22073 moveto
-0.17215 0.06617 lineto
stroke
0.21809 0.2555 moveto
-0.19564 0.10492 lineto
stroke
0.18984 0.29252 moveto
-0.2167 0.14455 lineto
stroke
0.16704 0.33151 moveto
-0.23539 0.18504 lineto
stroke
0.14934 0.37237 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.83296 0.66849 lineto
stroke
1.26579 0.73143 moveto
0.86336 0.58496 lineto
stroke
1.2167 0.85545 moveto
0.81016 0.70748 lineto
stroke
1.2775 0.68839 moveto
0.87097 0.54043 lineto
stroke
1.19564 0.89508 moveto
0.78191 0.7445 lineto
stroke
1.28684 0.6445 moveto
0.87311 0.49391 lineto
stroke
1.17215 0.93383 moveto
0.7475 0.77927 lineto
stroke
1.29376 0.59972 moveto
0.86911 0.44516 lineto
stroke
1.14616 0.97167 moveto
0.7057 0.81135 lineto
stroke
1.29817 0.55403 moveto
0.85771 0.39371 lineto
stroke
1.11756 1.00855 moveto
0.65409 0.83986 lineto
stroke
1.29997 0.50738 moveto
0.8365 0.3387 lineto
stroke
1.08617 1.04443 moveto
0.58723 0.86283 lineto
stroke
1.29899 0.45973 moveto
0.80004 0.27813 lineto
stroke
1.05182 1.07922 moveto
0.48484 0.87286 lineto
stroke
1.29503 0.41099 moveto
0.72805 0.20463 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48926 0.12699 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48926 0.87301 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.87716 0.5 moveto
0.87715 0.50309 lineto
0.87711 0.50617 lineto
0.87705 0.50926 lineto
0.87696 0.51234 lineto
0.87685 0.51542 lineto
0.87671 0.51851 lineto
0.87636 0.52467 lineto
0.8759 0.53082 lineto
0.87535 0.53697 lineto
0.87394 0.54923 lineto
0.87213 0.56144 lineto
0.86992 0.57358 lineto
0.86431 0.59762 lineto
0.85715 0.62124 lineto
0.84845 0.64433 lineto
0.82663 0.68858 lineto
0.79922 0.7296 lineto
0.7667 0.7667 lineto
0.7296 0.79922 lineto
0.68858 0.82663 lineto
0.66682 0.83827 lineto
0.64433 0.84845 lineto
0.62124 0.85715 lineto
0.59762 0.86431 lineto
0.57358 0.86992 lineto
0.56144 0.87213 lineto
0.54923 0.87394 lineto
0.53697 0.87535 lineto
0.53082 0.8759 lineto
0.52467 0.87636 lineto
0.51851 0.87671 lineto
0.51542 0.87685 lineto
0.51234 0.87696 lineto
0.50926 0.87705 lineto
0.50617 0.87711 lineto
0.50309 0.87715 lineto
0.5 0.87716 lineto
0.49691 0.87715 lineto
0.49383 0.87711 lineto
0.49074 0.87705 lineto
0.48766 0.87696 lineto
0.48149 0.87671 lineto
0.47533 0.87636 lineto
0.46918 0.8759 lineto
0.46303 0.87535 lineto
0.45077 0.87394 lineto
0.43856 0.87213 lineto
0.42642 0.86992 lineto
0.40238 0.86431 lineto
Mistroke
0.37876 0.85715 lineto
0.35567 0.84845 lineto
0.31142 0.82663 lineto
0.2704 0.79922 lineto
0.2333 0.7667 lineto
0.20078 0.7296 lineto
0.17337 0.68858 lineto
0.15155 0.64433 lineto
0.14285 0.62124 lineto
0.13569 0.59762 lineto
0.13008 0.57358 lineto
0.12787 0.56144 lineto
0.12606 0.54923 lineto
0.12465 0.53697 lineto
0.1241 0.53082 lineto
0.12364 0.52467 lineto
0.12329 0.51851 lineto
0.12315 0.51542 lineto
0.12304 0.51234 lineto
0.12295 0.50926 lineto
0.12289 0.50617 lineto
0.12285 0.50309 lineto
0.12284 0.5 lineto
0.12285 0.49691 lineto
0.12289 0.49383 lineto
0.12295 0.49074 lineto
0.12304 0.48766 lineto
0.12329 0.48149 lineto
0.12364 0.47533 lineto
0.1241 0.46918 lineto
0.12465 0.46303 lineto
0.12606 0.45077 lineto
0.12787 0.43856 lineto
0.13008 0.42642 lineto
0.13569 0.40238 lineto
0.14285 0.37876 lineto
0.15155 0.35567 lineto
0.17337 0.31142 lineto
0.20078 0.2704 lineto
0.2333 0.2333 lineto
0.2704 0.20078 lineto
0.31142 0.17337 lineto
0.33318 0.16173 lineto
0.35567 0.15155 lineto
0.37876 0.14285 lineto
0.40238 0.13569 lineto
0.42642 0.13008 lineto
0.43856 0.12787 lineto
0.45077 0.12606 lineto
0.46303 0.12465 lineto
Mistroke
0.46918 0.1241 lineto
0.47533 0.12364 lineto
0.48149 0.12329 lineto
0.48458 0.12315 lineto
0.48766 0.12304 lineto
0.49074 0.12295 lineto
0.49383 0.12289 lineto
0.49691 0.12285 lineto
0.5 0.12284 lineto
0.50309 0.12285 lineto
0.50617 0.12289 lineto
0.50926 0.12295 lineto
0.51234 0.12304 lineto
0.51851 0.12329 lineto
0.52467 0.12364 lineto
0.53082 0.1241 lineto
0.53697 0.12465 lineto
0.54923 0.12606 lineto
0.56144 0.12787 lineto
0.57358 0.13008 lineto
0.59762 0.13569 lineto
0.62124 0.14285 lineto
0.64433 0.15155 lineto
0.68858 0.17337 lineto
0.7296 0.20078 lineto
0.7667 0.2333 lineto
0.79922 0.2704 lineto
0.82663 0.31142 lineto
0.83827 0.33318 lineto
0.84845 0.35567 lineto
0.85715 0.37876 lineto
0.86431 0.40238 lineto
0.86992 0.42642 lineto
0.87213 0.43856 lineto
0.87394 0.45077 lineto
0.87535 0.46303 lineto
0.8759 0.46918 lineto
0.87636 0.47533 lineto
0.87671 0.48149 lineto
0.87685 0.48458 lineto
0.87696 0.48766 lineto
0.87705 0.49074 lineto
0.87711 0.49383 lineto
0.87715 0.49691 lineto
0.87716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.85442 0.629 lineto
stroke
0.13285 0.41367 moveto
-0.26579 0.26857 lineto
stroke
0.12516 0.45816 moveto
-0.2775 0.31161 lineto
stroke
0.12286 0.50462 moveto
-0.28684 0.3555 lineto
stroke
0.12662 0.55329 moveto
-0.29376 0.40028 lineto
stroke
0.13763 0.60459 moveto
-0.29817 0.44597 lineto
stroke
0.15816 0.65936 moveto
-0.29997 0.49262 lineto
stroke
0.19323 0.71942 moveto
-0.29899 0.54027 lineto
stroke
0.26015 0.79108 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.50337 0.12285 moveto
-0.05182 -0.07922 lineto
stroke
0.40605 0.13473 moveto
-0.08617 -0.04443 lineto
stroke
0.34057 0.15819 moveto
-0.11756 -0.00855 lineto
stroke
0.28964 0.18695 moveto
-0.14616 0.02833 lineto
stroke
0.24823 0.21917 moveto
-0.17215 0.06617 lineto
stroke
0.21407 0.25404 moveto
-0.19564 0.10492 lineto
stroke
0.18597 0.29111 moveto
-0.2167 0.14455 lineto
stroke
0.16325 0.33014 moveto
-0.23539 0.18504 lineto
stroke
0.14558 0.371 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.83675 0.66986 lineto
stroke
1.26579 0.73143 moveto
0.86715 0.58633 lineto
stroke
1.2167 0.85545 moveto
0.81403 0.70889 lineto
stroke
1.2775 0.68839 moveto
0.87484 0.54184 lineto
stroke
1.19564 0.89508 moveto
0.78593 0.74596 lineto
stroke
1.28684 0.6445 moveto
0.87714 0.49538 lineto
stroke
1.17215 0.93383 moveto
0.75177 0.78083 lineto
stroke
1.29376 0.59972 moveto
0.87338 0.44671 lineto
stroke
1.14616 0.97167 moveto
0.71036 0.81305 lineto
stroke
1.29817 0.55403 moveto
0.86237 0.39541 lineto
stroke
1.11756 1.00855 moveto
0.65943 0.84181 lineto
stroke
1.29997 0.50738 moveto
0.84184 0.34064 lineto
stroke
1.08617 1.04443 moveto
0.59395 0.86527 lineto
stroke
1.29899 0.45973 moveto
0.80677 0.28058 lineto
stroke
1.05182 1.07922 moveto
0.49663 0.87715 lineto
stroke
1.29503 0.41099 moveto
0.73985 0.20892 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48914 0.12299 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48914 0.87701 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.88116 0.5 moveto
0.88115 0.50312 lineto
0.88111 0.50624 lineto
0.88105 0.50935 lineto
0.88096 0.51247 lineto
0.88084 0.51559 lineto
0.8807 0.5187 lineto
0.88035 0.52493 lineto
0.87989 0.53115 lineto
0.87933 0.53736 lineto
0.8779 0.54975 lineto
0.87607 0.56209 lineto
0.87384 0.57436 lineto
0.86818 0.59865 lineto
0.86094 0.62252 lineto
0.85215 0.64587 lineto
0.8301 0.69058 lineto
0.8024 0.73204 lineto
0.76952 0.76952 lineto
0.73204 0.8024 lineto
0.69058 0.8301 lineto
0.66858 0.84186 lineto
0.64587 0.85215 lineto
0.62252 0.86094 lineto
0.59865 0.86818 lineto
0.57436 0.87384 lineto
0.56209 0.87607 lineto
0.54975 0.8779 lineto
0.53736 0.87933 lineto
0.53115 0.87989 lineto
0.52493 0.88035 lineto
0.5187 0.8807 lineto
0.51559 0.88084 lineto
0.51247 0.88096 lineto
0.50935 0.88105 lineto
0.50624 0.88111 lineto
0.50312 0.88115 lineto
0.5 0.88116 lineto
0.49688 0.88115 lineto
0.49376 0.88111 lineto
0.49065 0.88105 lineto
0.48753 0.88096 lineto
0.4813 0.8807 lineto
0.47507 0.88035 lineto
0.46885 0.87989 lineto
0.46264 0.87933 lineto
0.45025 0.8779 lineto
0.43791 0.87607 lineto
0.42564 0.87384 lineto
0.40135 0.86818 lineto
Mistroke
0.37748 0.86094 lineto
0.35413 0.85215 lineto
0.30942 0.8301 lineto
0.26796 0.8024 lineto
0.23048 0.76952 lineto
0.1976 0.73204 lineto
0.1699 0.69058 lineto
0.14785 0.64587 lineto
0.13906 0.62252 lineto
0.13182 0.59865 lineto
0.12616 0.57436 lineto
0.12393 0.56209 lineto
0.1221 0.54975 lineto
0.12067 0.53736 lineto
0.12011 0.53115 lineto
0.11965 0.52493 lineto
0.1193 0.5187 lineto
0.11916 0.51559 lineto
0.11904 0.51247 lineto
0.11895 0.50935 lineto
0.11889 0.50624 lineto
0.11885 0.50312 lineto
0.11884 0.5 lineto
0.11885 0.49688 lineto
0.11889 0.49376 lineto
0.11895 0.49065 lineto
0.11904 0.48753 lineto
0.1193 0.4813 lineto
0.11965 0.47507 lineto
0.12011 0.46885 lineto
0.12067 0.46264 lineto
0.1221 0.45025 lineto
0.12393 0.43791 lineto
0.12616 0.42564 lineto
0.13182 0.40135 lineto
0.13906 0.37748 lineto
0.14785 0.35413 lineto
0.1699 0.30942 lineto
0.1976 0.26796 lineto
0.23048 0.23048 lineto
0.26796 0.1976 lineto
0.30942 0.1699 lineto
0.33142 0.15814 lineto
0.35413 0.14785 lineto
0.37748 0.13906 lineto
0.40135 0.13182 lineto
0.42564 0.12616 lineto
0.43791 0.12393 lineto
0.45025 0.1221 lineto
0.46264 0.12067 lineto
Mistroke
0.46885 0.12011 lineto
0.47507 0.11965 lineto
0.4813 0.1193 lineto
0.48441 0.11916 lineto
0.48753 0.11904 lineto
0.49065 0.11895 lineto
0.49376 0.11889 lineto
0.49688 0.11885 lineto
0.5 0.11884 lineto
0.50312 0.11885 lineto
0.50624 0.11889 lineto
0.50935 0.11895 lineto
0.51247 0.11904 lineto
0.5187 0.1193 lineto
0.52493 0.11965 lineto
0.53115 0.12011 lineto
0.53736 0.12067 lineto
0.54975 0.1221 lineto
0.56209 0.12393 lineto
0.57436 0.12616 lineto
0.59865 0.13182 lineto
0.62252 0.13906 lineto
0.64587 0.14785 lineto
0.69058 0.1699 lineto
0.73204 0.1976 lineto
0.76952 0.23048 lineto
0.8024 0.26796 lineto
0.8301 0.30942 lineto
0.84186 0.33142 lineto
0.85215 0.35413 lineto
0.86094 0.37748 lineto
0.86818 0.40135 lineto
0.87384 0.42564 lineto
0.87607 0.43791 lineto
0.8779 0.45025 lineto
0.87933 0.46264 lineto
0.87989 0.46885 lineto
0.88035 0.47507 lineto
0.8807 0.4813 lineto
0.88084 0.48441 lineto
0.88096 0.48753 lineto
0.88105 0.49065 lineto
0.88111 0.49376 lineto
0.88115 0.49688 lineto
0.88116 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.85818 0.63037 lineto
stroke
0.12907 0.41229 moveto
-0.26579 0.26857 lineto
stroke
0.1213 0.45676 moveto
-0.2775 0.31161 lineto
stroke
0.11885 0.50316 moveto
-0.28684 0.3555 lineto
stroke
0.12236 0.55174 moveto
-0.29376 0.40028 lineto
stroke
0.13299 0.6029 moveto
-0.29817 0.44597 lineto
stroke
0.15287 0.65744 moveto
-0.29997 0.49262 lineto
stroke
0.18666 0.71703 moveto
-0.29899 0.54027 lineto
stroke
0.24932 0.78714 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.49254 0.11891 moveto
-0.05182 -0.07922 lineto
stroke
0.39947 0.13233 moveto
-0.08617 -0.04443 lineto
stroke
0.33528 0.15627 moveto
-0.11756 -0.00855 lineto
stroke
0.285 0.18526 moveto
-0.14616 0.02833 lineto
stroke
0.24397 0.21763 moveto
-0.17215 0.06617 lineto
stroke
0.21005 0.25258 moveto
-0.19564 0.10492 lineto
stroke
0.1821 0.2897 moveto
-0.2167 0.14455 lineto
stroke
0.15947 0.32876 moveto
-0.23539 0.18504 lineto
stroke
0.14182 0.36963 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.84053 0.67124 lineto
stroke
1.26579 0.73143 moveto
0.87093 0.58771 lineto
stroke
1.2167 0.85545 moveto
0.8179 0.7103 lineto
stroke
1.2775 0.68839 moveto
0.8787 0.54324 lineto
stroke
1.19564 0.89508 moveto
0.78995 0.74742 lineto
stroke
1.28684 0.6445 moveto
0.88115 0.49684 lineto
stroke
1.17215 0.93383 moveto
0.75603 0.78237 lineto
stroke
1.29376 0.59972 moveto
0.87764 0.44826 lineto
stroke
1.14616 0.97167 moveto
0.715 0.81474 lineto
stroke
1.29817 0.55403 moveto
0.86701 0.3971 lineto
stroke
1.11756 1.00855 moveto
0.66472 0.84373 lineto
stroke
1.29997 0.50738 moveto
0.84713 0.34256 lineto
stroke
1.08617 1.04443 moveto
0.60053 0.86767 lineto
stroke
1.29899 0.45973 moveto
0.81334 0.28297 lineto
stroke
1.05182 1.07922 moveto
0.50746 0.88109 lineto
stroke
1.29503 0.41099 moveto
0.75068 0.21286 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48903 0.11899 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48903 0.88101 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.88516 0.5 moveto
0.88515 0.50315 lineto
0.88511 0.5063 lineto
0.88505 0.50945 lineto
0.88496 0.5126 lineto
0.88484 0.51575 lineto
0.8847 0.5189 lineto
0.88434 0.52519 lineto
0.88388 0.53148 lineto
0.88331 0.53775 lineto
0.88187 0.55027 lineto
0.88002 0.56274 lineto
0.87776 0.57514 lineto
0.87204 0.59969 lineto
0.86472 0.62381 lineto
0.85584 0.6474 lineto
0.83356 0.69258 lineto
0.80557 0.73447 lineto
0.77235 0.77235 lineto
0.73447 0.80557 lineto
0.69258 0.83356 lineto
0.67035 0.84544 lineto
0.6474 0.85584 lineto
0.62381 0.86472 lineto
0.59969 0.87204 lineto
0.57514 0.87776 lineto
0.56274 0.88002 lineto
0.55027 0.88187 lineto
0.53775 0.88331 lineto
0.53148 0.88388 lineto
0.52519 0.88434 lineto
0.5189 0.8847 lineto
0.51575 0.88484 lineto
0.5126 0.88496 lineto
0.50945 0.88505 lineto
0.5063 0.88511 lineto
0.50315 0.88515 lineto
0.5 0.88516 lineto
0.49685 0.88515 lineto
0.4937 0.88511 lineto
0.49055 0.88505 lineto
0.4874 0.88496 lineto
0.4811 0.8847 lineto
0.47481 0.88434 lineto
0.46852 0.88388 lineto
0.46225 0.88331 lineto
0.44973 0.88187 lineto
0.43726 0.88002 lineto
0.42486 0.87776 lineto
0.40031 0.87204 lineto
Mistroke
0.37619 0.86472 lineto
0.3526 0.85584 lineto
0.30742 0.83356 lineto
0.26553 0.80557 lineto
0.22765 0.77235 lineto
0.19443 0.73447 lineto
0.16644 0.69258 lineto
0.14416 0.6474 lineto
0.13528 0.62381 lineto
0.12796 0.59969 lineto
0.12224 0.57514 lineto
0.11998 0.56274 lineto
0.11813 0.55027 lineto
0.11669 0.53775 lineto
0.11612 0.53148 lineto
0.11566 0.52519 lineto
0.1153 0.5189 lineto
0.11516 0.51575 lineto
0.11504 0.5126 lineto
0.11495 0.50945 lineto
0.11489 0.5063 lineto
0.11485 0.50315 lineto
0.11484 0.5 lineto
0.11485 0.49685 lineto
0.11489 0.4937 lineto
0.11495 0.49055 lineto
0.11504 0.4874 lineto
0.1153 0.4811 lineto
0.11566 0.47481 lineto
0.11612 0.46852 lineto
0.11669 0.46225 lineto
0.11813 0.44973 lineto
0.11998 0.43726 lineto
0.12224 0.42486 lineto
0.12796 0.40031 lineto
0.13528 0.37619 lineto
0.14416 0.3526 lineto
0.16644 0.30742 lineto
0.19443 0.26553 lineto
0.22765 0.22765 lineto
0.26553 0.19443 lineto
0.30742 0.16644 lineto
0.32965 0.15456 lineto
0.3526 0.14416 lineto
0.37619 0.13528 lineto
0.40031 0.12796 lineto
0.42486 0.12224 lineto
0.43726 0.11998 lineto
0.44973 0.11813 lineto
0.46225 0.11669 lineto
Mistroke
0.46852 0.11612 lineto
0.47481 0.11566 lineto
0.4811 0.1153 lineto
0.48425 0.11516 lineto
0.4874 0.11504 lineto
0.49055 0.11495 lineto
0.4937 0.11489 lineto
0.49685 0.11485 lineto
0.5 0.11484 lineto
0.50315 0.11485 lineto
0.5063 0.11489 lineto
0.50945 0.11495 lineto
0.5126 0.11504 lineto
0.5189 0.1153 lineto
0.52519 0.11566 lineto
0.53148 0.11612 lineto
0.53775 0.11669 lineto
0.55027 0.11813 lineto
0.56274 0.11998 lineto
0.57514 0.12224 lineto
0.59969 0.12796 lineto
0.62381 0.13528 lineto
0.6474 0.14416 lineto
0.69258 0.16644 lineto
0.73447 0.19443 lineto
0.77235 0.22765 lineto
0.80557 0.26553 lineto
0.83356 0.30742 lineto
0.84544 0.32965 lineto
0.85584 0.3526 lineto
0.86472 0.37619 lineto
0.87204 0.40031 lineto
0.87776 0.42486 lineto
0.88002 0.43726 lineto
0.88187 0.44973 lineto
0.88331 0.46225 lineto
0.88388 0.46852 lineto
0.88434 0.47481 lineto
0.8847 0.4811 lineto
0.88484 0.48425 lineto
0.88496 0.4874 lineto
0.88505 0.49055 lineto
0.88511 0.4937 lineto
0.88515 0.49685 lineto
0.88516 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.86194 0.63173 lineto
stroke
0.12528 0.41091 moveto
-0.26579 0.26857 lineto
stroke
0.11743 0.45535 moveto
-0.2775 0.31161 lineto
stroke
0.11484 0.5017 moveto
-0.28684 0.3555 lineto
stroke
0.11812 0.55019 moveto
-0.29376 0.40028 lineto
stroke
0.12838 0.60122 moveto
-0.29817 0.44597 lineto
stroke
0.14763 0.65553 moveto
-0.29997 0.49262 lineto
stroke
0.18022 0.71469 moveto
-0.29899 0.54027 lineto
stroke
0.23923 0.78346 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.48245 0.11524 moveto
-0.05182 -0.07922 lineto
stroke
0.39303 0.12999 moveto
-0.08617 -0.04443 lineto
stroke
0.33005 0.15436 moveto
-0.11756 -0.00855 lineto
stroke
0.28038 0.18358 moveto
-0.14616 0.02833 lineto
stroke
0.23973 0.21608 moveto
-0.17215 0.06617 lineto
stroke
0.20605 0.25112 moveto
-0.19564 0.10492 lineto
stroke
0.17824 0.28829 moveto
-0.2167 0.14455 lineto
stroke
0.15568 0.32738 moveto
-0.23539 0.18504 lineto
stroke
0.13806 0.36827 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.84432 0.67262 lineto
stroke
1.26579 0.73143 moveto
0.87472 0.58909 lineto
stroke
1.2167 0.85545 moveto
0.82176 0.71171 lineto
stroke
1.2775 0.68839 moveto
0.88257 0.54465 lineto
stroke
1.19564 0.89508 moveto
0.79395 0.74888 lineto
stroke
1.28684 0.6445 moveto
0.88516 0.4983 lineto
stroke
1.17215 0.93383 moveto
0.76027 0.78392 lineto
stroke
1.29376 0.59972 moveto
0.88188 0.44981 lineto
stroke
1.14616 0.97167 moveto
0.71962 0.81642 lineto
stroke
1.29817 0.55403 moveto
0.87162 0.39878 lineto
stroke
1.11756 1.00855 moveto
0.66995 0.84564 lineto
stroke
1.29997 0.50738 moveto
0.85237 0.34447 lineto
stroke
1.08617 1.04443 moveto
0.60697 0.87001 lineto
stroke
1.29899 0.45973 moveto
0.81978 0.28531 lineto
stroke
1.05182 1.07922 moveto
0.51755 0.88476 lineto
stroke
1.29503 0.41099 moveto
0.76077 0.21654 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48891 0.115 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48891 0.885 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.88916 0.5 moveto
0.88915 0.50318 lineto
0.88911 0.50637 lineto
0.88905 0.50955 lineto
0.88896 0.51273 lineto
0.88884 0.51591 lineto
0.8887 0.5191 lineto
0.88833 0.52545 lineto
0.88786 0.5318 lineto
0.88729 0.53814 lineto
0.88583 0.5508 lineto
0.88397 0.56339 lineto
0.88169 0.57592 lineto
0.8759 0.60072 lineto
0.86851 0.62509 lineto
0.85954 0.64893 lineto
0.83703 0.69458 lineto
0.80874 0.73691 lineto
0.77518 0.77518 lineto
0.73691 0.80874 lineto
0.69458 0.83703 lineto
0.67212 0.84903 lineto
0.64893 0.85954 lineto
0.62509 0.86851 lineto
0.60072 0.8759 lineto
0.57592 0.88169 lineto
0.56339 0.88397 lineto
0.5508 0.88583 lineto
0.53814 0.88729 lineto
0.5318 0.88786 lineto
0.52545 0.88833 lineto
0.5191 0.8887 lineto
0.51591 0.88884 lineto
0.51273 0.88896 lineto
0.50955 0.88905 lineto
0.50637 0.88911 lineto
0.50318 0.88915 lineto
0.5 0.88916 lineto
0.49682 0.88915 lineto
0.49363 0.88911 lineto
0.49045 0.88905 lineto
0.48727 0.88896 lineto
0.4809 0.8887 lineto
0.47455 0.88833 lineto
0.4682 0.88786 lineto
0.46186 0.88729 lineto
0.4492 0.88583 lineto
0.43661 0.88397 lineto
0.42408 0.88169 lineto
0.39928 0.8759 lineto
Mistroke
0.37491 0.86851 lineto
0.35107 0.85954 lineto
0.30542 0.83703 lineto
0.26309 0.80874 lineto
0.22482 0.77518 lineto
0.19126 0.73691 lineto
0.16297 0.69458 lineto
0.14046 0.64893 lineto
0.13149 0.62509 lineto
0.1241 0.60072 lineto
0.11831 0.57592 lineto
0.11603 0.56339 lineto
0.11417 0.5508 lineto
0.11271 0.53814 lineto
0.11214 0.5318 lineto
0.11167 0.52545 lineto
0.1113 0.5191 lineto
0.11116 0.51591 lineto
0.11104 0.51273 lineto
0.11095 0.50955 lineto
0.11089 0.50637 lineto
0.11085 0.50318 lineto
0.11084 0.5 lineto
0.11085 0.49682 lineto
0.11089 0.49363 lineto
0.11095 0.49045 lineto
0.11104 0.48727 lineto
0.1113 0.4809 lineto
0.11167 0.47455 lineto
0.11214 0.4682 lineto
0.11271 0.46186 lineto
0.11417 0.4492 lineto
0.11603 0.43661 lineto
0.11831 0.42408 lineto
0.1241 0.39928 lineto
0.13149 0.37491 lineto
0.14046 0.35107 lineto
0.16297 0.30542 lineto
0.19126 0.26309 lineto
0.22482 0.22482 lineto
0.26309 0.19126 lineto
0.30542 0.16297 lineto
0.32788 0.15097 lineto
0.35107 0.14046 lineto
0.37491 0.13149 lineto
0.39928 0.1241 lineto
0.42408 0.11831 lineto
0.43661 0.11603 lineto
0.4492 0.11417 lineto
0.46186 0.11271 lineto
Mistroke
0.4682 0.11214 lineto
0.47455 0.11167 lineto
0.4809 0.1113 lineto
0.48409 0.11116 lineto
0.48727 0.11104 lineto
0.49045 0.11095 lineto
0.49363 0.11089 lineto
0.49682 0.11085 lineto
0.5 0.11084 lineto
0.50318 0.11085 lineto
0.50637 0.11089 lineto
0.50955 0.11095 lineto
0.51273 0.11104 lineto
0.5191 0.1113 lineto
0.52545 0.11167 lineto
0.5318 0.11214 lineto
0.53814 0.11271 lineto
0.5508 0.11417 lineto
0.56339 0.11603 lineto
0.57592 0.11831 lineto
0.60072 0.1241 lineto
0.62509 0.13149 lineto
0.64893 0.14046 lineto
0.69458 0.16297 lineto
0.73691 0.19126 lineto
0.77518 0.22482 lineto
0.80874 0.26309 lineto
0.83703 0.30542 lineto
0.84903 0.32788 lineto
0.85954 0.35107 lineto
0.86851 0.37491 lineto
0.8759 0.39928 lineto
0.88169 0.42408 lineto
0.88397 0.43661 lineto
0.88583 0.4492 lineto
0.88729 0.46186 lineto
0.88786 0.4682 lineto
0.88833 0.47455 lineto
0.8887 0.4809 lineto
0.88884 0.48409 lineto
0.88896 0.48727 lineto
0.88905 0.49045 lineto
0.88911 0.49363 lineto
0.88915 0.49682 lineto
0.88916 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.86569 0.6331 lineto
stroke
0.1215 0.40953 moveto
-0.26579 0.26857 lineto
stroke
0.11357 0.45394 moveto
-0.2775 0.31161 lineto
stroke
0.11084 0.50025 moveto
-0.28684 0.3555 lineto
stroke
0.11389 0.54865 moveto
-0.29376 0.40028 lineto
stroke
0.12379 0.59955 moveto
-0.29817 0.44597 lineto
stroke
0.14245 0.65364 moveto
-0.29997 0.49262 lineto
stroke
0.1739 0.71239 moveto
-0.29899 0.54027 lineto
stroke
0.22973 0.78 moveto
-0.29503 0.58901 lineto
stroke
1.01423 1.11284 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
1.28785 0.36108 moveto
-0.01423 -0.11284 lineto
stroke
0.47294 0.11178 moveto
-0.05182 -0.07922 lineto
stroke
0.38671 0.12769 moveto
-0.08617 -0.04443 lineto
stroke
0.32486 0.15247 moveto
-0.11756 -0.00855 lineto
stroke
0.27579 0.18191 moveto
-0.14616 0.02833 lineto
stroke
0.2355 0.21454 moveto
-0.17215 0.06617 lineto
stroke
0.20204 0.24966 moveto
-0.19564 0.10492 lineto
stroke
0.17437 0.28689 moveto
-0.2167 0.14455 lineto
stroke
0.1519 0.326 moveto
-0.23539 0.18504 lineto
stroke
0.13431 0.3669 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.8481 0.674 lineto
stroke
1.26579 0.73143 moveto
0.8785 0.59047 lineto
stroke
1.2167 0.85545 moveto
0.82563 0.71311 lineto
stroke
1.2775 0.68839 moveto
0.88643 0.54606 lineto
stroke
1.19564 0.89508 moveto
0.79796 0.75034 lineto
stroke
1.28684 0.6445 moveto
0.88916 0.49975 lineto
stroke
1.17215 0.93383 moveto
0.7645 0.78546 lineto
stroke
1.29376 0.59972 moveto
0.88611 0.45135 lineto
stroke
1.14616 0.97167 moveto
0.72421 0.81809 lineto
stroke
1.29817 0.55403 moveto
0.87621 0.40045 lineto
stroke
1.11756 1.00855 moveto
0.67514 0.84753 lineto
stroke
1.29997 0.50738 moveto
0.85755 0.34636 lineto
stroke
1.08617 1.04443 moveto
0.61329 0.87231 lineto
stroke
1.29899 0.45973 moveto
0.8261 0.28761 lineto
stroke
1.05182 1.07922 moveto
0.52706 0.88822 lineto
stroke
1.29503 0.41099 moveto
0.77027 0.22 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48879 0.111 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48879 0.889 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.89316 0.5 moveto
0.89315 0.50322 lineto
0.89311 0.50643 lineto
0.89305 0.50965 lineto
0.89295 0.51286 lineto
0.89283 0.51608 lineto
0.89269 0.51929 lineto
0.89232 0.52571 lineto
0.89185 0.53213 lineto
0.89127 0.53854 lineto
0.8898 0.55132 lineto
0.88791 0.56404 lineto
0.88561 0.5767 lineto
0.87977 0.60176 lineto
0.8723 0.62638 lineto
0.86324 0.65046 lineto
0.84049 0.69658 lineto
0.81192 0.73934 lineto
0.77801 0.77801 lineto
0.73934 0.81192 lineto
0.69658 0.84049 lineto
0.67389 0.85262 lineto
0.65046 0.86324 lineto
0.62638 0.8723 lineto
0.60176 0.87977 lineto
0.5767 0.88561 lineto
0.56404 0.88791 lineto
0.55132 0.8898 lineto
0.53854 0.89127 lineto
0.53213 0.89185 lineto
0.52571 0.89232 lineto
0.51929 0.89269 lineto
0.51608 0.89283 lineto
0.51286 0.89295 lineto
0.50965 0.89305 lineto
0.50643 0.89311 lineto
0.50322 0.89315 lineto
0.5 0.89316 lineto
0.49678 0.89315 lineto
0.49357 0.89311 lineto
0.49035 0.89305 lineto
0.48714 0.89295 lineto
0.48071 0.89269 lineto
0.47429 0.89232 lineto
0.46787 0.89185 lineto
0.46146 0.89127 lineto
0.44868 0.8898 lineto
0.43596 0.88791 lineto
0.4233 0.88561 lineto
0.39824 0.87977 lineto
Mistroke
0.37362 0.8723 lineto
0.34954 0.86324 lineto
0.30342 0.84049 lineto
0.26066 0.81192 lineto
0.22199 0.77801 lineto
0.18808 0.73934 lineto
0.15951 0.69658 lineto
0.13676 0.65046 lineto
0.1277 0.62638 lineto
0.12023 0.60176 lineto
0.11439 0.5767 lineto
0.11209 0.56404 lineto
0.1102 0.55132 lineto
0.10873 0.53854 lineto
0.10815 0.53213 lineto
0.10768 0.52571 lineto
0.10731 0.51929 lineto
0.10717 0.51608 lineto
0.10705 0.51286 lineto
0.10695 0.50965 lineto
0.10689 0.50643 lineto
0.10685 0.50322 lineto
0.10684 0.5 lineto
0.10685 0.49678 lineto
0.10689 0.49357 lineto
0.10695 0.49035 lineto
0.10705 0.48714 lineto
0.10731 0.48071 lineto
0.10768 0.47429 lineto
0.10815 0.46787 lineto
0.10873 0.46146 lineto
0.1102 0.44868 lineto
0.11209 0.43596 lineto
0.11439 0.4233 lineto
0.12023 0.39824 lineto
0.1277 0.37362 lineto
0.13676 0.34954 lineto
0.15951 0.30342 lineto
0.18808 0.26066 lineto
0.22199 0.22199 lineto
0.26066 0.18808 lineto
0.30342 0.15951 lineto
0.32611 0.14738 lineto
0.34954 0.13676 lineto
0.37362 0.1277 lineto
0.39824 0.12023 lineto
0.4233 0.11439 lineto
0.43596 0.11209 lineto
0.44868 0.1102 lineto
0.46146 0.10873 lineto
Mistroke
0.46787 0.10815 lineto
0.47429 0.10768 lineto
0.48071 0.10731 lineto
0.48392 0.10717 lineto
0.48714 0.10705 lineto
0.49035 0.10695 lineto
0.49357 0.10689 lineto
0.49678 0.10685 lineto
0.5 0.10684 lineto
0.50322 0.10685 lineto
0.50643 0.10689 lineto
0.50965 0.10695 lineto
0.51286 0.10705 lineto
0.51929 0.10731 lineto
0.52571 0.10768 lineto
0.53213 0.10815 lineto
0.53854 0.10873 lineto
0.55132 0.1102 lineto
0.56404 0.11209 lineto
0.5767 0.11439 lineto
0.60176 0.12023 lineto
0.62638 0.1277 lineto
0.65046 0.13676 lineto
0.69658 0.15951 lineto
0.73934 0.18808 lineto
0.77801 0.22199 lineto
0.81192 0.26066 lineto
0.84049 0.30342 lineto
0.85262 0.32611 lineto
0.86324 0.34954 lineto
0.8723 0.37362 lineto
0.87977 0.39824 lineto
0.88561 0.4233 lineto
0.88791 0.43596 lineto
0.8898 0.44868 lineto
0.89127 0.46146 lineto
0.89185 0.46787 lineto
0.89232 0.47429 lineto
0.89269 0.48071 lineto
0.89283 0.48392 lineto
0.89295 0.48714 lineto
0.89305 0.49035 lineto
0.89311 0.49357 lineto
0.89315 0.49678 lineto
0.89316 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.86945 0.63447 lineto
stroke
0.11771 0.40816 moveto
-0.26579 0.26857 lineto
stroke
0.10971 0.45254 moveto
-0.2775 0.31161 lineto
stroke
0.10684 0.49879 moveto
-0.28684 0.3555 lineto
stroke
0.10967 0.54712 moveto
-0.29376 0.40028 lineto
stroke
0.11922 0.59789 moveto
-0.29817 0.44597 lineto
stroke
0.13731 0.65177 moveto
-0.29997 0.49262 lineto
stroke
0.1677 0.71013 moveto
-0.29899 0.54027 lineto
stroke
0.22071 0.77672 moveto
-0.29503 0.58901 lineto
stroke
0.36319 0.87588 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
0.63681 0.12412 moveto
-0.01423 -0.11284 lineto
stroke
0.46392 0.10849 moveto
-0.05182 -0.07922 lineto
stroke
0.38051 0.12543 moveto
-0.08617 -0.04443 lineto
stroke
0.31972 0.1506 moveto
-0.11756 -0.00855 lineto
stroke
0.27123 0.18025 moveto
-0.14616 0.02833 lineto
stroke
0.23128 0.21301 moveto
-0.17215 0.06617 lineto
stroke
0.19804 0.24821 moveto
-0.19564 0.10492 lineto
stroke
0.17051 0.28548 moveto
-0.2167 0.14455 lineto
stroke
0.14812 0.32463 moveto
-0.23539 0.18504 lineto
stroke
0.13055 0.36553 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.85188 0.67537 lineto
stroke
1.26579 0.73143 moveto
0.88229 0.59184 lineto
stroke
1.2167 0.85545 moveto
0.82949 0.71452 lineto
stroke
1.2775 0.68839 moveto
0.89029 0.54746 lineto
stroke
1.19564 0.89508 moveto
0.80196 0.75179 lineto
stroke
1.28684 0.6445 moveto
0.89316 0.50121 lineto
stroke
1.17215 0.93383 moveto
0.76872 0.78699 lineto
stroke
1.29376 0.59972 moveto
0.89033 0.45288 lineto
stroke
1.14616 0.97167 moveto
0.72877 0.81975 lineto
stroke
1.29817 0.55403 moveto
0.88078 0.40211 lineto
stroke
1.11756 1.00855 moveto
0.68028 0.8494 lineto
stroke
1.29997 0.50738 moveto
0.86269 0.34823 lineto
stroke
1.08617 1.04443 moveto
0.61949 0.87457 lineto
stroke
1.29899 0.45973 moveto
0.8323 0.28987 lineto
stroke
1.05182 1.07922 moveto
0.53608 0.89151 lineto
stroke
1.29503 0.41099 moveto
0.77929 0.22328 lineto
stroke
1.01423 1.11284 moveto
0.36319 0.87588 lineto
stroke
1.28785 0.36108 moveto
0.63681 0.12412 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48868 0.107 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48868 0.893 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 282; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
% Scaling calculations
0.5 0.4 0.5 0.4 [
[(-1)] 0.1 0.4875 0 1 Msboxa
[(-0.5)] 0.3 0.4875 0 1 Msboxa
[(0.5)] 0.7 0.4875 0 1 Msboxa
[(1)] 0.9 0.4875 0 1 Msboxa
[(Re z)] 1.00625 0.5 -1 0 Msboxa
[(-1)] 0.4875 0.1 1 0 Msboxa
[(-0.5)] 0.4875 0.3 1 0 Msboxa
[(0.5)] 0.4875 0.7 1 0 Msboxa
[(1)] 0.4875 0.9 1 0 Msboxa
[(Im z)] 0.5 1.00625 0 -1 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
gsave
gsave
0.002 setlinewidth
0 0.5 moveto
1 0.5 lineto
stroke
0.1 0.49375 moveto
0.1 0.50625 lineto
stroke
0 setgray
[(-1)] 0.1 0.4875 0 1 Mshowa
0.3 0.49375 moveto
0.3 0.50625 lineto
stroke
0 setgray
[(-0.5)] 0.3 0.4875 0 1 Mshowa
0.7 0.49375 moveto
0.7 0.50625 lineto
stroke
0 setgray
[(0.5)] 0.7 0.4875 0 1 Mshowa
0.9 0.49375 moveto
0.9 0.50625 lineto
stroke
0 setgray
[(1)] 0.9 0.4875 0 1 Mshowa
0 setgray
[(Re z)] 1.00625 0.5 -1 0 Mshowa
0.5 0 moveto
0.5 1 lineto
stroke
0.49375 0.1 moveto
0.50625 0.1 lineto
stroke
0 setgray
[(-1)] 0.4875 0.1 1 0 Mshowa
0.49375 0.3 moveto
0.50625 0.3 lineto
stroke
0 setgray
[(-0.5)] 0.4875 0.3 1 0 Mshowa
0.49375 0.7 moveto
0.50625 0.7 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.7 1 0 Mshowa
0.49375 0.9 moveto
0.50625 0.9 lineto
stroke
0 setgray
[(1)] 0.4875 0.9 1 0 Mshowa
0 setgray
[(Im z)] 0.5 1.00625 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 1 lineto
0 1 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
gsave
gsave
0.004 setlinewidth
0.9 0.5 moveto
0.89999 0.50327 lineto
0.89995 0.50654 lineto
0.89988 0.50982 lineto
0.89979 0.51309 lineto
0.89967 0.51636 lineto
0.89952 0.51963 lineto
0.89914 0.52616 lineto
0.89866 0.53269 lineto
0.89807 0.53921 lineto
0.89658 0.55221 lineto
0.89466 0.56516 lineto
0.89231 0.57804 lineto
0.88637 0.60353 lineto
0.87877 0.62858 lineto
0.86955 0.65307 lineto
0.84641 0.7 lineto
0.81734 0.7435 lineto
0.78284 0.78284 lineto
0.7435 0.81734 lineto
0.7 0.84641 lineto
0.67692 0.85875 lineto
0.65307 0.86955 lineto
0.62858 0.87877 lineto
0.60353 0.88637 lineto
0.57804 0.89231 lineto
0.56516 0.89466 lineto
0.55221 0.89658 lineto
0.53921 0.89807 lineto
0.53269 0.89866 lineto
0.52616 0.89914 lineto
0.51963 0.89952 lineto
0.51636 0.89967 lineto
0.51309 0.89979 lineto
0.50982 0.89988 lineto
0.50654 0.89995 lineto
0.50327 0.89999 lineto
0.5 0.9 lineto
0.49673 0.89999 lineto
0.49346 0.89995 lineto
0.49018 0.89988 lineto
0.48691 0.89979 lineto
0.48037 0.89952 lineto
0.47384 0.89914 lineto
0.46731 0.89866 lineto
0.46079 0.89807 lineto
0.44779 0.89658 lineto
0.43484 0.89466 lineto
0.42196 0.89231 lineto
0.39647 0.88637 lineto
Mistroke
0.37142 0.87877 lineto
0.34693 0.86955 lineto
0.3 0.84641 lineto
0.2565 0.81734 lineto
0.21716 0.78284 lineto
0.18266 0.7435 lineto
0.15359 0.7 lineto
0.13045 0.65307 lineto
0.12123 0.62858 lineto
0.11363 0.60353 lineto
0.10769 0.57804 lineto
0.10534 0.56516 lineto
0.10342 0.55221 lineto
0.10193 0.53921 lineto
0.10134 0.53269 lineto
0.10086 0.52616 lineto
0.10048 0.51963 lineto
0.10033 0.51636 lineto
0.10021 0.51309 lineto
0.10012 0.50982 lineto
0.10005 0.50654 lineto
0.10001 0.50327 lineto
0.1 0.5 lineto
0.10001 0.49673 lineto
0.10005 0.49346 lineto
0.10012 0.49018 lineto
0.10021 0.48691 lineto
0.10048 0.48037 lineto
0.10086 0.47384 lineto
0.10134 0.46731 lineto
0.10193 0.46079 lineto
0.10342 0.44779 lineto
0.10534 0.43484 lineto
0.10769 0.42196 lineto
0.11363 0.39647 lineto
0.12123 0.37142 lineto
0.13045 0.34693 lineto
0.15359 0.3 lineto
0.18266 0.2565 lineto
0.21716 0.21716 lineto
0.2565 0.18266 lineto
0.3 0.15359 lineto
0.32308 0.14125 lineto
0.34693 0.13045 lineto
0.37142 0.12123 lineto
0.39647 0.11363 lineto
0.42196 0.10769 lineto
0.43484 0.10534 lineto
0.44779 0.10342 lineto
0.46079 0.10193 lineto
Mistroke
0.46731 0.10134 lineto
0.47384 0.10086 lineto
0.48037 0.10048 lineto
0.48364 0.10033 lineto
0.48691 0.10021 lineto
0.49018 0.10012 lineto
0.49346 0.10005 lineto
0.49673 0.10001 lineto
0.5 0.1 lineto
0.50327 0.10001 lineto
0.50654 0.10005 lineto
0.50982 0.10012 lineto
0.51309 0.10021 lineto
0.51963 0.10048 lineto
0.52616 0.10086 lineto
0.53269 0.10134 lineto
0.53921 0.10193 lineto
0.55221 0.10342 lineto
0.56516 0.10534 lineto
0.57804 0.10769 lineto
0.60353 0.11363 lineto
0.62858 0.12123 lineto
0.65307 0.13045 lineto
0.7 0.15359 lineto
0.7435 0.18266 lineto
0.78284 0.21716 lineto
0.81734 0.2565 lineto
0.84641 0.3 lineto
0.85875 0.32308 lineto
0.86955 0.34693 lineto
0.87877 0.37142 lineto
0.88637 0.39647 lineto
0.89231 0.42196 lineto
0.89466 0.43484 lineto
0.89658 0.44779 lineto
0.89807 0.46079 lineto
0.89866 0.46731 lineto
0.89914 0.47384 lineto
0.89952 0.48037 lineto
0.89967 0.48364 lineto
0.89979 0.48691 lineto
0.89988 0.49018 lineto
0.89995 0.49346 lineto
0.89999 0.49673 lineto
0.9 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
gsave
[ 0.05 0.05 ] 0 setdash
gsave
0.004 setlinewidth
0.89716 0.5 moveto
0.89715 0.50325 lineto
0.89711 0.5065 lineto
0.89704 0.50975 lineto
0.89695 0.51299 lineto
0.89683 0.51624 lineto
0.89669 0.51949 lineto
0.89631 0.52598 lineto
0.89584 0.53246 lineto
0.89525 0.53893 lineto
0.89377 0.55184 lineto
0.89186 0.5647 lineto
0.88953 0.57748 lineto
0.88363 0.60279 lineto
0.87609 0.62766 lineto
0.86693 0.65199 lineto
0.84395 0.69858 lineto
0.81509 0.74178 lineto
0.78084 0.78084 lineto
0.74178 0.81509 lineto
0.69858 0.84395 lineto
0.67566 0.85621 lineto
0.65199 0.86693 lineto
0.62766 0.87609 lineto
0.60279 0.88363 lineto
0.57748 0.88953 lineto
0.5647 0.89186 lineto
0.55184 0.89377 lineto
0.53893 0.89525 lineto
0.53246 0.89584 lineto
0.52598 0.89631 lineto
0.51949 0.89669 lineto
0.51624 0.89683 lineto
0.51299 0.89695 lineto
0.50975 0.89704 lineto
0.5065 0.89711 lineto
0.50325 0.89715 lineto
0.5 0.89716 lineto
0.49675 0.89715 lineto
0.4935 0.89711 lineto
0.49025 0.89704 lineto
0.48701 0.89695 lineto
0.48051 0.89669 lineto
0.47402 0.89631 lineto
0.46754 0.89584 lineto
0.46107 0.89525 lineto
0.44816 0.89377 lineto
0.4353 0.89186 lineto
0.42252 0.88953 lineto
0.39721 0.88363 lineto
Mistroke
0.37234 0.87609 lineto
0.34801 0.86693 lineto
0.30142 0.84395 lineto
0.25822 0.81509 lineto
0.21916 0.78084 lineto
0.18491 0.74178 lineto
0.15605 0.69858 lineto
0.13307 0.65199 lineto
0.12391 0.62766 lineto
0.11637 0.60279 lineto
0.11047 0.57748 lineto
0.10814 0.5647 lineto
0.10623 0.55184 lineto
0.10475 0.53893 lineto
0.10416 0.53246 lineto
0.10369 0.52598 lineto
0.10331 0.51949 lineto
0.10317 0.51624 lineto
0.10305 0.51299 lineto
0.10296 0.50975 lineto
0.10289 0.5065 lineto
0.10285 0.50325 lineto
0.10284 0.5 lineto
0.10285 0.49675 lineto
0.10289 0.4935 lineto
0.10296 0.49025 lineto
0.10305 0.48701 lineto
0.10331 0.48051 lineto
0.10369 0.47402 lineto
0.10416 0.46754 lineto
0.10475 0.46107 lineto
0.10623 0.44816 lineto
0.10814 0.4353 lineto
0.11047 0.42252 lineto
0.11637 0.39721 lineto
0.12391 0.37234 lineto
0.13307 0.34801 lineto
0.15605 0.30142 lineto
0.18491 0.25822 lineto
0.21916 0.21916 lineto
0.25822 0.18491 lineto
0.30142 0.15605 lineto
0.32434 0.14379 lineto
0.34801 0.13307 lineto
0.37234 0.12391 lineto
0.39721 0.11637 lineto
0.42252 0.11047 lineto
0.4353 0.10814 lineto
0.44816 0.10623 lineto
0.46107 0.10475 lineto
Mistroke
0.46754 0.10416 lineto
0.47402 0.10369 lineto
0.48051 0.10331 lineto
0.48376 0.10317 lineto
0.48701 0.10305 lineto
0.49025 0.10296 lineto
0.4935 0.10289 lineto
0.49675 0.10285 lineto
0.5 0.10284 lineto
0.50325 0.10285 lineto
0.5065 0.10289 lineto
0.50975 0.10296 lineto
0.51299 0.10305 lineto
0.51949 0.10331 lineto
0.52598 0.10369 lineto
0.53246 0.10416 lineto
0.53893 0.10475 lineto
0.55184 0.10623 lineto
0.5647 0.10814 lineto
0.57748 0.11047 lineto
0.60279 0.11637 lineto
0.62766 0.12391 lineto
0.65199 0.13307 lineto
0.69858 0.15605 lineto
0.74178 0.18491 lineto
0.78084 0.21916 lineto
0.81509 0.25822 lineto
0.84395 0.30142 lineto
0.85621 0.32434 lineto
0.86693 0.34801 lineto
0.87609 0.37234 lineto
0.88363 0.39721 lineto
0.88953 0.42252 lineto
0.89186 0.4353 lineto
0.89377 0.44816 lineto
0.89525 0.46107 lineto
0.89584 0.46754 lineto
0.89631 0.47402 lineto
0.89669 0.48051 lineto
0.89683 0.48376 lineto
0.89695 0.48701 lineto
0.89704 0.49025 lineto
0.89711 0.4935 lineto
0.89715 0.49675 lineto
0.89716 0.5 lineto
Mfstroke
grestore
grestore
grestore
gsave
0.008 setlinewidth
0.5 0.5 Mdot
grestore
gsave
gsave
0.004 setlinewidth
1.25175 0.77362 moveto
0.87321 0.63584 lineto
stroke
0.11393 0.40678 moveto
-0.26579 0.26857 lineto
stroke
0.10585 0.45114 moveto
-0.2775 0.31161 lineto
stroke
0.10285 0.49734 moveto
-0.28684 0.3555 lineto
stroke
0.10546 0.54559 moveto
-0.29376 0.40028 lineto
stroke
0.11467 0.59624 moveto
-0.29817 0.44597 lineto
stroke
0.13222 0.64992 moveto
-0.29997 0.49262 lineto
stroke
0.1616 0.70791 moveto
-0.29899 0.54027 lineto
stroke
0.21209 0.77358 moveto
-0.29503 0.58901 lineto
stroke
0.36319 0.87588 moveto
-0.28785 0.63892 lineto
stroke
0.97306 1.14515 moveto
-0.27708 0.69013 lineto
stroke
0.92784 1.17598 moveto
-0.26226 0.74283 lineto
stroke
0.87791 1.20511 moveto
-0.24274 0.79723 lineto
stroke
0.82235 1.23218 moveto
-0.21757 0.85368 lineto
stroke
0.75969 1.25668 moveto
-0.18532 0.91272 lineto
stroke
0.68753 1.27771 moveto
-0.14356 0.97521 lineto
stroke
0.60118 1.29358 moveto
-0.08761 1.04288 lineto
stroke
0.48866 1.29992 moveto
-0.0055 1.12006 lineto
stroke
1.0055 -0.12006 moveto
0.51134 -0.29992 lineto
stroke
1.08761 -0.04288 moveto
0.39882 -0.29358 lineto
stroke
1.14356 0.02479 moveto
0.31247 -0.27771 lineto
stroke
1.18532 0.08728 moveto
0.24031 -0.25668 lineto
stroke
1.21757 0.14632 moveto
0.17765 -0.23218 lineto
stroke
1.24274 0.20277 moveto
0.12209 -0.20511 lineto
stroke
1.26226 0.25717 moveto
0.07216 -0.17598 lineto
stroke
1.27708 0.30987 moveto
0.02694 -0.14515 lineto
stroke
0.63681 0.12412 moveto
-0.01423 -0.11284 lineto
stroke
0.45531 0.10536 moveto
-0.05182 -0.07922 lineto
stroke
0.37442 0.12321 moveto
-0.08617 -0.04443 lineto
stroke
0.31463 0.14875 moveto
-0.11756 -0.00855 lineto
stroke
0.26668 0.17859 moveto
-0.14616 0.02833 lineto
stroke
0.22707 0.21147 moveto
-0.17215 0.06617 lineto
stroke
0.19405 0.24675 moveto
-0.19564 0.10492 lineto
stroke
0.16666 0.28408 moveto
-0.2167 0.14455 lineto
stroke
0.14433 0.32325 moveto
-0.23539 0.18504 lineto
stroke
0.12679 0.36416 moveto
-0.25175 0.22638 lineto
stroke
1.23539 0.81496 moveto
0.85567 0.67675 lineto
stroke
1.26579 0.73143 moveto
0.88607 0.59322 lineto
stroke
1.2167 0.85545 moveto
0.83334 0.71592 lineto
stroke
1.2775 0.68839 moveto
0.89415 0.54886 lineto
stroke
1.19564 0.89508 moveto
0.80595 0.75325 lineto
stroke
1.28684 0.6445 moveto
0.89715 0.50266 lineto
stroke
1.17215 0.93383 moveto
0.77293 0.78853 lineto
stroke
1.29376 0.59972 moveto
0.89454 0.45441 lineto
stroke
1.14616 0.97167 moveto
0.73332 0.82141 lineto
stroke
1.29817 0.55403 moveto
0.88533 0.40376 lineto
stroke
1.11756 1.00855 moveto
0.68537 0.85125 lineto
stroke
1.29997 0.50738 moveto
0.86778 0.35008 lineto
stroke
1.08617 1.04443 moveto
0.62558 0.87679 lineto
stroke
1.29899 0.45973 moveto
0.8384 0.29209 lineto
stroke
1.05182 1.07922 moveto
0.54469 0.89464 lineto
stroke
1.29503 0.41099 moveto
0.78791 0.22642 lineto
stroke
1.01423 1.11284 moveto
0.36319 0.87588 lineto
stroke
1.28785 0.36108 moveto
0.63681 0.12412 lineto
stroke
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.26592 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.17564 0.73408 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.1265 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(O)] 0.35682 0.8735 0 0 Mshowa
grestore
grestore
grestore
gsave
gsave
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48856 0.103 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.48856 0.897 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.32443 0 0 Mshowa
grestore
0 setgray
gsave
Bold 16 scalefont setfont
[(X)] 0.58062 0.67557 0 0 Mshowa
grestore
grestore
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = input; startGroup; ]
Do[ MagPhasePlot[ ExpandAll[ elliptic4thorder[ Exp[I w], rl, 0.4829798 ],
                  { w, -Pi, Pi }, 
                  PhaseRangeScale -> Null, 
                  PlotRange -> { 0, 2 } ],
    { rl, 0.8929096, 0.9929096, 0.01 } ] 
:[font = postscript; inactive; PostScript; output; startGroup; Cclosed; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00774 moveto
0.02505 0.00774 lineto
0.02629 0.00773 lineto
0.02753 0.00773 lineto
0.02877 0.00772 lineto
0.03125 0.00769 lineto
0.03373 0.00765 lineto
0.03621 0.0076 lineto
0.03869 0.00754 lineto
0.04365 0.00739 lineto
0.04861 0.00719 lineto
0.05357 0.00695 lineto
0.06349 0.00634 lineto
0.08333 0.0046 lineto
0.10317 0.00222 lineto
0.1131 0.00082 lineto
0.11558 0.00045 lineto
0.11682 0.00027 lineto
0.11806 8e-05 lineto
0.1193 0.00011 lineto
0.12054 0.0003 lineto
0.12302 0.00069 lineto
0.14286 0.00388 lineto
0.15278 0.0054 lineto
0.15774 0.00609 lineto
0.1627 0.00671 lineto
0.16766 0.00721 lineto
0.17014 0.00741 lineto
0.17138 0.0075 lineto
0.17262 0.00757 lineto
0.17386 0.00763 lineto
0.1751 0.00768 lineto
0.17634 0.00772 lineto
0.17758 0.00773 lineto
0.17882 0.00774 lineto
0.18006 0.00772 lineto
0.1813 0.00769 lineto
0.18254 0.00764 lineto
0.18378 0.00756 lineto
0.18502 0.00747 lineto
0.1875 0.0072 lineto
0.18998 0.00682 lineto
0.19246 0.00631 lineto
0.19494 0.00566 lineto
0.19742 0.00484 lineto
0.20238 0.00258 lineto
0.20486 0.00109 lineto
0.2061 0.00023 lineto
0.20734 0.00071 lineto
0.20982 0.00284 lineto
Mistroke
0.2123 0.00538 lineto
0.21726 0.01193 lineto
0.22222 0.02104 lineto
0.22718 0.03372 lineto
0.23214 0.05135 lineto
0.2371 0.07584 lineto
0.24206 0.10945 lineto
0.25198 0.20613 lineto
0.25446 0.23258 lineto
0.25694 0.25672 lineto
0.25942 0.27678 lineto
0.26066 0.28492 lineto
0.2619 0.29173 lineto
0.26314 0.29724 lineto
0.26438 0.30152 lineto
0.26562 0.30468 lineto
0.26687 0.30687 lineto
0.26811 0.30822 lineto
0.26935 0.30889 lineto
0.27059 0.309 lineto
0.27183 0.30868 lineto
0.28175 0.30024 lineto
0.28423 0.2981 lineto
0.28671 0.29626 lineto
0.28919 0.29474 lineto
0.29167 0.29356 lineto
0.29291 0.29308 lineto
0.29415 0.29269 lineto
0.29539 0.29236 lineto
0.29663 0.29211 lineto
0.29787 0.29193 lineto
0.29911 0.29181 lineto
0.30035 0.29174 lineto
0.30159 0.29174 lineto
0.30283 0.29178 lineto
0.30407 0.29188 lineto
0.30531 0.29202 lineto
0.30655 0.2922 lineto
0.31151 0.29329 lineto
0.31647 0.2948 lineto
0.32143 0.29657 lineto
0.34127 0.30387 lineto
0.35119 0.30659 lineto
0.35615 0.30758 lineto
0.35863 0.30798 lineto
0.36111 0.30831 lineto
0.36359 0.30858 lineto
0.36483 0.30869 lineto
0.36607 0.30878 lineto
0.36731 0.30886 lineto
Mistroke
0.36855 0.30892 lineto
0.36979 0.30896 lineto
0.37103 0.309 lineto
0.37227 0.30901 lineto
0.37351 0.30901 lineto
0.37475 0.309 lineto
0.37599 0.30898 lineto
0.37723 0.30894 lineto
0.37847 0.30889 lineto
0.38095 0.30875 lineto
0.38343 0.30856 lineto
0.38591 0.30833 lineto
0.39087 0.30775 lineto
0.40079 0.3062 lineto
0.42063 0.30221 lineto
0.44048 0.29808 lineto
0.4504 0.29626 lineto
0.46032 0.29468 lineto
0.47024 0.29342 lineto
0.4752 0.29291 lineto
0.48016 0.29249 lineto
0.48512 0.29216 lineto
0.4876 0.29203 lineto
0.49008 0.29192 lineto
0.49256 0.29184 lineto
0.4938 0.29181 lineto
0.49504 0.29178 lineto
0.49628 0.29176 lineto
0.49752 0.29175 lineto
0.49876 0.29174 lineto
0.5 0.29173 lineto
0.50124 0.29174 lineto
0.50248 0.29175 lineto
0.50372 0.29176 lineto
0.50496 0.29178 lineto
0.5062 0.29181 lineto
0.50744 0.29184 lineto
0.50992 0.29192 lineto
0.5124 0.29203 lineto
0.51488 0.29216 lineto
0.51984 0.29249 lineto
0.52976 0.29342 lineto
0.53968 0.29468 lineto
0.55952 0.29808 lineto
0.57937 0.30221 lineto
0.59921 0.3062 lineto
0.60417 0.30703 lineto
0.60913 0.30775 lineto
0.61409 0.30833 lineto
0.61657 0.30856 lineto
Mistroke
0.61905 0.30875 lineto
0.62029 0.30883 lineto
0.62153 0.30889 lineto
0.62277 0.30894 lineto
0.62401 0.30898 lineto
0.62525 0.309 lineto
0.62649 0.30901 lineto
0.62773 0.30901 lineto
0.62897 0.309 lineto
0.63021 0.30896 lineto
0.63145 0.30892 lineto
0.63393 0.30878 lineto
0.63517 0.30869 lineto
0.63641 0.30858 lineto
0.63889 0.30831 lineto
0.64385 0.30758 lineto
0.64881 0.30659 lineto
0.65873 0.30387 lineto
0.67857 0.29657 lineto
0.68353 0.2948 lineto
0.68849 0.29329 lineto
0.69097 0.29268 lineto
0.69221 0.29242 lineto
0.69345 0.2922 lineto
0.69469 0.29202 lineto
0.69593 0.29188 lineto
0.69717 0.29178 lineto
0.69841 0.29174 lineto
0.69965 0.29174 lineto
0.70089 0.29181 lineto
0.70213 0.29193 lineto
0.70337 0.29211 lineto
0.70461 0.29236 lineto
0.70585 0.29269 lineto
0.70833 0.29356 lineto
0.71081 0.29474 lineto
0.71329 0.29626 lineto
0.71825 0.30024 lineto
0.72321 0.30498 lineto
0.72569 0.30716 lineto
0.72693 0.30804 lineto
0.72817 0.30868 lineto
0.72941 0.309 lineto
0.73065 0.30889 lineto
0.73189 0.30822 lineto
0.73313 0.30687 lineto
0.73438 0.30468 lineto
0.73562 0.30152 lineto
0.73686 0.29724 lineto
0.7381 0.29173 lineto
Mistroke
0.74802 0.20613 lineto
0.75298 0.15367 lineto
0.75794 0.10945 lineto
0.7629 0.07584 lineto
0.76786 0.05135 lineto
0.77282 0.03372 lineto
0.77778 0.02104 lineto
0.78274 0.01193 lineto
0.7877 0.00538 lineto
0.79018 0.00284 lineto
0.79142 0.00173 lineto
0.79266 0.00071 lineto
0.7939 0.00023 lineto
0.79514 0.00109 lineto
0.79638 0.00187 lineto
0.79762 0.00258 lineto
0.8001 0.00382 lineto
0.80258 0.00484 lineto
0.80506 0.00566 lineto
0.80754 0.00631 lineto
0.81002 0.00682 lineto
0.8125 0.0072 lineto
0.81374 0.00735 lineto
0.81498 0.00747 lineto
0.81622 0.00756 lineto
0.81746 0.00764 lineto
0.8187 0.00769 lineto
0.81994 0.00772 lineto
0.82118 0.00774 lineto
0.82242 0.00773 lineto
0.82366 0.00772 lineto
0.8249 0.00768 lineto
0.82614 0.00763 lineto
0.82738 0.00757 lineto
0.8373 0.00671 lineto
0.84226 0.00609 lineto
0.84722 0.0054 lineto
0.85714 0.00388 lineto
0.86706 0.00228 lineto
0.87202 0.00148 lineto
0.87698 0.00069 lineto
0.87822 0.0005 lineto
0.87946 0.0003 lineto
0.8807 0.00011 lineto
0.88194 8e-05 lineto
0.88442 0.00045 lineto
0.8869 0.00082 lineto
0.89683 0.00222 lineto
0.91667 0.0046 lineto
0.92659 0.00555 lineto
Mistroke
0.93651 0.00634 lineto
0.94643 0.00695 lineto
0.95139 0.00719 lineto
0.95635 0.00739 lineto
0.96131 0.00754 lineto
0.96379 0.0076 lineto
0.96627 0.00765 lineto
0.96875 0.00769 lineto
0.96999 0.0077 lineto
0.97123 0.00772 lineto
0.97247 0.00773 lineto
0.97371 0.00773 lineto
0.97495 0.00774 lineto
0.97619 0.00774 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00766 moveto
0.02505 0.00766 lineto
0.02629 0.00766 lineto
0.02753 0.00765 lineto
0.02877 0.00764 lineto
0.03125 0.00761 lineto
0.03373 0.00758 lineto
0.03621 0.00753 lineto
0.03869 0.00747 lineto
0.04365 0.00731 lineto
0.04861 0.00712 lineto
0.05357 0.00688 lineto
0.06349 0.00628 lineto
0.08333 0.00456 lineto
0.10317 0.0022 lineto
0.1131 0.00081 lineto
0.11558 0.00045 lineto
0.11682 0.00026 lineto
0.11806 8e-05 lineto
0.1193 0.00011 lineto
0.12054 0.0003 lineto
0.12302 0.00068 lineto
0.14286 0.00384 lineto
0.15278 0.00536 lineto
0.15774 0.00605 lineto
0.1627 0.00666 lineto
0.16766 0.00716 lineto
0.17014 0.00736 lineto
0.17138 0.00745 lineto
0.17262 0.00752 lineto
0.17386 0.00758 lineto
0.1751 0.00763 lineto
0.17634 0.00766 lineto
0.17758 0.00768 lineto
0.17882 0.00769 lineto
0.18006 0.00767 lineto
0.1813 0.00764 lineto
0.18254 0.00759 lineto
0.18378 0.00752 lineto
0.18502 0.00742 lineto
0.1875 0.00716 lineto
0.18998 0.00679 lineto
0.19246 0.00628 lineto
0.19494 0.00564 lineto
0.19742 0.00482 lineto
0.20238 0.00258 lineto
0.20486 0.00109 lineto
0.2061 0.00023 lineto
0.20734 0.0007 lineto
0.20982 0.00284 lineto
Mistroke
0.2123 0.00538 lineto
0.21726 0.01197 lineto
0.22222 0.0212 lineto
0.22718 0.03414 lineto
0.23214 0.05236 lineto
0.2371 0.07812 lineto
0.24206 0.11434 lineto
0.25198 0.22375 lineto
0.25446 0.25428 lineto
0.25694 0.28163 lineto
0.25942 0.30327 lineto
0.26066 0.31147 lineto
0.2619 0.31788 lineto
0.26314 0.32258 lineto
0.26438 0.32573 lineto
0.26562 0.32753 lineto
0.26687 0.32821 lineto
0.26811 0.32798 lineto
0.26935 0.32705 lineto
0.27059 0.32561 lineto
0.27183 0.3238 lineto
0.27679 0.31506 lineto
0.28175 0.30678 lineto
0.28423 0.30334 lineto
0.28671 0.30041 lineto
0.28919 0.298 lineto
0.29167 0.29607 lineto
0.29415 0.29457 lineto
0.29539 0.29397 lineto
0.29663 0.29346 lineto
0.29787 0.29304 lineto
0.29911 0.29271 lineto
0.30035 0.29244 lineto
0.30159 0.29225 lineto
0.30283 0.29212 lineto
0.30407 0.29205 lineto
0.30531 0.29204 lineto
0.30655 0.29208 lineto
0.30779 0.29217 lineto
0.30903 0.2923 lineto
0.31151 0.29268 lineto
0.31399 0.29319 lineto
0.31647 0.29381 lineto
0.32143 0.29527 lineto
0.34127 0.30178 lineto
0.35119 0.30425 lineto
0.35615 0.30515 lineto
0.35863 0.3055 lineto
0.36111 0.30579 lineto
0.36359 0.30602 lineto
Mistroke
0.36483 0.30611 lineto
0.36607 0.30619 lineto
0.36731 0.30625 lineto
0.36855 0.3063 lineto
0.36979 0.30633 lineto
0.37103 0.30635 lineto
0.37227 0.30635 lineto
0.37351 0.30634 lineto
0.37475 0.30632 lineto
0.37599 0.30628 lineto
0.37723 0.30623 lineto
0.37847 0.30617 lineto
0.38095 0.30601 lineto
0.38591 0.30556 lineto
0.39087 0.30495 lineto
0.40079 0.30335 lineto
0.42063 0.29932 lineto
0.44048 0.29518 lineto
0.4504 0.29335 lineto
0.46032 0.29178 lineto
0.47024 0.29052 lineto
0.4752 0.29001 lineto
0.48016 0.28959 lineto
0.48512 0.28926 lineto
0.4876 0.28913 lineto
0.49008 0.28903 lineto
0.49256 0.28894 lineto
0.4938 0.28891 lineto
0.49504 0.28888 lineto
0.49628 0.28886 lineto
0.49752 0.28885 lineto
0.49876 0.28884 lineto
0.5 0.28884 lineto
0.50124 0.28884 lineto
0.50248 0.28885 lineto
0.50372 0.28886 lineto
0.50496 0.28888 lineto
0.5062 0.28891 lineto
0.50744 0.28894 lineto
0.50992 0.28903 lineto
0.5124 0.28913 lineto
0.51488 0.28926 lineto
0.51984 0.28959 lineto
0.52976 0.29052 lineto
0.53968 0.29178 lineto
0.55952 0.29518 lineto
0.57937 0.29932 lineto
0.59921 0.30335 lineto
0.60417 0.3042 lineto
0.60913 0.30495 lineto
Mistroke
0.61409 0.30556 lineto
0.61657 0.30581 lineto
0.61905 0.30601 lineto
0.62029 0.3061 lineto
0.62153 0.30617 lineto
0.62277 0.30623 lineto
0.62401 0.30628 lineto
0.62525 0.30632 lineto
0.62649 0.30634 lineto
0.62773 0.30635 lineto
0.62897 0.30635 lineto
0.63021 0.30633 lineto
0.63145 0.3063 lineto
0.63393 0.30619 lineto
0.63517 0.30611 lineto
0.63641 0.30602 lineto
0.63889 0.30579 lineto
0.64385 0.30515 lineto
0.64881 0.30425 lineto
0.65873 0.30178 lineto
0.67857 0.29527 lineto
0.68353 0.29381 lineto
0.68601 0.29319 lineto
0.68849 0.29268 lineto
0.68973 0.29248 lineto
0.69097 0.2923 lineto
0.69221 0.29217 lineto
0.69345 0.29208 lineto
0.69469 0.29204 lineto
0.69593 0.29205 lineto
0.69717 0.29212 lineto
0.69841 0.29225 lineto
0.69965 0.29244 lineto
0.70089 0.29271 lineto
0.70213 0.29304 lineto
0.70337 0.29346 lineto
0.70585 0.29457 lineto
0.70833 0.29607 lineto
0.71081 0.298 lineto
0.71329 0.30041 lineto
0.71825 0.30678 lineto
0.72321 0.31506 lineto
0.72569 0.31956 lineto
0.72817 0.3238 lineto
0.72941 0.32561 lineto
0.73065 0.32705 lineto
0.73189 0.32798 lineto
0.73313 0.32821 lineto
0.73438 0.32753 lineto
0.73562 0.32573 lineto
Mistroke
0.73686 0.32258 lineto
0.7381 0.31788 lineto
0.74802 0.22375 lineto
0.75298 0.16356 lineto
0.75794 0.11434 lineto
0.7629 0.07812 lineto
0.76786 0.05236 lineto
0.77282 0.03414 lineto
0.77778 0.0212 lineto
0.78274 0.01197 lineto
0.7877 0.00538 lineto
0.79018 0.00284 lineto
0.79142 0.00173 lineto
0.79266 0.0007 lineto
0.7939 0.00023 lineto
0.79514 0.00109 lineto
0.79638 0.00187 lineto
0.79762 0.00258 lineto
0.8001 0.00381 lineto
0.80258 0.00482 lineto
0.80506 0.00564 lineto
0.80754 0.00628 lineto
0.81002 0.00679 lineto
0.8125 0.00716 lineto
0.81374 0.00731 lineto
0.81498 0.00742 lineto
0.81622 0.00752 lineto
0.81746 0.00759 lineto
0.8187 0.00764 lineto
0.81994 0.00767 lineto
0.82118 0.00769 lineto
0.82242 0.00768 lineto
0.82366 0.00766 lineto
0.8249 0.00763 lineto
0.82614 0.00758 lineto
0.82738 0.00752 lineto
0.8373 0.00666 lineto
0.84226 0.00605 lineto
0.84722 0.00536 lineto
0.85714 0.00384 lineto
0.86706 0.00226 lineto
0.87202 0.00146 lineto
0.87698 0.00068 lineto
0.87822 0.00049 lineto
0.87946 0.0003 lineto
0.8807 0.00011 lineto
0.88194 8e-05 lineto
0.88442 0.00045 lineto
0.8869 0.00081 lineto
0.89683 0.0022 lineto
Mistroke
0.91667 0.00456 lineto
0.92659 0.0055 lineto
0.93651 0.00628 lineto
0.94643 0.00688 lineto
0.95139 0.00712 lineto
0.95635 0.00731 lineto
0.96131 0.00747 lineto
0.96379 0.00753 lineto
0.96627 0.00758 lineto
0.96875 0.00761 lineto
0.96999 0.00763 lineto
0.97123 0.00764 lineto
0.97247 0.00765 lineto
0.97371 0.00766 lineto
0.97495 0.00766 lineto
0.97619 0.00766 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00759 moveto
0.02505 0.00759 lineto
0.02629 0.00758 lineto
0.02753 0.00757 lineto
0.02877 0.00756 lineto
0.03125 0.00754 lineto
0.03373 0.0075 lineto
0.03621 0.00745 lineto
0.03869 0.00739 lineto
0.04365 0.00724 lineto
0.04861 0.00705 lineto
0.05357 0.00681 lineto
0.06349 0.00621 lineto
0.08333 0.00451 lineto
0.10317 0.00218 lineto
0.1131 0.00081 lineto
0.11558 0.00044 lineto
0.11682 0.00026 lineto
0.11806 8e-05 lineto
0.1193 0.00011 lineto
0.12054 0.0003 lineto
0.12302 0.00068 lineto
0.14286 0.00381 lineto
0.15278 0.00531 lineto
0.15774 0.006 lineto
0.1627 0.0066 lineto
0.16766 0.00711 lineto
0.17014 0.00731 lineto
0.17138 0.00739 lineto
0.17262 0.00746 lineto
0.17386 0.00753 lineto
0.1751 0.00758 lineto
0.17634 0.00761 lineto
0.17758 0.00763 lineto
0.17882 0.00764 lineto
0.18006 0.00762 lineto
0.1813 0.00759 lineto
0.18254 0.00754 lineto
0.18378 0.00747 lineto
0.18502 0.00738 lineto
0.18626 0.00726 lineto
0.1875 0.00712 lineto
0.18998 0.00675 lineto
0.19246 0.00625 lineto
0.19494 0.00561 lineto
0.19742 0.0048 lineto
0.20238 0.00257 lineto
0.20486 0.00108 lineto
0.2061 0.00023 lineto
0.20734 0.0007 lineto
Mistroke
0.20982 0.00284 lineto
0.2123 0.00538 lineto
0.21726 0.012 lineto
0.22222 0.02133 lineto
0.2247 0.02735 lineto
0.22718 0.03451 lineto
0.23214 0.0533 lineto
0.23462 0.06558 lineto
0.2371 0.08034 lineto
0.24206 0.11938 lineto
0.24702 0.17446 lineto
0.25198 0.24458 lineto
0.25446 0.28064 lineto
0.25694 0.31227 lineto
0.25818 0.32518 lineto
0.25942 0.3357 lineto
0.26066 0.3437 lineto
0.2619 0.34924 lineto
0.26314 0.35254 lineto
0.26438 0.35389 lineto
0.26562 0.35364 lineto
0.26687 0.35216 lineto
0.26935 0.34672 lineto
0.27183 0.33962 lineto
0.27679 0.32502 lineto
0.28175 0.31294 lineto
0.28423 0.30814 lineto
0.28671 0.30413 lineto
0.29167 0.29816 lineto
0.29415 0.29607 lineto
0.29663 0.29446 lineto
0.29787 0.29381 lineto
0.29911 0.29327 lineto
0.30035 0.29282 lineto
0.30159 0.29245 lineto
0.30283 0.29216 lineto
0.30407 0.29194 lineto
0.30531 0.29179 lineto
0.30655 0.2917 lineto
0.30779 0.29167 lineto
0.30903 0.29168 lineto
0.31027 0.29175 lineto
0.31151 0.29185 lineto
0.31399 0.29218 lineto
0.31647 0.29263 lineto
0.32143 0.29381 lineto
0.34127 0.29959 lineto
0.35119 0.30186 lineto
0.35615 0.30266 lineto
0.35863 0.30298 lineto
Mistroke
0.36111 0.30324 lineto
0.36359 0.30343 lineto
0.36483 0.30351 lineto
0.36607 0.30357 lineto
0.36731 0.30362 lineto
0.36855 0.30365 lineto
0.36979 0.30367 lineto
0.37103 0.30368 lineto
0.37227 0.30367 lineto
0.37351 0.30365 lineto
0.37475 0.30361 lineto
0.37599 0.30357 lineto
0.37847 0.30344 lineto
0.38095 0.30326 lineto
0.38591 0.30278 lineto
0.39087 0.30214 lineto
0.40079 0.30051 lineto
0.42063 0.29644 lineto
0.44048 0.2923 lineto
0.4504 0.29047 lineto
0.46032 0.2889 lineto
0.47024 0.28764 lineto
0.4752 0.28714 lineto
0.48016 0.28672 lineto
0.48512 0.28639 lineto
0.4876 0.28626 lineto
0.49008 0.28616 lineto
0.49256 0.28607 lineto
0.4938 0.28604 lineto
0.49504 0.28602 lineto
0.49628 0.28599 lineto
0.49752 0.28598 lineto
0.49876 0.28597 lineto
0.5 0.28597 lineto
0.50124 0.28597 lineto
0.50248 0.28598 lineto
0.50372 0.28599 lineto
0.50496 0.28602 lineto
0.5062 0.28604 lineto
0.50744 0.28607 lineto
0.50992 0.28616 lineto
0.5124 0.28626 lineto
0.51488 0.28639 lineto
0.51984 0.28672 lineto
0.52976 0.28764 lineto
0.53968 0.2889 lineto
0.55952 0.2923 lineto
0.57937 0.29644 lineto
0.59921 0.30051 lineto
0.60417 0.30137 lineto
Mistroke
0.60913 0.30214 lineto
0.61409 0.30278 lineto
0.61657 0.30304 lineto
0.61905 0.30326 lineto
0.62153 0.30344 lineto
0.62277 0.30351 lineto
0.62401 0.30357 lineto
0.62525 0.30361 lineto
0.62649 0.30365 lineto
0.62773 0.30367 lineto
0.62897 0.30368 lineto
0.63021 0.30367 lineto
0.63145 0.30365 lineto
0.63269 0.30362 lineto
0.63393 0.30357 lineto
0.63517 0.30351 lineto
0.63641 0.30343 lineto
0.63889 0.30324 lineto
0.64137 0.30298 lineto
0.64385 0.30266 lineto
0.64881 0.30186 lineto
0.65873 0.29959 lineto
0.66865 0.29672 lineto
0.67361 0.29522 lineto
0.67857 0.29381 lineto
0.68105 0.29318 lineto
0.68353 0.29263 lineto
0.68601 0.29218 lineto
0.68725 0.292 lineto
0.68849 0.29185 lineto
0.68973 0.29175 lineto
0.69097 0.29168 lineto
0.69221 0.29167 lineto
0.69345 0.2917 lineto
0.69469 0.29179 lineto
0.69593 0.29194 lineto
0.69717 0.29216 lineto
0.69841 0.29245 lineto
0.70089 0.29327 lineto
0.70213 0.29381 lineto
0.70337 0.29446 lineto
0.70585 0.29607 lineto
0.70833 0.29816 lineto
0.71081 0.30083 lineto
0.71329 0.30413 lineto
0.71825 0.31294 lineto
0.72321 0.32502 lineto
0.72817 0.33962 lineto
0.73065 0.34672 lineto
0.73189 0.34976 lineto
Mistroke
0.73313 0.35216 lineto
0.73438 0.35364 lineto
0.73562 0.35389 lineto
0.73686 0.35254 lineto
0.7381 0.34924 lineto
0.74802 0.24458 lineto
0.75298 0.17446 lineto
0.75794 0.11938 lineto
0.7629 0.08034 lineto
0.76538 0.06558 lineto
0.76786 0.0533 lineto
0.77034 0.04306 lineto
0.77282 0.03451 lineto
0.77778 0.02133 lineto
0.78274 0.012 lineto
0.7877 0.00538 lineto
0.79018 0.00284 lineto
0.79142 0.00172 lineto
0.79266 0.0007 lineto
0.7939 0.00023 lineto
0.79514 0.00108 lineto
0.79638 0.00186 lineto
0.79762 0.00257 lineto
0.8001 0.00379 lineto
0.80258 0.0048 lineto
0.80506 0.00561 lineto
0.80754 0.00625 lineto
0.81002 0.00675 lineto
0.8125 0.00712 lineto
0.81374 0.00726 lineto
0.81498 0.00738 lineto
0.81622 0.00747 lineto
0.81746 0.00754 lineto
0.8187 0.00759 lineto
0.81994 0.00762 lineto
0.82118 0.00764 lineto
0.82242 0.00763 lineto
0.82366 0.00761 lineto
0.8249 0.00758 lineto
0.82614 0.00753 lineto
0.82738 0.00746 lineto
0.8373 0.0066 lineto
0.84226 0.006 lineto
0.84722 0.00531 lineto
0.85714 0.00381 lineto
0.86706 0.00224 lineto
0.87202 0.00145 lineto
0.87698 0.00068 lineto
0.87822 0.00049 lineto
0.87946 0.0003 lineto
Mistroke
0.8807 0.00011 lineto
0.88194 8e-05 lineto
0.88442 0.00044 lineto
0.8869 0.00081 lineto
0.89683 0.00218 lineto
0.91667 0.00451 lineto
0.92659 0.00545 lineto
0.93651 0.00621 lineto
0.94643 0.00681 lineto
0.95139 0.00705 lineto
0.95635 0.00724 lineto
0.96131 0.00739 lineto
0.96379 0.00745 lineto
0.96627 0.0075 lineto
0.96875 0.00754 lineto
0.96999 0.00755 lineto
0.97123 0.00756 lineto
0.97247 0.00757 lineto
0.97371 0.00758 lineto
0.97495 0.00759 lineto
0.97619 0.00759 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00751 moveto
0.02505 0.00751 lineto
0.02629 0.00751 lineto
0.02753 0.0075 lineto
0.02877 0.00749 lineto
0.03125 0.00746 lineto
0.03373 0.00743 lineto
0.03621 0.00738 lineto
0.03869 0.00732 lineto
0.04365 0.00717 lineto
0.04861 0.00698 lineto
0.05357 0.00675 lineto
0.06349 0.00615 lineto
0.08333 0.00447 lineto
0.10317 0.00216 lineto
0.1131 0.0008 lineto
0.11558 0.00044 lineto
0.11682 0.00026 lineto
0.11806 8e-05 lineto
0.1193 0.00011 lineto
0.12054 0.0003 lineto
0.12302 0.00067 lineto
0.14286 0.00378 lineto
0.15278 0.00527 lineto
0.15774 0.00595 lineto
0.1627 0.00655 lineto
0.16766 0.00705 lineto
0.17014 0.00725 lineto
0.17138 0.00733 lineto
0.17262 0.00741 lineto
0.17386 0.00747 lineto
0.1751 0.00752 lineto
0.17634 0.00755 lineto
0.17758 0.00758 lineto
0.17882 0.00758 lineto
0.18006 0.00757 lineto
0.1813 0.00754 lineto
0.18254 0.00749 lineto
0.18378 0.00742 lineto
0.18502 0.00733 lineto
0.18626 0.00721 lineto
0.1875 0.00707 lineto
0.18998 0.00671 lineto
0.19246 0.00622 lineto
0.19494 0.00558 lineto
0.19742 0.00477 lineto
0.20238 0.00256 lineto
0.20486 0.00108 lineto
0.2061 0.00023 lineto
0.20734 0.0007 lineto
Mistroke
0.20982 0.00283 lineto
0.2123 0.00538 lineto
0.21726 0.01202 lineto
0.21974 0.01631 lineto
0.22222 0.02143 lineto
0.2247 0.02753 lineto
0.22718 0.03483 lineto
0.23214 0.05415 lineto
0.23462 0.06692 lineto
0.2371 0.08245 lineto
0.23958 0.10138 lineto
0.24206 0.12449 lineto
0.24702 0.1864 lineto
0.25198 0.26948 lineto
0.25446 0.31325 lineto
0.2557 0.33325 lineto
0.25694 0.35085 lineto
0.25818 0.36534 lineto
0.25942 0.37628 lineto
0.26066 0.38357 lineto
0.2619 0.38743 lineto
0.27183 0.35593 lineto
0.27679 0.33464 lineto
0.27927 0.32594 lineto
0.28175 0.31857 lineto
0.28423 0.31241 lineto
0.28671 0.30732 lineto
0.29167 0.29981 lineto
0.29415 0.29714 lineto
0.29663 0.29506 lineto
0.29911 0.29348 lineto
0.30035 0.29286 lineto
0.30159 0.29233 lineto
0.30283 0.29189 lineto
0.30407 0.29154 lineto
0.30531 0.29126 lineto
0.30655 0.29105 lineto
0.30779 0.2909 lineto
0.30903 0.29082 lineto
0.31027 0.29078 lineto
0.31151 0.2908 lineto
0.31275 0.29086 lineto
0.31399 0.29096 lineto
0.31647 0.29126 lineto
0.31895 0.29168 lineto
0.32143 0.29219 lineto
0.34127 0.29733 lineto
0.35119 0.2994 lineto
0.35615 0.30014 lineto
0.35863 0.30042 lineto
Mistroke
0.36111 0.30064 lineto
0.36359 0.30081 lineto
0.36483 0.30088 lineto
0.36607 0.30093 lineto
0.36731 0.30096 lineto
0.36855 0.30098 lineto
0.36979 0.30099 lineto
0.37103 0.30099 lineto
0.37227 0.30097 lineto
0.37351 0.30094 lineto
0.37475 0.30089 lineto
0.37599 0.30084 lineto
0.37847 0.30069 lineto
0.38095 0.3005 lineto
0.38591 0.29999 lineto
0.39087 0.29933 lineto
0.40079 0.29767 lineto
0.42063 0.29357 lineto
0.44048 0.28943 lineto
0.4504 0.28761 lineto
0.46032 0.28605 lineto
0.47024 0.28479 lineto
0.4752 0.28429 lineto
0.48016 0.28387 lineto
0.48512 0.28355 lineto
0.4876 0.28342 lineto
0.49008 0.28331 lineto
0.49256 0.28323 lineto
0.4938 0.2832 lineto
0.49504 0.28317 lineto
0.49628 0.28315 lineto
0.49752 0.28314 lineto
0.49876 0.28313 lineto
0.5 0.28313 lineto
0.50124 0.28313 lineto
0.50248 0.28314 lineto
0.50372 0.28315 lineto
0.50496 0.28317 lineto
0.5062 0.2832 lineto
0.50744 0.28323 lineto
0.50992 0.28331 lineto
0.5124 0.28342 lineto
0.51488 0.28355 lineto
0.51984 0.28387 lineto
0.52976 0.28479 lineto
0.53968 0.28605 lineto
0.55952 0.28943 lineto
0.57937 0.29357 lineto
0.59921 0.29767 lineto
0.60417 0.29855 lineto
Mistroke
0.60913 0.29933 lineto
0.61409 0.29999 lineto
0.61657 0.30026 lineto
0.61905 0.3005 lineto
0.62153 0.30069 lineto
0.62277 0.30077 lineto
0.62401 0.30084 lineto
0.62525 0.30089 lineto
0.62649 0.30094 lineto
0.62773 0.30097 lineto
0.62897 0.30099 lineto
0.63021 0.30099 lineto
0.63145 0.30098 lineto
0.63269 0.30096 lineto
0.63393 0.30093 lineto
0.63517 0.30088 lineto
0.63641 0.30081 lineto
0.63889 0.30064 lineto
0.64137 0.30042 lineto
0.64385 0.30014 lineto
0.64881 0.2994 lineto
0.65873 0.29733 lineto
0.66865 0.29472 lineto
0.67361 0.29339 lineto
0.67857 0.29219 lineto
0.68105 0.29168 lineto
0.68353 0.29126 lineto
0.68477 0.29109 lineto
0.68601 0.29096 lineto
0.68725 0.29086 lineto
0.68849 0.2908 lineto
0.68973 0.29078 lineto
0.69097 0.29082 lineto
0.69221 0.2909 lineto
0.69345 0.29105 lineto
0.69469 0.29126 lineto
0.69593 0.29154 lineto
0.69717 0.29189 lineto
0.69841 0.29233 lineto
0.70089 0.29348 lineto
0.70337 0.29506 lineto
0.70585 0.29714 lineto
0.70833 0.29981 lineto
0.71081 0.30316 lineto
0.71329 0.30732 lineto
0.71577 0.31241 lineto
0.71825 0.31857 lineto
0.72321 0.33464 lineto
0.72817 0.35593 lineto
0.73065 0.3678 lineto
Mistroke
0.73313 0.37894 lineto
0.73438 0.3835 lineto
0.73562 0.38681 lineto
0.73686 0.38831 lineto
0.7381 0.38743 lineto
0.74802 0.26948 lineto
0.75298 0.1864 lineto
0.75546 0.15261 lineto
0.75794 0.12449 lineto
0.7629 0.08245 lineto
0.76538 0.06692 lineto
0.76786 0.05415 lineto
0.77034 0.04359 lineto
0.77282 0.03483 lineto
0.7753 0.02753 lineto
0.77778 0.02143 lineto
0.78274 0.01202 lineto
0.7877 0.00538 lineto
0.79018 0.00283 lineto
0.79142 0.00172 lineto
0.79266 0.0007 lineto
0.7939 0.00023 lineto
0.79514 0.00108 lineto
0.79638 0.00185 lineto
0.79762 0.00256 lineto
0.8001 0.00378 lineto
0.80258 0.00477 lineto
0.80506 0.00558 lineto
0.80754 0.00622 lineto
0.81002 0.00671 lineto
0.8125 0.00707 lineto
0.81374 0.00721 lineto
0.81498 0.00733 lineto
0.81622 0.00742 lineto
0.81746 0.00749 lineto
0.8187 0.00754 lineto
0.81994 0.00757 lineto
0.82118 0.00758 lineto
0.82242 0.00758 lineto
0.82366 0.00755 lineto
0.8249 0.00752 lineto
0.82614 0.00747 lineto
0.82738 0.00741 lineto
0.8373 0.00655 lineto
0.84226 0.00595 lineto
0.84722 0.00527 lineto
0.85714 0.00378 lineto
0.86706 0.00222 lineto
0.87202 0.00144 lineto
0.87698 0.00067 lineto
Mistroke
0.87822 0.00048 lineto
0.87946 0.0003 lineto
0.8807 0.00011 lineto
0.88194 8e-05 lineto
0.88442 0.00044 lineto
0.8869 0.0008 lineto
0.89683 0.00216 lineto
0.91667 0.00447 lineto
0.92659 0.00539 lineto
0.93651 0.00615 lineto
0.94643 0.00675 lineto
0.95139 0.00698 lineto
0.95635 0.00717 lineto
0.96131 0.00732 lineto
0.96379 0.00738 lineto
0.96627 0.00743 lineto
0.96875 0.00746 lineto
0.96999 0.00748 lineto
0.97123 0.00749 lineto
0.97247 0.0075 lineto
0.97371 0.00751 lineto
0.97495 0.00751 lineto
0.97619 0.00751 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00744 moveto
0.02505 0.00744 lineto
0.02629 0.00743 lineto
0.02753 0.00743 lineto
0.02877 0.00742 lineto
0.03125 0.00739 lineto
0.03373 0.00735 lineto
0.03621 0.00731 lineto
0.03869 0.00725 lineto
0.04365 0.0071 lineto
0.04861 0.00691 lineto
0.05357 0.00668 lineto
0.06349 0.00609 lineto
0.08333 0.00443 lineto
0.10317 0.00214 lineto
0.1131 0.00079 lineto
0.11558 0.00044 lineto
0.11682 0.00026 lineto
0.11806 7e-05 lineto
0.1193 0.00011 lineto
0.12054 0.00029 lineto
0.12302 0.00067 lineto
0.14286 0.00374 lineto
0.15278 0.00522 lineto
0.15774 0.00589 lineto
0.1627 0.00649 lineto
0.16766 0.00699 lineto
0.17014 0.00719 lineto
0.17262 0.00735 lineto
0.17386 0.00741 lineto
0.1751 0.00746 lineto
0.17634 0.0075 lineto
0.17758 0.00752 lineto
0.17882 0.00752 lineto
0.18006 0.00751 lineto
0.1813 0.00748 lineto
0.18254 0.00744 lineto
0.18378 0.00737 lineto
0.18502 0.00728 lineto
0.18626 0.00716 lineto
0.1875 0.00703 lineto
0.18998 0.00666 lineto
0.19246 0.00618 lineto
0.19494 0.00555 lineto
0.19742 0.00475 lineto
0.20238 0.00255 lineto
0.20486 0.00107 lineto
0.2061 0.00023 lineto
0.20734 0.0007 lineto
0.20982 0.00283 lineto
Mistroke
0.2123 0.00537 lineto
0.21478 0.0084 lineto
0.21726 0.01202 lineto
0.21974 0.01634 lineto
0.22222 0.02149 lineto
0.2247 0.02766 lineto
0.22718 0.03508 lineto
0.23214 0.05488 lineto
0.23462 0.06812 lineto
0.2371 0.0844 lineto
0.23958 0.10452 lineto
0.24206 0.12954 lineto
0.24702 0.19929 lineto
0.2495 0.24598 lineto
0.25198 0.29952 lineto
0.25446 0.35453 lineto
0.2557 0.37953 lineto
0.25694 0.4009 lineto
0.25818 0.41742 lineto
0.25942 0.42845 lineto
0.26066 0.43398 lineto
0.2619 0.43465 lineto
0.27183 0.37236 lineto
0.27431 0.35685 lineto
0.27679 0.34365 lineto
0.27927 0.33263 lineto
0.28175 0.32351 lineto
0.28423 0.31603 lineto
0.28671 0.30991 lineto
0.29167 0.30095 lineto
0.29415 0.29777 lineto
0.29663 0.29526 lineto
0.29911 0.29333 lineto
0.30159 0.29188 lineto
0.30407 0.29083 lineto
0.30531 0.29044 lineto
0.30655 0.29012 lineto
0.30779 0.28988 lineto
0.30903 0.2897 lineto
0.31027 0.28958 lineto
0.31151 0.28952 lineto
0.31275 0.2895 lineto
0.31399 0.28953 lineto
0.31523 0.2896 lineto
0.31647 0.28971 lineto
0.31895 0.29001 lineto
0.32143 0.29041 lineto
0.34127 0.29499 lineto
0.34623 0.29603 lineto
0.35119 0.29689 lineto
Mistroke
0.35615 0.29756 lineto
0.35863 0.29782 lineto
0.36111 0.29802 lineto
0.36359 0.29816 lineto
0.36483 0.29821 lineto
0.36607 0.29825 lineto
0.36731 0.29828 lineto
0.36855 0.29829 lineto
0.36979 0.29829 lineto
0.37103 0.29827 lineto
0.37227 0.29825 lineto
0.37351 0.29821 lineto
0.37599 0.29809 lineto
0.37847 0.29793 lineto
0.38095 0.29772 lineto
0.38591 0.29719 lineto
0.39087 0.29652 lineto
0.40079 0.29483 lineto
0.42063 0.29073 lineto
0.44048 0.28659 lineto
0.4504 0.28478 lineto
0.46032 0.28322 lineto
0.47024 0.28197 lineto
0.4752 0.28147 lineto
0.48016 0.28105 lineto
0.48512 0.28073 lineto
0.4876 0.2806 lineto
0.49008 0.2805 lineto
0.49256 0.28042 lineto
0.4938 0.28038 lineto
0.49504 0.28036 lineto
0.49628 0.28034 lineto
0.49752 0.28032 lineto
0.49876 0.28031 lineto
0.5 0.28031 lineto
0.50124 0.28031 lineto
0.50248 0.28032 lineto
0.50372 0.28034 lineto
0.50496 0.28036 lineto
0.5062 0.28038 lineto
0.50744 0.28042 lineto
0.50992 0.2805 lineto
0.5124 0.2806 lineto
0.51488 0.28073 lineto
0.51984 0.28105 lineto
0.52976 0.28197 lineto
0.53968 0.28322 lineto
0.55952 0.28659 lineto
0.57937 0.29073 lineto
0.59921 0.29483 lineto
Mistroke
0.60913 0.29652 lineto
0.61409 0.29719 lineto
0.61657 0.29748 lineto
0.61905 0.29772 lineto
0.62153 0.29793 lineto
0.62401 0.29809 lineto
0.62525 0.29815 lineto
0.62649 0.29821 lineto
0.62773 0.29825 lineto
0.62897 0.29827 lineto
0.63021 0.29829 lineto
0.63145 0.29829 lineto
0.63269 0.29828 lineto
0.63393 0.29825 lineto
0.63517 0.29821 lineto
0.63641 0.29816 lineto
0.63889 0.29802 lineto
0.64137 0.29782 lineto
0.64385 0.29756 lineto
0.64881 0.29689 lineto
0.65377 0.29603 lineto
0.65873 0.29499 lineto
0.66865 0.29262 lineto
0.67361 0.29144 lineto
0.67609 0.2909 lineto
0.67857 0.29041 lineto
0.68105 0.29001 lineto
0.68229 0.28984 lineto
0.68353 0.28971 lineto
0.68477 0.2896 lineto
0.68601 0.28953 lineto
0.68725 0.2895 lineto
0.68849 0.28952 lineto
0.68973 0.28958 lineto
0.69097 0.2897 lineto
0.69221 0.28988 lineto
0.69345 0.29012 lineto
0.69469 0.29044 lineto
0.69593 0.29083 lineto
0.69841 0.29188 lineto
0.70089 0.29333 lineto
0.70337 0.29526 lineto
0.70585 0.29777 lineto
0.70833 0.30095 lineto
0.71081 0.30495 lineto
0.71329 0.30991 lineto
0.71577 0.31603 lineto
0.71825 0.32351 lineto
0.72073 0.33263 lineto
0.72321 0.34365 lineto
Mistroke
0.72817 0.37236 lineto
0.73313 0.4086 lineto
0.73562 0.42538 lineto
0.73686 0.43142 lineto
0.7381 0.43465 lineto
0.73934 0.43398 lineto
0.74058 0.42845 lineto
0.74182 0.41742 lineto
0.74306 0.4009 lineto
0.74554 0.35453 lineto
0.74802 0.29952 lineto
0.7505 0.24598 lineto
0.75298 0.19929 lineto
0.75546 0.16071 lineto
0.75794 0.12954 lineto
0.7629 0.0844 lineto
0.76538 0.06812 lineto
0.76786 0.05488 lineto
0.77034 0.04402 lineto
0.77282 0.03508 lineto
0.7753 0.02766 lineto
0.77778 0.02149 lineto
0.78026 0.01634 lineto
0.78274 0.01202 lineto
0.78522 0.0084 lineto
0.7877 0.00537 lineto
0.79018 0.00283 lineto
0.79142 0.00171 lineto
0.79266 0.0007 lineto
0.7939 0.00023 lineto
0.79514 0.00107 lineto
0.79638 0.00185 lineto
0.79762 0.00255 lineto
0.8001 0.00376 lineto
0.80258 0.00475 lineto
0.80506 0.00555 lineto
0.80754 0.00618 lineto
0.81002 0.00666 lineto
0.8125 0.00703 lineto
0.81374 0.00716 lineto
0.81498 0.00728 lineto
0.81622 0.00737 lineto
0.81746 0.00744 lineto
0.8187 0.00748 lineto
0.81994 0.00751 lineto
0.82118 0.00752 lineto
0.82242 0.00752 lineto
0.82366 0.0075 lineto
0.8249 0.00746 lineto
0.82614 0.00741 lineto
Mistroke
0.82738 0.00735 lineto
0.8373 0.00649 lineto
0.84226 0.00589 lineto
0.84722 0.00522 lineto
0.85714 0.00374 lineto
0.86706 0.0022 lineto
0.87202 0.00142 lineto
0.87698 0.00067 lineto
0.87822 0.00048 lineto
0.87946 0.00029 lineto
0.8807 0.00011 lineto
0.88194 7e-05 lineto
0.88442 0.00044 lineto
0.8869 0.00079 lineto
0.89683 0.00214 lineto
0.91667 0.00443 lineto
0.92659 0.00534 lineto
0.93651 0.00609 lineto
0.94643 0.00668 lineto
0.95139 0.00691 lineto
0.95635 0.0071 lineto
0.96131 0.00725 lineto
0.96379 0.00731 lineto
0.96627 0.00735 lineto
0.96875 0.00739 lineto
0.96999 0.0074 lineto
0.97123 0.00742 lineto
0.97247 0.00743 lineto
0.97371 0.00743 lineto
0.97495 0.00744 lineto
0.97619 0.00744 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00736 moveto
0.02505 0.00736 lineto
0.02629 0.00736 lineto
0.02753 0.00735 lineto
0.02877 0.00734 lineto
0.03125 0.00732 lineto
0.03373 0.00728 lineto
0.03621 0.00723 lineto
0.03869 0.00718 lineto
0.04365 0.00703 lineto
0.04861 0.00684 lineto
0.05357 0.00661 lineto
0.06349 0.00603 lineto
0.08333 0.00438 lineto
0.10317 0.00212 lineto
0.1131 0.00078 lineto
0.11558 0.00043 lineto
0.11682 0.00025 lineto
0.11806 7e-05 lineto
0.1193 0.00011 lineto
0.12054 0.00029 lineto
0.12302 0.00066 lineto
0.14286 0.00371 lineto
0.15278 0.00517 lineto
0.15774 0.00584 lineto
0.1627 0.00644 lineto
0.16766 0.00693 lineto
0.17014 0.00713 lineto
0.17262 0.00729 lineto
0.17386 0.00735 lineto
0.1751 0.0074 lineto
0.17634 0.00744 lineto
0.17758 0.00746 lineto
0.17882 0.00746 lineto
0.18006 0.00745 lineto
0.1813 0.00743 lineto
0.18254 0.00738 lineto
0.18378 0.00731 lineto
0.18502 0.00722 lineto
0.18626 0.00711 lineto
0.1875 0.00697 lineto
0.18998 0.00662 lineto
0.19246 0.00613 lineto
0.19494 0.00551 lineto
0.19742 0.00472 lineto
0.20238 0.00253 lineto
0.20486 0.00107 lineto
0.2061 0.00023 lineto
0.20734 0.0007 lineto
0.20982 0.00282 lineto
Mistroke
0.2123 0.00535 lineto
0.21478 0.00838 lineto
0.21726 0.01201 lineto
0.21974 0.01633 lineto
0.22222 0.02152 lineto
0.2247 0.02774 lineto
0.22718 0.03525 lineto
0.23214 0.05547 lineto
0.23462 0.06915 lineto
0.2371 0.08612 lineto
0.23958 0.10741 lineto
0.24206 0.13437 lineto
0.24454 0.1688 lineto
0.24702 0.2129 lineto
0.25198 0.33599 lineto
0.25446 0.40819 lineto
0.2557 0.44115 lineto
0.25694 0.4684 lineto
0.25818 0.48766 lineto
0.25942 0.49785 lineto
0.26066 0.49944 lineto
0.2619 0.49402 lineto
0.26687 0.44089 lineto
0.26935 0.41271 lineto
0.27183 0.38838 lineto
0.27431 0.36821 lineto
0.27679 0.35176 lineto
0.27927 0.33842 lineto
0.28175 0.32762 lineto
0.28423 0.31889 lineto
0.28671 0.31183 lineto
0.29167 0.30157 lineto
0.29415 0.29792 lineto
0.29663 0.29504 lineto
0.29911 0.2928 lineto
0.30159 0.29108 lineto
0.30407 0.28982 lineto
0.30531 0.28933 lineto
0.30655 0.28893 lineto
0.30779 0.2886 lineto
0.30903 0.28834 lineto
0.31027 0.28815 lineto
0.31151 0.28802 lineto
0.31275 0.28794 lineto
0.31399 0.2879 lineto
0.31523 0.28791 lineto
0.31647 0.28797 lineto
0.31771 0.28805 lineto
0.31895 0.28817 lineto
0.32019 0.28831 lineto
Mistroke
0.32143 0.28848 lineto
0.34127 0.29258 lineto
0.34623 0.29354 lineto
0.35119 0.29434 lineto
0.35615 0.29495 lineto
0.35863 0.29518 lineto
0.35987 0.29528 lineto
0.36111 0.29536 lineto
0.36235 0.29543 lineto
0.36359 0.29548 lineto
0.36483 0.29552 lineto
0.36607 0.29555 lineto
0.36731 0.29557 lineto
0.36855 0.29557 lineto
0.36979 0.29556 lineto
0.37103 0.29554 lineto
0.37227 0.29551 lineto
0.37351 0.29546 lineto
0.37599 0.29533 lineto
0.37847 0.29516 lineto
0.38095 0.29495 lineto
0.38591 0.2944 lineto
0.39087 0.29371 lineto
0.40079 0.29201 lineto
0.42063 0.28789 lineto
0.44048 0.28377 lineto
0.4504 0.28196 lineto
0.46032 0.28041 lineto
0.47024 0.27917 lineto
0.4752 0.27867 lineto
0.48016 0.27826 lineto
0.48512 0.27794 lineto
0.4876 0.27781 lineto
0.49008 0.27771 lineto
0.49256 0.27763 lineto
0.4938 0.27759 lineto
0.49504 0.27757 lineto
0.49628 0.27755 lineto
0.49752 0.27753 lineto
0.49876 0.27752 lineto
0.5 0.27752 lineto
0.50124 0.27752 lineto
0.50248 0.27753 lineto
0.50372 0.27755 lineto
0.50496 0.27757 lineto
0.5062 0.27759 lineto
0.50744 0.27763 lineto
0.50992 0.27771 lineto
0.5124 0.27781 lineto
0.51488 0.27794 lineto
Mistroke
0.51984 0.27826 lineto
0.52976 0.27917 lineto
0.53968 0.28041 lineto
0.55952 0.28377 lineto
0.57937 0.28789 lineto
0.59921 0.29201 lineto
0.60913 0.29371 lineto
0.61409 0.2944 lineto
0.61905 0.29495 lineto
0.62153 0.29516 lineto
0.62401 0.29533 lineto
0.62525 0.2954 lineto
0.62649 0.29546 lineto
0.62773 0.29551 lineto
0.62897 0.29554 lineto
0.63021 0.29556 lineto
0.63145 0.29557 lineto
0.63269 0.29557 lineto
0.63393 0.29555 lineto
0.63517 0.29552 lineto
0.63641 0.29548 lineto
0.63765 0.29543 lineto
0.63889 0.29536 lineto
0.64137 0.29518 lineto
0.64385 0.29495 lineto
0.64881 0.29434 lineto
0.65377 0.29354 lineto
0.65873 0.29258 lineto
0.66865 0.2904 lineto
0.67361 0.28935 lineto
0.67609 0.28889 lineto
0.67857 0.28848 lineto
0.67981 0.28831 lineto
0.68105 0.28817 lineto
0.68229 0.28805 lineto
0.68353 0.28797 lineto
0.68477 0.28791 lineto
0.68601 0.2879 lineto
0.68725 0.28794 lineto
0.68849 0.28802 lineto
0.68973 0.28815 lineto
0.69097 0.28834 lineto
0.69221 0.2886 lineto
0.69345 0.28893 lineto
0.69593 0.28982 lineto
0.69841 0.29108 lineto
0.70089 0.2928 lineto
0.70337 0.29504 lineto
0.70585 0.29792 lineto
0.70833 0.30157 lineto
Mistroke
0.71081 0.30614 lineto
0.71329 0.31183 lineto
0.71577 0.31889 lineto
0.71825 0.32762 lineto
0.72073 0.33842 lineto
0.72321 0.35176 lineto
0.72569 0.36821 lineto
0.72817 0.38838 lineto
0.73313 0.44089 lineto
0.73562 0.47042 lineto
0.73686 0.48369 lineto
0.7381 0.49402 lineto
0.73934 0.49944 lineto
0.74058 0.49785 lineto
0.74182 0.48766 lineto
0.74306 0.4684 lineto
0.74554 0.40819 lineto
0.74802 0.33599 lineto
0.7505 0.26868 lineto
0.75298 0.2129 lineto
0.75546 0.1688 lineto
0.75794 0.13437 lineto
0.76042 0.10741 lineto
0.7629 0.08612 lineto
0.76538 0.06915 lineto
0.76786 0.05547 lineto
0.77034 0.04436 lineto
0.77282 0.03525 lineto
0.7753 0.02774 lineto
0.77778 0.02152 lineto
0.78026 0.01633 lineto
0.78274 0.01201 lineto
0.78522 0.00838 lineto
0.7877 0.00535 lineto
0.79018 0.00282 lineto
0.79142 0.00171 lineto
0.79266 0.0007 lineto
0.7939 0.00023 lineto
0.79514 0.00107 lineto
0.79638 0.00184 lineto
0.79762 0.00253 lineto
0.8001 0.00374 lineto
0.80258 0.00472 lineto
0.80506 0.00551 lineto
0.80754 0.00613 lineto
0.81002 0.00662 lineto
0.8125 0.00697 lineto
0.81374 0.00711 lineto
0.81498 0.00722 lineto
0.81622 0.00731 lineto
Mistroke
0.81746 0.00738 lineto
0.8187 0.00743 lineto
0.81994 0.00745 lineto
0.82118 0.00746 lineto
0.82242 0.00746 lineto
0.82366 0.00744 lineto
0.8249 0.0074 lineto
0.82614 0.00735 lineto
0.82738 0.00729 lineto
0.8373 0.00644 lineto
0.84226 0.00584 lineto
0.84722 0.00517 lineto
0.85714 0.00371 lineto
0.86706 0.00218 lineto
0.87202 0.00141 lineto
0.87698 0.00066 lineto
0.87822 0.00047 lineto
0.87946 0.00029 lineto
0.8807 0.00011 lineto
0.88194 7e-05 lineto
0.88442 0.00043 lineto
0.8869 0.00078 lineto
0.89683 0.00212 lineto
0.91667 0.00438 lineto
0.92659 0.00529 lineto
0.93651 0.00603 lineto
0.94643 0.00661 lineto
0.95139 0.00684 lineto
0.95635 0.00703 lineto
0.96131 0.00718 lineto
0.96379 0.00723 lineto
0.96627 0.00728 lineto
0.96875 0.00732 lineto
0.96999 0.00733 lineto
0.97123 0.00734 lineto
0.97247 0.00735 lineto
0.97371 0.00736 lineto
0.97495 0.00736 lineto
0.97619 0.00736 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00729 moveto
0.02505 0.00729 lineto
0.02629 0.00729 lineto
0.02753 0.00728 lineto
0.02877 0.00727 lineto
0.03125 0.00724 lineto
0.03373 0.00721 lineto
0.03621 0.00716 lineto
0.03869 0.0071 lineto
0.04365 0.00696 lineto
0.04861 0.00678 lineto
0.05357 0.00655 lineto
0.06349 0.00597 lineto
0.08333 0.00434 lineto
0.10317 0.0021 lineto
0.1131 0.00078 lineto
0.11558 0.00043 lineto
0.11682 0.00025 lineto
0.11806 7e-05 lineto
0.1193 0.00011 lineto
0.12054 0.00029 lineto
0.12302 0.00065 lineto
0.14286 0.00367 lineto
0.15278 0.00513 lineto
0.15774 0.00579 lineto
0.1627 0.00638 lineto
0.16766 0.00687 lineto
0.17014 0.00707 lineto
0.17262 0.00723 lineto
0.17386 0.00729 lineto
0.1751 0.00734 lineto
0.17634 0.00737 lineto
0.17758 0.0074 lineto
0.17882 0.0074 lineto
0.18006 0.00739 lineto
0.1813 0.00737 lineto
0.18254 0.00732 lineto
0.18378 0.00725 lineto
0.18502 0.00717 lineto
0.18626 0.00706 lineto
0.1875 0.00692 lineto
0.18998 0.00657 lineto
0.19246 0.00609 lineto
0.19494 0.00547 lineto
0.19742 0.00469 lineto
0.20238 0.00252 lineto
0.20486 0.00106 lineto
0.2061 0.00023 lineto
0.20734 0.00069 lineto
0.20982 0.0028 lineto
Mistroke
0.2123 0.00533 lineto
0.21478 0.00836 lineto
0.21726 0.01197 lineto
0.21974 0.01631 lineto
0.22222 0.02151 lineto
0.2247 0.02777 lineto
0.22718 0.03535 lineto
0.23214 0.05591 lineto
0.23462 0.06995 lineto
0.2371 0.08755 lineto
0.23958 0.10991 lineto
0.24206 0.13874 lineto
0.24454 0.17654 lineto
0.24702 0.22676 lineto
0.2495 0.29368 lineto
0.25198 0.38025 lineto
0.25446 0.48009 lineto
0.2557 0.52691 lineto
0.25694 0.56435 lineto
0.25818 0.58744 lineto
0.25942 0.59434 lineto
0.26066 0.587 lineto
0.2619 0.56971 lineto
0.26687 0.47494 lineto
0.26935 0.43506 lineto
0.27183 0.40327 lineto
0.27431 0.37828 lineto
0.27679 0.35863 lineto
0.27927 0.3431 lineto
0.28175 0.33076 lineto
0.28423 0.32091 lineto
0.28671 0.31301 lineto
0.29167 0.30162 lineto
0.29415 0.29758 lineto
0.29663 0.29438 lineto
0.29911 0.29188 lineto
0.30159 0.28995 lineto
0.30407 0.2885 lineto
0.30531 0.28793 lineto
0.30655 0.28745 lineto
0.30779 0.28706 lineto
0.30903 0.28674 lineto
0.31027 0.28648 lineto
0.31151 0.28629 lineto
0.31275 0.28616 lineto
0.31399 0.28608 lineto
0.31523 0.28604 lineto
0.31647 0.28604 lineto
0.31771 0.28609 lineto
0.31895 0.28617 lineto
Mistroke
0.32019 0.28627 lineto
0.32143 0.28641 lineto
0.34127 0.2901 lineto
0.34623 0.29099 lineto
0.35119 0.29174 lineto
0.35615 0.2923 lineto
0.35863 0.29251 lineto
0.35987 0.2926 lineto
0.36111 0.29267 lineto
0.36235 0.29273 lineto
0.36359 0.29278 lineto
0.36483 0.29281 lineto
0.36607 0.29283 lineto
0.36731 0.29284 lineto
0.36855 0.29284 lineto
0.36979 0.29282 lineto
0.37103 0.29279 lineto
0.37227 0.29275 lineto
0.37351 0.2927 lineto
0.37599 0.29256 lineto
0.37847 0.29238 lineto
0.38095 0.29216 lineto
0.39087 0.2909 lineto
0.40079 0.28919 lineto
0.42063 0.28508 lineto
0.44048 0.28097 lineto
0.4504 0.27917 lineto
0.46032 0.27763 lineto
0.47024 0.2764 lineto
0.4752 0.2759 lineto
0.48016 0.27549 lineto
0.48512 0.27517 lineto
0.4876 0.27505 lineto
0.49008 0.27494 lineto
0.49256 0.27486 lineto
0.4938 0.27483 lineto
0.49504 0.27481 lineto
0.49628 0.27479 lineto
0.49752 0.27477 lineto
0.49876 0.27476 lineto
0.5 0.27476 lineto
0.50124 0.27476 lineto
0.50248 0.27477 lineto
0.50372 0.27479 lineto
0.50496 0.27481 lineto
0.5062 0.27483 lineto
0.50744 0.27486 lineto
0.50992 0.27494 lineto
0.5124 0.27505 lineto
0.51488 0.27517 lineto
Mistroke
0.51984 0.27549 lineto
0.52976 0.2764 lineto
0.53968 0.27763 lineto
0.55952 0.28097 lineto
0.57937 0.28508 lineto
0.59921 0.28919 lineto
0.60913 0.2909 lineto
0.61409 0.2916 lineto
0.61905 0.29216 lineto
0.62153 0.29238 lineto
0.62401 0.29256 lineto
0.62525 0.29264 lineto
0.62649 0.2927 lineto
0.62773 0.29275 lineto
0.62897 0.29279 lineto
0.63021 0.29282 lineto
0.63145 0.29284 lineto
0.63269 0.29284 lineto
0.63393 0.29283 lineto
0.63517 0.29281 lineto
0.63641 0.29278 lineto
0.63765 0.29273 lineto
0.63889 0.29267 lineto
0.64137 0.29251 lineto
0.64385 0.2923 lineto
0.64881 0.29174 lineto
0.65377 0.29099 lineto
0.65873 0.2901 lineto
0.66865 0.28809 lineto
0.67361 0.28714 lineto
0.67609 0.28674 lineto
0.67857 0.28641 lineto
0.67981 0.28627 lineto
0.68105 0.28617 lineto
0.68229 0.28609 lineto
0.68353 0.28604 lineto
0.68477 0.28604 lineto
0.68601 0.28608 lineto
0.68725 0.28616 lineto
0.68849 0.28629 lineto
0.68973 0.28648 lineto
0.69097 0.28674 lineto
0.69221 0.28706 lineto
0.69345 0.28745 lineto
0.69593 0.2885 lineto
0.69841 0.28995 lineto
0.70089 0.29188 lineto
0.70337 0.29438 lineto
0.70585 0.29758 lineto
0.70833 0.30162 lineto
Mistroke
0.71081 0.30669 lineto
0.71329 0.31301 lineto
0.71577 0.32091 lineto
0.71825 0.33076 lineto
0.72073 0.3431 lineto
0.72321 0.35863 lineto
0.72569 0.37828 lineto
0.72817 0.40327 lineto
0.73065 0.43506 lineto
0.73313 0.47494 lineto
0.73562 0.52232 lineto
0.73686 0.54699 lineto
0.7381 0.56971 lineto
0.73934 0.587 lineto
0.74058 0.59434 lineto
0.74182 0.58744 lineto
0.74306 0.56435 lineto
0.74554 0.48009 lineto
0.74802 0.38025 lineto
0.7505 0.29368 lineto
0.75298 0.22676 lineto
0.75546 0.17654 lineto
0.75794 0.13874 lineto
0.76042 0.10991 lineto
0.7629 0.08755 lineto
0.76538 0.06995 lineto
0.76786 0.05591 lineto
0.77034 0.04458 lineto
0.77282 0.03535 lineto
0.7753 0.02777 lineto
0.77778 0.02151 lineto
0.78026 0.01631 lineto
0.78274 0.01197 lineto
0.78522 0.00836 lineto
0.7877 0.00533 lineto
0.79018 0.0028 lineto
0.79142 0.0017 lineto
0.79266 0.00069 lineto
0.7939 0.00023 lineto
0.79514 0.00106 lineto
0.79638 0.00182 lineto
0.79762 0.00252 lineto
0.8001 0.00371 lineto
0.80258 0.00469 lineto
0.80506 0.00547 lineto
0.80754 0.00609 lineto
0.81002 0.00657 lineto
0.8125 0.00692 lineto
0.81374 0.00706 lineto
0.81498 0.00717 lineto
Mistroke
0.81622 0.00725 lineto
0.81746 0.00732 lineto
0.8187 0.00737 lineto
0.81994 0.00739 lineto
0.82118 0.0074 lineto
0.82242 0.0074 lineto
0.82366 0.00737 lineto
0.8249 0.00734 lineto
0.82614 0.00729 lineto
0.82738 0.00723 lineto
0.8373 0.00638 lineto
0.84226 0.00579 lineto
0.84722 0.00513 lineto
0.85714 0.00367 lineto
0.86706 0.00215 lineto
0.87202 0.0014 lineto
0.87698 0.00065 lineto
0.87822 0.00047 lineto
0.87946 0.00029 lineto
0.8807 0.00011 lineto
0.88194 7e-05 lineto
0.88442 0.00043 lineto
0.8869 0.00078 lineto
0.89683 0.0021 lineto
0.91667 0.00434 lineto
0.92659 0.00524 lineto
0.93651 0.00597 lineto
0.94643 0.00655 lineto
0.95139 0.00678 lineto
0.95635 0.00696 lineto
0.96131 0.0071 lineto
0.96379 0.00716 lineto
0.96627 0.00721 lineto
0.96875 0.00724 lineto
0.96999 0.00726 lineto
0.97123 0.00727 lineto
0.97247 0.00728 lineto
0.97371 0.00729 lineto
0.97495 0.00729 lineto
0.97619 0.00729 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00722 moveto
0.02505 0.00722 lineto
0.02629 0.00721 lineto
0.02753 0.00721 lineto
0.02877 0.0072 lineto
0.03125 0.00717 lineto
0.03373 0.00714 lineto
0.03621 0.00709 lineto
0.03869 0.00703 lineto
0.04365 0.00689 lineto
0.04861 0.00671 lineto
0.05357 0.00648 lineto
0.06349 0.00591 lineto
0.08333 0.0043 lineto
0.10317 0.00208 lineto
0.1131 0.00077 lineto
0.11558 0.00042 lineto
0.11682 0.00025 lineto
0.11806 7e-05 lineto
0.1193 0.00011 lineto
0.12054 0.00028 lineto
0.12302 0.00065 lineto
0.14286 0.00364 lineto
0.15278 0.00508 lineto
0.15774 0.00574 lineto
0.1627 0.00632 lineto
0.16766 0.00681 lineto
0.17014 0.00701 lineto
0.17262 0.00716 lineto
0.17386 0.00722 lineto
0.1751 0.00727 lineto
0.17634 0.00731 lineto
0.17758 0.00733 lineto
0.17882 0.00734 lineto
0.18006 0.00733 lineto
0.1813 0.0073 lineto
0.18254 0.00726 lineto
0.18378 0.00719 lineto
0.18502 0.00711 lineto
0.18626 0.007 lineto
0.1875 0.00686 lineto
0.18998 0.00651 lineto
0.19246 0.00604 lineto
0.19494 0.00543 lineto
0.19742 0.00465 lineto
0.20238 0.0025 lineto
0.20486 0.00106 lineto
0.2061 0.00022 lineto
0.20734 0.00069 lineto
0.20982 0.00279 lineto
Mistroke
0.2123 0.0053 lineto
0.21478 0.00832 lineto
0.21726 0.01192 lineto
0.21974 0.01625 lineto
0.22222 0.02146 lineto
0.2247 0.02774 lineto
0.22718 0.03536 lineto
0.23214 0.05618 lineto
0.23462 0.0705 lineto
0.2371 0.08862 lineto
0.23958 0.1119 lineto
0.24206 0.14243 lineto
0.24454 0.18345 lineto
0.24702 0.24004 lineto
0.2495 0.31998 lineto
0.25198 0.43306 lineto
0.25446 0.57965 lineto
0.2557 0.6535 lineto
0.25694 0.71139 lineto
0.25818 0.74023 lineto
0.25942 0.73645 lineto
0.26066 0.70789 lineto
0.2619 0.66667 lineto
0.26438 0.58006 lineto
0.26687 0.50896 lineto
0.26935 0.45568 lineto
0.27183 0.41616 lineto
0.27431 0.38652 lineto
0.27679 0.36393 lineto
0.27927 0.34646 lineto
0.28175 0.33279 lineto
0.28423 0.32199 lineto
0.28671 0.31341 lineto
0.29167 0.30109 lineto
0.29415 0.29674 lineto
0.29663 0.29329 lineto
0.29911 0.29058 lineto
0.30159 0.28848 lineto
0.30407 0.28689 lineto
0.30531 0.28625 lineto
0.30655 0.28572 lineto
0.30779 0.28526 lineto
0.30903 0.28489 lineto
0.31027 0.28459 lineto
0.31151 0.28435 lineto
0.31275 0.28418 lineto
0.31399 0.28405 lineto
0.31523 0.28398 lineto
0.31647 0.28395 lineto
0.31771 0.28396 lineto
Mistroke
0.31895 0.284 lineto
0.32019 0.28408 lineto
0.32143 0.28418 lineto
0.34127 0.28755 lineto
0.34623 0.28839 lineto
0.35119 0.28909 lineto
0.35615 0.28962 lineto
0.35863 0.28981 lineto
0.35987 0.28989 lineto
0.36111 0.28995 lineto
0.36235 0.29001 lineto
0.36359 0.29005 lineto
0.36483 0.29008 lineto
0.36607 0.29009 lineto
0.36731 0.29009 lineto
0.36855 0.29009 lineto
0.36979 0.29006 lineto
0.37103 0.29003 lineto
0.37227 0.28999 lineto
0.37351 0.28993 lineto
0.37599 0.28979 lineto
0.37847 0.2896 lineto
0.38095 0.28937 lineto
0.39087 0.2881 lineto
0.40079 0.28638 lineto
0.42063 0.28228 lineto
0.44048 0.2782 lineto
0.4504 0.27641 lineto
0.46032 0.27488 lineto
0.47024 0.27365 lineto
0.4752 0.27316 lineto
0.48016 0.27275 lineto
0.48512 0.27244 lineto
0.4876 0.27231 lineto
0.49008 0.27221 lineto
0.49256 0.27213 lineto
0.4938 0.2721 lineto
0.49504 0.27207 lineto
0.49628 0.27205 lineto
0.49752 0.27204 lineto
0.49876 0.27203 lineto
0.5 0.27203 lineto
0.50124 0.27203 lineto
0.50248 0.27204 lineto
0.50372 0.27205 lineto
0.50496 0.27207 lineto
0.5062 0.2721 lineto
0.50744 0.27213 lineto
0.50992 0.27221 lineto
0.5124 0.27231 lineto
Mistroke
0.51488 0.27244 lineto
0.51984 0.27275 lineto
0.52976 0.27365 lineto
0.53968 0.27488 lineto
0.55952 0.2782 lineto
0.57937 0.28228 lineto
0.59921 0.28638 lineto
0.60913 0.2881 lineto
0.61409 0.2888 lineto
0.61905 0.28937 lineto
0.62153 0.2896 lineto
0.62401 0.28979 lineto
0.62525 0.28986 lineto
0.62649 0.28993 lineto
0.62773 0.28999 lineto
0.62897 0.29003 lineto
0.63021 0.29006 lineto
0.63145 0.29009 lineto
0.63269 0.29009 lineto
0.63393 0.29009 lineto
0.63517 0.29008 lineto
0.63641 0.29005 lineto
0.63765 0.29001 lineto
0.63889 0.28995 lineto
0.64137 0.28981 lineto
0.64385 0.28962 lineto
0.64881 0.28909 lineto
0.65377 0.28839 lineto
0.65873 0.28755 lineto
0.66865 0.28568 lineto
0.67361 0.28482 lineto
0.67609 0.28446 lineto
0.67733 0.28431 lineto
0.67857 0.28418 lineto
0.67981 0.28408 lineto
0.68105 0.284 lineto
0.68229 0.28396 lineto
0.68353 0.28395 lineto
0.68477 0.28398 lineto
0.68601 0.28405 lineto
0.68725 0.28418 lineto
0.68849 0.28435 lineto
0.68973 0.28459 lineto
0.69097 0.28489 lineto
0.69221 0.28526 lineto
0.69345 0.28572 lineto
0.69593 0.28689 lineto
0.69841 0.28848 lineto
0.70089 0.29058 lineto
0.70337 0.29329 lineto
Mistroke
0.70585 0.29674 lineto
0.70833 0.30109 lineto
0.71081 0.30656 lineto
0.71329 0.31341 lineto
0.71577 0.32199 lineto
0.71825 0.33279 lineto
0.72073 0.34646 lineto
0.72321 0.36393 lineto
0.72569 0.38652 lineto
0.72817 0.41616 lineto
0.73065 0.45568 lineto
0.73313 0.50896 lineto
0.73562 0.58006 lineto
0.7381 0.66667 lineto
0.73934 0.70789 lineto
0.74058 0.73645 lineto
0.74182 0.74023 lineto
0.74306 0.71139 lineto
0.74554 0.57965 lineto
0.74802 0.43306 lineto
0.7505 0.31998 lineto
0.75298 0.24004 lineto
0.75546 0.18345 lineto
0.75794 0.14243 lineto
0.76042 0.1119 lineto
0.7629 0.08862 lineto
0.76538 0.0705 lineto
0.76786 0.05618 lineto
0.77034 0.04468 lineto
0.77282 0.03536 lineto
0.7753 0.02774 lineto
0.77778 0.02146 lineto
0.78026 0.01625 lineto
0.78274 0.01192 lineto
0.78522 0.00832 lineto
0.7877 0.0053 lineto
0.79018 0.00279 lineto
0.79142 0.00169 lineto
0.79266 0.00069 lineto
0.7939 0.00022 lineto
0.79514 0.00106 lineto
0.79638 0.00181 lineto
0.79762 0.0025 lineto
0.8001 0.00369 lineto
0.80258 0.00465 lineto
0.80506 0.00543 lineto
0.80754 0.00604 lineto
0.81002 0.00651 lineto
0.8125 0.00686 lineto
0.81374 0.007 lineto
Mistroke
0.81498 0.00711 lineto
0.81622 0.00719 lineto
0.81746 0.00726 lineto
0.8187 0.0073 lineto
0.81994 0.00733 lineto
0.82118 0.00734 lineto
0.82242 0.00733 lineto
0.82366 0.00731 lineto
0.8249 0.00727 lineto
0.82614 0.00722 lineto
0.82738 0.00716 lineto
0.8373 0.00632 lineto
0.84226 0.00574 lineto
0.84722 0.00508 lineto
0.85714 0.00364 lineto
0.86706 0.00213 lineto
0.87202 0.00138 lineto
0.87698 0.00065 lineto
0.87822 0.00047 lineto
0.87946 0.00028 lineto
0.8807 0.00011 lineto
0.88194 7e-05 lineto
0.88442 0.00042 lineto
0.8869 0.00077 lineto
0.89683 0.00208 lineto
0.91667 0.0043 lineto
0.92659 0.00518 lineto
0.93651 0.00591 lineto
0.94643 0.00648 lineto
0.95139 0.00671 lineto
0.95635 0.00689 lineto
0.96131 0.00703 lineto
0.96379 0.00709 lineto
0.96627 0.00714 lineto
0.96875 0.00717 lineto
0.96999 0.00719 lineto
0.97123 0.0072 lineto
0.97247 0.00721 lineto
0.97371 0.00721 lineto
0.97495 0.00722 lineto
0.97619 0.00722 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00715 moveto
0.02505 0.00714 lineto
0.02629 0.00714 lineto
0.02753 0.00713 lineto
0.02877 0.00713 lineto
0.03125 0.0071 lineto
0.03373 0.00707 lineto
0.03621 0.00702 lineto
0.03869 0.00696 lineto
0.04365 0.00682 lineto
0.04861 0.00664 lineto
0.05357 0.00642 lineto
0.06349 0.00586 lineto
0.08333 0.00426 lineto
0.10317 0.00206 lineto
0.1131 0.00076 lineto
0.11558 0.00042 lineto
0.11682 0.00025 lineto
0.11806 7e-05 lineto
0.1193 0.0001 lineto
0.12054 0.00028 lineto
0.12302 0.00064 lineto
0.14286 0.0036 lineto
0.15278 0.00503 lineto
0.15774 0.00568 lineto
0.1627 0.00626 lineto
0.16766 0.00675 lineto
0.17014 0.00694 lineto
0.17262 0.0071 lineto
0.17386 0.00716 lineto
0.1751 0.00721 lineto
0.17634 0.00724 lineto
0.17758 0.00727 lineto
0.17882 0.00727 lineto
0.18006 0.00727 lineto
0.1813 0.00724 lineto
0.18254 0.0072 lineto
0.18378 0.00713 lineto
0.18502 0.00705 lineto
0.18626 0.00694 lineto
0.1875 0.00681 lineto
0.18998 0.00646 lineto
0.19246 0.00599 lineto
0.19494 0.00538 lineto
0.19742 0.00461 lineto
0.20238 0.00248 lineto
0.20486 0.00105 lineto
0.2061 0.00022 lineto
0.20734 0.00068 lineto
0.20982 0.00277 lineto
Mistroke
0.2123 0.00527 lineto
0.21478 0.00827 lineto
0.21726 0.01186 lineto
0.21974 0.01617 lineto
0.22222 0.02137 lineto
0.2247 0.02765 lineto
0.22718 0.03529 lineto
0.23214 0.05625 lineto
0.23462 0.07078 lineto
0.2371 0.08926 lineto
0.23958 0.11325 lineto
0.24206 0.14517 lineto
0.24454 0.18899 lineto
0.24578 0.21733 lineto
0.24702 0.25157 lineto
0.24826 0.29347 lineto
0.2495 0.34539 lineto
0.25074 0.4105 lineto
0.25198 0.49275 lineto
0.25446 0.7208 lineto
0.2557 0.85531 lineto
0.25694 0.96445 lineto
0.25818 1.00275 lineto
0.25942 0.96207 lineto
0.26066 0.87846 lineto
0.2619 0.78795 lineto
0.26314 0.7071 lineto
0.26438 0.63971 lineto
0.26562 0.58471 lineto
0.26687 0.53991 lineto
0.26935 0.47282 lineto
0.27059 0.44746 lineto
0.27183 0.4261 lineto
0.27431 0.39239 lineto
0.27679 0.36735 lineto
0.27927 0.34832 lineto
0.28175 0.33361 lineto
0.28423 0.32208 lineto
0.28671 0.31297 lineto
0.29167 0.29998 lineto
0.29415 0.29539 lineto
0.29663 0.29176 lineto
0.29911 0.2889 lineto
0.30159 0.28668 lineto
0.30407 0.28498 lineto
0.30655 0.28372 lineto
0.30779 0.28322 lineto
0.30903 0.28281 lineto
0.31027 0.28247 lineto
0.31151 0.28221 lineto
Mistroke
0.31275 0.282 lineto
0.31399 0.28185 lineto
0.31523 0.28174 lineto
0.31647 0.28169 lineto
0.31771 0.28167 lineto
0.31895 0.28169 lineto
0.32019 0.28174 lineto
0.32143 0.28183 lineto
0.34127 0.28494 lineto
0.34623 0.28574 lineto
0.35119 0.28641 lineto
0.35615 0.2869 lineto
0.35863 0.28708 lineto
0.35987 0.28716 lineto
0.36111 0.28722 lineto
0.36235 0.28726 lineto
0.36359 0.2873 lineto
0.36483 0.28732 lineto
0.36607 0.28733 lineto
0.36731 0.28733 lineto
0.36855 0.28732 lineto
0.36979 0.28729 lineto
0.37103 0.28726 lineto
0.37351 0.28715 lineto
0.37599 0.287 lineto
0.38095 0.28658 lineto
0.38591 0.286 lineto
0.39087 0.2853 lineto
0.40079 0.28358 lineto
0.42063 0.2795 lineto
0.44048 0.27544 lineto
0.4504 0.27367 lineto
0.46032 0.27215 lineto
0.47024 0.27093 lineto
0.4752 0.27044 lineto
0.48016 0.27004 lineto
0.48512 0.26973 lineto
0.4876 0.2696 lineto
0.49008 0.2695 lineto
0.49256 0.26942 lineto
0.4938 0.26939 lineto
0.49504 0.26936 lineto
0.49628 0.26934 lineto
0.49752 0.26933 lineto
0.49876 0.26932 lineto
0.5 0.26932 lineto
0.50124 0.26932 lineto
0.50248 0.26933 lineto
0.50372 0.26934 lineto
0.50496 0.26936 lineto
Mistroke
0.5062 0.26939 lineto
0.50744 0.26942 lineto
0.50992 0.2695 lineto
0.5124 0.2696 lineto
0.51488 0.26973 lineto
0.51984 0.27004 lineto
0.52976 0.27093 lineto
0.53968 0.27215 lineto
0.55952 0.27544 lineto
0.57937 0.2795 lineto
0.59921 0.28358 lineto
0.60913 0.2853 lineto
0.61409 0.286 lineto
0.61905 0.28658 lineto
0.62153 0.28681 lineto
0.62401 0.287 lineto
0.62649 0.28715 lineto
0.62773 0.28721 lineto
0.62897 0.28726 lineto
0.63021 0.28729 lineto
0.63145 0.28732 lineto
0.63269 0.28733 lineto
0.63393 0.28733 lineto
0.63517 0.28732 lineto
0.63641 0.2873 lineto
0.63765 0.28726 lineto
0.63889 0.28722 lineto
0.64137 0.28708 lineto
0.64385 0.2869 lineto
0.64881 0.28641 lineto
0.65377 0.28574 lineto
0.65873 0.28494 lineto
0.66865 0.28317 lineto
0.67361 0.28238 lineto
0.67609 0.28207 lineto
0.67733 0.28194 lineto
0.67857 0.28183 lineto
0.67981 0.28174 lineto
0.68105 0.28169 lineto
0.68229 0.28167 lineto
0.68353 0.28169 lineto
0.68477 0.28174 lineto
0.68601 0.28185 lineto
0.68725 0.282 lineto
0.68849 0.28221 lineto
0.68973 0.28247 lineto
0.69097 0.28281 lineto
0.69345 0.28372 lineto
0.69593 0.28498 lineto
0.69841 0.28668 lineto
Mistroke
0.70089 0.2889 lineto
0.70337 0.29176 lineto
0.70585 0.29539 lineto
0.70833 0.29998 lineto
0.71081 0.30574 lineto
0.71329 0.31297 lineto
0.71577 0.32208 lineto
0.71825 0.33361 lineto
0.72073 0.34832 lineto
0.72321 0.36735 lineto
0.72569 0.39239 lineto
0.72817 0.4261 lineto
0.72941 0.44746 lineto
0.73065 0.47282 lineto
0.73189 0.50318 lineto
0.73313 0.53991 lineto
0.73562 0.63971 lineto
0.73686 0.7071 lineto
0.7381 0.78795 lineto
0.74802 0.49275 lineto
0.74926 0.4105 lineto
0.7505 0.34539 lineto
0.75174 0.29347 lineto
0.75298 0.25157 lineto
0.75422 0.21733 lineto
0.75546 0.18899 lineto
0.75794 0.14517 lineto
0.76042 0.11325 lineto
0.7629 0.08926 lineto
0.76538 0.07078 lineto
0.76786 0.05625 lineto
0.77034 0.04466 lineto
0.77282 0.03529 lineto
0.7753 0.02765 lineto
0.77778 0.02137 lineto
0.78026 0.01617 lineto
0.78274 0.01186 lineto
0.78522 0.00827 lineto
0.7877 0.00527 lineto
0.79018 0.00277 lineto
0.79142 0.00168 lineto
0.79266 0.00068 lineto
0.7939 0.00022 lineto
0.79514 0.00105 lineto
0.79638 0.0018 lineto
0.79762 0.00248 lineto
0.8001 0.00366 lineto
0.80258 0.00461 lineto
0.80506 0.00538 lineto
0.80754 0.00599 lineto
Mistroke
0.81002 0.00646 lineto
0.8125 0.00681 lineto
0.81374 0.00694 lineto
0.81498 0.00705 lineto
0.81622 0.00713 lineto
0.81746 0.0072 lineto
0.8187 0.00724 lineto
0.81994 0.00727 lineto
0.82118 0.00727 lineto
0.82242 0.00727 lineto
0.82366 0.00724 lineto
0.8249 0.00721 lineto
0.82614 0.00716 lineto
0.82738 0.0071 lineto
0.8373 0.00626 lineto
0.84226 0.00568 lineto
0.84722 0.00503 lineto
0.85714 0.0036 lineto
0.86706 0.00211 lineto
0.87202 0.00137 lineto
0.87698 0.00064 lineto
0.87822 0.00046 lineto
0.87946 0.00028 lineto
0.8807 0.0001 lineto
0.88194 7e-05 lineto
0.88442 0.00042 lineto
0.8869 0.00076 lineto
0.89683 0.00206 lineto
0.91667 0.00426 lineto
0.92659 0.00513 lineto
0.93651 0.00586 lineto
0.94643 0.00642 lineto
0.95139 0.00664 lineto
0.95635 0.00682 lineto
0.96131 0.00696 lineto
0.96379 0.00702 lineto
0.96627 0.00707 lineto
0.96875 0.0071 lineto
0.96999 0.00711 lineto
0.97123 0.00713 lineto
0.97247 0.00713 lineto
0.97371 0.00714 lineto
0.97495 0.00714 lineto
0.97619 0.00715 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.00708 moveto
0.02505 0.00707 lineto
0.02629 0.00707 lineto
0.02753 0.00706 lineto
0.02877 0.00706 lineto
0.03125 0.00703 lineto
0.03373 0.007 lineto
0.03621 0.00695 lineto
0.03869 0.0069 lineto
0.04365 0.00676 lineto
0.04861 0.00658 lineto
0.05357 0.00636 lineto
0.06349 0.0058 lineto
0.08333 0.00421 lineto
0.10317 0.00204 lineto
0.1131 0.00075 lineto
0.11558 0.00042 lineto
0.11682 0.00024 lineto
0.11806 7e-05 lineto
0.1193 0.0001 lineto
0.12054 0.00028 lineto
0.12302 0.00063 lineto
0.14286 0.00357 lineto
0.15278 0.00498 lineto
0.15774 0.00563 lineto
0.1627 0.0062 lineto
0.16766 0.00668 lineto
0.17014 0.00688 lineto
0.17262 0.00703 lineto
0.17386 0.00709 lineto
0.1751 0.00714 lineto
0.17634 0.00718 lineto
0.17758 0.0072 lineto
0.17882 0.00721 lineto
0.18006 0.0072 lineto
0.1813 0.00717 lineto
0.18254 0.00713 lineto
0.18378 0.00707 lineto
0.18502 0.00698 lineto
0.18626 0.00687 lineto
0.1875 0.00674 lineto
0.18998 0.0064 lineto
0.19246 0.00594 lineto
0.19494 0.00534 lineto
0.19742 0.00457 lineto
0.20238 0.00246 lineto
0.20486 0.00104 lineto
0.2061 0.00022 lineto
0.20734 0.00068 lineto
0.20982 0.00275 lineto
Mistroke
0.2123 0.00523 lineto
0.21478 0.00821 lineto
0.21726 0.01178 lineto
0.21974 0.01607 lineto
0.22222 0.02124 lineto
0.2247 0.0275 lineto
0.22718 0.03513 lineto
0.23214 0.05613 lineto
0.23462 0.07075 lineto
0.2371 0.08945 lineto
0.23958 0.11389 lineto
0.24206 0.14674 lineto
0.24454 0.19259 lineto
0.24578 0.22279 lineto
0.24702 0.25993 lineto
0.24826 0.30649 lineto
0.2495 0.36618 lineto
0.25074 0.44479 lineto
0.25198 0.55156 lineto
0.25322 0.70125 lineto
0.25446 0.9151 lineto
0.2557 1.20634 lineto
0.25694 1.49814 lineto
0.25818 1.55373 lineto
0.25942 1.35083 lineto
0.26066 1.11123 lineto
0.2619 0.92481 lineto
0.26314 0.79026 lineto
0.26438 0.69243 lineto
0.26562 0.61948 lineto
0.26687 0.56358 lineto
0.26935 0.48456 lineto
0.27059 0.4559 lineto
0.27183 0.43217 lineto
0.27431 0.39545 lineto
0.27679 0.36867 lineto
0.27927 0.34857 lineto
0.28175 0.33315 lineto
0.28423 0.32115 lineto
0.28671 0.31171 lineto
0.29167 0.29828 lineto
0.29415 0.29355 lineto
0.29663 0.2898 lineto
0.29911 0.28685 lineto
0.30159 0.28455 lineto
0.30407 0.28278 lineto
0.30655 0.28146 lineto
0.30779 0.28094 lineto
0.30903 0.28051 lineto
0.31027 0.28015 lineto
Mistroke
0.31151 0.27986 lineto
0.31275 0.27963 lineto
0.31399 0.27946 lineto
0.31523 0.27934 lineto
0.31647 0.27926 lineto
0.31771 0.27923 lineto
0.31895 0.27923 lineto
0.32019 0.27927 lineto
0.32143 0.27934 lineto
0.34127 0.28228 lineto
0.34623 0.28304 lineto
0.35119 0.28368 lineto
0.35615 0.28416 lineto
0.35863 0.28433 lineto
0.35987 0.2844 lineto
0.36111 0.28446 lineto
0.36235 0.2845 lineto
0.36359 0.28453 lineto
0.36483 0.28455 lineto
0.36607 0.28456 lineto
0.36731 0.28456 lineto
0.36855 0.28454 lineto
0.36979 0.28451 lineto
0.37103 0.28448 lineto
0.37351 0.28437 lineto
0.37599 0.28421 lineto
0.38095 0.28378 lineto
0.38591 0.28321 lineto
0.39087 0.2825 lineto
0.40079 0.28079 lineto
0.42063 0.27674 lineto
0.44048 0.27271 lineto
0.4504 0.27095 lineto
0.46032 0.26944 lineto
0.47024 0.26824 lineto
0.4752 0.26775 lineto
0.48016 0.26735 lineto
0.48512 0.26704 lineto
0.4876 0.26692 lineto
0.49008 0.26682 lineto
0.49256 0.26674 lineto
0.4938 0.26671 lineto
0.49504 0.26668 lineto
0.49628 0.26666 lineto
0.49752 0.26665 lineto
0.49876 0.26664 lineto
0.5 0.26664 lineto
0.50124 0.26664 lineto
0.50248 0.26665 lineto
0.50372 0.26666 lineto
Mistroke
0.50496 0.26668 lineto
0.5062 0.26671 lineto
0.50744 0.26674 lineto
0.50992 0.26682 lineto
0.5124 0.26692 lineto
0.51488 0.26704 lineto
0.51984 0.26735 lineto
0.52976 0.26824 lineto
0.53968 0.26944 lineto
0.55952 0.27271 lineto
0.57937 0.27674 lineto
0.59921 0.28079 lineto
0.60913 0.2825 lineto
0.61409 0.28321 lineto
0.61905 0.28378 lineto
0.62153 0.28402 lineto
0.62401 0.28421 lineto
0.62649 0.28437 lineto
0.62773 0.28443 lineto
0.62897 0.28448 lineto
0.63021 0.28451 lineto
0.63145 0.28454 lineto
0.63269 0.28456 lineto
0.63393 0.28456 lineto
0.63517 0.28455 lineto
0.63641 0.28453 lineto
0.63765 0.2845 lineto
0.63889 0.28446 lineto
0.64137 0.28433 lineto
0.64385 0.28416 lineto
0.64881 0.28368 lineto
0.65377 0.28304 lineto
0.65873 0.28228 lineto
0.66865 0.28059 lineto
0.67113 0.28019 lineto
0.67361 0.27984 lineto
0.67609 0.27955 lineto
0.67733 0.27943 lineto
0.67857 0.27934 lineto
0.67981 0.27927 lineto
0.68105 0.27923 lineto
0.68229 0.27923 lineto
0.68353 0.27926 lineto
0.68477 0.27934 lineto
0.68601 0.27946 lineto
0.68725 0.27963 lineto
0.68849 0.27986 lineto
0.68973 0.28015 lineto
0.69097 0.28051 lineto
0.69345 0.28146 lineto
Mistroke
0.69593 0.28278 lineto
0.69841 0.28455 lineto
0.70089 0.28685 lineto
0.70337 0.2898 lineto
0.70585 0.29355 lineto
0.70833 0.29828 lineto
0.71081 0.30422 lineto
0.71329 0.31171 lineto
0.71577 0.32115 lineto
0.71825 0.33315 lineto
0.72073 0.34857 lineto
0.72321 0.36867 lineto
0.72569 0.39545 lineto
0.72693 0.41229 lineto
0.72817 0.43217 lineto
0.72941 0.4559 lineto
0.73065 0.48456 lineto
0.73189 0.51972 lineto
0.73313 0.56358 lineto
0.73438 0.61948 lineto
0.73562 0.69243 lineto
0.73686 0.79026 lineto
0.7381 0.92481 lineto
0.74802 0.55156 lineto
0.74926 0.44479 lineto
0.7505 0.36618 lineto
0.75174 0.30649 lineto
0.75298 0.25993 lineto
0.75422 0.22279 lineto
0.75546 0.19259 lineto
0.75794 0.14674 lineto
0.76042 0.11389 lineto
0.7629 0.08945 lineto
0.76538 0.07075 lineto
0.76786 0.05613 lineto
0.77034 0.0445 lineto
0.77282 0.03513 lineto
0.7753 0.0275 lineto
0.77778 0.02124 lineto
0.78026 0.01607 lineto
0.78274 0.01178 lineto
0.78522 0.00821 lineto
0.7877 0.00523 lineto
0.79018 0.00275 lineto
0.79142 0.00166 lineto
0.79266 0.00068 lineto
0.7939 0.00022 lineto
0.79514 0.00104 lineto
0.79638 0.00178 lineto
0.79762 0.00246 lineto
Mistroke
0.8001 0.00363 lineto
0.80258 0.00457 lineto
0.80506 0.00534 lineto
0.80754 0.00594 lineto
0.81002 0.0064 lineto
0.8125 0.00674 lineto
0.81374 0.00687 lineto
0.81498 0.00698 lineto
0.81622 0.00707 lineto
0.81746 0.00713 lineto
0.8187 0.00717 lineto
0.81994 0.0072 lineto
0.82118 0.00721 lineto
0.82242 0.0072 lineto
0.82366 0.00718 lineto
0.8249 0.00714 lineto
0.82614 0.00709 lineto
0.82738 0.00703 lineto
0.8373 0.0062 lineto
0.84226 0.00563 lineto
0.84722 0.00498 lineto
0.85714 0.00357 lineto
0.86706 0.00209 lineto
0.87202 0.00136 lineto
0.87698 0.00063 lineto
0.87822 0.00046 lineto
0.87946 0.00028 lineto
0.8807 0.0001 lineto
0.88194 7e-05 lineto
0.88442 0.00042 lineto
0.8869 0.00075 lineto
0.89683 0.00204 lineto
0.91667 0.00421 lineto
0.92659 0.00508 lineto
0.93651 0.0058 lineto
0.94643 0.00636 lineto
0.95139 0.00658 lineto
0.95635 0.00676 lineto
0.96131 0.0069 lineto
0.96379 0.00695 lineto
0.96627 0.007 lineto
0.96875 0.00703 lineto
0.96999 0.00704 lineto
0.97123 0.00706 lineto
0.97247 0.00706 lineto
0.97371 0.00707 lineto
0.97495 0.00707 lineto
0.97619 0.00708 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; PostScript; output; endGroup; endGroup; endGroup; endGroup; endGroup; pictureLeft = 120; pictureWidth = 282; pictureHeight = 176; preserveAspect; ]
%!
%%Creator: Mathematica
%%AspectRatio: 0.61803 
MathPictureStart
% Scaling calculations
0.5 0.15158 0 0.30902 [
[(Magnitude Response)] 0.5 0.62428 0 -1 Msboxa
[(-3)] 0.04527 -0.0125 0 1 Msboxa
[(-2)] 0.19685 -0.0125 0 1 Msboxa
[(-1)] 0.34842 -0.0125 0 1 Msboxa
[(1)] 0.65158 -0.0125 0 1 Msboxa
[(2)] 0.80315 -0.0125 0 1 Msboxa
[(3)] 0.95473 -0.0125 0 1 Msboxa
[(w)] 1.00625 0 -1 0 Msboxa
[(0.25)] 0.4875 0.07725 1 0 Msboxa
[(0.5)] 0.4875 0.15451 1 0 Msboxa
[(0.75)] 0.4875 0.23176 1 0 Msboxa
[(1)] 0.4875 0.30902 1 0 Msboxa
[(1.25)] 0.4875 0.38627 1 0 Msboxa
[(1.5)] 0.4875 0.46353 1 0 Msboxa
[(1.75)] 0.4875 0.54078 1 0 Msboxa
[(2)] 0.4875 0.61803 1 0 Msboxa
[( )] 0.5 0.62428 0 -1 Msboxa
[ -0.001 -0.00725 0 0 ]
[ 1.001 0.61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
%%Object: Graphics
[ ] 0 setdash
0 setgray
0 setgray
[(Magnitude Response)] 0.5 0.62428 0 -1 Mshowa
gsave
gsave
0.002 setlinewidth
0 0 moveto
1 0 lineto
stroke
0.04527 -0.00625 moveto
0.04527 0.00625 lineto
stroke
0 setgray
[(-3)] 0.04527 -0.0125 0 1 Mshowa
0.19685 -0.00625 moveto
0.19685 0.00625 lineto
stroke
0 setgray
[(-2)] 0.19685 -0.0125 0 1 Mshowa
0.34842 -0.00625 moveto
0.34842 0.00625 lineto
stroke
0 setgray
[(-1)] 0.34842 -0.0125 0 1 Mshowa
0.65158 -0.00625 moveto
0.65158 0.00625 lineto
stroke
0 setgray
[(1)] 0.65158 -0.0125 0 1 Mshowa
0.80315 -0.00625 moveto
0.80315 0.00625 lineto
stroke
0 setgray
[(2)] 0.80315 -0.0125 0 1 Mshowa
0.95473 -0.00625 moveto
0.95473 0.00625 lineto
stroke
0 setgray
[(3)] 0.95473 -0.0125 0 1 Mshowa
0 setgray
[(w)] 1.00625 0 -1 0 Mshowa
0.5 0 moveto
0.5 0.61803 lineto
stroke
0.49375 0.07725 moveto
0.50625 0.07725 lineto
stroke
0 setgray
[(0.25)] 0.4875 0.07725 1 0 Mshowa
0.49375 0.15451 moveto
0.50625 0.15451 lineto
stroke
0 setgray
[(0.5)] 0.4875 0.15451 1 0 Mshowa
0.49375 0.23176 moveto
0.50625 0.23176 lineto
stroke
0 setgray
[(0.75)] 0.4875 0.23176 1 0 Mshowa
0.49375 0.30902 moveto
0.50625 0.30902 lineto
stroke
0 setgray
[(1)] 0.4875 0.30902 1 0 Mshowa
0.49375 0.38627 moveto
0.50625 0.38627 lineto
stroke
0 setgray
[(1.25)] 0.4875 0.38627 1 0 Mshowa
0.49375 0.46353 moveto
0.50625 0.46353 lineto
stroke
0 setgray
[(1.5)] 0.4875 0.46353 1 0 Mshowa
0.49375 0.54078 moveto
0.50625 0.54078 lineto
stroke
0 setgray
[(1.75)] 0.4875 0.54078 1 0 Mshowa
0.49375 0.61803 moveto
0.50625 0.61803 lineto
stroke
0 setgray
[(2)] 0.4875 0.61803 1 0 Mshowa
0 setgray
[( )] 0.5 0.62428 0 -1 Mshowa
grestore
grestore
0 0 moveto
1 0 lineto
1 0.618034 lineto
0 0.618034 lineto
closepath
clip
newpath
0 setgray
gsave
gsave
0.004 setlinewidth
0.02381 0.007 moveto
0.02505 0.007 lineto
0.02629 0.007 lineto
0.02753 0.00699 lineto
0.02877 0.00699 lineto
0.03125 0.00696 lineto
0.03373 0.00693 lineto
0.03621 0.00688 lineto
0.03869 0.00683 lineto
0.04365 0.00669 lineto
0.04861 0.00651 lineto
0.05357 0.00629 lineto
0.06349 0.00574 lineto
0.08333 0.00417 lineto
0.10317 0.00202 lineto
0.1131 0.00075 lineto
0.11558 0.00041 lineto
0.11682 0.00024 lineto
0.11806 7e-05 lineto
0.1193 0.0001 lineto
0.12054 0.00028 lineto
0.12302 0.00063 lineto
0.14286 0.00353 lineto
0.15278 0.00493 lineto
0.15774 0.00557 lineto
0.1627 0.00614 lineto
0.16766 0.00662 lineto
0.17014 0.00681 lineto
0.17262 0.00696 lineto
0.17386 0.00702 lineto
0.1751 0.00707 lineto
0.17634 0.00711 lineto
0.17758 0.00713 lineto
0.17882 0.00714 lineto
0.18006 0.00713 lineto
0.1813 0.0071 lineto
0.18254 0.00706 lineto
0.18378 0.007 lineto
0.18502 0.00692 lineto
0.18626 0.00681 lineto
0.1875 0.00668 lineto
0.18998 0.00634 lineto
0.19246 0.00588 lineto
0.19494 0.00529 lineto
0.19742 0.00453 lineto
0.20238 0.00244 lineto
0.20486 0.00103 lineto
0.2061 0.00022 lineto
0.20734 0.00067 lineto
0.20982 0.00272 lineto
Mistroke
0.2123 0.00518 lineto
0.21478 0.00814 lineto
0.21726 0.01168 lineto
0.21974 0.01594 lineto
0.22222 0.02108 lineto
0.2247 0.0273 lineto
0.22718 0.03489 lineto
0.23214 0.05581 lineto
0.23462 0.07042 lineto
0.2371 0.08915 lineto
0.23958 0.11373 lineto
0.24206 0.14696 lineto
0.24454 0.1938 lineto
0.24578 0.22499 lineto
0.24702 0.26377 lineto
0.24826 0.31311 lineto
0.2495 0.3778 lineto
0.25074 0.46592 lineto
0.25198 0.59234 lineto
0.25322 0.78732 lineto
0.25446 1.12174 lineto
0.2557 1.79122 lineto
0.25694 3.22609 lineto
0.25942 1.98401 lineto
0.26066 1.35552 lineto
0.2619 1.03588 lineto
0.26314 0.84761 lineto
0.26438 0.72479 lineto
0.26562 0.63883 lineto
0.26687 0.57558 lineto
0.26935 0.48927 lineto
0.27059 0.45872 lineto
0.27183 0.4337 lineto
0.27431 0.39539 lineto
0.27679 0.36774 lineto
0.27927 0.34713 lineto
0.28175 0.3314 lineto
0.28423 0.31919 lineto
0.28671 0.3096 lineto
0.29167 0.296 lineto
0.29415 0.29122 lineto
0.29663 0.28742 lineto
0.29911 0.28444 lineto
0.30159 0.2821 lineto
0.30407 0.28031 lineto
0.30655 0.27897 lineto
0.30779 0.27844 lineto
0.30903 0.27799 lineto
0.31027 0.27762 lineto
0.31151 0.27732 lineto
Mistroke
0.31275 0.27708 lineto
0.31399 0.2769 lineto
0.31523 0.27677 lineto
0.31647 0.27669 lineto
0.31771 0.27665 lineto
0.31895 0.27664 lineto
0.32019 0.27667 lineto
0.32143 0.27673 lineto
0.34127 0.27956 lineto
0.34623 0.28031 lineto
0.35119 0.28093 lineto
0.35615 0.28139 lineto
0.35863 0.28156 lineto
0.35987 0.28162 lineto
0.36111 0.28168 lineto
0.36235 0.28172 lineto
0.36359 0.28175 lineto
0.36483 0.28177 lineto
0.36607 0.28177 lineto
0.36731 0.28177 lineto
0.36855 0.28175 lineto
0.36979 0.28172 lineto
0.37103 0.28169 lineto
0.37351 0.28157 lineto
0.37599 0.28142 lineto
0.38095 0.28099 lineto
0.38591 0.28042 lineto
0.39087 0.27972 lineto
0.40079 0.27802 lineto
0.42063 0.27399 lineto
0.44048 0.27 lineto
0.4504 0.26826 lineto
0.46032 0.26676 lineto
0.47024 0.26557 lineto
0.4752 0.26509 lineto
0.48016 0.26469 lineto
0.48512 0.26438 lineto
0.4876 0.26426 lineto
0.49008 0.26416 lineto
0.49256 0.26408 lineto
0.4938 0.26405 lineto
0.49504 0.26403 lineto
0.49628 0.26401 lineto
0.49752 0.26399 lineto
0.49876 0.26399 lineto
0.5 0.26398 lineto
0.50124 0.26399 lineto
0.50248 0.26399 lineto
0.50372 0.26401 lineto
0.50496 0.26403 lineto
Mistroke
0.5062 0.26405 lineto
0.50744 0.26408 lineto
0.50992 0.26416 lineto
0.5124 0.26426 lineto
0.51488 0.26438 lineto
0.51984 0.26469 lineto
0.52976 0.26557 lineto
0.53968 0.26676 lineto
0.55952 0.27 lineto
0.57937 0.27399 lineto
0.59921 0.27802 lineto
0.60913 0.27972 lineto
0.61409 0.28042 lineto
0.61905 0.28099 lineto
0.62153 0.28122 lineto
0.62401 0.28142 lineto
0.62649 0.28157 lineto
0.62773 0.28163 lineto
0.62897 0.28169 lineto
0.63021 0.28172 lineto
0.63145 0.28175 lineto
0.63269 0.28177 lineto
0.63393 0.28177 lineto
0.63517 0.28177 lineto
0.63641 0.28175 lineto
0.63765 0.28172 lineto
0.63889 0.28168 lineto
0.64137 0.28156 lineto
0.64385 0.28139 lineto
0.64881 0.28093 lineto
0.65377 0.28031 lineto
0.65873 0.27956 lineto
0.66865 0.27792 lineto
0.67113 0.27754 lineto
0.67361 0.2772 lineto
0.67609 0.27692 lineto
0.67733 0.27682 lineto
0.67857 0.27673 lineto
0.67981 0.27667 lineto
0.68105 0.27664 lineto
0.68229 0.27665 lineto
0.68353 0.27669 lineto
0.68477 0.27677 lineto
0.68601 0.2769 lineto
0.68725 0.27708 lineto
0.68849 0.27732 lineto
0.68973 0.27762 lineto
0.69097 0.27799 lineto
0.69345 0.27897 lineto
0.69593 0.28031 lineto
Mistroke
0.69841 0.2821 lineto
0.70089 0.28444 lineto
0.70337 0.28742 lineto
0.70585 0.29122 lineto
0.70833 0.296 lineto
0.71081 0.30202 lineto
0.71329 0.3096 lineto
0.71577 0.31919 lineto
0.71825 0.3314 lineto
0.72073 0.34713 lineto
0.72321 0.36774 lineto
0.72569 0.39539 lineto
0.72693 0.4129 lineto
0.72817 0.4337 lineto
0.72941 0.45872 lineto
0.73065 0.48927 lineto
0.73189 0.52726 lineto
0.73313 0.57558 lineto
0.73438 0.63883 lineto
0.73562 0.72479 lineto
0.73686 0.84761 lineto
0.7381 1.03588 lineto
0.74802 0.59234 lineto
0.74926 0.46592 lineto
0.7505 0.3778 lineto
0.75174 0.31311 lineto
0.75298 0.26377 lineto
0.75422 0.22499 lineto
0.75546 0.1938 lineto
0.75794 0.14696 lineto
0.76042 0.11373 lineto
0.7629 0.08915 lineto
0.76538 0.07042 lineto
0.76786 0.05581 lineto
0.77034 0.04422 lineto
0.77282 0.03489 lineto
0.7753 0.0273 lineto
0.77778 0.02108 lineto
0.78026 0.01594 lineto
0.78274 0.01168 lineto
0.78522 0.00814 lineto
0.7877 0.00518 lineto
0.79018 0.00272 lineto
0.79142 0.00165 lineto
0.79266 0.00067 lineto
0.7939 0.00022 lineto
0.79514 0.00103 lineto
0.79638 0.00177 lineto
0.79762 0.00244 lineto
0.8001 0.00359 lineto
Mistroke
0.80258 0.00453 lineto
0.80506 0.00529 lineto
0.80754 0.00588 lineto
0.81002 0.00634 lineto
0.8125 0.00668 lineto
0.81374 0.00681 lineto
0.81498 0.00692 lineto
0.81622 0.007 lineto
0.81746 0.00706 lineto
0.8187 0.0071 lineto
0.81994 0.00713 lineto
0.82118 0.00714 lineto
0.82242 0.00713 lineto
0.82366 0.00711 lineto
0.8249 0.00707 lineto
0.82614 0.00702 lineto
0.82738 0.00696 lineto
0.8373 0.00614 lineto
0.84226 0.00557 lineto
0.84722 0.00493 lineto
0.85714 0.00353 lineto
0.86706 0.00207 lineto
0.87202 0.00134 lineto
0.87698 0.00063 lineto
0.87822 0.00045 lineto
0.87946 0.00028 lineto
0.8807 0.0001 lineto
0.88194 7e-05 lineto
0.88442 0.00041 lineto
0.8869 0.00075 lineto
0.89683 0.00202 lineto
0.91667 0.00417 lineto
0.92659 0.00503 lineto
0.93651 0.00574 lineto
0.94643 0.00629 lineto
0.95139 0.00651 lineto
0.95635 0.00669 lineto
0.96131 0.00683 lineto
0.96379 0.00688 lineto
0.96627 0.00693 lineto
0.96875 0.00696 lineto
0.96999 0.00697 lineto
0.97123 0.00699 lineto
0.97247 0.00699 lineto
0.97371 0.007 lineto
0.97495 0.007 lineto
0.97619 0.007 lineto
Mfstroke
grestore
grestore
% End of Graphics
MathPictureEnd
:[font = section; inactive; startGroup; Cclosed; ]
References
:[font = subsection; inactive; ]
Alan V. Oppenheim and Ronald W. Schafer.  Discrete-Time Signal Processing.  1989.  Chapters 4 & 5.
:[font = subsection; inactive; ]
T.W. Parks and C.S. Burrus. Digital Filter Design.
:[font = subsection; inactive; endGroup; ]
Churchill and Brown.  Complex Variables and Applications.
:[font = smalltext; inactive; ]
This work was supported in part by the Joint Services Electronics Program
contract #DAAL-03-90-C-0004.  
^*)